Class: XeroRuby::Accounting::Account

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/account.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

ACTIVE =
"ACTIVE".freeze
ARCHIVED =
"ARCHIVED".freeze
DELETED =
"DELETED".freeze
BANK =
"BANK".freeze
CREDITCARD =
"CREDITCARD".freeze
PAYPAL =
"PAYPAL".freeze
NONE =
"NONE".freeze
EMPTY =
"".freeze
ASSET =
"ASSET".freeze
EQUITY =
"EQUITY".freeze
EXPENSE =
"EXPENSE".freeze
LIABILITY =
"LIABILITY".freeze
REVENUE =
"REVENUE".freeze
DEBTORS =
"DEBTORS".freeze
CREDITORS =
"CREDITORS".freeze
BANKCURRENCYGAIN =
"BANKCURRENCYGAIN".freeze
GST =
"GST".freeze
GSTONIMPORTS =
"GSTONIMPORTS".freeze
HISTORICAL =
"HISTORICAL".freeze
REALISEDCURRENCYGAIN =
"REALISEDCURRENCYGAIN".freeze
RETAINEDEARNINGS =
"RETAINEDEARNINGS".freeze
ROUNDING =
"ROUNDING".freeze
TRACKINGTRANSFERS =
"TRACKINGTRANSFERS".freeze
UNPAIDEXPCLM =
"UNPAIDEXPCLM".freeze
UNREALISEDCURRENCYGAIN =
"UNREALISEDCURRENCYGAIN".freeze
WAGEPAYABLES =
"WAGEPAYABLES".freeze
CISASSETS =
"CISASSETS".freeze
CISASSET =
"CISASSET".freeze
CISLABOUR =
"CISLABOUR".freeze
CISLABOUREXPENSE =
"CISLABOUREXPENSE".freeze
CISLABOURINCOME =
"CISLABOURINCOME".freeze
CISLIABILITY =
"CISLIABILITY".freeze
CISMATERIALS =
"CISMATERIALS".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Account

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/xero-ruby/models/accounting/account.rb', line 188

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Account` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Account`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'bank_account_number')
    self. = attributes[:'bank_account_number']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'bank_account_type')
    self. = attributes[:'bank_account_type']
  end

  if attributes.key?(:'currency_code')
    self.currency_code = attributes[:'currency_code']
  end

  if attributes.key?(:'tax_type')
    self.tax_type = attributes[:'tax_type']
  end

  if attributes.key?(:'enable_payments_to_account')
    self. = attributes[:'enable_payments_to_account']
  end

  if attributes.key?(:'show_in_expense_claims')
    self.show_in_expense_claims = attributes[:'show_in_expense_claims']
  end

  if attributes.key?(:'_class')
    self._class = attributes[:'_class']
  end

  if attributes.key?(:'system_account')
    self. = attributes[:'system_account']
  end

  if attributes.key?(:'reporting_code')
    self.reporting_code = attributes[:'reporting_code']
  end

  if attributes.key?(:'reporting_code_name')
    self.reporting_code_name = attributes[:'reporting_code_name']
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  else
    self.has_attachments = false
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'add_to_watchlist')
    self.add_to_watchlist = attributes[:'add_to_watchlist']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end
end

Instance Attribute Details

#_class ⇒ Object

See Account Class Types



63
64
65
# File 'lib/xero-ruby/models/accounting/account.rb', line 63

def _class
  @_class
end

#account_id ⇒ Object

The Xero identifier for an account – specified as a string following the endpoint name e.g. /297c2dc5-cc47-4afd-8ec8-74990b8761e9



25
26
27
# File 'lib/xero-ruby/models/accounting/account.rb', line 25

def 
  @account_id
end

#add_to_watchlist ⇒ Object

Boolean – describes whether the account is shown in the watchlist widget on the dashboard



107
108
109
# File 'lib/xero-ruby/models/accounting/account.rb', line 107

def add_to_watchlist
  @add_to_watchlist
end

#bank_account_number ⇒ Object

For bank accounts only (Account Type BANK)



31
32
33
# File 'lib/xero-ruby/models/accounting/account.rb', line 31

def 
  
end

#bank_account_type ⇒ Object

For bank accounts only. See Bank Account types



43
44
45
# File 'lib/xero-ruby/models/accounting/account.rb', line 43

def 
  
end

#code ⇒ Object

Customer defined alpha numeric account code e.g 200 or SALES (max length = 10)



19
20
21
# File 'lib/xero-ruby/models/accounting/account.rb', line 19

def code
  @code
end

#currency_code ⇒ Object

Returns the value of attribute currency_code.



51
52
53
# File 'lib/xero-ruby/models/accounting/account.rb', line 51

def currency_code
  @currency_code
end

#description ⇒ Object

Description of the Account. Valid for all types of accounts except bank accounts (max length = 4000)



40
41
42
# File 'lib/xero-ruby/models/accounting/account.rb', line 40

def description
  @description
end

#enable_payments_to_account ⇒ Object

Boolean – describes whether account can have payments applied to it



57
58
59
# File 'lib/xero-ruby/models/accounting/account.rb', line 57

def 
  
end

#has_attachments ⇒ Object

boolean to indicate if an account has an attachment (read only)



101
102
103
# File 'lib/xero-ruby/models/accounting/account.rb', line 101

def has_attachments
  @has_attachments
end

#name ⇒ Object

Name of account (max length = 150)



22
23
24
# File 'lib/xero-ruby/models/accounting/account.rb', line 22

def name
  @name
end

#reporting_code ⇒ Object

Shown if set



95
96
97
# File 'lib/xero-ruby/models/accounting/account.rb', line 95

def reporting_code
  @reporting_code
end

#reporting_code_name ⇒ Object

Shown if set



98
99
100
# File 'lib/xero-ruby/models/accounting/account.rb', line 98

def reporting_code_name
  @reporting_code_name
end

#show_in_expense_claims ⇒ Object

Boolean – describes whether account code is available for use with expense claims



60
61
62
# File 'lib/xero-ruby/models/accounting/account.rb', line 60

def show_in_expense_claims
  @show_in_expense_claims
end

#status ⇒ Object

Accounts with a status of ACTIVE can be updated to ARCHIVED. See Account Status Codes



34
35
36
# File 'lib/xero-ruby/models/accounting/account.rb', line 34

def status
  @status
end

#system_account ⇒ Object

If this is a system account then this element is returned. See System Account types. Note that non-system accounts may have this element set as either “” or null.



71
72
73
# File 'lib/xero-ruby/models/accounting/account.rb', line 71

def 
  
end

#tax_type ⇒ Object

The tax type from TaxRates



54
55
56
# File 'lib/xero-ruby/models/accounting/account.rb', line 54

def tax_type
  @tax_type
end

#type ⇒ Object

Returns the value of attribute type.



28
29
30
# File 'lib/xero-ruby/models/accounting/account.rb', line 28

def type
  @type
end

#updated_date_utc ⇒ Object

Last modified date UTC format



104
105
106
# File 'lib/xero-ruby/models/accounting/account.rb', line 104

def updated_date_utc
  @updated_date_utc
end

#validation_errors ⇒ Object

Displays array of validation error messages from the API



110
111
112
# File 'lib/xero-ruby/models/accounting/account.rb', line 110

def validation_errors
  @validation_errors
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/xero-ruby/models/accounting/account.rb', line 135

def self.attribute_map
  {
    :'code' => :'Code',
    :'name' => :'Name',
    :'account_id' => :'AccountID',
    :'type' => :'Type',
    :'bank_account_number' => :'BankAccountNumber',
    :'status' => :'Status',
    :'description' => :'Description',
    :'bank_account_type' => :'BankAccountType',
    :'currency_code' => :'CurrencyCode',
    :'tax_type' => :'TaxType',
    :'enable_payments_to_account' => :'EnablePaymentsToAccount',
    :'show_in_expense_claims' => :'ShowInExpenseClaims',
    :'_class' => :'Class',
    :'system_account' => :'SystemAccount',
    :'reporting_code' => :'ReportingCode',
    :'reporting_code_name' => :'ReportingCodeName',
    :'has_attachments' => :'HasAttachments',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'add_to_watchlist' => :'AddToWatchlist',
    :'validation_errors' => :'ValidationErrors'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



419
420
421
# File 'lib/xero-ruby/models/accounting/account.rb', line 419

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/xero-ruby/models/accounting/account.rb', line 161

def self.openapi_types
  {
    :'code' => :'String',
    :'name' => :'String',
    :'account_id' => :'String',
    :'type' => :'AccountType',
    :'bank_account_number' => :'String',
    :'status' => :'String',
    :'description' => :'String',
    :'bank_account_type' => :'String',
    :'currency_code' => :'CurrencyCode',
    :'tax_type' => :'String',
    :'enable_payments_to_account' => :'Boolean',
    :'show_in_expense_claims' => :'Boolean',
    :'_class' => :'String',
    :'system_account' => :'String',
    :'reporting_code' => :'String',
    :'reporting_code_name' => :'String',
    :'has_attachments' => :'Boolean',
    :'updated_date_utc' => :'DateTime',
    :'add_to_watchlist' => :'Boolean',
    :'validation_errors' => :'Array<ValidationError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/xero-ruby/models/accounting/account.rb', line 379

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      code == o.code &&
      name == o.name &&
       == o. &&
      type == o.type &&
       == o. &&
      status == o.status &&
      description == o.description &&
       == o. &&
      currency_code == o.currency_code &&
      tax_type == o.tax_type &&
       == o. &&
      show_in_expense_claims == o.show_in_expense_claims &&
      _class == o._class &&
       == o. &&
      reporting_code == o.reporting_code &&
      reporting_code_name == o.reporting_code_name &&
      has_attachments == o.has_attachments &&
      updated_date_utc == o.updated_date_utc &&
      add_to_watchlist == o.add_to_watchlist &&
      validation_errors == o.validation_errors
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/xero-ruby/models/accounting/account.rb', line 447

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



512
513
514
515
516
517
518
519
520
521
522
523
524
# File 'lib/xero-ruby/models/accounting/account.rb', line 512

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/xero-ruby/models/accounting/account.rb', line 426

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


406
407
408
# File 'lib/xero-ruby/models/accounting/account.rb', line 406

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



412
413
414
# File 'lib/xero-ruby/models/accounting/account.rb', line 412

def hash
  [code, name, , type, , status, description, , currency_code, tax_type, , show_in_expense_claims, _class, , reporting_code, reporting_code_name, has_attachments, updated_date_utc, add_to_watchlist, validation_errors].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/xero-ruby/models/accounting/account.rb', line 288

def list_invalid_properties
  invalid_properties = Array.new
  if !@code.nil? && @code.to_s.length > 10
    invalid_properties.push('invalid value for "code", the character length must be smaller than or equal to 10.')
  end

  if !@name.nil? && @name.to_s.length > 150
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 150.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



527
528
529
530
# File 'lib/xero-ruby/models/accounting/account.rb', line 527

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



492
493
494
# File 'lib/xero-ruby/models/accounting/account.rb', line 492

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



498
499
500
501
502
503
504
505
506
# File 'lib/xero-ruby/models/accounting/account.rb', line 498

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



486
487
488
# File 'lib/xero-ruby/models/accounting/account.rb', line 486

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/xero-ruby/models/accounting/account.rb', line 303

def valid?
  return false if !@code.nil? && @code.to_s.length > 10
  return false if !@name.nil? && @name.to_s.length > 150
  status_validator = EnumAttributeValidator.new('String', ["ACTIVE", "ARCHIVED", "DELETED"])
  return false unless status_validator.valid?(@status)
   = EnumAttributeValidator.new('String', ["BANK", "CREDITCARD", "PAYPAL", "NONE", ""])
  return false unless .valid?()
  _class_validator = EnumAttributeValidator.new('String', ["ASSET", "EQUITY", "EXPENSE", "LIABILITY", "REVENUE"])
  return false unless _class_validator.valid?(@_class)
   = EnumAttributeValidator.new('String', ["DEBTORS", "CREDITORS", "BANKCURRENCYGAIN", "GST", "GSTONIMPORTS", "HISTORICAL", "REALISEDCURRENCYGAIN", "RETAINEDEARNINGS", "ROUNDING", "TRACKINGTRANSFERS", "UNPAIDEXPCLM", "UNREALISEDCURRENCYGAIN", "WAGEPAYABLES", "CISASSETS", "CISASSET", "CISLABOUR", "CISLABOUREXPENSE", "CISLABOURINCOME", "CISLIABILITY", "CISMATERIALS", ""])
  return false unless .valid?()
  true
end