Class: XeroRuby::Accounting::BankTransaction

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/bank_transaction.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

RECEIVE =
"RECEIVE".freeze
RECEIVE_OVERPAYMENT =
"RECEIVE-OVERPAYMENT".freeze
RECEIVE_PREPAYMENT =
"RECEIVE-PREPAYMENT".freeze
SPEND =
"SPEND".freeze
SPEND_OVERPAYMENT =
"SPEND-OVERPAYMENT".freeze
SPEND_PREPAYMENT =
"SPEND-PREPAYMENT".freeze
RECEIVE_TRANSFER =
"RECEIVE-TRANSFER".freeze
SPEND_TRANSFER =
"SPEND-TRANSFER".freeze
AUTHORISED =
"AUTHORISED".freeze
DELETED =
"DELETED".freeze
VOIDED =
"VOIDED".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BankTransaction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 175

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::BankTransaction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::BankTransaction`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'contact')
    self.contact = attributes[:'contact']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'bank_account')
    self. = attributes[:'bank_account']
  end

  if attributes.key?(:'is_reconciled')
    self.is_reconciled = attributes[:'is_reconciled']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'currency_code')
    self.currency_code = attributes[:'currency_code']
  end

  if attributes.key?(:'currency_rate')
    self.currency_rate = attributes[:'currency_rate']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'line_amount_types')
    self.line_amount_types = attributes[:'line_amount_types']
  end

  if attributes.key?(:'sub_total')
    self.sub_total = attributes[:'sub_total']
  end

  if attributes.key?(:'total_tax')
    self.total_tax = attributes[:'total_tax']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'bank_transaction_id')
    self.bank_transaction_id = attributes[:'bank_transaction_id']
  end

  if attributes.key?(:'prepayment_id')
    self.prepayment_id = attributes[:'prepayment_id']
  end

  if attributes.key?(:'overpayment_id')
    self.overpayment_id = attributes[:'overpayment_id']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  else
    self.has_attachments = false
  end

  if attributes.key?(:'status_attribute_string')
    self.status_attribute_string = attributes[:'status_attribute_string']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end
end

Instance Attribute Details

#bank_account ⇒ Object

Returns the value of attribute bank_account.



36
37
38
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 36

def 
  
end

#bank_transaction_id ⇒ Object

Xero generated unique identifier for bank transaction



75
76
77
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 75

def bank_transaction_id
  @bank_transaction_id
end

#contact ⇒ Object

Returns the value of attribute contact.



30
31
32
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 30

def contact
  @contact
end

#currency_code ⇒ Object

Returns the value of attribute currency_code.



48
49
50
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 48

def currency_code
  @currency_code
end

#currency_rate ⇒ Object

Exchange rate to base currency when money is spent or received. e.g.0.7500 Only used for bank transactions in non base currency. If this isn’t specified for non base currency accounts then either the user-defined rate (preference) or the XE.com day rate will be used. Setting currency is only supported on overpayments.



51
52
53
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 51

def currency_rate
  @currency_rate
end

#date ⇒ Object

Date of transaction – YYYY-MM-DD



42
43
44
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 42

def date
  @date
end

#has_attachments ⇒ Object

Boolean to indicate if a bank transaction has an attachment



87
88
89
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 87

def has_attachments
  @has_attachments
end

#is_reconciled ⇒ Object

Boolean to show if transaction is reconciled



39
40
41
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 39

def is_reconciled
  @is_reconciled
end

#line_amount_types ⇒ Object

Returns the value of attribute line_amount_types.



63
64
65
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 63

def line_amount_types
  @line_amount_types
end

#line_items ⇒ Object

See LineItems



33
34
35
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 33

def line_items
  @line_items
end

#overpayment_id ⇒ Object

Xero generated unique identifier for an Overpayment. This will be returned on BankTransactions with a Type of SPEND-OVERPAYMENT or RECEIVE-OVERPAYMENT



81
82
83
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 81

def overpayment_id
  @overpayment_id
end

#prepayment_id ⇒ Object

Xero generated unique identifier for a Prepayment. This will be returned on BankTransactions with a Type of SPEND-PREPAYMENT or RECEIVE-PREPAYMENT



78
79
80
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 78

def prepayment_id
  @prepayment_id
end

#reference ⇒ Object

Reference for the transaction. Only supported for SPEND and RECEIVE transactions.



45
46
47
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 45

def reference
  @reference
end

#status ⇒ Object

See Bank Transaction Status Codes



57
58
59
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 57

def status
  @status
end

#status_attribute_string ⇒ Object

A string to indicate if a invoice status



90
91
92
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 90

def status_attribute_string
  @status_attribute_string
end

#sub_total ⇒ Object

Total of bank transaction excluding taxes



66
67
68
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 66

def sub_total
  @sub_total
end

#total ⇒ Object

Total of bank transaction tax inclusive



72
73
74
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 72

def total
  @total
end

#total_tax ⇒ Object

Total tax on bank transaction



69
70
71
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 69

def total_tax
  @total_tax
end

#type ⇒ Object

See Bank Transaction Types



19
20
21
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 19

def type
  @type
end

#updated_date_utc ⇒ Object

Last modified date UTC format



84
85
86
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 84

def updated_date_utc
  @updated_date_utc
end

#url ⇒ Object

URL link to a source document – shown as “Go to App Name”



54
55
56
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 54

def url
  @url
end

#validation_errors ⇒ Object

Displays array of validation error messages from the API



93
94
95
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 93

def validation_errors
  @validation_errors
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 118

def self.attribute_map
  {
    :'type' => :'Type',
    :'contact' => :'Contact',
    :'line_items' => :'LineItems',
    :'bank_account' => :'BankAccount',
    :'is_reconciled' => :'IsReconciled',
    :'date' => :'Date',
    :'reference' => :'Reference',
    :'currency_code' => :'CurrencyCode',
    :'currency_rate' => :'CurrencyRate',
    :'url' => :'Url',
    :'status' => :'Status',
    :'line_amount_types' => :'LineAmountTypes',
    :'sub_total' => :'SubTotal',
    :'total_tax' => :'TotalTax',
    :'total' => :'Total',
    :'bank_transaction_id' => :'BankTransactionID',
    :'prepayment_id' => :'PrepaymentID',
    :'overpayment_id' => :'OverpaymentID',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'has_attachments' => :'HasAttachments',
    :'status_attribute_string' => :'StatusAttributeString',
    :'validation_errors' => :'ValidationErrors'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



384
385
386
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 384

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 146

def self.openapi_types
  {
    :'type' => :'String',
    :'contact' => :'Contact',
    :'line_items' => :'Array<LineItem>',
    :'bank_account' => :'Account',
    :'is_reconciled' => :'Boolean',
    :'date' => :'Date',
    :'reference' => :'String',
    :'currency_code' => :'CurrencyCode',
    :'currency_rate' => :'Float',
    :'url' => :'String',
    :'status' => :'String',
    :'line_amount_types' => :'LineAmountTypes',
    :'sub_total' => :'Float',
    :'total_tax' => :'Float',
    :'total' => :'Float',
    :'bank_transaction_id' => :'String',
    :'prepayment_id' => :'String',
    :'overpayment_id' => :'String',
    :'updated_date_utc' => :'DateTime',
    :'has_attachments' => :'Boolean',
    :'status_attribute_string' => :'String',
    :'validation_errors' => :'Array<ValidationError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 342

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      contact == o.contact &&
      line_items == o.line_items &&
       == o. &&
      is_reconciled == o.is_reconciled &&
      date == o.date &&
      reference == o.reference &&
      currency_code == o.currency_code &&
      currency_rate == o.currency_rate &&
      url == o.url &&
      status == o.status &&
      line_amount_types == o.line_amount_types &&
      sub_total == o.sub_total &&
      total_tax == o.total_tax &&
      total == o.total &&
      bank_transaction_id == o.bank_transaction_id &&
      prepayment_id == o.prepayment_id &&
      overpayment_id == o.overpayment_id &&
      updated_date_utc == o.updated_date_utc &&
      has_attachments == o.has_attachments &&
      status_attribute_string == o.status_attribute_string &&
      validation_errors == o.validation_errors
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 412

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 477

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 391

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


371
372
373
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 371

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



377
378
379
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 377

def hash
  [type, contact, line_items, , is_reconciled, date, reference, currency_code, currency_rate, url, status, line_amount_types, sub_total, total_tax, total, bank_transaction_id, prepayment_id, overpayment_id, updated_date_utc, has_attachments, status_attribute_string, validation_errors].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 285

def list_invalid_properties
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @contact.nil?
    invalid_properties.push('invalid value for "contact", contact cannot be nil.')
  end

  if @line_items.nil?
    invalid_properties.push('invalid value for "line_items", line_items cannot be nil.')
  end

  if .nil?
    invalid_properties.push('invalid value for "bank_account", bank_account cannot be nil.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



492
493
494
495
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 492

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



457
458
459
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 457

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



463
464
465
466
467
468
469
470
471
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 463

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



451
452
453
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 451

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



308
309
310
311
312
313
314
315
316
317
318
# File 'lib/xero-ruby/models/accounting/bank_transaction.rb', line 308

def valid?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["RECEIVE", "RECEIVE-OVERPAYMENT", "RECEIVE-PREPAYMENT", "SPEND", "SPEND-OVERPAYMENT", "SPEND-PREPAYMENT", "RECEIVE-TRANSFER", "SPEND-TRANSFER"])
  return false unless type_validator.valid?(@type)
  return false if @contact.nil?
  return false if @line_items.nil?
  return false if .nil?
  status_validator = EnumAttributeValidator.new('String', ["AUTHORISED", "DELETED", "VOIDED"])
  return false unless status_validator.valid?(@status)
  true
end