Class: XeroRuby::Accounting::BatchPayment

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/batch_payment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

PAYBATCH =
"PAYBATCH".freeze
RECBATCH =
"RECBATCH".freeze
AUTHORISED =
"AUTHORISED".freeze
DELETED =
"DELETED".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BatchPayment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 138

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::BatchPayment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::BatchPayment`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'particulars')
    self.particulars = attributes[:'particulars']
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'narrative')
    self.narrative = attributes[:'narrative']
  end

  if attributes.key?(:'batch_payment_id')
    self.batch_payment_id = attributes[:'batch_payment_id']
  end

  if attributes.key?(:'date_string')
    self.date_string = attributes[:'date_string']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'payments')
    if (value = attributes[:'payments']).is_a?(Array)
      self.payments = value
    end
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'total_amount')
    self.total_amount = attributes[:'total_amount']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'is_reconciled')
    self.is_reconciled = attributes[:'is_reconciled']
  end
end

Instance Attribute Details

#account ⇒ Object

Returns the value of attribute account.



19
20
21
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 19

def 
  @account
end

#amount ⇒ Object

The amount of the payment. Must be less than or equal to the outstanding amount owing on the invoice e.g. 200.00



46
47
48
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 46

def amount
  @amount
end

#batch_payment_id ⇒ Object

The Xero generated unique identifier for the bank transaction (read-only)



37
38
39
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 37

def batch_payment_id
  @batch_payment_id
end

#code ⇒ Object

(NZ Only) Optional references for the batch payment transaction. It will also show with the batch payment transaction in the bank reconciliation Find & Match screen. Depending on your individual bank, the detail may also show on the bank statement you import into Xero.



28
29
30
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 28

def code
  @code
end

#date ⇒ Object

Date the payment is being made (YYYY-MM-DD) e.g. 2009-09-06



43
44
45
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 43

def date
  @date
end

#date_string ⇒ Object

Date the payment is being made (YYYY-MM-DD) e.g. 2009-09-06



40
41
42
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 40

def date_string
  @date_string
end

#details ⇒ Object

(Non-NZ Only) These details are sent to the org’s bank as a reference for the batch payment transaction. They will also show with the batch payment transaction in the bank reconciliation Find & Match screen. Depending on your individual bank, the detail may also show on the bank statement imported into Xero. Maximum field length = 18



31
32
33
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 31

def details
  @details
end

#is_reconciled ⇒ Object

Booelan that tells you if the batch payment has been reconciled (read-only)



68
69
70
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 68

def is_reconciled
  @is_reconciled
end

#narrative ⇒ Object

(UK Only) Only shows on the statement line in Xero. Max length =18



34
35
36
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 34

def narrative
  @narrative
end

#particulars ⇒ Object

(NZ Only) Optional references for the batch payment transaction. It will also show with the batch payment transaction in the bank reconciliation Find & Match screen. Depending on your individual bank, the detail may also show on the bank statement you import into Xero.



25
26
27
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 25

def particulars
  @particulars
end

#payments ⇒ Object

An array of payments



49
50
51
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 49

def payments
  @payments
end

#reference ⇒ Object

(NZ Only) Optional references for the batch payment transaction. It will also show with the batch payment transaction in the bank reconciliation Find & Match screen. Depending on your individual bank, the detail may also show on the bank statement you import into Xero.



22
23
24
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 22

def reference
  @reference
end

#status ⇒ Object

AUTHORISED or DELETED (read-only). New batch payments will have a status of AUTHORISED. It is not possible to delete batch payments via the API.



57
58
59
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 57

def status
  @status
end

#total_amount ⇒ Object

The total of the payments that make up the batch (read-only)



62
63
64
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 62

def total_amount
  @total_amount
end

#type ⇒ Object

PAYBATCH for bill payments or RECBATCH for sales invoice payments (read-only)



52
53
54
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 52

def type
  @type
end

#updated_date_utc ⇒ Object

UTC timestamp of last update to the payment



65
66
67
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 65

def updated_date_utc
  @updated_date_utc
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 93

def self.attribute_map
  {
    :'account' => :'Account',
    :'reference' => :'Reference',
    :'particulars' => :'Particulars',
    :'code' => :'Code',
    :'details' => :'Details',
    :'narrative' => :'Narrative',
    :'batch_payment_id' => :'BatchPaymentID',
    :'date_string' => :'DateString',
    :'date' => :'Date',
    :'amount' => :'Amount',
    :'payments' => :'Payments',
    :'type' => :'Type',
    :'status' => :'Status',
    :'total_amount' => :'TotalAmount',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'is_reconciled' => :'IsReconciled'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



368
369
370
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 368

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 115

def self.openapi_types
  {
    :'account' => :'Account',
    :'reference' => :'String',
    :'particulars' => :'String',
    :'code' => :'String',
    :'details' => :'String',
    :'narrative' => :'String',
    :'batch_payment_id' => :'String',
    :'date_string' => :'String',
    :'date' => :'Date',
    :'amount' => :'Float',
    :'payments' => :'Array<Payment>',
    :'type' => :'String',
    :'status' => :'String',
    :'total_amount' => :'String',
    :'updated_date_utc' => :'DateTime',
    :'is_reconciled' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 332

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      reference == o.reference &&
      particulars == o.particulars &&
      code == o.code &&
      details == o.details &&
      narrative == o.narrative &&
      batch_payment_id == o.batch_payment_id &&
      date_string == o.date_string &&
      date == o.date &&
      amount == o.amount &&
      payments == o.payments &&
      type == o.type &&
      status == o.status &&
      total_amount == o.total_amount &&
      updated_date_utc == o.updated_date_utc &&
      is_reconciled == o.is_reconciled
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 396

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 461

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 375

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


355
356
357
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 355

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



361
362
363
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 361

def hash
  [, reference, particulars, code, details, narrative, batch_payment_id, date_string, date, amount, payments, type, status, total_amount, updated_date_utc, is_reconciled].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 220

def list_invalid_properties
  invalid_properties = Array.new
  if !@reference.nil? && @reference.to_s.length > 12
    invalid_properties.push('invalid value for "reference", the character length must be smaller than or equal to 12.')
  end

  if !@particulars.nil? && @particulars.to_s.length > 12
    invalid_properties.push('invalid value for "particulars", the character length must be smaller than or equal to 12.')
  end

  if !@code.nil? && @code.to_s.length > 12
    invalid_properties.push('invalid value for "code", the character length must be smaller than or equal to 12.')
  end

  if !@details.nil? && @details.to_s.length > 18
    invalid_properties.push('invalid value for "details", the character length must be smaller than or equal to 18.')
  end

  if !@narrative.nil? && @narrative.to_s.length > 18
    invalid_properties.push('invalid value for "narrative", the character length must be smaller than or equal to 18.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



476
477
478
479
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 476

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



441
442
443
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 441

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



447
448
449
450
451
452
453
454
455
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 447

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



435
436
437
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 435

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/xero-ruby/models/accounting/batch_payment.rb', line 247

def valid?
  return false if !@reference.nil? && @reference.to_s.length > 12
  return false if !@particulars.nil? && @particulars.to_s.length > 12
  return false if !@code.nil? && @code.to_s.length > 12
  return false if !@details.nil? && @details.to_s.length > 18
  return false if !@narrative.nil? && @narrative.to_s.length > 18
  type_validator = EnumAttributeValidator.new('String', ["PAYBATCH", "RECBATCH"])
  return false unless type_validator.valid?(@type)
  status_validator = EnumAttributeValidator.new('String', ["AUTHORISED", "DELETED"])
  return false unless status_validator.valid?(@status)
  true
end