Class: XeroRuby::Accounting::Contact

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/contact.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

ACTIVE =
"ACTIVE".freeze
ARCHIVED =
"ARCHIVED".freeze
GDPRREQUEST =
"GDPRREQUEST".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Contact

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
# File 'lib/xero-ruby/models/accounting/contact.rb', line 252

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Contact` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Contact`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'contact_id')
    self.contact_id = attributes[:'contact_id']
  end

  if attributes.key?(:'contact_number')
    self.contact_number = attributes[:'contact_number']
  end

  if attributes.key?(:'account_number')
    self. = attributes[:'account_number']
  end

  if attributes.key?(:'contact_status')
    self.contact_status = attributes[:'contact_status']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'email_address')
    self.email_address = attributes[:'email_address']
  end

  if attributes.key?(:'skype_user_name')
    self.skype_user_name = attributes[:'skype_user_name']
  end

  if attributes.key?(:'contact_persons')
    if (value = attributes[:'contact_persons']).is_a?(Array)
      self.contact_persons = value
    end
  end

  if attributes.key?(:'bank_account_details')
    self. = attributes[:'bank_account_details']
  end

  if attributes.key?(:'tax_number')
    self.tax_number = attributes[:'tax_number']
  end

  if attributes.key?(:'accounts_receivable_tax_type')
    self.accounts_receivable_tax_type = attributes[:'accounts_receivable_tax_type']
  end

  if attributes.key?(:'accounts_payable_tax_type')
    self.accounts_payable_tax_type = attributes[:'accounts_payable_tax_type']
  end

  if attributes.key?(:'addresses')
    if (value = attributes[:'addresses']).is_a?(Array)
      self.addresses = value
    end
  end

  if attributes.key?(:'phones')
    if (value = attributes[:'phones']).is_a?(Array)
      self.phones = value
    end
  end

  if attributes.key?(:'is_supplier')
    self.is_supplier = attributes[:'is_supplier']
  end

  if attributes.key?(:'is_customer')
    self.is_customer = attributes[:'is_customer']
  end

  if attributes.key?(:'default_currency')
    self.default_currency = attributes[:'default_currency']
  end

  if attributes.key?(:'xero_network_key')
    self.xero_network_key = attributes[:'xero_network_key']
  end

  if attributes.key?(:'sales_default_account_code')
    self. = attributes[:'sales_default_account_code']
  end

  if attributes.key?(:'purchases_default_account_code')
    self. = attributes[:'purchases_default_account_code']
  end

  if attributes.key?(:'sales_tracking_categories')
    if (value = attributes[:'sales_tracking_categories']).is_a?(Array)
      self.sales_tracking_categories = value
    end
  end

  if attributes.key?(:'purchases_tracking_categories')
    if (value = attributes[:'purchases_tracking_categories']).is_a?(Array)
      self.purchases_tracking_categories = value
    end
  end

  if attributes.key?(:'tracking_category_name')
    self.tracking_category_name = attributes[:'tracking_category_name']
  end

  if attributes.key?(:'tracking_category_option')
    self.tracking_category_option = attributes[:'tracking_category_option']
  end

  if attributes.key?(:'payment_terms')
    self.payment_terms = attributes[:'payment_terms']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'contact_groups')
    if (value = attributes[:'contact_groups']).is_a?(Array)
      self.contact_groups = value
    end
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  end

  if attributes.key?(:'branding_theme')
    self.branding_theme = attributes[:'branding_theme']
  end

  if attributes.key?(:'batch_payments')
    self.batch_payments = attributes[:'batch_payments']
  end

  if attributes.key?(:'discount')
    self.discount = attributes[:'discount']
  end

  if attributes.key?(:'balances')
    self.balances = attributes[:'balances']
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  else
    self.has_attachments = false
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end

  if attributes.key?(:'has_validation_errors')
    self.has_validation_errors = attributes[:'has_validation_errors']
  else
    self.has_validation_errors = false
  end

  if attributes.key?(:'status_attribute_string')
    self.status_attribute_string = attributes[:'status_attribute_string']
  end
end

Instance Attribute Details

#account_number ⇒ Object

A user defined account number. This can be updated via the API and the Xero UI (max length = 50)



25
26
27
# File 'lib/xero-ruby/models/accounting/contact.rb', line 25

def 
  @account_number
end

#accounts_payable_tax_type ⇒ Object

The tax type from TaxRates



61
62
63
# File 'lib/xero-ruby/models/accounting/contact.rb', line 61

def accounts_payable_tax_type
  @accounts_payable_tax_type
end

#accounts_receivable_tax_type ⇒ Object

The tax type from TaxRates



58
59
60
# File 'lib/xero-ruby/models/accounting/contact.rb', line 58

def accounts_receivable_tax_type
  @accounts_receivable_tax_type
end

#addresses ⇒ Object

Store certain address types for a contact – see address types



64
65
66
# File 'lib/xero-ruby/models/accounting/contact.rb', line 64

def addresses
  @addresses
end

#attachments ⇒ Object

Displays array of attachments from the API



124
125
126
# File 'lib/xero-ruby/models/accounting/contact.rb', line 124

def attachments
  @attachments
end

#balances ⇒ Object

Returns the value of attribute balances.



121
122
123
# File 'lib/xero-ruby/models/accounting/contact.rb', line 121

def balances
  @balances
end

#bank_account_details ⇒ Object

Bank account number of contact



52
53
54
# File 'lib/xero-ruby/models/accounting/contact.rb', line 52

def 
  
end

#batch_payments ⇒ Object

Returns the value of attribute batch_payments.



115
116
117
# File 'lib/xero-ruby/models/accounting/contact.rb', line 115

def batch_payments
  @batch_payments
end

#branding_theme ⇒ Object

Returns the value of attribute branding_theme.



112
113
114
# File 'lib/xero-ruby/models/accounting/contact.rb', line 112

def branding_theme
  @branding_theme
end

#contact_groups ⇒ Object

Displays which contact groups a contact is included in



106
107
108
# File 'lib/xero-ruby/models/accounting/contact.rb', line 106

def contact_groups
  @contact_groups
end

#contact_id ⇒ Object

Xero identifier



19
20
21
# File 'lib/xero-ruby/models/accounting/contact.rb', line 19

def contact_id
  @contact_id
end

#contact_number ⇒ Object

This can be updated via the API only i.e. This field is read only on the Xero contact screen, used to identify contacts in external systems (max length = 50). If the Contact Number is used, this is displayed as Contact Code in the Contacts UI in Xero.



22
23
24
# File 'lib/xero-ruby/models/accounting/contact.rb', line 22

def contact_number
  @contact_number
end

#contact_persons ⇒ Object

See contact persons



49
50
51
# File 'lib/xero-ruby/models/accounting/contact.rb', line 49

def contact_persons
  @contact_persons
end

#contact_status ⇒ Object

Current status of a contact – see contact status types



28
29
30
# File 'lib/xero-ruby/models/accounting/contact.rb', line 28

def contact_status
  @contact_status
end

#default_currency ⇒ Object

Returns the value of attribute default_currency.



76
77
78
# File 'lib/xero-ruby/models/accounting/contact.rb', line 76

def default_currency
  @default_currency
end

#discount ⇒ Object

The default discount rate for the contact (read only)



118
119
120
# File 'lib/xero-ruby/models/accounting/contact.rb', line 118

def discount
  @discount
end

#email_address ⇒ Object

Email address of contact person (umlauts not supported) (max length = 255)



43
44
45
# File 'lib/xero-ruby/models/accounting/contact.rb', line 43

def email_address
  @email_address
end

#first_name ⇒ Object

First name of contact person (max length = 255)



37
38
39
# File 'lib/xero-ruby/models/accounting/contact.rb', line 37

def first_name
  @first_name
end

#has_attachments ⇒ Object

A boolean to indicate if a contact has an attachment



127
128
129
# File 'lib/xero-ruby/models/accounting/contact.rb', line 127

def has_attachments
  @has_attachments
end

#has_validation_errors ⇒ Object

A boolean to indicate if a contact has an validation errors



133
134
135
# File 'lib/xero-ruby/models/accounting/contact.rb', line 133

def has_validation_errors
  @has_validation_errors
end

#is_customer ⇒ Object

true or false – Boolean that describes if a contact has any AR invoices entered against them. Cannot be set via PUT or POST – it is automatically set when an accounts receivable invoice is generated against this contact.



73
74
75
# File 'lib/xero-ruby/models/accounting/contact.rb', line 73

def is_customer
  @is_customer
end

#is_supplier ⇒ Object

true or false – Boolean that describes if a contact that has any AP invoices entered against them. Cannot be set via PUT or POST – it is automatically set when an accounts payable invoice is generated against this contact.



70
71
72
# File 'lib/xero-ruby/models/accounting/contact.rb', line 70

def is_supplier
  @is_supplier
end

#last_name ⇒ Object

Last name of contact person (max length = 255)



40
41
42
# File 'lib/xero-ruby/models/accounting/contact.rb', line 40

def last_name
  @last_name
end

#name ⇒ Object

Full name of contact/organisation (max length = 255)



34
35
36
# File 'lib/xero-ruby/models/accounting/contact.rb', line 34

def name
  @name
end

#payment_terms ⇒ Object

Returns the value of attribute payment_terms.



100
101
102
# File 'lib/xero-ruby/models/accounting/contact.rb', line 100

def payment_terms
  @payment_terms
end

#phones ⇒ Object

Store certain phone types for a contact – see phone types



67
68
69
# File 'lib/xero-ruby/models/accounting/contact.rb', line 67

def phones
  @phones
end

#purchases_default_account_code ⇒ Object

The default purchases account code for contacts



85
86
87
# File 'lib/xero-ruby/models/accounting/contact.rb', line 85

def 
  
end

#purchases_tracking_categories ⇒ Object

The default purchases tracking categories for contacts



91
92
93
# File 'lib/xero-ruby/models/accounting/contact.rb', line 91

def purchases_tracking_categories
  @purchases_tracking_categories
end

#sales_default_account_code ⇒ Object

The default sales account code for contacts



82
83
84
# File 'lib/xero-ruby/models/accounting/contact.rb', line 82

def 
  
end

#sales_tracking_categories ⇒ Object

The default sales tracking categories for contacts



88
89
90
# File 'lib/xero-ruby/models/accounting/contact.rb', line 88

def sales_tracking_categories
  @sales_tracking_categories
end

#skype_user_name ⇒ Object

Skype user name of contact



46
47
48
# File 'lib/xero-ruby/models/accounting/contact.rb', line 46

def skype_user_name
  @skype_user_name
end

#status_attribute_string ⇒ Object

Status of object



136
137
138
# File 'lib/xero-ruby/models/accounting/contact.rb', line 136

def status_attribute_string
  @status_attribute_string
end

#tax_number ⇒ Object

Tax number of contact – this is also known as the ABN (Australia), GST Number (New Zealand), VAT Number (UK) or Tax ID Number (US and global) in the Xero UI depending on which regionalized version of Xero you are using (max length = 50)



55
56
57
# File 'lib/xero-ruby/models/accounting/contact.rb', line 55

def tax_number
  @tax_number
end

#tracking_category_name ⇒ Object

The name of the Tracking Category assigned to the contact under SalesTrackingCategories and PurchasesTrackingCategories



94
95
96
# File 'lib/xero-ruby/models/accounting/contact.rb', line 94

def tracking_category_name
  @tracking_category_name
end

#tracking_category_option ⇒ Object

The name of the Tracking Option assigned to the contact under SalesTrackingCategories and PurchasesTrackingCategories



97
98
99
# File 'lib/xero-ruby/models/accounting/contact.rb', line 97

def tracking_category_option
  @tracking_category_option
end

#updated_date_utc ⇒ Object

UTC timestamp of last update to contact



103
104
105
# File 'lib/xero-ruby/models/accounting/contact.rb', line 103

def updated_date_utc
  @updated_date_utc
end

#validation_errors ⇒ Object

Displays validation errors returned from the API



130
131
132
# File 'lib/xero-ruby/models/accounting/contact.rb', line 130

def validation_errors
  @validation_errors
end

#website ⇒ Object

Website address for contact (read only)



109
110
111
# File 'lib/xero-ruby/models/accounting/contact.rb', line 109

def website
  @website
end

#xero_network_key ⇒ Object

Store XeroNetworkKey for contacts.



79
80
81
# File 'lib/xero-ruby/models/accounting/contact.rb', line 79

def xero_network_key
  @xero_network_key
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/xero-ruby/models/accounting/contact.rb', line 161

def self.attribute_map
  {
    :'contact_id' => :'ContactID',
    :'contact_number' => :'ContactNumber',
    :'account_number' => :'AccountNumber',
    :'contact_status' => :'ContactStatus',
    :'name' => :'Name',
    :'first_name' => :'FirstName',
    :'last_name' => :'LastName',
    :'email_address' => :'EmailAddress',
    :'skype_user_name' => :'SkypeUserName',
    :'contact_persons' => :'ContactPersons',
    :'bank_account_details' => :'BankAccountDetails',
    :'tax_number' => :'TaxNumber',
    :'accounts_receivable_tax_type' => :'AccountsReceivableTaxType',
    :'accounts_payable_tax_type' => :'AccountsPayableTaxType',
    :'addresses' => :'Addresses',
    :'phones' => :'Phones',
    :'is_supplier' => :'IsSupplier',
    :'is_customer' => :'IsCustomer',
    :'default_currency' => :'DefaultCurrency',
    :'xero_network_key' => :'XeroNetworkKey',
    :'sales_default_account_code' => :'SalesDefaultAccountCode',
    :'purchases_default_account_code' => :'PurchasesDefaultAccountCode',
    :'sales_tracking_categories' => :'SalesTrackingCategories',
    :'purchases_tracking_categories' => :'PurchasesTrackingCategories',
    :'tracking_category_name' => :'TrackingCategoryName',
    :'tracking_category_option' => :'TrackingCategoryOption',
    :'payment_terms' => :'PaymentTerms',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'contact_groups' => :'ContactGroups',
    :'website' => :'Website',
    :'branding_theme' => :'BrandingTheme',
    :'batch_payments' => :'BatchPayments',
    :'discount' => :'Discount',
    :'balances' => :'Balances',
    :'attachments' => :'Attachments',
    :'has_attachments' => :'HasAttachments',
    :'validation_errors' => :'ValidationErrors',
    :'has_validation_errors' => :'HasValidationErrors',
    :'status_attribute_string' => :'StatusAttributeString'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



633
634
635
# File 'lib/xero-ruby/models/accounting/contact.rb', line 633

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/xero-ruby/models/accounting/contact.rb', line 206

def self.openapi_types
  {
    :'contact_id' => :'String',
    :'contact_number' => :'String',
    :'account_number' => :'String',
    :'contact_status' => :'String',
    :'name' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'email_address' => :'String',
    :'skype_user_name' => :'String',
    :'contact_persons' => :'Array<ContactPerson>',
    :'bank_account_details' => :'String',
    :'tax_number' => :'String',
    :'accounts_receivable_tax_type' => :'String',
    :'accounts_payable_tax_type' => :'String',
    :'addresses' => :'Array<Address>',
    :'phones' => :'Array<Phone>',
    :'is_supplier' => :'Boolean',
    :'is_customer' => :'Boolean',
    :'default_currency' => :'CurrencyCode',
    :'xero_network_key' => :'String',
    :'sales_default_account_code' => :'String',
    :'purchases_default_account_code' => :'String',
    :'sales_tracking_categories' => :'Array<SalesTrackingCategory>',
    :'purchases_tracking_categories' => :'Array<SalesTrackingCategory>',
    :'tracking_category_name' => :'String',
    :'tracking_category_option' => :'String',
    :'payment_terms' => :'PaymentTerm',
    :'updated_date_utc' => :'DateTime',
    :'contact_groups' => :'Array<ContactGroup>',
    :'website' => :'String',
    :'branding_theme' => :'BrandingTheme',
    :'batch_payments' => :'BatchPaymentDetails',
    :'discount' => :'Float',
    :'balances' => :'Balances',
    :'attachments' => :'Array<Attachment>',
    :'has_attachments' => :'Boolean',
    :'validation_errors' => :'Array<ValidationError>',
    :'has_validation_errors' => :'Boolean',
    :'status_attribute_string' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
# File 'lib/xero-ruby/models/accounting/contact.rb', line 574

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      contact_id == o.contact_id &&
      contact_number == o.contact_number &&
       == o. &&
      contact_status == o.contact_status &&
      name == o.name &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      email_address == o.email_address &&
      skype_user_name == o.skype_user_name &&
      contact_persons == o.contact_persons &&
       == o. &&
      tax_number == o.tax_number &&
      accounts_receivable_tax_type == o.accounts_receivable_tax_type &&
      accounts_payable_tax_type == o.accounts_payable_tax_type &&
      addresses == o.addresses &&
      phones == o.phones &&
      is_supplier == o.is_supplier &&
      is_customer == o.is_customer &&
      default_currency == o.default_currency &&
      xero_network_key == o.xero_network_key &&
       == o. &&
       == o. &&
      sales_tracking_categories == o.sales_tracking_categories &&
      purchases_tracking_categories == o.purchases_tracking_categories &&
      tracking_category_name == o.tracking_category_name &&
      tracking_category_option == o.tracking_category_option &&
      payment_terms == o.payment_terms &&
      updated_date_utc == o.updated_date_utc &&
      contact_groups == o.contact_groups &&
      website == o.website &&
      branding_theme == o.branding_theme &&
      batch_payments == o.batch_payments &&
      discount == o.discount &&
      balances == o.balances &&
      attachments == o.attachments &&
      has_attachments == o.has_attachments &&
      validation_errors == o.validation_errors &&
      has_validation_errors == o.has_validation_errors &&
      status_attribute_string == o.status_attribute_string
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'lib/xero-ruby/models/accounting/contact.rb', line 661

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



726
727
728
729
730
731
732
733
734
735
736
737
738
# File 'lib/xero-ruby/models/accounting/contact.rb', line 726

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
# File 'lib/xero-ruby/models/accounting/contact.rb', line 640

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


620
621
622
# File 'lib/xero-ruby/models/accounting/contact.rb', line 620

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



626
627
628
# File 'lib/xero-ruby/models/accounting/contact.rb', line 626

def hash
  [contact_id, contact_number, , contact_status, name, first_name, last_name, email_address, skype_user_name, contact_persons, , tax_number, accounts_receivable_tax_type, accounts_payable_tax_type, addresses, phones, is_supplier, is_customer, default_currency, xero_network_key, , , sales_tracking_categories, purchases_tracking_categories, tracking_category_name, tracking_category_option, payment_terms, updated_date_utc, contact_groups, website, branding_theme, batch_payments, discount, balances, attachments, has_attachments, validation_errors, has_validation_errors, status_attribute_string].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'lib/xero-ruby/models/accounting/contact.rb', line 444

def list_invalid_properties
  invalid_properties = Array.new
  if !@contact_number.nil? && @contact_number.to_s.length > 50
    invalid_properties.push('invalid value for "contact_number", the character length must be smaller than or equal to 50.')
  end

  if !@account_number.nil? && @account_number.to_s.length > 50
    invalid_properties.push('invalid value for "account_number", the character length must be smaller than or equal to 50.')
  end

  if !@name.nil? && @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if !@first_name.nil? && @first_name.to_s.length > 255
    invalid_properties.push('invalid value for "first_name", the character length must be smaller than or equal to 255.')
  end

  if !@last_name.nil? && @last_name.to_s.length > 255
    invalid_properties.push('invalid value for "last_name", the character length must be smaller than or equal to 255.')
  end

  if !@email_address.nil? && @email_address.to_s.length > 255
    invalid_properties.push('invalid value for "email_address", the character length must be smaller than or equal to 255.')
  end

  if !@tax_number.nil? && @tax_number.to_s.length > 50
    invalid_properties.push('invalid value for "tax_number", the character length must be smaller than or equal to 50.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



741
742
743
744
# File 'lib/xero-ruby/models/accounting/contact.rb', line 741

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



706
707
708
# File 'lib/xero-ruby/models/accounting/contact.rb', line 706

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



712
713
714
715
716
717
718
719
720
# File 'lib/xero-ruby/models/accounting/contact.rb', line 712

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



700
701
702
# File 'lib/xero-ruby/models/accounting/contact.rb', line 700

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



479
480
481
482
483
484
485
486
487
488
489
490
# File 'lib/xero-ruby/models/accounting/contact.rb', line 479

def valid?
  return false if !@contact_number.nil? && @contact_number.to_s.length > 50
  return false if !@account_number.nil? && @account_number.to_s.length > 50
  contact_status_validator = EnumAttributeValidator.new('String', ["ACTIVE", "ARCHIVED", "GDPRREQUEST"])
  return false unless contact_status_validator.valid?(@contact_status)
  return false if !@name.nil? && @name.to_s.length > 255
  return false if !@first_name.nil? && @first_name.to_s.length > 255
  return false if !@last_name.nil? && @last_name.to_s.length > 255
  return false if !@email_address.nil? && @email_address.to_s.length > 255
  return false if !@tax_number.nil? && @tax_number.to_s.length > 50
  true
end