Class: XeroRuby::Accounting::CreditNote
- Inherits:
-
Object
- Object
- XeroRuby::Accounting::CreditNote
- Defined in:
- lib/xero-ruby/models/accounting/credit_note.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Constant Summary collapse
- ACCPAYCREDIT =
"ACCPAYCREDIT".freeze
- ACCRECCREDIT =
"ACCRECCREDIT".freeze
- DRAFT =
"DRAFT".freeze
- SUBMITTED =
"SUBMITTED".freeze
- DELETED =
"DELETED".freeze
- AUTHORISED =
"AUTHORISED".freeze
- PAID =
"PAID".freeze
- VOIDED =
"VOIDED".freeze
Instance Attribute Summary collapse
-
#allocations ⇒ Object
See Allocations.
-
#applied_amount ⇒ Object
The amount of applied to an invoice.
-
#branding_theme_id ⇒ Object
See BrandingThemes.
-
#contact ⇒ Object
Returns the value of attribute contact.
-
#credit_note_id ⇒ Object
Xero generated unique identifier.
-
#credit_note_number ⇒ Object
ACCRECCREDIT – Unique alpha numeric code identifying credit note (when missing will auto-generate from your Organisation Invoice Settings).
-
#currency_code ⇒ Object
Returns the value of attribute currency_code.
-
#currency_rate ⇒ Object
The currency rate for a multicurrency invoice.
-
#date ⇒ Object
The date the credit note is issued YYYY-MM-DD.
-
#due_date ⇒ Object
Date invoice is due – YYYY-MM-DD.
-
#fully_paid_on_date ⇒ Object
Date when credit note was fully paid(UTC format).
-
#has_attachments ⇒ Object
boolean to indicate if a credit note has an attachment.
-
#has_errors ⇒ Object
A boolean to indicate if a credit note has an validation errors.
-
#line_amount_types ⇒ Object
Returns the value of attribute line_amount_types.
-
#line_items ⇒ Object
See Invoice Line Items.
-
#payments ⇒ Object
See Payments.
-
#reference ⇒ Object
ACCRECCREDIT only – additional reference number.
-
#remaining_credit ⇒ Object
The remaining credit balance on the Credit Note.
-
#sent_to_contact ⇒ Object
boolean to indicate if a credit note has been sent to a contact via the Xero app (currently read only).
-
#status ⇒ Object
See Credit Note Status Codes.
-
#status_attribute_string ⇒ Object
A string to indicate if a invoice status.
-
#sub_total ⇒ Object
The subtotal of the credit note excluding taxes.
-
#total ⇒ Object
The total of the Credit Note(subtotal + total tax).
-
#total_tax ⇒ Object
The total tax on the credit note.
-
#type ⇒ Object
See Credit Note Types.
-
#updated_date_utc ⇒ Object
UTC timestamp of last update to the credit note.
-
#validation_errors ⇒ Object
Displays array of validation error messages from the API.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreditNote
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreditNote
Initializes the object
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 199 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::CreditNote` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::CreditNote`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'contact') self.contact = attributes[:'contact'] end if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'due_date') self.due_date = attributes[:'due_date'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'line_amount_types') self.line_amount_types = attributes[:'line_amount_types'] end if attributes.key?(:'line_items') if (value = attributes[:'line_items']).is_a?(Array) self.line_items = value end end if attributes.key?(:'sub_total') self.sub_total = attributes[:'sub_total'] end if attributes.key?(:'total_tax') self.total_tax = attributes[:'total_tax'] end if attributes.key?(:'total') self.total = attributes[:'total'] end if attributes.key?(:'updated_date_utc') self.updated_date_utc = attributes[:'updated_date_utc'] end if attributes.key?(:'currency_code') self.currency_code = attributes[:'currency_code'] end if attributes.key?(:'fully_paid_on_date') self.fully_paid_on_date = attributes[:'fully_paid_on_date'] end if attributes.key?(:'credit_note_id') self.credit_note_id = attributes[:'credit_note_id'] end if attributes.key?(:'credit_note_number') self.credit_note_number = attributes[:'credit_note_number'] end if attributes.key?(:'reference') self.reference = attributes[:'reference'] end if attributes.key?(:'sent_to_contact') self.sent_to_contact = attributes[:'sent_to_contact'] end if attributes.key?(:'currency_rate') self.currency_rate = attributes[:'currency_rate'] end if attributes.key?(:'remaining_credit') self.remaining_credit = attributes[:'remaining_credit'] end if attributes.key?(:'allocations') if (value = attributes[:'allocations']).is_a?(Array) self.allocations = value end end if attributes.key?(:'applied_amount') self.applied_amount = attributes[:'applied_amount'] end if attributes.key?(:'payments') if (value = attributes[:'payments']).is_a?(Array) self.payments = value end end if attributes.key?(:'branding_theme_id') self.branding_theme_id = attributes[:'branding_theme_id'] end if attributes.key?(:'status_attribute_string') self.status_attribute_string = attributes[:'status_attribute_string'] end if attributes.key?(:'has_attachments') self. = attributes[:'has_attachments'] else self. = false end if attributes.key?(:'has_errors') self.has_errors = attributes[:'has_errors'] else self.has_errors = false end if attributes.key?(:'validation_errors') if (value = attributes[:'validation_errors']).is_a?(Array) self.validation_errors = value end end end |
Instance Attribute Details
#allocations ⇒ Object
See Allocations
86 87 88 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 86 def allocations @allocations end |
#applied_amount ⇒ Object
The amount of applied to an invoice
89 90 91 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 89 def applied_amount @applied_amount end |
#branding_theme_id ⇒ Object
See BrandingThemes
95 96 97 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 95 def branding_theme_id @branding_theme_id end |
#contact ⇒ Object
Returns the value of attribute contact.
26 27 28 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 26 def contact @contact end |
#credit_note_id ⇒ Object
Xero generated unique identifier
68 69 70 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 68 def credit_note_id @credit_note_id end |
#credit_note_number ⇒ Object
ACCRECCREDIT – Unique alpha numeric code identifying credit note (when missing will auto-generate from your Organisation Invoice Settings)
71 72 73 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 71 def credit_note_number @credit_note_number end |
#currency_code ⇒ Object
Returns the value of attribute currency_code.
62 63 64 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 62 def currency_code @currency_code end |
#currency_rate ⇒ Object
The currency rate for a multicurrency invoice. If no rate is specified, the XE.com day rate is used
80 81 82 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 80 def currency_rate @currency_rate end |
#date ⇒ Object
The date the credit note is issued YYYY-MM-DD. If the Date element is not specified then it will default to the current date based on the timezone setting of the organisation
29 30 31 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 29 def date @date end |
#due_date ⇒ Object
Date invoice is due – YYYY-MM-DD
32 33 34 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 32 def due_date @due_date end |
#fully_paid_on_date ⇒ Object
Date when credit note was fully paid(UTC format)
65 66 67 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 65 def fully_paid_on_date @fully_paid_on_date end |
#has_attachments ⇒ Object
boolean to indicate if a credit note has an attachment
101 102 103 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 101 def @has_attachments end |
#has_errors ⇒ Object
A boolean to indicate if a credit note has an validation errors
104 105 106 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 104 def has_errors @has_errors end |
#line_amount_types ⇒ Object
Returns the value of attribute line_amount_types.
44 45 46 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 44 def line_amount_types @line_amount_types end |
#line_items ⇒ Object
See Invoice Line Items
47 48 49 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 47 def line_items @line_items end |
#payments ⇒ Object
See Payments
92 93 94 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 92 def payments @payments end |
#reference ⇒ Object
ACCRECCREDIT only – additional reference number
74 75 76 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 74 def reference @reference end |
#remaining_credit ⇒ Object
The remaining credit balance on the Credit Note
83 84 85 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 83 def remaining_credit @remaining_credit end |
#sent_to_contact ⇒ Object
boolean to indicate if a credit note has been sent to a contact via the Xero app (currently read only)
77 78 79 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 77 def sent_to_contact @sent_to_contact end |
#status ⇒ Object
See Credit Note Status Codes
35 36 37 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 35 def status @status end |
#status_attribute_string ⇒ Object
A string to indicate if a invoice status
98 99 100 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 98 def status_attribute_string @status_attribute_string end |
#sub_total ⇒ Object
The subtotal of the credit note excluding taxes
50 51 52 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 50 def sub_total @sub_total end |
#total ⇒ Object
The total of the Credit Note(subtotal + total tax)
56 57 58 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 56 def total @total end |
#total_tax ⇒ Object
The total tax on the credit note
53 54 55 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 53 def total_tax @total_tax end |
#type ⇒ Object
See Credit Note Types
21 22 23 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 21 def type @type end |
#updated_date_utc ⇒ Object
UTC timestamp of last update to the credit note
59 60 61 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 59 def updated_date_utc @updated_date_utc end |
#validation_errors ⇒ Object
Displays array of validation error messages from the API
107 108 109 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 107 def validation_errors @validation_errors end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 132 def self.attribute_map { :'type' => :'Type', :'contact' => :'Contact', :'date' => :'Date', :'due_date' => :'DueDate', :'status' => :'Status', :'line_amount_types' => :'LineAmountTypes', :'line_items' => :'LineItems', :'sub_total' => :'SubTotal', :'total_tax' => :'TotalTax', :'total' => :'Total', :'updated_date_utc' => :'UpdatedDateUTC', :'currency_code' => :'CurrencyCode', :'fully_paid_on_date' => :'FullyPaidOnDate', :'credit_note_id' => :'CreditNoteID', :'credit_note_number' => :'CreditNoteNumber', :'reference' => :'Reference', :'sent_to_contact' => :'SentToContact', :'currency_rate' => :'CurrencyRate', :'remaining_credit' => :'RemainingCredit', :'allocations' => :'Allocations', :'applied_amount' => :'AppliedAmount', :'payments' => :'Payments', :'branding_theme_id' => :'BrandingThemeID', :'status_attribute_string' => :'StatusAttributeString', :'has_attachments' => :'HasAttachments', :'has_errors' => :'HasErrors', :'validation_errors' => :'ValidationErrors' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
419 420 421 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 419 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 165 def self.openapi_types { :'type' => :'String', :'contact' => :'Contact', :'date' => :'Date', :'due_date' => :'Date', :'status' => :'String', :'line_amount_types' => :'LineAmountTypes', :'line_items' => :'Array<LineItem>', :'sub_total' => :'BigDecimal', :'total_tax' => :'BigDecimal', :'total' => :'BigDecimal', :'updated_date_utc' => :'DateTime', :'currency_code' => :'CurrencyCode', :'fully_paid_on_date' => :'Date', :'credit_note_id' => :'String', :'credit_note_number' => :'String', :'reference' => :'String', :'sent_to_contact' => :'Boolean', :'currency_rate' => :'BigDecimal', :'remaining_credit' => :'BigDecimal', :'allocations' => :'Array<Allocation>', :'applied_amount' => :'Float', :'payments' => :'Array<Payment>', :'branding_theme_id' => :'String', :'status_attribute_string' => :'String', :'has_attachments' => :'Boolean', :'has_errors' => :'Boolean', :'validation_errors' => :'Array<ValidationError>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 372 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && contact == o.contact && date == o.date && due_date == o.due_date && status == o.status && line_amount_types == o.line_amount_types && line_items == o.line_items && sub_total == o.sub_total && total_tax == o.total_tax && total == o.total && updated_date_utc == o.updated_date_utc && currency_code == o.currency_code && fully_paid_on_date == o.fully_paid_on_date && credit_note_id == o.credit_note_id && credit_note_number == o.credit_note_number && reference == o.reference && sent_to_contact == o.sent_to_contact && currency_rate == o.currency_rate && remaining_credit == o.remaining_credit && allocations == o.allocations && applied_amount == o.applied_amount && payments == o.payments && branding_theme_id == o.branding_theme_id && status_attribute_string == o.status_attribute_string && == o. && has_errors == o.has_errors && validation_errors == o.validation_errors end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 447 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::Accounting.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 514 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 426 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
406 407 408 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 406 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
412 413 414 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 412 def hash [type, contact, date, due_date, status, line_amount_types, line_items, sub_total, total_tax, total, updated_date_utc, currency_code, fully_paid_on_date, credit_note_id, credit_note_number, reference, sent_to_contact, currency_rate, remaining_credit, allocations, applied_amount, payments, branding_theme_id, status_attribute_string, , has_errors, validation_errors].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
335 336 337 338 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 335 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
529 530 531 532 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 529 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
494 495 496 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 494 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
500 501 502 503 504 505 506 507 508 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 500 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
488 489 490 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 488 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
342 343 344 345 346 347 348 |
# File 'lib/xero-ruby/models/accounting/credit_note.rb', line 342 def valid? type_validator = EnumAttributeValidator.new('String', ["ACCPAYCREDIT", "ACCRECCREDIT"]) return false unless type_validator.valid?(@type) status_validator = EnumAttributeValidator.new('String', ["DRAFT", "SUBMITTED", "DELETED", "AUTHORISED", "PAID", "VOIDED"]) return false unless status_validator.valid?(@status) true end |