Class: XeroRuby::Accounting::ExpenseClaim

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/expense_claim.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

SUBMITTED =
"SUBMITTED".freeze
AUTHORISED =
"AUTHORISED".freeze
"PAID".freeze
VOIDED =
"VOIDED".freeze
DELETED =
"DELETED".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ExpenseClaim

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::ExpenseClaim` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::ExpenseClaim`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'expense_claim_id')
    self.expense_claim_id = attributes[:'expense_claim_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'payments')
    if (value = attributes[:'payments']).is_a?(Array)
      self.payments = value
    end
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'receipts')
    if (value = attributes[:'receipts']).is_a?(Array)
      self.receipts = value
    end
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'amount_due')
    self.amount_due = attributes[:'amount_due']
  end

  if attributes.key?(:'amount_paid')
    self.amount_paid = attributes[:'amount_paid']
  end

  if attributes.key?(:'payment_due_date')
    self.payment_due_date = attributes[:'payment_due_date']
  end

  if attributes.key?(:'reporting_date')
    self.reporting_date = attributes[:'reporting_date']
  end

  if attributes.key?(:'receipt_id')
    self.receipt_id = attributes[:'receipt_id']
  end
end

Instance Attribute Details

#amount_due ⇒ Object

The amount due to be paid for an expense claim



45
46
47
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 45

def amount_due
  @amount_due
end

#amount_paid ⇒ Object

The amount still to pay for an expense claim



48
49
50
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 48

def amount_paid
  @amount_paid
end

#expense_claim_id ⇒ Object

Xero generated unique identifier for an expense claim



19
20
21
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 19

def expense_claim_id
  @expense_claim_id
end

#payment_due_date ⇒ Object

The date when the expense claim is due to be paid YYYY-MM-DD



51
52
53
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 51

def payment_due_date
  @payment_due_date
end

#payments ⇒ Object

See Payments



30
31
32
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 30

def payments
  @payments
end

#receipt_id ⇒ Object

The Xero identifier for the Receipt e.g. e59a2c7f-1306-4078-a0f3-73537afcbba9



57
58
59
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 57

def receipt_id
  @receipt_id
end

#receipts ⇒ Object

Returns the value of attribute receipts.



36
37
38
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 36

def receipts
  @receipts
end

#reporting_date ⇒ Object

The date the expense claim will be reported in Xero YYYY-MM-DD



54
55
56
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 54

def reporting_date
  @reporting_date
end

#status ⇒ Object

Current status of an expense claim – see status types



22
23
24
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 22

def status
  @status
end

#total ⇒ Object

The total of an expense claim being paid



42
43
44
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 42

def total
  @total
end

#updated_date_utc ⇒ Object

Last modified date UTC format



39
40
41
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 39

def updated_date_utc
  @updated_date_utc
end

#user ⇒ Object

Returns the value of attribute user.



33
34
35
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 33

def user
  @user
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 82

def self.attribute_map
  {
    :'expense_claim_id' => :'ExpenseClaimID',
    :'status' => :'Status',
    :'payments' => :'Payments',
    :'user' => :'User',
    :'receipts' => :'Receipts',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'total' => :'Total',
    :'amount_due' => :'AmountDue',
    :'amount_paid' => :'AmountPaid',
    :'payment_due_date' => :'PaymentDueDate',
    :'reporting_date' => :'ReportingDate',
    :'receipt_id' => :'ReceiptID'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



244
245
246
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 244

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 100

def self.openapi_types
  {
    :'expense_claim_id' => :'String',
    :'status' => :'String',
    :'payments' => :'Array<Payment>',
    :'user' => :'User',
    :'receipts' => :'Array<Receipt>',
    :'updated_date_utc' => :'DateTime',
    :'total' => :'Float',
    :'amount_due' => :'Float',
    :'amount_paid' => :'Float',
    :'payment_due_date' => :'Date',
    :'reporting_date' => :'Date',
    :'receipt_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 212

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      expense_claim_id == o.expense_claim_id &&
      status == o.status &&
      payments == o.payments &&
      user == o.user &&
      receipts == o.receipts &&
      updated_date_utc == o.updated_date_utc &&
      total == o.total &&
      amount_due == o.amount_due &&
      amount_paid == o.amount_paid &&
      payment_due_date == o.payment_due_date &&
      reporting_date == o.reporting_date &&
      receipt_id == o.receipt_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 272

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 337

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 251

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


231
232
233
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 231

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



237
238
239
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 237

def hash
  [expense_claim_id, status, payments, user, receipts, updated_date_utc, total, amount_due, amount_paid, payment_due_date, reporting_date, receipt_id].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 187

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



352
353
354
355
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 352

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



317
318
319
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 317

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



323
324
325
326
327
328
329
330
331
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 323

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



311
312
313
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 311

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



194
195
196
197
198
# File 'lib/xero-ruby/models/accounting/expense_claim.rb', line 194

def valid?
  status_validator = EnumAttributeValidator.new('String', ["SUBMITTED", "AUTHORISED", "PAID", "VOIDED", "DELETED"])
  return false unless status_validator.valid?(@status)
  true
end