Class: XeroRuby::Accounting::Invoice

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/invoice.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

ACCPAY =
"ACCPAY".freeze
ACCPAYCREDIT =
"ACCPAYCREDIT".freeze
APOVERPAYMENT =
"APOVERPAYMENT".freeze
APPREPAYMENT =
"APPREPAYMENT".freeze
ACCREC =
"ACCREC".freeze
ACCRECCREDIT =
"ACCRECCREDIT".freeze
AROVERPAYMENT =
"AROVERPAYMENT".freeze
ARPREPAYMENT =
"ARPREPAYMENT".freeze
DRAFT =
"DRAFT".freeze
SUBMITTED =
"SUBMITTED".freeze
DELETED =
"DELETED".freeze
AUTHORISED =
"AUTHORISED".freeze
"PAID".freeze
VOIDED =
"VOIDED".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Invoice

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 258

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Invoice` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Invoice`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'contact')
    self.contact = attributes[:'contact']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'due_date')
    self.due_date = attributes[:'due_date']
  end

  if attributes.key?(:'line_amount_types')
    self.line_amount_types = attributes[:'line_amount_types']
  end

  if attributes.key?(:'invoice_number')
    self.invoice_number = attributes[:'invoice_number']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'branding_theme_id')
    self.branding_theme_id = attributes[:'branding_theme_id']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'currency_code')
    self.currency_code = attributes[:'currency_code']
  end

  if attributes.key?(:'currency_rate')
    self.currency_rate = attributes[:'currency_rate']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'sent_to_contact')
    self.sent_to_contact = attributes[:'sent_to_contact']
  end

  if attributes.key?(:'expected_payment_date')
    self.expected_payment_date = attributes[:'expected_payment_date']
  end

  if attributes.key?(:'planned_payment_date')
    self.planned_payment_date = attributes[:'planned_payment_date']
  end

  if attributes.key?(:'cis_deduction')
    self.cis_deduction = attributes[:'cis_deduction']
  end

  if attributes.key?(:'sub_total')
    self.sub_total = attributes[:'sub_total']
  end

  if attributes.key?(:'total_tax')
    self.total_tax = attributes[:'total_tax']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'total_discount')
    self.total_discount = attributes[:'total_discount']
  end

  if attributes.key?(:'invoice_id')
    self.invoice_id = attributes[:'invoice_id']
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  else
    self.has_attachments = false
  end

  if attributes.key?(:'is_discounted')
    self.is_discounted = attributes[:'is_discounted']
  end

  if attributes.key?(:'payments')
    if (value = attributes[:'payments']).is_a?(Array)
      self.payments = value
    end
  end

  if attributes.key?(:'prepayments')
    if (value = attributes[:'prepayments']).is_a?(Array)
      self.prepayments = value
    end
  end

  if attributes.key?(:'overpayments')
    if (value = attributes[:'overpayments']).is_a?(Array)
      self.overpayments = value
    end
  end

  if attributes.key?(:'amount_due')
    self.amount_due = attributes[:'amount_due']
  end

  if attributes.key?(:'amount_paid')
    self.amount_paid = attributes[:'amount_paid']
  end

  if attributes.key?(:'fully_paid_on_date')
    self.fully_paid_on_date = attributes[:'fully_paid_on_date']
  end

  if attributes.key?(:'amount_credited')
    self.amount_credited = attributes[:'amount_credited']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'credit_notes')
    if (value = attributes[:'credit_notes']).is_a?(Array)
      self.credit_notes = value
    end
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end

  if attributes.key?(:'has_errors')
    self.has_errors = attributes[:'has_errors']
  else
    self.has_errors = false
  end

  if attributes.key?(:'status_attribute_string')
    self.status_attribute_string = attributes[:'status_attribute_string']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end

  if attributes.key?(:'warnings')
    if (value = attributes[:'warnings']).is_a?(Array)
      self.warnings = value
    end
  end
end

Instance Attribute Details

#amount_credited ⇒ Object

Sum of all credit notes, over-payments and pre-payments applied to invoice



123
124
125
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 123

def amount_credited
  @amount_credited
end

#amount_due ⇒ Object

Amount remaining to be paid on invoice



114
115
116
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 114

def amount_due
  @amount_due
end

#amount_paid ⇒ Object

Sum of payments received for invoice



117
118
119
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 117

def amount_paid
  @amount_paid
end

#attachments ⇒ Object

Displays array of attachments from the API



132
133
134
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 132

def attachments
  @attachments
end

#branding_theme_id ⇒ Object

See BrandingThemes



51
52
53
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 51

def branding_theme_id
  @branding_theme_id
end

#cis_deduction ⇒ Object

CIS deduction for UK contractors



81
82
83
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 81

def cis_deduction
  @cis_deduction
end

#contact ⇒ Object

Returns the value of attribute contact.



30
31
32
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 30

def contact
  @contact
end

#credit_notes ⇒ Object

Details of credit notes that have been applied to an invoice



129
130
131
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 129

def credit_notes
  @credit_notes
end

#currency_code ⇒ Object

Returns the value of attribute currency_code.



57
58
59
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 57

def currency_code
  @currency_code
end

#currency_rate ⇒ Object

The currency rate for a multicurrency invoice. If no rate is specified, the XE.com day rate is used. (max length = [18].[6])



60
61
62
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 60

def currency_rate
  @currency_rate
end

#date ⇒ Object

Date invoice was issued – YYYY-MM-DD. If the Date element is not specified it will default to the current date based on the timezone setting of the organisation



36
37
38
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 36

def date
  @date
end

#due_date ⇒ Object

Date invoice is due – YYYY-MM-DD



39
40
41
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 39

def due_date
  @due_date
end

#expected_payment_date ⇒ Object

Shown on sales invoices (Accounts Receivable) when this has been set



75
76
77
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 75

def expected_payment_date
  @expected_payment_date
end

#fully_paid_on_date ⇒ Object

The date the invoice was fully paid. Only returned on fully paid invoices



120
121
122
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 120

def fully_paid_on_date
  @fully_paid_on_date
end

#has_attachments ⇒ Object

boolean to indicate if an invoice has an attachment



99
100
101
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 99

def has_attachments
  @has_attachments
end

#has_errors ⇒ Object

A boolean to indicate if a invoice has an validation errors



135
136
137
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 135

def has_errors
  @has_errors
end

#invoice_id ⇒ Object

Xero generated unique identifier for invoice



96
97
98
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 96

def invoice_id
  @invoice_id
end

#invoice_number ⇒ Object

ACCREC – Unique alpha numeric code identifying invoice (when missing will auto-generate from your Organisation Invoice Settings) (max length = 255)



45
46
47
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 45

def invoice_number
  @invoice_number
end

#is_discounted ⇒ Object

boolean to indicate if an invoice has a discount



102
103
104
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 102

def is_discounted
  @is_discounted
end

#line_amount_types ⇒ Object

Returns the value of attribute line_amount_types.



42
43
44
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 42

def line_amount_types
  @line_amount_types
end

#line_items ⇒ Object

See LineItems



33
34
35
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 33

def line_items
  @line_items
end

#overpayments ⇒ Object

See Overpayments



111
112
113
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 111

def overpayments
  @overpayments
end

#payments ⇒ Object

See Payments



105
106
107
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 105

def payments
  @payments
end

#planned_payment_date ⇒ Object

Shown on bills (Accounts Payable) when this has been set



78
79
80
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 78

def planned_payment_date
  @planned_payment_date
end

#prepayments ⇒ Object

See Prepayments



108
109
110
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 108

def prepayments
  @prepayments
end

#reference ⇒ Object

ACCREC only – additional reference number (max length = 255)



48
49
50
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 48

def reference
  @reference
end

#sent_to_contact ⇒ Object

Boolean to set whether the invoice in the Xero app should be marked as “sent”. This can be set only on invoices that have been approved



72
73
74
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 72

def sent_to_contact
  @sent_to_contact
end

#status ⇒ Object

See Invoice Status Codes



63
64
65
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 63

def status
  @status
end

#status_attribute_string ⇒ Object

A string to indicate if a invoice status



138
139
140
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 138

def status_attribute_string
  @status_attribute_string
end

#sub_total ⇒ Object

Total of invoice excluding taxes



84
85
86
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 84

def sub_total
  @sub_total
end

#total ⇒ Object

Total of Invoice tax inclusive (i.e. SubTotal + TotalTax). This will be ignored if it doesn’t equal the sum of the LineAmounts



90
91
92
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 90

def total
  @total
end

#total_discount ⇒ Object

Total of discounts applied on the invoice line items



93
94
95
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 93

def total_discount
  @total_discount
end

#total_tax ⇒ Object

Total tax on invoice



87
88
89
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 87

def total_tax
  @total_tax
end

#type ⇒ Object

See Invoice Types



19
20
21
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 19

def type
  @type
end

#updated_date_utc ⇒ Object

Last modified date UTC format



126
127
128
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 126

def updated_date_utc
  @updated_date_utc
end

#url ⇒ Object

URL link to a source document – shown as “Go to [appName]” in the Xero app



54
55
56
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 54

def url
  @url
end

#validation_errors ⇒ Object

Displays array of validation error messages from the API



141
142
143
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 141

def validation_errors
  @validation_errors
end

#warnings ⇒ Object

Displays array of warning messages from the API



144
145
146
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 144

def warnings
  @warnings
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 169

def self.attribute_map
  {
    :'type' => :'Type',
    :'contact' => :'Contact',
    :'line_items' => :'LineItems',
    :'date' => :'Date',
    :'due_date' => :'DueDate',
    :'line_amount_types' => :'LineAmountTypes',
    :'invoice_number' => :'InvoiceNumber',
    :'reference' => :'Reference',
    :'branding_theme_id' => :'BrandingThemeID',
    :'url' => :'Url',
    :'currency_code' => :'CurrencyCode',
    :'currency_rate' => :'CurrencyRate',
    :'status' => :'Status',
    :'sent_to_contact' => :'SentToContact',
    :'expected_payment_date' => :'ExpectedPaymentDate',
    :'planned_payment_date' => :'PlannedPaymentDate',
    :'cis_deduction' => :'CISDeduction',
    :'sub_total' => :'SubTotal',
    :'total_tax' => :'TotalTax',
    :'total' => :'Total',
    :'total_discount' => :'TotalDiscount',
    :'invoice_id' => :'InvoiceID',
    :'has_attachments' => :'HasAttachments',
    :'is_discounted' => :'IsDiscounted',
    :'payments' => :'Payments',
    :'prepayments' => :'Prepayments',
    :'overpayments' => :'Overpayments',
    :'amount_due' => :'AmountDue',
    :'amount_paid' => :'AmountPaid',
    :'fully_paid_on_date' => :'FullyPaidOnDate',
    :'amount_credited' => :'AmountCredited',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'credit_notes' => :'CreditNotes',
    :'attachments' => :'Attachments',
    :'has_errors' => :'HasErrors',
    :'status_attribute_string' => :'StatusAttributeString',
    :'validation_errors' => :'ValidationErrors',
    :'warnings' => :'Warnings'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



571
572
573
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 571

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 213

def self.openapi_types
  {
    :'type' => :'String',
    :'contact' => :'Contact',
    :'line_items' => :'Array<LineItem>',
    :'date' => :'Date',
    :'due_date' => :'Date',
    :'line_amount_types' => :'LineAmountTypes',
    :'invoice_number' => :'String',
    :'reference' => :'String',
    :'branding_theme_id' => :'String',
    :'url' => :'String',
    :'currency_code' => :'CurrencyCode',
    :'currency_rate' => :'Float',
    :'status' => :'String',
    :'sent_to_contact' => :'Boolean',
    :'expected_payment_date' => :'Date',
    :'planned_payment_date' => :'Date',
    :'cis_deduction' => :'Float',
    :'sub_total' => :'Float',
    :'total_tax' => :'Float',
    :'total' => :'Float',
    :'total_discount' => :'Float',
    :'invoice_id' => :'String',
    :'has_attachments' => :'Boolean',
    :'is_discounted' => :'Boolean',
    :'payments' => :'Array<Payment>',
    :'prepayments' => :'Array<Prepayment>',
    :'overpayments' => :'Array<Overpayment>',
    :'amount_due' => :'Float',
    :'amount_paid' => :'Float',
    :'fully_paid_on_date' => :'Date',
    :'amount_credited' => :'Float',
    :'updated_date_utc' => :'DateTime',
    :'credit_notes' => :'Array<CreditNote>',
    :'attachments' => :'Array<Attachment>',
    :'has_errors' => :'Boolean',
    :'status_attribute_string' => :'String',
    :'validation_errors' => :'Array<ValidationError>',
    :'warnings' => :'Array<ValidationError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 513

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      contact == o.contact &&
      line_items == o.line_items &&
      date == o.date &&
      due_date == o.due_date &&
      line_amount_types == o.line_amount_types &&
      invoice_number == o.invoice_number &&
      reference == o.reference &&
      branding_theme_id == o.branding_theme_id &&
      url == o.url &&
      currency_code == o.currency_code &&
      currency_rate == o.currency_rate &&
      status == o.status &&
      sent_to_contact == o.sent_to_contact &&
      expected_payment_date == o.expected_payment_date &&
      planned_payment_date == o.planned_payment_date &&
      cis_deduction == o.cis_deduction &&
      sub_total == o.sub_total &&
      total_tax == o.total_tax &&
      total == o.total &&
      total_discount == o.total_discount &&
      invoice_id == o.invoice_id &&
      has_attachments == o.has_attachments &&
      is_discounted == o.is_discounted &&
      payments == o.payments &&
      prepayments == o.prepayments &&
      overpayments == o.overpayments &&
      amount_due == o.amount_due &&
      amount_paid == o.amount_paid &&
      fully_paid_on_date == o.fully_paid_on_date &&
      amount_credited == o.amount_credited &&
      updated_date_utc == o.updated_date_utc &&
      credit_notes == o.credit_notes &&
      attachments == o.attachments &&
      has_errors == o.has_errors &&
      status_attribute_string == o.status_attribute_string &&
      validation_errors == o.validation_errors &&
      warnings == o.warnings
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 599

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 664

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 578

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


558
559
560
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 558

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



564
565
566
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 564

def hash
  [type, contact, line_items, date, due_date, line_amount_types, invoice_number, reference, branding_theme_id, url, currency_code, currency_rate, status, sent_to_contact, expected_payment_date, planned_payment_date, cis_deduction, sub_total, total_tax, total, total_discount, invoice_id, has_attachments, is_discounted, payments, prepayments, overpayments, amount_due, amount_paid, fully_paid_on_date, amount_credited, updated_date_utc, credit_notes, attachments, has_errors, status_attribute_string, validation_errors, warnings].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 446

def list_invalid_properties
  invalid_properties = Array.new
  if !@invoice_number.nil? && @invoice_number.to_s.length > 255
    invalid_properties.push('invalid value for "invoice_number", the character length must be smaller than or equal to 255.')
  end

  if !@reference.nil? && @reference.to_s.length > 255
    invalid_properties.push('invalid value for "reference", the character length must be smaller than or equal to 255.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



679
680
681
682
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 679

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



644
645
646
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 644

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



650
651
652
653
654
655
656
657
658
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 650

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



638
639
640
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 638

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



461
462
463
464
465
466
467
468
469
# File 'lib/xero-ruby/models/accounting/invoice.rb', line 461

def valid?
  type_validator = EnumAttributeValidator.new('String', ["ACCPAY", "ACCPAYCREDIT", "APOVERPAYMENT", "APPREPAYMENT", "ACCREC", "ACCRECCREDIT", "AROVERPAYMENT", "ARPREPAYMENT"])
  return false unless type_validator.valid?(@type)
  return false if !@invoice_number.nil? && @invoice_number.to_s.length > 255
  return false if !@reference.nil? && @reference.to_s.length > 255
  status_validator = EnumAttributeValidator.new('String', ["DRAFT", "SUBMITTED", "DELETED", "AUTHORISED", "PAID", "VOIDED"])
  return false unless status_validator.valid?(@status)
  true
end