Class: XeroRuby::Accounting::Item

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/item.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Item

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/xero-ruby/models/accounting/item.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Item` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Item`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'inventory_asset_account_code')
    self. = attributes[:'inventory_asset_account_code']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'is_sold')
    self.is_sold = attributes[:'is_sold']
  end

  if attributes.key?(:'is_purchased')
    self.is_purchased = attributes[:'is_purchased']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'purchase_description')
    self.purchase_description = attributes[:'purchase_description']
  end

  if attributes.key?(:'purchase_details')
    self.purchase_details = attributes[:'purchase_details']
  end

  if attributes.key?(:'sales_details')
    self.sales_details = attributes[:'sales_details']
  end

  if attributes.key?(:'is_tracked_as_inventory')
    self.is_tracked_as_inventory = attributes[:'is_tracked_as_inventory']
  end

  if attributes.key?(:'total_cost_pool')
    self.total_cost_pool = attributes[:'total_cost_pool']
  end

  if attributes.key?(:'quantity_on_hand')
    self.quantity_on_hand = attributes[:'quantity_on_hand']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'item_id')
    self.item_id = attributes[:'item_id']
  end

  if attributes.key?(:'status_attribute_string')
    self.status_attribute_string = attributes[:'status_attribute_string']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end
end

Instance Attribute Details

#code ⇒ Object

User defined item code (max length = 30)



19
20
21
# File 'lib/xero-ruby/models/accounting/item.rb', line 19

def code
  @code
end

#description ⇒ Object

The sales description of the item (max length = 4000)



34
35
36
# File 'lib/xero-ruby/models/accounting/item.rb', line 34

def description
  @description
end

#inventory_asset_account_code ⇒ Object

The inventory asset account for the item. The account must be of type INVENTORY. The COGSAccountCode in PurchaseDetails is also required to create a tracked item



22
23
24
# File 'lib/xero-ruby/models/accounting/item.rb', line 22

def 
  
end

#is_purchased ⇒ Object

Boolean value, defaults to true. When IsPurchased is true the item is available for purchase transactions in the Xero UI. If IsPurchased is updated to false then PurchaseDescription and PurchaseDetails values will be nulled.



31
32
33
# File 'lib/xero-ruby/models/accounting/item.rb', line 31

def is_purchased
  @is_purchased
end

#is_sold ⇒ Object

Boolean value, defaults to true. When IsSold is true the item will be available on sales transactions in the Xero UI. If IsSold is updated to false then Description and SalesDetails values will be nulled.



28
29
30
# File 'lib/xero-ruby/models/accounting/item.rb', line 28

def is_sold
  @is_sold
end

#is_tracked_as_inventory ⇒ Object

True for items that are tracked as inventory. An item will be tracked as inventory if the InventoryAssetAccountCode and COGSAccountCode are set.



46
47
48
# File 'lib/xero-ruby/models/accounting/item.rb', line 46

def is_tracked_as_inventory
  @is_tracked_as_inventory
end

#item_id ⇒ Object

The Xero identifier for an Item



58
59
60
# File 'lib/xero-ruby/models/accounting/item.rb', line 58

def item_id
  @item_id
end

#name ⇒ Object

The name of the item (max length = 50)



25
26
27
# File 'lib/xero-ruby/models/accounting/item.rb', line 25

def name
  @name
end

#purchase_description ⇒ Object

The purchase description of the item (max length = 4000)



37
38
39
# File 'lib/xero-ruby/models/accounting/item.rb', line 37

def purchase_description
  @purchase_description
end

#purchase_details ⇒ Object

Returns the value of attribute purchase_details.



40
41
42
# File 'lib/xero-ruby/models/accounting/item.rb', line 40

def purchase_details
  @purchase_details
end

#quantity_on_hand ⇒ Object

The quantity of the item on hand



52
53
54
# File 'lib/xero-ruby/models/accounting/item.rb', line 52

def quantity_on_hand
  @quantity_on_hand
end

#sales_details ⇒ Object

Returns the value of attribute sales_details.



43
44
45
# File 'lib/xero-ruby/models/accounting/item.rb', line 43

def sales_details
  @sales_details
end

#status_attribute_string ⇒ Object

Status of object



61
62
63
# File 'lib/xero-ruby/models/accounting/item.rb', line 61

def status_attribute_string
  @status_attribute_string
end

#total_cost_pool ⇒ Object

The value of the item on hand. Calculated using average cost accounting.



49
50
51
# File 'lib/xero-ruby/models/accounting/item.rb', line 49

def total_cost_pool
  @total_cost_pool
end

#updated_date_utc ⇒ Object

Last modified date in UTC format



55
56
57
# File 'lib/xero-ruby/models/accounting/item.rb', line 55

def updated_date_utc
  @updated_date_utc
end

#validation_errors ⇒ Object

Displays array of validation error messages from the API



64
65
66
# File 'lib/xero-ruby/models/accounting/item.rb', line 64

def validation_errors
  @validation_errors
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/xero-ruby/models/accounting/item.rb', line 67

def self.attribute_map
  {
    :'code' => :'Code',
    :'inventory_asset_account_code' => :'InventoryAssetAccountCode',
    :'name' => :'Name',
    :'is_sold' => :'IsSold',
    :'is_purchased' => :'IsPurchased',
    :'description' => :'Description',
    :'purchase_description' => :'PurchaseDescription',
    :'purchase_details' => :'PurchaseDetails',
    :'sales_details' => :'SalesDetails',
    :'is_tracked_as_inventory' => :'IsTrackedAsInventory',
    :'total_cost_pool' => :'TotalCostPool',
    :'quantity_on_hand' => :'QuantityOnHand',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'item_id' => :'ItemID',
    :'status_attribute_string' => :'StatusAttributeString',
    :'validation_errors' => :'ValidationErrors'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



312
313
314
# File 'lib/xero-ruby/models/accounting/item.rb', line 312

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/xero-ruby/models/accounting/item.rb', line 89

def self.openapi_types
  {
    :'code' => :'String',
    :'inventory_asset_account_code' => :'String',
    :'name' => :'String',
    :'is_sold' => :'Boolean',
    :'is_purchased' => :'Boolean',
    :'description' => :'String',
    :'purchase_description' => :'String',
    :'purchase_details' => :'Purchase',
    :'sales_details' => :'Purchase',
    :'is_tracked_as_inventory' => :'Boolean',
    :'total_cost_pool' => :'Float',
    :'quantity_on_hand' => :'Float',
    :'updated_date_utc' => :'DateTime',
    :'item_id' => :'String',
    :'status_attribute_string' => :'String',
    :'validation_errors' => :'Array<ValidationError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/xero-ruby/models/accounting/item.rb', line 276

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      code == o.code &&
       == o. &&
      name == o.name &&
      is_sold == o.is_sold &&
      is_purchased == o.is_purchased &&
      description == o.description &&
      purchase_description == o.purchase_description &&
      purchase_details == o.purchase_details &&
      sales_details == o.sales_details &&
      is_tracked_as_inventory == o.is_tracked_as_inventory &&
      total_cost_pool == o.total_cost_pool &&
      quantity_on_hand == o.quantity_on_hand &&
      updated_date_utc == o.updated_date_utc &&
      item_id == o.item_id &&
      status_attribute_string == o.status_attribute_string &&
      validation_errors == o.validation_errors
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/xero-ruby/models/accounting/item.rb', line 340

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/xero-ruby/models/accounting/item.rb', line 405

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/xero-ruby/models/accounting/item.rb', line 319

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


299
300
301
# File 'lib/xero-ruby/models/accounting/item.rb', line 299

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



305
306
307
# File 'lib/xero-ruby/models/accounting/item.rb', line 305

def hash
  [code, , name, is_sold, is_purchased, description, purchase_description, purchase_details, sales_details, is_tracked_as_inventory, total_cost_pool, quantity_on_hand, updated_date_utc, item_id, status_attribute_string, validation_errors].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/xero-ruby/models/accounting/item.rb', line 194

def list_invalid_properties
  invalid_properties = Array.new
  if @code.nil?
    invalid_properties.push('invalid value for "code", code cannot be nil.')
  end

  if @code.to_s.length > 30
    invalid_properties.push('invalid value for "code", the character length must be smaller than or equal to 30.')
  end

  if !@name.nil? && @name.to_s.length > 50
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 50.')
  end

  if !@description.nil? && @description.to_s.length > 4000
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 4000.')
  end

  if !@purchase_description.nil? && @purchase_description.to_s.length > 4000
    invalid_properties.push('invalid value for "purchase_description", the character length must be smaller than or equal to 4000.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



420
421
422
423
# File 'lib/xero-ruby/models/accounting/item.rb', line 420

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



385
386
387
# File 'lib/xero-ruby/models/accounting/item.rb', line 385

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



391
392
393
394
395
396
397
398
399
# File 'lib/xero-ruby/models/accounting/item.rb', line 391

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



379
380
381
# File 'lib/xero-ruby/models/accounting/item.rb', line 379

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



221
222
223
224
225
226
227
228
# File 'lib/xero-ruby/models/accounting/item.rb', line 221

def valid?
  return false if @code.nil?
  return false if @code.to_s.length > 30
  return false if !@name.nil? && @name.to_s.length > 50
  return false if !@description.nil? && @description.to_s.length > 4000
  return false if !@purchase_description.nil? && @purchase_description.to_s.length > 4000
  true
end