Class: XeroRuby::Accounting::JournalLine
- Inherits:
-
Object
- Object
- XeroRuby::Accounting::JournalLine
- Defined in:
- lib/xero-ruby/models/accounting/journal_line.rb
Instance Attribute Summary collapse
-
#account_code ⇒ Object
See Accounts.
-
#account_id ⇒ Object
See Accounts.
-
#account_name ⇒ Object
See AccountCodes.
-
#account_type ⇒ Object
Returns the value of attribute account_type.
-
#description ⇒ Object
The description from the source transaction line item.
-
#gross_amount ⇒ Object
Gross amount of journal line (NetAmount + TaxAmount).
-
#journal_line_id ⇒ Object
Xero identifier for Journal.
-
#net_amount ⇒ Object
Net amount of journal line.
-
#tax_amount ⇒ Object
Total tax on a journal line.
-
#tax_name ⇒ Object
see TaxRates.
-
#tax_type ⇒ Object
The tax type from TaxRates.
-
#tracking_categories ⇒ Object
Optional Tracking Category – see Tracking.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JournalLine
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ JournalLine
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::JournalLine` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::JournalLine`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'journal_line_id') self.journal_line_id = attributes[:'journal_line_id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'account_code') self.account_code = attributes[:'account_code'] end if attributes.key?(:'account_type') self.account_type = attributes[:'account_type'] end if attributes.key?(:'account_name') self.account_name = attributes[:'account_name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'net_amount') self.net_amount = attributes[:'net_amount'] end if attributes.key?(:'gross_amount') self.gross_amount = attributes[:'gross_amount'] end if attributes.key?(:'tax_amount') self.tax_amount = attributes[:'tax_amount'] end if attributes.key?(:'tax_type') self.tax_type = attributes[:'tax_type'] end if attributes.key?(:'tax_name') self.tax_name = attributes[:'tax_name'] end if attributes.key?(:'tracking_categories') if (value = attributes[:'tracking_categories']).is_a?(Array) self.tracking_categories = value end end end |
Instance Attribute Details
#account_code ⇒ Object
See Accounts
25 26 27 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 25 def account_code @account_code end |
#account_id ⇒ Object
See Accounts
22 23 24 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 22 def account_id @account_id end |
#account_name ⇒ Object
See AccountCodes
31 32 33 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 31 def account_name @account_name end |
#account_type ⇒ Object
Returns the value of attribute account_type.
28 29 30 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 28 def account_type @account_type end |
#description ⇒ Object
The description from the source transaction line item. Only returned if populated.
34 35 36 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 34 def description @description end |
#gross_amount ⇒ Object
Gross amount of journal line (NetAmount + TaxAmount).
40 41 42 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 40 def gross_amount @gross_amount end |
#journal_line_id ⇒ Object
Xero identifier for Journal
19 20 21 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 19 def journal_line_id @journal_line_id end |
#net_amount ⇒ Object
Net amount of journal line. This will be a positive value for a debit and negative for a credit
37 38 39 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 37 def net_amount @net_amount end |
#tax_amount ⇒ Object
Total tax on a journal line
43 44 45 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 43 def tax_amount @tax_amount end |
#tax_name ⇒ Object
see TaxRates
49 50 51 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 49 def tax_name @tax_name end |
#tax_type ⇒ Object
The tax type from TaxRates
46 47 48 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 46 def tax_type @tax_type end |
#tracking_categories ⇒ Object
Optional Tracking Category – see Tracking. Any JournalLine can have a maximum of 2
52 53 54 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 52 def tracking_categories @tracking_categories end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 55 def self.attribute_map { :'journal_line_id' => :'JournalLineID', :'account_id' => :'AccountID', :'account_code' => :'AccountCode', :'account_type' => :'AccountType', :'account_name' => :'AccountName', :'description' => :'Description', :'net_amount' => :'NetAmount', :'gross_amount' => :'GrossAmount', :'tax_amount' => :'TaxAmount', :'tax_type' => :'TaxType', :'tax_name' => :'TaxName', :'tracking_categories' => :'TrackingCategories' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 203 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 73 def self.openapi_types { :'journal_line_id' => :'String', :'account_id' => :'String', :'account_code' => :'String', :'account_type' => :'AccountType', :'account_name' => :'String', :'description' => :'String', :'net_amount' => :'Float', :'gross_amount' => :'Float', :'tax_amount' => :'Float', :'tax_type' => :'String', :'tax_name' => :'String', :'tracking_categories' => :'Array<TrackingCategory>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 171 def ==(o) return true if self.equal?(o) self.class == o.class && journal_line_id == o.journal_line_id && account_id == o.account_id && account_code == o.account_code && account_type == o.account_type && account_name == o.account_name && description == o.description && net_amount == o.net_amount && gross_amount == o.gross_amount && tax_amount == o.tax_amount && tax_type == o.tax_type && tax_name == o.tax_name && tracking_categories == o.tracking_categories end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 231 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::Accounting.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 296 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 210 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
190 191 192 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 190 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 196 def hash [journal_line_id, account_id, account_code, account_type, account_name, description, net_amount, gross_amount, tax_amount, tax_type, tax_name, tracking_categories].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 158 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
311 312 313 314 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 311 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
276 277 278 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 276 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
282 283 284 285 286 287 288 289 290 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 282 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
270 271 272 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 270 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 |
# File 'lib/xero-ruby/models/accounting/journal_line.rb', line 165 def valid? true end |