Class: XeroRuby::Accounting::ManualJournal

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/manual_journal.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

DRAFT =
"DRAFT".freeze
POSTED =
"POSTED".freeze
DELETED =
"DELETED".freeze
VOIDED =
"VOIDED".freeze
ARCHIVED =
"ARCHIVED".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ManualJournal

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 129

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::ManualJournal` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::ManualJournal`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'narration')
    self.narration = attributes[:'narration']
  end

  if attributes.key?(:'journal_lines')
    if (value = attributes[:'journal_lines']).is_a?(Array)
      self.journal_lines = value
    end
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'line_amount_types')
    self.line_amount_types = attributes[:'line_amount_types']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'show_on_cash_basis_reports')
    self.show_on_cash_basis_reports = attributes[:'show_on_cash_basis_reports']
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  else
    self.has_attachments = false
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'manual_journal_id')
    self.manual_journal_id = attributes[:'manual_journal_id']
  end

  if attributes.key?(:'status_attribute_string')
    self.status_attribute_string = attributes[:'status_attribute_string']
  end

  if attributes.key?(:'warnings')
    if (value = attributes[:'warnings']).is_a?(Array)
      self.warnings = value
    end
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end
end

Instance Attribute Details

#attachments ⇒ Object

Displays array of attachments from the API



63
64
65
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 63

def attachments
  @attachments
end

#date ⇒ Object

Date journal was posted – YYYY-MM-DD



25
26
27
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 25

def date
  @date
end

#has_attachments ⇒ Object

Boolean to indicate if a manual journal has an attachment



45
46
47
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 45

def has_attachments
  @has_attachments
end

#journal_lines ⇒ Object

See JournalLines



22
23
24
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 22

def journal_lines
  @journal_lines
end

#line_amount_types ⇒ Object

Returns the value of attribute line_amount_types.



28
29
30
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 28

def line_amount_types
  @line_amount_types
end

#manual_journal_id ⇒ Object

The Xero identifier for a Manual Journal



51
52
53
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 51

def manual_journal_id
  @manual_journal_id
end

#narration ⇒ Object

Description of journal being posted



19
20
21
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 19

def narration
  @narration
end

#show_on_cash_basis_reports ⇒ Object

Boolean – default is true if not specified



42
43
44
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 42

def show_on_cash_basis_reports
  @show_on_cash_basis_reports
end

#status ⇒ Object

See Manual Journal Status Codes



31
32
33
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 31

def status
  @status
end

#status_attribute_string ⇒ Object

A string to indicate if a invoice status



54
55
56
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 54

def status_attribute_string
  @status_attribute_string
end

#updated_date_utc ⇒ Object

Last modified date UTC format



48
49
50
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 48

def updated_date_utc
  @updated_date_utc
end

#url ⇒ Object

Url link to a source document – shown as “Go to [appName]” in the Xero app



39
40
41
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 39

def url
  @url
end

#validation_errors ⇒ Object

Displays array of validation error messages from the API



60
61
62
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 60

def validation_errors
  @validation_errors
end

#warnings ⇒ Object

Displays array of warning messages from the API



57
58
59
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 57

def warnings
  @warnings
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 88

def self.attribute_map
  {
    :'narration' => :'Narration',
    :'journal_lines' => :'JournalLines',
    :'date' => :'Date',
    :'line_amount_types' => :'LineAmountTypes',
    :'status' => :'Status',
    :'url' => :'Url',
    :'show_on_cash_basis_reports' => :'ShowOnCashBasisReports',
    :'has_attachments' => :'HasAttachments',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'manual_journal_id' => :'ManualJournalID',
    :'status_attribute_string' => :'StatusAttributeString',
    :'warnings' => :'Warnings',
    :'validation_errors' => :'ValidationErrors',
    :'attachments' => :'Attachments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



275
276
277
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 275

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 108

def self.openapi_types
  {
    :'narration' => :'String',
    :'journal_lines' => :'Array<ManualJournalLine>',
    :'date' => :'Date',
    :'line_amount_types' => :'LineAmountTypes',
    :'status' => :'String',
    :'url' => :'String',
    :'show_on_cash_basis_reports' => :'Boolean',
    :'has_attachments' => :'Boolean',
    :'updated_date_utc' => :'DateTime',
    :'manual_journal_id' => :'String',
    :'status_attribute_string' => :'String',
    :'warnings' => :'Array<ValidationError>',
    :'validation_errors' => :'Array<ValidationError>',
    :'attachments' => :'Array<Attachment>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 241

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      narration == o.narration &&
      journal_lines == o.journal_lines &&
      date == o.date &&
      line_amount_types == o.line_amount_types &&
      status == o.status &&
      url == o.url &&
      show_on_cash_basis_reports == o.show_on_cash_basis_reports &&
      has_attachments == o.has_attachments &&
      updated_date_utc == o.updated_date_utc &&
      manual_journal_id == o.manual_journal_id &&
      status_attribute_string == o.status_attribute_string &&
      warnings == o.warnings &&
      validation_errors == o.validation_errors &&
      attachments == o.attachments
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 303

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 368

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 282

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 262

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



268
269
270
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 268

def hash
  [narration, journal_lines, date, line_amount_types, status, url, show_on_cash_basis_reports, has_attachments, updated_date_utc, manual_journal_id, status_attribute_string, warnings, validation_errors, attachments].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



211
212
213
214
215
216
217
218
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 211

def list_invalid_properties
  invalid_properties = Array.new
  if @narration.nil?
    invalid_properties.push('invalid value for "narration", narration cannot be nil.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



383
384
385
386
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 383

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



348
349
350
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 348

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



354
355
356
357
358
359
360
361
362
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 354

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



342
343
344
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 342

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



222
223
224
225
226
227
# File 'lib/xero-ruby/models/accounting/manual_journal.rb', line 222

def valid?
  return false if @narration.nil?
  status_validator = EnumAttributeValidator.new('String', ["DRAFT", "POSTED", "DELETED", "VOIDED", "ARCHIVED"])
  return false unless status_validator.valid?(@status)
  true
end