Class: XeroRuby::Accounting::Organisation
- Inherits:
-
Object
- Object
- XeroRuby::Accounting::Organisation
- Defined in:
- lib/xero-ruby/models/accounting/organisation.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_class ⇒ Object
Organisation Classes describe which plan the Xero organisation is on (e.g. DEMO, TRIAL, PREMIUM).
-
#addresses ⇒ Object
Address details for organisation – see Addresses.
-
#api_key ⇒ Object
Display a unique key used for Xero-to-Xero transactions.
-
#base_currency ⇒ Object
Returns the value of attribute base_currency.
-
#country_code ⇒ Object
Returns the value of attribute country_code.
-
#created_date_utc ⇒ Object
Timestamp when the organisation was created in Xero.
-
#default_purchases_tax ⇒ Object
The default for LineAmountTypes on purchase transactions.
-
#default_sales_tax ⇒ Object
The default for LineAmountTypes on sales transactions.
-
#edition ⇒ Object
BUSINESS or PARTNER.
-
#employer_identification_number ⇒ Object
Shown if set.
-
#end_of_year_lock_date ⇒ Object
Shown if set.
-
#external_links ⇒ Object
Organisation profile links for popular services such as Facebook,Twitter, GooglePlus and LinkedIn.
-
#financial_year_end_day ⇒ Object
Calendar day e.g.
-
#financial_year_end_month ⇒ Object
Calendar Month e.g.
-
#is_demo_company ⇒ Object
Boolean to describe if organisation is a demo company.
-
#legal_name ⇒ Object
Organisation name shown on Reports.
-
#line_of_business ⇒ Object
Description of business type as defined in Organisation settings.
-
#name ⇒ Object
Display name of organisation shown in Xero.
-
#organisation_entity_type ⇒ Object
Organisation Entity Type.
-
#organisation_id ⇒ Object
Unique Xero identifier.
-
#organisation_status ⇒ Object
Will be set to ACTIVE if you can connect to organisation via the Xero API.
-
#organisation_type ⇒ Object
Organisation Type.
-
#payment_terms ⇒ Object
Returns the value of attribute payment_terms.
-
#pays_tax ⇒ Object
Boolean to describe if organisation is registered with a local tax authority i.e.
-
#period_lock_date ⇒ Object
Shown if set.
-
#phones ⇒ Object
Phones details for organisation – see Phones.
-
#registration_number ⇒ Object
Shows for New Zealand, Australian and UK organisations.
-
#sales_tax_basis ⇒ Object
The accounting basis used for tax returns.
-
#sales_tax_period ⇒ Object
The frequency with which tax returns are processed.
-
#short_code ⇒ Object
A unique identifier for the organisation.
-
#tax_number ⇒ Object
Shown if set.
-
#timezone ⇒ Object
Returns the value of attribute timezone.
-
#version ⇒ Object
See Version Types.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value, downcase: false) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Organisation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
- #parse_date(datestring) ⇒ Object
-
#to_attributes ⇒ Object
Returns the object in the form of hash with snake_case.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash(downcase: false) ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Organisation
Initializes the object
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 318 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Organisation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Organisation`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'organisation_id') self.organisation_id = attributes[:'organisation_id'] end if attributes.key?(:'api_key') self.api_key = attributes[:'api_key'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'legal_name') self.legal_name = attributes[:'legal_name'] end if attributes.key?(:'pays_tax') self.pays_tax = attributes[:'pays_tax'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'organisation_type') self.organisation_type = attributes[:'organisation_type'] end if attributes.key?(:'base_currency') self.base_currency = attributes[:'base_currency'] end if attributes.key?(:'country_code') self.country_code = attributes[:'country_code'] end if attributes.key?(:'is_demo_company') self.is_demo_company = attributes[:'is_demo_company'] end if attributes.key?(:'organisation_status') self.organisation_status = attributes[:'organisation_status'] end if attributes.key?(:'registration_number') self.registration_number = attributes[:'registration_number'] end if attributes.key?(:'employer_identification_number') self.employer_identification_number = attributes[:'employer_identification_number'] end if attributes.key?(:'tax_number') self.tax_number = attributes[:'tax_number'] end if attributes.key?(:'financial_year_end_day') self.financial_year_end_day = attributes[:'financial_year_end_day'] end if attributes.key?(:'financial_year_end_month') self.financial_year_end_month = attributes[:'financial_year_end_month'] end if attributes.key?(:'sales_tax_basis') self.sales_tax_basis = attributes[:'sales_tax_basis'] end if attributes.key?(:'sales_tax_period') self.sales_tax_period = attributes[:'sales_tax_period'] end if attributes.key?(:'default_sales_tax') self.default_sales_tax = attributes[:'default_sales_tax'] end if attributes.key?(:'default_purchases_tax') self.default_purchases_tax = attributes[:'default_purchases_tax'] end if attributes.key?(:'period_lock_date') self.period_lock_date = attributes[:'period_lock_date'] end if attributes.key?(:'end_of_year_lock_date') self.end_of_year_lock_date = attributes[:'end_of_year_lock_date'] end if attributes.key?(:'created_date_utc') self.created_date_utc = attributes[:'created_date_utc'] end if attributes.key?(:'timezone') self.timezone = attributes[:'timezone'] end if attributes.key?(:'organisation_entity_type') self.organisation_entity_type = attributes[:'organisation_entity_type'] end if attributes.key?(:'short_code') self.short_code = attributes[:'short_code'] end if attributes.key?(:'_class') self._class = attributes[:'_class'] end if attributes.key?(:'edition') self.edition = attributes[:'edition'] end if attributes.key?(:'line_of_business') self.line_of_business = attributes[:'line_of_business'] end if attributes.key?(:'addresses') if (value = attributes[:'addresses']).is_a?(Array) self.addresses = value end end if attributes.key?(:'phones') if (value = attributes[:'phones']).is_a?(Array) self.phones = value end end if attributes.key?(:'external_links') if (value = attributes[:'external_links']).is_a?(Array) self.external_links = value end end if attributes.key?(:'payment_terms') self.payment_terms = attributes[:'payment_terms'] end end |
Instance Attribute Details
#_class ⇒ Object
Organisation Classes describe which plan the Xero organisation is on (e.g. DEMO, TRIAL, PREMIUM)
173 174 175 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 173 def _class @_class end |
#addresses ⇒ Object
Address details for organisation – see Addresses
205 206 207 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 205 def addresses @addresses end |
#api_key ⇒ Object
Display a unique key used for Xero-to-Xero transactions
23 24 25 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 23 def api_key @api_key end |
#base_currency ⇒ Object
Returns the value of attribute base_currency.
72 73 74 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 72 def base_currency @base_currency end |
#country_code ⇒ Object
Returns the value of attribute country_code.
75 76 77 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 75 def country_code @country_code end |
#created_date_utc ⇒ Object
Timestamp when the organisation was created in Xero
140 141 142 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 140 def created_date_utc @created_date_utc end |
#default_purchases_tax ⇒ Object
The default for LineAmountTypes on purchase transactions
131 132 133 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 131 def default_purchases_tax @default_purchases_tax end |
#default_sales_tax ⇒ Object
The default for LineAmountTypes on sales transactions
128 129 130 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 128 def default_sales_tax @default_sales_tax end |
#edition ⇒ Object
BUSINESS or PARTNER. Partner edition organisations are sold exclusively through accounting partners and have restricted functionality (e.g. no access to invoicing)
197 198 199 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 197 def edition @edition end |
#employer_identification_number ⇒ Object
Shown if set. US Only.
87 88 89 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 87 def employer_identification_number @employer_identification_number end |
#end_of_year_lock_date ⇒ Object
Shown if set. See lock dates
137 138 139 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 137 def end_of_year_lock_date @end_of_year_lock_date end |
#external_links ⇒ Object
Organisation profile links for popular services such as Facebook,Twitter, GooglePlus and LinkedIn. You can also add link to your website here. Shown if Organisation settings is updated in Xero. See ExternalLinks below
211 212 213 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 211 def external_links @external_links end |
#financial_year_end_day ⇒ Object
Calendar day e.g. 0-31
93 94 95 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 93 def financial_year_end_day @financial_year_end_day end |
#financial_year_end_month ⇒ Object
Calendar Month e.g. 1-12
96 97 98 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 96 def financial_year_end_month @financial_year_end_month end |
#is_demo_company ⇒ Object
Boolean to describe if organisation is a demo company.
78 79 80 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 78 def is_demo_company @is_demo_company end |
#legal_name ⇒ Object
Organisation name shown on Reports
29 30 31 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 29 def legal_name @legal_name end |
#line_of_business ⇒ Object
Description of business type as defined in Organisation settings
202 203 204 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 202 def line_of_business @line_of_business end |
#name ⇒ Object
Display name of organisation shown in Xero
26 27 28 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 26 def name @name end |
#organisation_entity_type ⇒ Object
Organisation Entity Type
146 147 148 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 146 def organisation_entity_type @organisation_entity_type end |
#organisation_id ⇒ Object
Unique Xero identifier
20 21 22 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 20 def organisation_id @organisation_id end |
#organisation_status ⇒ Object
Will be set to ACTIVE if you can connect to organisation via the Xero API
81 82 83 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 81 def organisation_status @organisation_status end |
#organisation_type ⇒ Object
Organisation Type
48 49 50 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 48 def organisation_type @organisation_type end |
#payment_terms ⇒ Object
Returns the value of attribute payment_terms.
214 215 216 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 214 def payment_terms @payment_terms end |
#pays_tax ⇒ Object
Boolean to describe if organisation is registered with a local tax authority i.e. true, false
32 33 34 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 32 def pays_tax @pays_tax end |
#period_lock_date ⇒ Object
Shown if set. See lock dates
134 135 136 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 134 def period_lock_date @period_lock_date end |
#phones ⇒ Object
Phones details for organisation – see Phones
208 209 210 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 208 def phones @phones end |
#registration_number ⇒ Object
Shows for New Zealand, Australian and UK organisations
84 85 86 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 84 def registration_number @registration_number end |
#sales_tax_basis ⇒ Object
The accounting basis used for tax returns. See Sales Tax Basis
99 100 101 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 99 def sales_tax_basis @sales_tax_basis end |
#sales_tax_period ⇒ Object
The frequency with which tax returns are processed. See Sales Tax Period
110 111 112 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 110 def sales_tax_period @sales_tax_period end |
#short_code ⇒ Object
A unique identifier for the organisation. Potential uses.
170 171 172 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 170 def short_code @short_code end |
#tax_number ⇒ Object
Shown if set. Displays in the Xero UI as Tax File Number (AU), GST Number (NZ), VAT Number (UK) and Tax ID Number (US & Global).
90 91 92 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 90 def tax_number @tax_number end |
#timezone ⇒ Object
Returns the value of attribute timezone.
143 144 145 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 143 def timezone @timezone end |
#version ⇒ Object
See Version Types
35 36 37 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 35 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 239 def self.attribute_map { :'organisation_id' => :'OrganisationID', :'api_key' => :'APIKey', :'name' => :'Name', :'legal_name' => :'LegalName', :'pays_tax' => :'PaysTax', :'version' => :'Version', :'organisation_type' => :'OrganisationType', :'base_currency' => :'BaseCurrency', :'country_code' => :'CountryCode', :'is_demo_company' => :'IsDemoCompany', :'organisation_status' => :'OrganisationStatus', :'registration_number' => :'RegistrationNumber', :'employer_identification_number' => :'EmployerIdentificationNumber', :'tax_number' => :'TaxNumber', :'financial_year_end_day' => :'FinancialYearEndDay', :'financial_year_end_month' => :'FinancialYearEndMonth', :'sales_tax_basis' => :'SalesTaxBasis', :'sales_tax_period' => :'SalesTaxPeriod', :'default_sales_tax' => :'DefaultSalesTax', :'default_purchases_tax' => :'DefaultPurchasesTax', :'period_lock_date' => :'PeriodLockDate', :'end_of_year_lock_date' => :'EndOfYearLockDate', :'created_date_utc' => :'CreatedDateUTC', :'timezone' => :'Timezone', :'organisation_entity_type' => :'OrganisationEntityType', :'short_code' => :'ShortCode', :'_class' => :'Class', :'edition' => :'Edition', :'line_of_business' => :'LineOfBusiness', :'addresses' => :'Addresses', :'phones' => :'Phones', :'external_links' => :'ExternalLinks', :'payment_terms' => :'PaymentTerms' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
622 623 624 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 622 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 278 def self.openapi_types { :'organisation_id' => :'String', :'api_key' => :'String', :'name' => :'String', :'legal_name' => :'String', :'pays_tax' => :'Boolean', :'version' => :'String', :'organisation_type' => :'String', :'base_currency' => :'CurrencyCode', :'country_code' => :'CountryCode', :'is_demo_company' => :'Boolean', :'organisation_status' => :'String', :'registration_number' => :'String', :'employer_identification_number' => :'String', :'tax_number' => :'String', :'financial_year_end_day' => :'Integer', :'financial_year_end_month' => :'Integer', :'sales_tax_basis' => :'String', :'sales_tax_period' => :'String', :'default_sales_tax' => :'String', :'default_purchases_tax' => :'String', :'period_lock_date' => :'Date', :'end_of_year_lock_date' => :'Date', :'created_date_utc' => :'DateTime', :'timezone' => :'TimeZone', :'organisation_entity_type' => :'String', :'short_code' => :'String', :'_class' => :'String', :'edition' => :'String', :'line_of_business' => :'String', :'addresses' => :'Array<AddressForOrganisation>', :'phones' => :'Array<Phone>', :'external_links' => :'Array<ExternalLink>', :'payment_terms' => :'PaymentTerm' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 569 def ==(o) return true if self.equal?(o) self.class == o.class && organisation_id == o.organisation_id && api_key == o.api_key && name == o.name && legal_name == o.legal_name && pays_tax == o.pays_tax && version == o.version && organisation_type == o.organisation_type && base_currency == o.base_currency && country_code == o.country_code && is_demo_company == o.is_demo_company && organisation_status == o.organisation_status && registration_number == o.registration_number && employer_identification_number == o.employer_identification_number && tax_number == o.tax_number && financial_year_end_day == o.financial_year_end_day && financial_year_end_month == o.financial_year_end_month && sales_tax_basis == o.sales_tax_basis && sales_tax_period == o.sales_tax_period && default_sales_tax == o.default_sales_tax && default_purchases_tax == o.default_purchases_tax && period_lock_date == o.period_lock_date && end_of_year_lock_date == o.end_of_year_lock_date && created_date_utc == o.created_date_utc && timezone == o.timezone && organisation_entity_type == o.organisation_entity_type && short_code == o.short_code && _class == o._class && edition == o.edition && line_of_business == o.line_of_business && addresses == o.addresses && phones == o.phones && external_links == o.external_links && payment_terms == o.payment_terms end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 650 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::Accounting.const_get(type).build_from_hash(value) end end |
#_to_hash(value, downcase: false) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 723 def _to_hash(value, downcase: false) if value.is_a?(Array) value.map do |v| v.to_hash(downcase: downcase) end elsif value.is_a?(Hash) {}.tap do |hash| value.map { |k, v| hash[k] = _to_hash(v, downcase: downcase) } end elsif value.respond_to? :to_hash value.to_hash(downcase: downcase) else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 629 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
609 610 611 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 609 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
615 616 617 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 615 def hash [organisation_id, api_key, name, legal_name, pays_tax, version, organisation_type, base_currency, country_code, is_demo_company, organisation_status, registration_number, employer_identification_number, tax_number, financial_year_end_day, financial_year_end_month, sales_tax_basis, sales_tax_period, default_sales_tax, default_purchases_tax, period_lock_date, end_of_year_lock_date, created_date_utc, timezone, organisation_entity_type, short_code, _class, edition, line_of_business, addresses, phones, external_links, payment_terms].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
472 473 474 475 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 472 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 739 def parse_date(datestring) if datestring.include?('Date') date_pattern = /\/Date\((-?\d+)(\+\d+)?\)\// original, date, timezone = *date_pattern.match(datestring) date = (date.to_i / 1000) Time.at(date).utc.strftime('%Y-%m-%dT%H:%M:%S%z').to_s elsif /(\d\d\d\d)-(\d\d)/.match(datestring) # handles dates w/out Days: YYYY-MM*-DD Time.parse(datestring + '-01').strftime('%Y-%m-%dT%H:%M:%S').to_s else # handle date 'types' for small subset of payroll API's Time.parse(datestring).strftime('%Y-%m-%dT%H:%M:%S').to_s end end |
#to_attributes ⇒ Object
Returns the object in the form of hash with snake_case
715 716 717 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 715 def to_attributes to_hash(downcase: true) end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
697 698 699 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 697 def to_body to_hash end |
#to_hash(downcase: false) ⇒ Hash
Returns the object in the form of hash
703 704 705 706 707 708 709 710 711 712 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 703 def to_hash(downcase: false) hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? key = downcase ? attr : param hash[key] = _to_hash(value, downcase: downcase) end hash end |
#to_s ⇒ String
Returns the string representation of the object
691 692 693 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 691 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 |
# File 'lib/xero-ruby/models/accounting/organisation.rb', line 479 def valid? version_validator = EnumAttributeValidator.new('String', ["AU", "NZ", "GLOBAL", "UK", "US", "AUONRAMP", "NZONRAMP", "GLOBALONRAMP", "UKONRAMP", "USONRAMP"]) return false unless version_validator.valid?(@version) organisation_type_validator = EnumAttributeValidator.new('String', ["ACCOUNTING_PRACTICE", "COMPANY", "CHARITY", "CLUB_OR_SOCIETY", "INDIVIDUAL", "LOOK_THROUGH_COMPANY", "NOT_FOR_PROFIT", "PARTNERSHIP", "S_CORPORATION", "SELF_MANAGED_SUPERANNUATION_FUND", "SOLE_TRADER", "SUPERANNUATION_FUND", "TRUST", "PERSONAL", "SINGLEMEMBERLLC", "CCORPORATIONLLC", "PARTNERSHIPLLC", "SCORPORATIONLLC", "LLC", "NOTLLC", "UNSPECIFIED"]) return false unless organisation_type_validator.valid?(@organisation_type) sales_tax_basis_validator = EnumAttributeValidator.new('String', ["PAYMENTS", "INVOICE", "NONE", "CASH", "ACCRUAL", "FLATRATECASH", "FLATRATEACCRUAL", "ACCRUALS"]) return false unless sales_tax_basis_validator.valid?(@sales_tax_basis) sales_tax_period_validator = EnumAttributeValidator.new('String', ["MONTHLY", "QUARTERLY1", "QUARTERLY2", "QUARTERLY3", "ANNUALLY", "ONEMONTHS", "TWOMONTHS", "SIXMONTHS", "1MONTHLY", "2MONTHLY", "3MONTHLY", "6MONTHLY", "QUARTERLY", "YEARLY", "NONE"]) return false unless sales_tax_period_validator.valid?(@sales_tax_period) organisation_entity_type_validator = EnumAttributeValidator.new('String', ["ACCOUNTING_PRACTICE", "COMPANY", "CHARITY", "CLUB_OR_SOCIETY", "INDIVIDUAL", "LOOK_THROUGH_COMPANY", "NOT_FOR_PROFIT", "PARTNERSHIP", "S_CORPORATION", "SELF_MANAGED_SUPERANNUATION_FUND", "SOLE_TRADER", "SUPERANNUATION_FUND", "TRUST", "PERSONAL", "SINGLEMEMBERLLC", "CCORPORATIONLLC", "PARTNERSHIPLLC", "SCORPORATIONLLC", "LLC", "NOTLLC", "UNSPECIFIED"]) return false unless organisation_entity_type_validator.valid?(@organisation_entity_type) _class_validator = EnumAttributeValidator.new('String', ["DEMO", "TRIAL", "STARTER", "STANDARD", "PREMIUM", "PREMIUM_20", "PREMIUM_50", "PREMIUM_100", "LEDGER", "GST_CASHBOOK", "NON_GST_CASHBOOK", "ULTIMATE", "LITE", "ULTIMATE_10", "ULTIMATE_20", "ULTIMATE_50", "ULTIMATE_100", "IGNITE", "GROW", "COMPREHENSIVE", "SIMPLE"]) return false unless _class_validator.valid?(@_class) edition_validator = EnumAttributeValidator.new('String', ["BUSINESS", "PARTNER"]) return false unless edition_validator.valid?(@edition) true end |