Class: XeroRuby::Accounting::Overpayment

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/overpayment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Overpayment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 166

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Overpayment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Overpayment`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'contact')
    self.contact = attributes[:'contact']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'line_amount_types')
    self.line_amount_types = attributes[:'line_amount_types']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'sub_total')
    self.sub_total = attributes[:'sub_total']
  end

  if attributes.key?(:'total_tax')
    self.total_tax = attributes[:'total_tax']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'updated_date_utc_string')
    self.updated_date_utc_string = attributes[:'updated_date_utc_string']
  end

  if attributes.key?(:'currency_code')
    self.currency_code = attributes[:'currency_code']
  end

  if attributes.key?(:'overpayment_id')
    self.overpayment_id = attributes[:'overpayment_id']
  end

  if attributes.key?(:'currency_rate')
    self.currency_rate = attributes[:'currency_rate']
  end

  if attributes.key?(:'remaining_credit')
    self.remaining_credit = attributes[:'remaining_credit']
  end

  if attributes.key?(:'allocations')
    if (value = attributes[:'allocations']).is_a?(Array)
      self.allocations = value
    end
  end

  if attributes.key?(:'applied_amount')
    self.applied_amount = attributes[:'applied_amount']
  end

  if attributes.key?(:'payments')
    if (value = attributes[:'payments']).is_a?(Array)
      self.payments = value
    end
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  else
    self.has_attachments = false
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end
end

Instance Attribute Details

#allocationsObject

See Allocations



71
72
73
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 71

def allocations
  @allocations
end

#applied_amountObject

The amount of applied to an invoice



74
75
76
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 74

def applied_amount
  @applied_amount
end

#attachmentsObject

See Attachments



86
87
88
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 86

def attachments
  @attachments
end

#contactObject

Returns the value of attribute contact.



26
27
28
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 26

def contact
  @contact
end

#currency_codeObject

Returns the value of attribute currency_code.



59
60
61
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 59

def currency_code
  @currency_code
end

#currency_rateObject

The currency rate for a multicurrency overpayment. If no rate is specified, the XE.com day rate is used



65
66
67
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 65

def currency_rate
  @currency_rate
end

#dateObject

The date the overpayment is created YYYY-MM-DD



29
30
31
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 29

def date
  @date
end

#has_attachmentsObject

boolean to indicate if a overpayment has an attachment



80
81
82
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 80

def has_attachments
  @has_attachments
end

#line_amount_typesObject

Returns the value of attribute line_amount_types.



38
39
40
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 38

def line_amount_types
  @line_amount_types
end

#line_itemsObject

See Overpayment Line Items



41
42
43
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 41

def line_items
  @line_items
end

#overpayment_idObject

Xero generated unique identifier



62
63
64
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 62

def overpayment_id
  @overpayment_id
end

#paymentsObject

See Payments



77
78
79
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 77

def payments
  @payments
end

#referenceObject

An optional description for Overpayment



83
84
85
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 83

def reference
  @reference
end

#remaining_creditObject

The remaining credit balance on the overpayment



68
69
70
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 68

def remaining_credit
  @remaining_credit
end

#statusObject

See Overpayment Status Codes



32
33
34
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 32

def status
  @status
end

#sub_totalObject

The subtotal of the overpayment excluding taxes



44
45
46
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 44

def sub_total
  @sub_total
end

#totalObject

The total of the overpayment (subtotal + total tax)



50
51
52
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 50

def total
  @total
end

#total_taxObject

The total tax on the overpayment



47
48
49
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 47

def total_tax
  @total_tax
end

#typeObject

See Overpayment Types



20
21
22
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 20

def type
  @type
end

#updated_date_utcObject

UTC timestamp of last update to the overpayment



53
54
55
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 53

def updated_date_utc
  @updated_date_utc
end

#updated_date_utc_stringObject

UTC ISO-8601 formatted timestamp of last update to the overpayment



56
57
58
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 56

def updated_date_utc_string
  @updated_date_utc_string
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 111

def self.attribute_map
  {
    :'type' => :'Type',
    :'contact' => :'Contact',
    :'date' => :'Date',
    :'status' => :'Status',
    :'line_amount_types' => :'LineAmountTypes',
    :'line_items' => :'LineItems',
    :'sub_total' => :'SubTotal',
    :'total_tax' => :'TotalTax',
    :'total' => :'Total',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'updated_date_utc_string' => :'UpdatedDateUTCString',
    :'currency_code' => :'CurrencyCode',
    :'overpayment_id' => :'OverpaymentID',
    :'currency_rate' => :'CurrencyRate',
    :'remaining_credit' => :'RemainingCredit',
    :'allocations' => :'Allocations',
    :'applied_amount' => :'AppliedAmount',
    :'payments' => :'Payments',
    :'has_attachments' => :'HasAttachments',
    :'reference' => :'Reference',
    :'attachments' => :'Attachments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



354
355
356
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 354

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 138

def self.openapi_types
  {
    :'type' => :'String',
    :'contact' => :'Contact',
    :'date' => :'Date',
    :'status' => :'String',
    :'line_amount_types' => :'LineAmountTypes',
    :'line_items' => :'Array<LineItem>',
    :'sub_total' => :'BigDecimal',
    :'total_tax' => :'BigDecimal',
    :'total' => :'BigDecimal',
    :'updated_date_utc' => :'DateTime',
    :'updated_date_utc_string' => :'String',
    :'currency_code' => :'CurrencyCode',
    :'overpayment_id' => :'String',
    :'currency_rate' => :'BigDecimal',
    :'remaining_credit' => :'BigDecimal',
    :'allocations' => :'Array<Allocation>',
    :'applied_amount' => :'Float',
    :'payments' => :'Array<Payment>',
    :'has_attachments' => :'Boolean',
    :'reference' => :'String',
    :'attachments' => :'Array<Attachment>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 313

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      contact == o.contact &&
      date == o.date &&
      status == o.status &&
      line_amount_types == o.line_amount_types &&
      line_items == o.line_items &&
      sub_total == o.sub_total &&
      total_tax == o.total_tax &&
      total == o.total &&
      updated_date_utc == o.updated_date_utc &&
      updated_date_utc_string == o.updated_date_utc_string &&
      currency_code == o.currency_code &&
      overpayment_id == o.overpayment_id &&
      currency_rate == o.currency_rate &&
      remaining_credit == o.remaining_credit &&
      allocations == o.allocations &&
      applied_amount == o.applied_amount &&
      payments == o.payments &&
      has_attachments == o.has_attachments &&
      reference == o.reference &&
      attachments == o.attachments
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 382

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BigDecimal
    BigDecimal(value.to_s)
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value, downcase: false) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 455

def _to_hash(value, downcase: false)
  if value.is_a?(Array)
    value.map do |v|
      v.to_hash(downcase: downcase)
    end
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.map { |k, v| hash[k] = _to_hash(v, downcase: downcase) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash(downcase: downcase)
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 361

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


341
342
343
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 341

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



347
348
349
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 347

def hash
  [type, contact, date, status, line_amount_types, line_items, sub_total, total_tax, total, updated_date_utc, updated_date_utc_string, currency_code, overpayment_id, currency_rate, remaining_credit, allocations, applied_amount, payments, has_attachments, reference, attachments].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



276
277
278
279
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 276

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object



471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 471

def parse_date(datestring)
  if datestring.include?('Date')
    date_pattern = /\/Date\((-?\d+)(\+\d+)?\)\//
    original, date, timezone = *date_pattern.match(datestring)
    date = (date.to_i / 1000)
    Time.at(date).utc.strftime('%Y-%m-%dT%H:%M:%S%z').to_s
  elsif /(\d\d\d\d)-(\d\d)/.match(datestring) # handles dates w/out Days: YYYY-MM*-DD
    Time.parse(datestring + '-01').strftime('%Y-%m-%dT%H:%M:%S').to_s
  else # handle date 'types' for small subset of payroll API's
    Time.parse(datestring).strftime('%Y-%m-%dT%H:%M:%S').to_s
  end
end

#to_attributesObject

Returns the object in the form of hash with snake_case



447
448
449
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 447

def to_attributes
  to_hash(downcase: true)
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



429
430
431
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 429

def to_body
  to_hash
end

#to_hash(downcase: false) ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



435
436
437
438
439
440
441
442
443
444
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 435

def to_hash(downcase: false)
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    key = downcase ? attr : param
    hash[key] = _to_hash(value, downcase: downcase)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



423
424
425
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 423

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



283
284
285
286
287
288
289
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 283

def valid?
  type_validator = EnumAttributeValidator.new('String', ["RECEIVE-OVERPAYMENT", "SPEND-OVERPAYMENT", "AROVERPAYMENT"])
  return false unless type_validator.valid?(@type)
  status_validator = EnumAttributeValidator.new('String', ["AUTHORISED", "PAID", "VOIDED"])
  return false unless status_validator.valid?(@status)
  true
end