Class: XeroRuby::Accounting::Payment

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/payment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Payment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/xero-ruby/models/accounting/payment.rb', line 210

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Payment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Payment`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'invoice')
    self.invoice = attributes[:'invoice']
  end

  if attributes.key?(:'credit_note')
    self.credit_note = attributes[:'credit_note']
  end

  if attributes.key?(:'prepayment')
    self.prepayment = attributes[:'prepayment']
  end

  if attributes.key?(:'overpayment')
    self.overpayment = attributes[:'overpayment']
  end

  if attributes.key?(:'invoice_number')
    self.invoice_number = attributes[:'invoice_number']
  end

  if attributes.key?(:'credit_note_number')
    self.credit_note_number = attributes[:'credit_note_number']
  end

  if attributes.key?(:'batch_payment')
    self.batch_payment = attributes[:'batch_payment']
  end

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'currency_rate')
    self.currency_rate = attributes[:'currency_rate']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'bank_amount')
    self.bank_amount = attributes[:'bank_amount']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'is_reconciled')
    self.is_reconciled = attributes[:'is_reconciled']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'payment_type')
    self.payment_type = attributes[:'payment_type']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'updated_date_utc_string')
    self.updated_date_utc_string = attributes[:'updated_date_utc_string']
  end

  if attributes.key?(:'payment_id')
    self.payment_id = attributes[:'payment_id']
  end

  if attributes.key?(:'batch_payment_id')
    self.batch_payment_id = attributes[:'batch_payment_id']
  end

  if attributes.key?(:'bank_account_number')
    self. = attributes[:'bank_account_number']
  end

  if attributes.key?(:'particulars')
    self.particulars = attributes[:'particulars']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'has_account')
    self. = attributes[:'has_account']
  else
    self. = false
  end

  if attributes.key?(:'has_validation_errors')
    self.has_validation_errors = attributes[:'has_validation_errors']
  else
    self.has_validation_errors = false
  end

  if attributes.key?(:'status_attribute_string')
    self.status_attribute_string = attributes[:'status_attribute_string']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end

  if attributes.key?(:'warnings')
    if (value = attributes[:'warnings']).is_a?(Array)
      self.warnings = value
    end
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



41
42
43
# File 'lib/xero-ruby/models/accounting/payment.rb', line 41

def 
  @account
end

#amountObject

The amount of the payment. Must be less than or equal to the outstanding amount owing on the invoice e.g. 200.00



53
54
55
# File 'lib/xero-ruby/models/accounting/payment.rb', line 53

def amount
  @amount
end

#bank_account_numberObject

The suppliers bank account number the payment is being made to



93
94
95
# File 'lib/xero-ruby/models/accounting/payment.rb', line 93

def 
  @bank_account_number
end

#bank_amountObject

The amount of the payment in the currency of the bank account.



56
57
58
# File 'lib/xero-ruby/models/accounting/payment.rb', line 56

def bank_amount
  @bank_amount
end

#batch_paymentObject

Returns the value of attribute batch_payment.



38
39
40
# File 'lib/xero-ruby/models/accounting/payment.rb', line 38

def batch_payment
  @batch_payment
end

#batch_payment_idObject

Present if the payment was created as part of a batch.



90
91
92
# File 'lib/xero-ruby/models/accounting/payment.rb', line 90

def batch_payment_id
  @batch_payment_id
end

#codeObject

Code of account you are using to make the payment e.g. 001 (note- not all accounts have a code value)



44
45
46
# File 'lib/xero-ruby/models/accounting/payment.rb', line 44

def code
  @code
end

#credit_noteObject

Returns the value of attribute credit_note.



23
24
25
# File 'lib/xero-ruby/models/accounting/payment.rb', line 23

def credit_note
  @credit_note
end

#credit_note_numberObject

Number of invoice or credit note you are applying payment to e.g. INV-4003



35
36
37
# File 'lib/xero-ruby/models/accounting/payment.rb', line 35

def credit_note_number
  @credit_note_number
end

#currency_rateObject

Exchange rate when payment is received. Only used for non base currency invoices and credit notes e.g. 0.7500



50
51
52
# File 'lib/xero-ruby/models/accounting/payment.rb', line 50

def currency_rate
  @currency_rate
end

#dateObject

Date the payment is being made (YYYY-MM-DD) e.g. 2009-09-06



47
48
49
# File 'lib/xero-ruby/models/accounting/payment.rb', line 47

def date
  @date
end

#detailsObject

The information to appear on the supplier's bank account



99
100
101
# File 'lib/xero-ruby/models/accounting/payment.rb', line 99

def details
  @details
end

#has_accountObject

A boolean to indicate if a contact has an validation errors



102
103
104
# File 'lib/xero-ruby/models/accounting/payment.rb', line 102

def 
  @has_account
end

#has_validation_errorsObject

A boolean to indicate if a contact has an validation errors



105
106
107
# File 'lib/xero-ruby/models/accounting/payment.rb', line 105

def has_validation_errors
  @has_validation_errors
end

#invoiceObject

Returns the value of attribute invoice.



20
21
22
# File 'lib/xero-ruby/models/accounting/payment.rb', line 20

def invoice
  @invoice
end

#invoice_numberObject

Number of invoice or credit note you are applying payment to e.g.INV-4003



32
33
34
# File 'lib/xero-ruby/models/accounting/payment.rb', line 32

def invoice_number
  @invoice_number
end

#is_reconciledObject

An optional parameter for the payment. A boolean indicating whether you would like the payment to be created as reconciled when using PUT, or whether a payment has been reconciled when using GET



62
63
64
# File 'lib/xero-ruby/models/accounting/payment.rb', line 62

def is_reconciled
  @is_reconciled
end

#overpaymentObject

Returns the value of attribute overpayment.



29
30
31
# File 'lib/xero-ruby/models/accounting/payment.rb', line 29

def overpayment
  @overpayment
end

#particularsObject

The suppliers bank account number the payment is being made to



96
97
98
# File 'lib/xero-ruby/models/accounting/payment.rb', line 96

def particulars
  @particulars
end

#payment_idObject

The Xero identifier for an Payment e.g. 297c2dc5-cc47-4afd-8ec8-74990b8761e9



87
88
89
# File 'lib/xero-ruby/models/accounting/payment.rb', line 87

def payment_id
  @payment_id
end

#payment_typeObject

See Payment Types.



70
71
72
# File 'lib/xero-ruby/models/accounting/payment.rb', line 70

def payment_type
  @payment_type
end

#prepaymentObject

Returns the value of attribute prepayment.



26
27
28
# File 'lib/xero-ruby/models/accounting/payment.rb', line 26

def prepayment
  @prepayment
end

#referenceObject

An optional description for the payment e.g. Direct Debit



59
60
61
# File 'lib/xero-ruby/models/accounting/payment.rb', line 59

def reference
  @reference
end

#statusObject

The status of the payment.



65
66
67
# File 'lib/xero-ruby/models/accounting/payment.rb', line 65

def status
  @status
end

#status_attribute_stringObject

A string to indicate if a invoice status



108
109
110
# File 'lib/xero-ruby/models/accounting/payment.rb', line 108

def status_attribute_string
  @status_attribute_string
end

#updated_date_utcObject

UTC timestamp of last update to the payment



81
82
83
# File 'lib/xero-ruby/models/accounting/payment.rb', line 81

def updated_date_utc
  @updated_date_utc
end

#updated_date_utc_stringObject

UTC ISO-8601 formatted timestamp of last update to the payment



84
85
86
# File 'lib/xero-ruby/models/accounting/payment.rb', line 84

def updated_date_utc_string
  @updated_date_utc_string
end

#validation_errorsObject

Displays array of validation error messages from the API



111
112
113
# File 'lib/xero-ruby/models/accounting/payment.rb', line 111

def validation_errors
  @validation_errors
end

#warningsObject

Displays array of warning messages from the API



114
115
116
# File 'lib/xero-ruby/models/accounting/payment.rb', line 114

def warnings
  @warnings
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/xero-ruby/models/accounting/payment.rb', line 139

def self.attribute_map
  {
    :'invoice' => :'Invoice',
    :'credit_note' => :'CreditNote',
    :'prepayment' => :'Prepayment',
    :'overpayment' => :'Overpayment',
    :'invoice_number' => :'InvoiceNumber',
    :'credit_note_number' => :'CreditNoteNumber',
    :'batch_payment' => :'BatchPayment',
    :'account' => :'Account',
    :'code' => :'Code',
    :'date' => :'Date',
    :'currency_rate' => :'CurrencyRate',
    :'amount' => :'Amount',
    :'bank_amount' => :'BankAmount',
    :'reference' => :'Reference',
    :'is_reconciled' => :'IsReconciled',
    :'status' => :'Status',
    :'payment_type' => :'PaymentType',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'updated_date_utc_string' => :'UpdatedDateUTCString',
    :'payment_id' => :'PaymentID',
    :'batch_payment_id' => :'BatchPaymentID',
    :'bank_account_number' => :'BankAccountNumber',
    :'particulars' => :'Particulars',
    :'details' => :'Details',
    :'has_account' => :'HasAccount',
    :'has_validation_errors' => :'HasValidationErrors',
    :'status_attribute_string' => :'StatusAttributeString',
    :'validation_errors' => :'ValidationErrors',
    :'warnings' => :'Warnings'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



436
437
438
# File 'lib/xero-ruby/models/accounting/payment.rb', line 436

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/xero-ruby/models/accounting/payment.rb', line 174

def self.openapi_types
  {
    :'invoice' => :'Invoice',
    :'credit_note' => :'CreditNote',
    :'prepayment' => :'Prepayment',
    :'overpayment' => :'Overpayment',
    :'invoice_number' => :'String',
    :'credit_note_number' => :'String',
    :'batch_payment' => :'BatchPayment',
    :'account' => :'Account',
    :'code' => :'String',
    :'date' => :'Date',
    :'currency_rate' => :'BigDecimal',
    :'amount' => :'BigDecimal',
    :'bank_amount' => :'BigDecimal',
    :'reference' => :'String',
    :'is_reconciled' => :'Boolean',
    :'status' => :'String',
    :'payment_type' => :'String',
    :'updated_date_utc' => :'DateTime',
    :'updated_date_utc_string' => :'String',
    :'payment_id' => :'String',
    :'batch_payment_id' => :'String',
    :'bank_account_number' => :'String',
    :'particulars' => :'String',
    :'details' => :'String',
    :'has_account' => :'Boolean',
    :'has_validation_errors' => :'Boolean',
    :'status_attribute_string' => :'String',
    :'validation_errors' => :'Array<ValidationError>',
    :'warnings' => :'Array<ValidationError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/xero-ruby/models/accounting/payment.rb', line 387

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      invoice == o.invoice &&
      credit_note == o.credit_note &&
      prepayment == o.prepayment &&
      overpayment == o.overpayment &&
      invoice_number == o.invoice_number &&
      credit_note_number == o.credit_note_number &&
      batch_payment == o.batch_payment &&
       == o. &&
      code == o.code &&
      date == o.date &&
      currency_rate == o.currency_rate &&
      amount == o.amount &&
      bank_amount == o.bank_amount &&
      reference == o.reference &&
      is_reconciled == o.is_reconciled &&
      status == o.status &&
      payment_type == o.payment_type &&
      updated_date_utc == o.updated_date_utc &&
      updated_date_utc_string == o.updated_date_utc_string &&
      payment_id == o.payment_id &&
      batch_payment_id == o.batch_payment_id &&
       == o. &&
      particulars == o.particulars &&
      details == o.details &&
       == o. &&
      has_validation_errors == o.has_validation_errors &&
      status_attribute_string == o.status_attribute_string &&
      validation_errors == o.validation_errors &&
      warnings == o.warnings
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/xero-ruby/models/accounting/payment.rb', line 464

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BigDecimal
    BigDecimal(value.to_s)
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value, downcase: false) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
# File 'lib/xero-ruby/models/accounting/payment.rb', line 537

def _to_hash(value, downcase: false)
  if value.is_a?(Array)
    value.map do |v|
      v.to_hash(downcase: downcase)
    end
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.map { |k, v| hash[k] = _to_hash(v, downcase: downcase) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash(downcase: downcase)
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/xero-ruby/models/accounting/payment.rb', line 443

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


423
424
425
# File 'lib/xero-ruby/models/accounting/payment.rb', line 423

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



429
430
431
# File 'lib/xero-ruby/models/accounting/payment.rb', line 429

def hash
  [invoice, credit_note, prepayment, overpayment, invoice_number, credit_note_number, batch_payment, , code, date, currency_rate, amount, bank_amount, reference, is_reconciled, status, payment_type, updated_date_utc, updated_date_utc_string, payment_id, batch_payment_id, , particulars, details, , has_validation_errors, status_attribute_string, validation_errors, warnings].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



350
351
352
353
# File 'lib/xero-ruby/models/accounting/payment.rb', line 350

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object



553
554
555
556
557
558
559
560
561
562
563
564
# File 'lib/xero-ruby/models/accounting/payment.rb', line 553

def parse_date(datestring)
  if datestring.include?('Date')
    date_pattern = /\/Date\((-?\d+)(\+\d+)?\)\//
    original, date, timezone = *date_pattern.match(datestring)
    date = (date.to_i / 1000)
    Time.at(date).utc.strftime('%Y-%m-%dT%H:%M:%S%z').to_s
  elsif /(\d\d\d\d)-(\d\d)/.match(datestring) # handles dates w/out Days: YYYY-MM*-DD
    Time.parse(datestring + '-01').strftime('%Y-%m-%dT%H:%M:%S').to_s
  else # handle date 'types' for small subset of payroll API's
    Time.parse(datestring).strftime('%Y-%m-%dT%H:%M:%S').to_s
  end
end

#to_attributesObject

Returns the object in the form of hash with snake_case



529
530
531
# File 'lib/xero-ruby/models/accounting/payment.rb', line 529

def to_attributes
  to_hash(downcase: true)
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



511
512
513
# File 'lib/xero-ruby/models/accounting/payment.rb', line 511

def to_body
  to_hash
end

#to_hash(downcase: false) ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



517
518
519
520
521
522
523
524
525
526
# File 'lib/xero-ruby/models/accounting/payment.rb', line 517

def to_hash(downcase: false)
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    key = downcase ? attr : param
    hash[key] = _to_hash(value, downcase: downcase)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



505
506
507
# File 'lib/xero-ruby/models/accounting/payment.rb', line 505

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



357
358
359
360
361
362
363
# File 'lib/xero-ruby/models/accounting/payment.rb', line 357

def valid?
  status_validator = EnumAttributeValidator.new('String', ["AUTHORISED", "DELETED"])
  return false unless status_validator.valid?(@status)
  payment_type_validator = EnumAttributeValidator.new('String', ["ACCRECPAYMENT", "ACCPAYPAYMENT", "ARCREDITPAYMENT", "APCREDITPAYMENT", "AROVERPAYMENTPAYMENT", "ARPREPAYMENTPAYMENT", "APPREPAYMENTPAYMENT", "APOVERPAYMENTPAYMENT"])
  return false unless payment_type_validator.valid?(@payment_type)
  true
end