Class: XeroRuby::Accounting::Quote

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/quote.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Quote

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/xero-ruby/models/accounting/quote.rb', line 152

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Quote` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Quote`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'quote_id')
    self.quote_id = attributes[:'quote_id']
  end

  if attributes.key?(:'quote_number')
    self.quote_number = attributes[:'quote_number']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'terms')
    self.terms = attributes[:'terms']
  end

  if attributes.key?(:'contact')
    self.contact = attributes[:'contact']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'date_string')
    self.date_string = attributes[:'date_string']
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  end

  if attributes.key?(:'expiry_date_string')
    self.expiry_date_string = attributes[:'expiry_date_string']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'currency_code')
    self.currency_code = attributes[:'currency_code']
  end

  if attributes.key?(:'currency_rate')
    self.currency_rate = attributes[:'currency_rate']
  end

  if attributes.key?(:'sub_total')
    self.sub_total = attributes[:'sub_total']
  end

  if attributes.key?(:'total_tax')
    self.total_tax = attributes[:'total_tax']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'total_discount')
    self.total_discount = attributes[:'total_discount']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'summary')
    self.summary = attributes[:'summary']
  end

  if attributes.key?(:'branding_theme_id')
    self.branding_theme_id = attributes[:'branding_theme_id']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'line_amount_types')
    self.line_amount_types = attributes[:'line_amount_types']
  end

  if attributes.key?(:'status_attribute_string')
    self.status_attribute_string = attributes[:'status_attribute_string']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end
end

Instance Attribute Details

#branding_theme_id ⇒ Object

See BrandingThemes



76
77
78
# File 'lib/xero-ruby/models/accounting/quote.rb', line 76

def branding_theme_id
  @branding_theme_id
end

#contact ⇒ Object

Returns the value of attribute contact.



31
32
33
# File 'lib/xero-ruby/models/accounting/quote.rb', line 31

def contact
  @contact
end

#currency_code ⇒ Object

Returns the value of attribute currency_code.



52
53
54
# File 'lib/xero-ruby/models/accounting/quote.rb', line 52

def currency_code
  @currency_code
end

#currency_rate ⇒ Object

The currency rate for a multicurrency quote



55
56
57
# File 'lib/xero-ruby/models/accounting/quote.rb', line 55

def currency_rate
  @currency_rate
end

#date ⇒ Object

Date quote was issued – YYYY-MM-DD. If the Date element is not specified it will default to the current date based on the timezone setting of the organisation



37
38
39
# File 'lib/xero-ruby/models/accounting/quote.rb', line 37

def date
  @date
end

#date_string ⇒ Object

Date the quote was issued (YYYY-MM-DD)



40
41
42
# File 'lib/xero-ruby/models/accounting/quote.rb', line 40

def date_string
  @date_string
end

#expiry_date ⇒ Object

Date the quote expires – YYYY-MM-DD.



43
44
45
# File 'lib/xero-ruby/models/accounting/quote.rb', line 43

def expiry_date
  @expiry_date
end

#expiry_date_string ⇒ Object

Date the quote expires – YYYY-MM-DD.



46
47
48
# File 'lib/xero-ruby/models/accounting/quote.rb', line 46

def expiry_date_string
  @expiry_date_string
end

#line_amount_types ⇒ Object

Returns the value of attribute line_amount_types.



82
83
84
# File 'lib/xero-ruby/models/accounting/quote.rb', line 82

def line_amount_types
  @line_amount_types
end

#line_items ⇒ Object

See LineItems



34
35
36
# File 'lib/xero-ruby/models/accounting/quote.rb', line 34

def line_items
  @line_items
end

#quote_id ⇒ Object

QuoteID GUID is automatically generated and is returned after create or GET.



19
20
21
# File 'lib/xero-ruby/models/accounting/quote.rb', line 19

def quote_id
  @quote_id
end

#quote_number ⇒ Object

Unique alpha numeric code identifying a quote (Max Length = 255)



22
23
24
# File 'lib/xero-ruby/models/accounting/quote.rb', line 22

def quote_number
  @quote_number
end

#reference ⇒ Object

Additional reference number



25
26
27
# File 'lib/xero-ruby/models/accounting/quote.rb', line 25

def reference
  @reference
end

#status ⇒ Object

Returns the value of attribute status.



49
50
51
# File 'lib/xero-ruby/models/accounting/quote.rb', line 49

def status
  @status
end

#status_attribute_string ⇒ Object

A string to indicate if a invoice status



85
86
87
# File 'lib/xero-ruby/models/accounting/quote.rb', line 85

def status_attribute_string
  @status_attribute_string
end

#sub_total ⇒ Object

Total of quote excluding taxes.



58
59
60
# File 'lib/xero-ruby/models/accounting/quote.rb', line 58

def sub_total
  @sub_total
end

#summary ⇒ Object

Summary text for the quote



73
74
75
# File 'lib/xero-ruby/models/accounting/quote.rb', line 73

def summary
  @summary
end

#terms ⇒ Object

Terms of the quote



28
29
30
# File 'lib/xero-ruby/models/accounting/quote.rb', line 28

def terms
  @terms
end

#title ⇒ Object

Title text for the quote



70
71
72
# File 'lib/xero-ruby/models/accounting/quote.rb', line 70

def title
  @title
end

#total ⇒ Object

Total of Quote tax inclusive (i.e. SubTotal + TotalTax). This will be ignored if it doesn’t equal the sum of the LineAmounts



64
65
66
# File 'lib/xero-ruby/models/accounting/quote.rb', line 64

def total
  @total
end

#total_discount ⇒ Object

Total of discounts applied on the quote line items



67
68
69
# File 'lib/xero-ruby/models/accounting/quote.rb', line 67

def total_discount
  @total_discount
end

#total_tax ⇒ Object

Total tax on quote



61
62
63
# File 'lib/xero-ruby/models/accounting/quote.rb', line 61

def total_tax
  @total_tax
end

#updated_date_utc ⇒ Object

Last modified date UTC format



79
80
81
# File 'lib/xero-ruby/models/accounting/quote.rb', line 79

def updated_date_utc
  @updated_date_utc
end

#validation_errors ⇒ Object

Displays array of validation error messages from the API



88
89
90
# File 'lib/xero-ruby/models/accounting/quote.rb', line 88

def validation_errors
  @validation_errors
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/xero-ruby/models/accounting/quote.rb', line 91

def self.attribute_map
  {
    :'quote_id' => :'QuoteID',
    :'quote_number' => :'QuoteNumber',
    :'reference' => :'Reference',
    :'terms' => :'Terms',
    :'contact' => :'Contact',
    :'line_items' => :'LineItems',
    :'date' => :'Date',
    :'date_string' => :'DateString',
    :'expiry_date' => :'ExpiryDate',
    :'expiry_date_string' => :'ExpiryDateString',
    :'status' => :'Status',
    :'currency_code' => :'CurrencyCode',
    :'currency_rate' => :'CurrencyRate',
    :'sub_total' => :'SubTotal',
    :'total_tax' => :'TotalTax',
    :'total' => :'Total',
    :'total_discount' => :'TotalDiscount',
    :'title' => :'Title',
    :'summary' => :'Summary',
    :'branding_theme_id' => :'BrandingThemeID',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'line_amount_types' => :'LineAmountTypes',
    :'status_attribute_string' => :'StatusAttributeString',
    :'validation_errors' => :'ValidationErrors'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



400
401
402
# File 'lib/xero-ruby/models/accounting/quote.rb', line 400

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/xero-ruby/models/accounting/quote.rb', line 121

def self.openapi_types
  {
    :'quote_id' => :'String',
    :'quote_number' => :'String',
    :'reference' => :'String',
    :'terms' => :'String',
    :'contact' => :'Contact',
    :'line_items' => :'Array<LineItem>',
    :'date' => :'Date',
    :'date_string' => :'String',
    :'expiry_date' => :'Date',
    :'expiry_date_string' => :'String',
    :'status' => :'QuoteStatusCodes',
    :'currency_code' => :'CurrencyCode',
    :'currency_rate' => :'Float',
    :'sub_total' => :'Float',
    :'total_tax' => :'Float',
    :'total' => :'Float',
    :'total_discount' => :'Float',
    :'title' => :'String',
    :'summary' => :'String',
    :'branding_theme_id' => :'String',
    :'updated_date_utc' => :'DateTime',
    :'line_amount_types' => :'QuoteLineAmountTypes',
    :'status_attribute_string' => :'String',
    :'validation_errors' => :'Array<ValidationError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/xero-ruby/models/accounting/quote.rb', line 356

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      quote_id == o.quote_id &&
      quote_number == o.quote_number &&
      reference == o.reference &&
      terms == o.terms &&
      contact == o.contact &&
      line_items == o.line_items &&
      date == o.date &&
      date_string == o.date_string &&
      expiry_date == o.expiry_date &&
      expiry_date_string == o.expiry_date_string &&
      status == o.status &&
      currency_code == o.currency_code &&
      currency_rate == o.currency_rate &&
      sub_total == o.sub_total &&
      total_tax == o.total_tax &&
      total == o.total &&
      total_discount == o.total_discount &&
      title == o.title &&
      summary == o.summary &&
      branding_theme_id == o.branding_theme_id &&
      updated_date_utc == o.updated_date_utc &&
      line_amount_types == o.line_amount_types &&
      status_attribute_string == o.status_attribute_string &&
      validation_errors == o.validation_errors
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/xero-ruby/models/accounting/quote.rb', line 428

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/xero-ruby/models/accounting/quote.rb', line 493

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/xero-ruby/models/accounting/quote.rb', line 407

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


387
388
389
# File 'lib/xero-ruby/models/accounting/quote.rb', line 387

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



393
394
395
# File 'lib/xero-ruby/models/accounting/quote.rb', line 393

def hash
  [quote_id, quote_number, reference, terms, contact, line_items, date, date_string, expiry_date, expiry_date_string, status, currency_code, currency_rate, sub_total, total_tax, total, total_discount, title, summary, branding_theme_id, updated_date_utc, line_amount_types, status_attribute_string, validation_errors].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/xero-ruby/models/accounting/quote.rb', line 268

def list_invalid_properties
  invalid_properties = Array.new
  if !@quote_number.nil? && @quote_number.to_s.length > 255
    invalid_properties.push('invalid value for "quote_number", the character length must be smaller than or equal to 255.')
  end

  if !@reference.nil? && @reference.to_s.length > 4000
    invalid_properties.push('invalid value for "reference", the character length must be smaller than or equal to 4000.')
  end

  if !@terms.nil? && @terms.to_s.length > 4000
    invalid_properties.push('invalid value for "terms", the character length must be smaller than or equal to 4000.')
  end

  if !@title.nil? && @title.to_s.length > 100
    invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 100.')
  end

  if !@summary.nil? && @summary.to_s.length > 3000
    invalid_properties.push('invalid value for "summary", the character length must be smaller than or equal to 3000.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



508
509
510
511
# File 'lib/xero-ruby/models/accounting/quote.rb', line 508

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



473
474
475
# File 'lib/xero-ruby/models/accounting/quote.rb', line 473

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



479
480
481
482
483
484
485
486
487
# File 'lib/xero-ruby/models/accounting/quote.rb', line 479

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



467
468
469
# File 'lib/xero-ruby/models/accounting/quote.rb', line 467

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



295
296
297
298
299
300
301
302
# File 'lib/xero-ruby/models/accounting/quote.rb', line 295

def valid?
  return false if !@quote_number.nil? && @quote_number.to_s.length > 255
  return false if !@reference.nil? && @reference.to_s.length > 4000
  return false if !@terms.nil? && @terms.to_s.length > 4000
  return false if !@title.nil? && @title.to_s.length > 100
  return false if !@summary.nil? && @summary.to_s.length > 3000
  true
end