Class: XeroRuby::Accounting::Receipt

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/receipt.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

DRAFT =
"DRAFT".freeze
SUBMITTED =
"SUBMITTED".freeze
AUTHORISED =
"AUTHORISED".freeze
DECLINED =
"DECLINED".freeze
VOIDED =
"VOIDED".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Receipt

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 149

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Receipt` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Receipt`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'contact')
    self.contact = attributes[:'contact']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'line_amount_types')
    self.line_amount_types = attributes[:'line_amount_types']
  end

  if attributes.key?(:'sub_total')
    self.sub_total = attributes[:'sub_total']
  end

  if attributes.key?(:'total_tax')
    self.total_tax = attributes[:'total_tax']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'receipt_id')
    self.receipt_id = attributes[:'receipt_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'receipt_number')
    self.receipt_number = attributes[:'receipt_number']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  else
    self.has_attachments = false
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end

  if attributes.key?(:'warnings')
    if (value = attributes[:'warnings']).is_a?(Array)
      self.warnings = value
    end
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end
end

Instance Attribute Details

#attachments ⇒ Object

Displays array of attachments from the API



75
76
77
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 75

def attachments
  @attachments
end

#contact ⇒ Object

Returns the value of attribute contact.



22
23
24
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 22

def contact
  @contact
end

#date ⇒ Object

Date of receipt – YYYY-MM-DD



19
20
21
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 19

def date
  @date
end

#has_attachments ⇒ Object

boolean to indicate if a receipt has an attachment



63
64
65
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 63

def has_attachments
  @has_attachments
end

#line_amount_types ⇒ Object

Returns the value of attribute line_amount_types.



34
35
36
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 34

def line_amount_types
  @line_amount_types
end

#line_items ⇒ Object

Returns the value of attribute line_items.



25
26
27
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 25

def line_items
  @line_items
end

#receipt_id ⇒ Object

Xero generated unique identifier for receipt



46
47
48
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 46

def receipt_id
  @receipt_id
end

#receipt_number ⇒ Object

Xero generated sequence number for receipt in current claim for a given user



57
58
59
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 57

def receipt_number
  @receipt_number
end

#reference ⇒ Object

Additional reference number



31
32
33
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 31

def reference
  @reference
end

#status ⇒ Object

Current status of receipt – see status types



49
50
51
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 49

def status
  @status
end

#sub_total ⇒ Object

Total of receipt excluding taxes



37
38
39
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 37

def sub_total
  @sub_total
end

#total ⇒ Object

Total of receipt tax inclusive (i.e. SubTotal + TotalTax)



43
44
45
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 43

def total
  @total
end

#total_tax ⇒ Object

Total tax on receipt



40
41
42
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 40

def total_tax
  @total_tax
end

#updated_date_utc ⇒ Object

Last modified date UTC format



60
61
62
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 60

def updated_date_utc
  @updated_date_utc
end

#url ⇒ Object

URL link to a source document – shown as “Go to [appName]” in the Xero app



66
67
68
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 66

def url
  @url
end

#user ⇒ Object

Returns the value of attribute user.



28
29
30
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 28

def user
  @user
end

#validation_errors ⇒ Object

Displays array of validation error messages from the API



69
70
71
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 69

def validation_errors
  @validation_errors
end

#warnings ⇒ Object

Displays array of warning messages from the API



72
73
74
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 72

def warnings
  @warnings
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 100

def self.attribute_map
  {
    :'date' => :'Date',
    :'contact' => :'Contact',
    :'line_items' => :'LineItems',
    :'user' => :'User',
    :'reference' => :'Reference',
    :'line_amount_types' => :'LineAmountTypes',
    :'sub_total' => :'SubTotal',
    :'total_tax' => :'TotalTax',
    :'total' => :'Total',
    :'receipt_id' => :'ReceiptID',
    :'status' => :'Status',
    :'receipt_number' => :'ReceiptNumber',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'has_attachments' => :'HasAttachments',
    :'url' => :'Url',
    :'validation_errors' => :'ValidationErrors',
    :'warnings' => :'Warnings',
    :'attachments' => :'Attachments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



310
311
312
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 310

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 124

def self.openapi_types
  {
    :'date' => :'Date',
    :'contact' => :'Contact',
    :'line_items' => :'Array<LineItem>',
    :'user' => :'User',
    :'reference' => :'String',
    :'line_amount_types' => :'LineAmountTypes',
    :'sub_total' => :'Float',
    :'total_tax' => :'Float',
    :'total' => :'Float',
    :'receipt_id' => :'String',
    :'status' => :'String',
    :'receipt_number' => :'String',
    :'updated_date_utc' => :'DateTime',
    :'has_attachments' => :'Boolean',
    :'url' => :'String',
    :'validation_errors' => :'Array<ValidationError>',
    :'warnings' => :'Array<ValidationError>',
    :'attachments' => :'Array<Attachment>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 272

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date == o.date &&
      contact == o.contact &&
      line_items == o.line_items &&
      user == o.user &&
      reference == o.reference &&
      line_amount_types == o.line_amount_types &&
      sub_total == o.sub_total &&
      total_tax == o.total_tax &&
      total == o.total &&
      receipt_id == o.receipt_id &&
      status == o.status &&
      receipt_number == o.receipt_number &&
      updated_date_utc == o.updated_date_utc &&
      has_attachments == o.has_attachments &&
      url == o.url &&
      validation_errors == o.validation_errors &&
      warnings == o.warnings &&
      attachments == o.attachments
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 338

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



403
404
405
406
407
408
409
410
411
412
413
414
415
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 403

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 317

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


297
298
299
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 297

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



303
304
305
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 303

def hash
  [date, contact, line_items, user, reference, line_amount_types, sub_total, total_tax, total, receipt_id, status, receipt_number, updated_date_utc, has_attachments, url, validation_errors, warnings, attachments].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



247
248
249
250
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 247

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



418
419
420
421
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 418

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



383
384
385
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 383

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



389
390
391
392
393
394
395
396
397
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 389

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



377
378
379
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 377

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



254
255
256
257
258
# File 'lib/xero-ruby/models/accounting/receipt.rb', line 254

def valid?
  status_validator = EnumAttributeValidator.new('String', ["DRAFT", "SUBMITTED", "AUTHORISED", "DECLINED", "VOIDED"])
  return false unless status_validator.valid?(@status)
  true
end