Class: XeroRuby::Accounting::TaxRate

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/tax_rate.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

ACTIVE =
"ACTIVE".freeze
DELETED =
"DELETED".freeze
ARCHIVED =
"ARCHIVED".freeze
PENDING =
"PENDING".freeze
AVALARA =
"AVALARA".freeze
BASEXCLUDED =
"BASEXCLUDED".freeze
CAPITALSALESOUTPUT =
"CAPITALSALESOUTPUT".freeze
CAPITALEXPENSESINPUT =
"CAPITALEXPENSESINPUT".freeze
ECOUTPUT =
"ECOUTPUT".freeze
ECOUTPUTSERVICES =
"ECOUTPUTSERVICES".freeze
ECINPUT =
"ECINPUT".freeze
ECACQUISITIONS =
"ECACQUISITIONS".freeze
EXEMPTEXPENSES =
"EXEMPTEXPENSES".freeze
EXEMPTINPUT =
"EXEMPTINPUT".freeze
EXEMPTOUTPUT =
"EXEMPTOUTPUT".freeze
GSTONIMPORTS =
"GSTONIMPORTS".freeze
INPUT =
"INPUT".freeze
INPUTTAXED =
"INPUTTAXED".freeze
MOSSSALES =
"MOSSSALES".freeze
NONE =
"NONE".freeze
NONEOUTPUT =
"NONEOUTPUT".freeze
OUTPUT =
"OUTPUT".freeze
PURCHASESINPUT =
"PURCHASESINPUT".freeze
SALESOUTPUT =
"SALESOUTPUT".freeze
EXEMPTCAPITAL =
"EXEMPTCAPITAL".freeze
EXEMPTEXPORT =
"EXEMPTEXPORT".freeze
CAPITALEXINPUT =
"CAPITALEXINPUT".freeze
GSTONCAPIMPORTS =
"GSTONCAPIMPORTS".freeze
GSTONCAPITALIMPORTS =
"GSTONCAPITALIMPORTS".freeze
REVERSECHARGES =
"REVERSECHARGES".freeze
PAYMENTS =
"PAYMENTS".freeze
INVOICE =
"INVOICE".freeze
CASH =
"CASH".freeze
ACCRUAL =
"ACCRUAL".freeze
FLATRATECASH =
"FLATRATECASH".freeze
FLATRATEACCRUAL =
"FLATRATEACCRUAL".freeze
ACCRUALS =
"ACCRUALS".freeze
TXCA =
"TXCA".freeze
SRCAS =
"SRCAS".freeze
DSOUTPUT =
"DSOUTPUT".freeze
BLINPUT2 =
"BLINPUT2".freeze
EPINPUT =
"EPINPUT".freeze
IMINPUT2 =
"IMINPUT2".freeze
MEINPUT =
"MEINPUT".freeze
IGDSINPUT2 =
"IGDSINPUT2".freeze
ESN33_OUTPUT =
"ESN33OUTPUT".freeze
OPINPUT =
"OPINPUT".freeze
OSOUTPUT =
"OSOUTPUT".freeze
TXN33_INPUT =
"TXN33INPUT".freeze
TXESSINPUT =
"TXESSINPUT".freeze
TXREINPUT =
"TXREINPUT".freeze
TXPETINPUT =
"TXPETINPUT".freeze
NRINPUT =
"NRINPUT".freeze
ES33_OUTPUT =
"ES33OUTPUT".freeze
ZERORATEDINPUT =
"ZERORATEDINPUT".freeze
ZERORATEDOUTPUT =
"ZERORATEDOUTPUT".freeze
DRCHARGESUPPLY =
"DRCHARGESUPPLY".freeze
DRCHARGE =
"DRCHARGE".freeze
CAPINPUT =
"CAPINPUT".freeze
CAPIMPORTS =
"CAPIMPORTS".freeze
IMINPUT =
"IMINPUT".freeze
INPUT2 =
"INPUT2".freeze
CIUINPUT =
"CIUINPUT".freeze
SRINPUT =
"SRINPUT".freeze
OUTPUT2 =
"OUTPUT2".freeze
SROUTPUT =
"SROUTPUT".freeze
CAPOUTPUT =
"CAPOUTPUT".freeze
SROUTPUT2 =
"SROUTPUT2".freeze
CIUOUTPUT =
"CIUOUTPUT".freeze
ZROUTPUT =
"ZROUTPUT".freeze
ZREXPORT =
"ZREXPORT".freeze
ACC28_PLUS =
"ACC28PLUS".freeze
ACCUPTO28 =
"ACCUPTO28".freeze
OTHEROUTPUT =
"OTHEROUTPUT".freeze
SHOUTPUT =
"SHOUTPUT".freeze
ZRINPUT =
"ZRINPUT".freeze
BADDEBT =
"BADDEBT".freeze
OTHERINPUT =
"OTHERINPUT".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TaxRate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 192

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::TaxRate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::TaxRate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'tax_type')
    self.tax_type = attributes[:'tax_type']
  end

  if attributes.key?(:'tax_components')
    if (value = attributes[:'tax_components']).is_a?(Array)
      self.tax_components = value
    end
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'report_tax_type')
    self.report_tax_type = attributes[:'report_tax_type']
  end

  if attributes.key?(:'can_apply_to_assets')
    self.can_apply_to_assets = attributes[:'can_apply_to_assets']
  end

  if attributes.key?(:'can_apply_to_equity')
    self.can_apply_to_equity = attributes[:'can_apply_to_equity']
  end

  if attributes.key?(:'can_apply_to_expenses')
    self.can_apply_to_expenses = attributes[:'can_apply_to_expenses']
  end

  if attributes.key?(:'can_apply_to_liabilities')
    self.can_apply_to_liabilities = attributes[:'can_apply_to_liabilities']
  end

  if attributes.key?(:'can_apply_to_revenue')
    self.can_apply_to_revenue = attributes[:'can_apply_to_revenue']
  end

  if attributes.key?(:'display_tax_rate')
    self.display_tax_rate = attributes[:'display_tax_rate']
  end

  if attributes.key?(:'effective_rate')
    self.effective_rate = attributes[:'effective_rate']
  end
end

Instance Attribute Details

#can_apply_to_assets ⇒ Object

Boolean to describe if tax rate can be used for asset accounts i.e. true,false



112
113
114
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 112

def can_apply_to_assets
  @can_apply_to_assets
end

#can_apply_to_equity ⇒ Object

Boolean to describe if tax rate can be used for equity accounts i.e true,false



115
116
117
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 115

def can_apply_to_equity
  @can_apply_to_equity
end

#can_apply_to_expenses ⇒ Object

Boolean to describe if tax rate can be used for expense accounts i.e. true,false



118
119
120
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 118

def can_apply_to_expenses
  @can_apply_to_expenses
end

#can_apply_to_liabilities ⇒ Object

Boolean to describe if tax rate can be used for liability accounts i.e. true,false



121
122
123
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 121

def can_apply_to_liabilities
  @can_apply_to_liabilities
end

#can_apply_to_revenue ⇒ Object

Boolean to describe if tax rate can be used for revenue accounts i.e. true,false



124
125
126
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 124

def can_apply_to_revenue
  @can_apply_to_revenue
end

#display_tax_rate ⇒ Object

Tax Rate (decimal to 4dp) e.g 12.5000



127
128
129
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 127

def display_tax_rate
  @display_tax_rate
end

#effective_rate ⇒ Object

Effective Tax Rate (decimal to 4dp) e.g 12.5000



130
131
132
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 130

def effective_rate
  @effective_rate
end

#name ⇒ Object

Name of tax rate



19
20
21
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 19

def name
  @name
end

#report_tax_type ⇒ Object

See ReportTaxTypes



35
36
37
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 35

def report_tax_type
  @report_tax_type
end

#status ⇒ Object

See Status Codes



28
29
30
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 28

def status
  @status
end

#tax_components ⇒ Object

See TaxComponents



25
26
27
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 25

def tax_components
  @tax_components
end

#tax_type ⇒ Object

The tax type



22
23
24
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 22

def tax_type
  @tax_type
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 155

def self.attribute_map
  {
    :'name' => :'Name',
    :'tax_type' => :'TaxType',
    :'tax_components' => :'TaxComponents',
    :'status' => :'Status',
    :'report_tax_type' => :'ReportTaxType',
    :'can_apply_to_assets' => :'CanApplyToAssets',
    :'can_apply_to_equity' => :'CanApplyToEquity',
    :'can_apply_to_expenses' => :'CanApplyToExpenses',
    :'can_apply_to_liabilities' => :'CanApplyToLiabilities',
    :'can_apply_to_revenue' => :'CanApplyToRevenue',
    :'display_tax_rate' => :'DisplayTaxRate',
    :'effective_rate' => :'EffectiveRate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



327
328
329
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 327

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 173

def self.openapi_types
  {
    :'name' => :'String',
    :'tax_type' => :'String',
    :'tax_components' => :'Array<TaxComponent>',
    :'status' => :'String',
    :'report_tax_type' => :'String',
    :'can_apply_to_assets' => :'Boolean',
    :'can_apply_to_equity' => :'Boolean',
    :'can_apply_to_expenses' => :'Boolean',
    :'can_apply_to_liabilities' => :'Boolean',
    :'can_apply_to_revenue' => :'Boolean',
    :'display_tax_rate' => :'Float',
    :'effective_rate' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 295

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      tax_type == o.tax_type &&
      tax_components == o.tax_components &&
      status == o.status &&
      report_tax_type == o.report_tax_type &&
      can_apply_to_assets == o.can_apply_to_assets &&
      can_apply_to_equity == o.can_apply_to_equity &&
      can_apply_to_expenses == o.can_apply_to_expenses &&
      can_apply_to_liabilities == o.can_apply_to_liabilities &&
      can_apply_to_revenue == o.can_apply_to_revenue &&
      display_tax_rate == o.display_tax_rate &&
      effective_rate == o.effective_rate
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 355

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 420

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 334

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


314
315
316
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 314

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



320
321
322
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 320

def hash
  [name, tax_type, tax_components, status, report_tax_type, can_apply_to_assets, can_apply_to_equity, can_apply_to_expenses, can_apply_to_liabilities, can_apply_to_revenue, display_tax_rate, effective_rate].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



258
259
260
261
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 258

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



435
436
437
438
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 435

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



400
401
402
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 400

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



406
407
408
409
410
411
412
413
414
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 406

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



394
395
396
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 394

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



265
266
267
268
269
270
271
# File 'lib/xero-ruby/models/accounting/tax_rate.rb', line 265

def valid?
  status_validator = EnumAttributeValidator.new('String', ["ACTIVE", "DELETED", "ARCHIVED", "PENDING"])
  return false unless status_validator.valid?(@status)
  report_tax_type_validator = EnumAttributeValidator.new('String', ["AVALARA", "BASEXCLUDED", "CAPITALSALESOUTPUT", "CAPITALEXPENSESINPUT", "ECOUTPUT", "ECOUTPUTSERVICES", "ECINPUT", "ECACQUISITIONS", "EXEMPTEXPENSES", "EXEMPTINPUT", "EXEMPTOUTPUT", "GSTONIMPORTS", "INPUT", "INPUTTAXED", "MOSSSALES", "NONE", "NONEOUTPUT", "OUTPUT", "PURCHASESINPUT", "SALESOUTPUT", "EXEMPTCAPITAL", "EXEMPTEXPORT", "CAPITALEXINPUT", "GSTONCAPIMPORTS", "GSTONCAPITALIMPORTS", "REVERSECHARGES", "PAYMENTS", "INVOICE", "CASH", "ACCRUAL", "FLATRATECASH", "FLATRATEACCRUAL", "ACCRUALS", "TXCA", "SRCAS", "DSOUTPUT", "BLINPUT2", "EPINPUT", "IMINPUT2", "MEINPUT", "IGDSINPUT2", "ESN33OUTPUT", "OPINPUT", "OSOUTPUT", "TXN33INPUT", "TXESSINPUT", "TXREINPUT", "TXPETINPUT", "NRINPUT", "ES33OUTPUT", "ZERORATEDINPUT", "ZERORATEDOUTPUT", "DRCHARGESUPPLY", "DRCHARGE", "CAPINPUT", "CAPIMPORTS", "IMINPUT", "INPUT2", "CIUINPUT", "SRINPUT", "OUTPUT2", "SROUTPUT", "CAPOUTPUT", "SROUTPUT2", "CIUOUTPUT", "ZROUTPUT", "ZREXPORT", "ACC28PLUS", "ACCUPTO28", "OTHEROUTPUT", "SHOUTPUT", "ZRINPUT", "BADDEBT", "OTHERINPUT"])
  return false unless report_tax_type_validator.valid?(@report_tax_type)
  true
end