Class: XeroRuby::ApiClient

Inherits:
Object
  • Object
show all
Includes:
StringSerialization
Defined in:
lib/xero-ruby/api_client.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from StringSerialization

#camelize, #camelize_key, #capitalize_first, #gsubbed, #to_camel_keys

Constructor Details

#initialize(config: {}, credentials: {}) ⇒ ApiClient

Initializes the ApiClient

Parameters:

  • config (Hash) (defaults to: {})

    a customizable set of options

Options Hash (config:):

  • Configuration (Configuration)

    for initializing the object, default to Configuration.default



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/xero-ruby/api_client.rb', line 36

def initialize(config: {}, credentials: {})
  @client_id = credentials[:client_id]
  @client_secret = credentials[:client_secret]
  @redirect_uri = credentials[:redirect_uri]
  @grant_type = credentials[:grant_type] || 'authorization_code'
  @scopes = credentials[:scopes]
  @state = credentials[:state]
  default_config = Configuration.default.clone
  @config = append_to_default_config(default_config, config)

  @user_agent = "xero-ruby-#{VERSION}"
  @default_headers = {
    'Content-Type' => 'application/json',
    'User-Agent' => @user_agent
  }
end

Instance Attribute Details

#configObject

The Configuration object holding settings to be used in the API client.



27
28
29
# File 'lib/xero-ruby/api_client.rb', line 27

def config
  @config
end

#default_headersHash

Defines the headers to be used in HTTP requests of all API calls by default.

Returns:

  • (Hash)


32
33
34
# File 'lib/xero-ruby/api_client.rb', line 32

def default_headers
  @default_headers
end

#grant_typeHash

Defines the headers to be used in HTTP requests of all API calls by default.

Returns:

  • (Hash)


32
33
34
# File 'lib/xero-ruby/api_client.rb', line 32

def grant_type
  @grant_type
end

Instance Method Details

#access_tokenObject



113
114
115
# File 'lib/xero-ruby/api_client.rb', line 113

def access_token
  @config.access_token
end

#accounting_apiObject



73
74
75
76
# File 'lib/xero-ruby/api_client.rb', line 73

def accounting_api
  @config.base_url = @config.accounting_url
  XeroRuby::AccountingApi.new(self)
end

#append_to_default_config(default_config, user_config) ⇒ Object



53
54
55
56
57
# File 'lib/xero-ruby/api_client.rb', line 53

def append_to_default_config(default_config, user_config)
  config = default_config
  user_config.each{|k,v| config.send("#{k}=", v)}
  config
end

#asset_apiObject



78
79
80
81
# File 'lib/xero-ruby/api_client.rb', line 78

def asset_api
  @config.base_url = @config.asset_url
  XeroRuby::AssetApi.new(self)
end

#authorization_urlObject



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/xero-ruby/api_client.rb', line 59

def authorization_url
  url = URI.parse @config.
  url.query = URI.encode_www_form(
    {
      response_type: 'code',
      client_id: @client_id,
      redirect_uri: @redirect_uri,
      scope: @scopes,
      state: @state
    }.compact
  )
  url.to_s
end

#build_collection_param(param, collection_format) ⇒ Object

Build parameter value according to the given collection format.

Parameters:

  • collection_format (String)

    one of :csv, :ssv, :tsv, :pipes and :multi



629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
# File 'lib/xero-ruby/api_client.rb', line 629

def build_collection_param(param, collection_format)
  case collection_format
  when :csv
    param.join(',')
  when :ssv
    param.join(' ')
  when :tsv
    param.join("\t")
  when :pipes
    param.join('|')
  when :multi
    # return the array directly as http client will handle it as expected
    param
  else
    fail "unknown collection format: #{collection_format.inspect}"
  end
end

#build_request(http_method, path, request, opts = {}) ⇒ Object

Builds the HTTP request

Parameters:

  • http_method (String)

    HTTP method/verb (e.g. POST)

  • path (String)

    URL path (e.g. /account/new)

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :header_params (Hash)

    Header parameters

  • :query_params (Hash)

    Query parameters

  • :form_params (Hash)

    Query parameters

  • :body (Object)

    HTTP body (JSON/XML)

Returns:

  • A Faraday Request



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/xero-ruby/api_client.rb', line 342

def build_request(http_method, path, request, opts = {})
  url = build_request_url(path)
  http_method = http_method.to_sym.downcase

  header_params = @default_headers.merge(opts[:header_params] || {})
  query_params = opts[:query_params] || {}
  form_params = opts[:form_params] || {}

  update_params_for_auth! header_params, query_params, opts[:auth_names]

  req_opts = {
    :method => http_method,
    :headers => header_params,
    :params => query_params,
    :params_encoding => @config.params_encoding,
    :timeout => @config.timeout,
    :verbose => @config.debugging
  }

  if [:post, :patch, :put, :delete].include?(http_method)
    req_body = build_request_body(header_params, form_params, opts[:body])
    req_opts.update :body => req_body
    if @config.debugging
      @config.logger.debug "HTTP request body param ~BEGIN~\n#{req_body}\n~END~\n"
    end
  end
  request.headers = header_params
  timeout = @config.timeout
  request.options.timeout = timeout if timeout > 0
  request.body = req_body
  request.url url
  request.params = query_params
  request
end

#build_request_body(header_params, form_params, body) ⇒ String

Builds the HTTP request body

Parameters:

  • header_params (Hash)

    Header parameters

  • form_params (Hash)

    Query parameters

  • body (Object)

    HTTP body (JSON/XML)

Returns:

  • (String)

    HTTP body data in the form of string



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/xero-ruby/api_client.rb', line 383

def build_request_body(header_params, form_params, body)
  # http form
  if header_params['Content-Type'] == 'application/x-www-form-urlencoded'
    data = URI.encode_www_form(form_params)
  elsif header_params['Content-Type'] == 'multipart/form-data'
    data = {}
    form_params.each do |key, value|
      case value
      when ::File, ::Tempfile
        data[form_params["name"]] = Faraday::UploadIO.new(value.path, form_params["mimeType"], value.path)
      when ::Array, nil
        # let Faraday handle Array and nil parameters
        data[key] = value
      else
        data[key] = value.to_s
      end
    end
  elsif body
    data = body.is_a?(String) ? body : body.to_json
  else
    data = nil
  end
  data
end

#build_request_url(path) ⇒ Object



546
547
548
549
550
551
552
553
554
# File 'lib/xero-ruby/api_client.rb', line 546

def build_request_url(path)
  if @config.base_url
    # Add leading and trailing slashes to path
    path = "/#{path}".gsub(/\/+/, '/')
    @config.base_url + path
  else
    path
  end
end

#call_api(http_method, path, api_client, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Call an API with given options.

Returns:

  • (Array<(Object, Integer, Hash)>)

    an array of 3 elements: the data deserialized from response body (could be nil), response status code and response headers.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/xero-ruby/api_client.rb', line 258

def call_api(http_method, path, api_client, opts = {})
  ssl_options = {
    :ca_file => @config.ssl_ca_file,
    :verify => @config.ssl_verify,
    :verify_mode => @config.ssl_verify_mode,
    :client_cert => @config.ssl_client_cert,
    :client_key => @config.ssl_client_key
  }

  case api_client
  when "AccountingApi"
    method_base_url = @config.accounting_url
  when "AssetApi"
    method_base_url = @config.asset_url
  when "FilesApi"
   method_base_url = @config.files_url
  when "PayrollAuApi"
    method_base_url = @config.payroll_au_url
  when "PayrollNzApi"
    method_base_url = @config.payroll_nz_url
  when "PayrollUkApi"
    method_base_url = @config.payroll_uk_url
  when "ProjectApi"
    method_base_url = @config.project_url
  else
    method_base_url = @config.accounting_url
  end

  connection = Faraday.new(:url => method_base_url, :ssl => ssl_options) do |conn|
    conn.basic_auth(config.username, config.password)
    if opts[:header_params]["Content-Type"] == "multipart/form-data"
      conn.request :multipart
      conn.request :url_encoded
    end
    conn.adapter(Faraday.default_adapter)
  end

  begin
    response = connection.public_send(http_method.to_sym.downcase) do |req|
      build_request(http_method, path, req, opts)
    end

    if @config.debugging
      @config.logger.debug "HTTP response body ~BEGIN~\n#{response.body}\n~END~\n"
    end

    return_error(response) unless response.success?
  rescue Faraday::TimeoutError
    fail ApiError.new('Connection timed out')
  end

  if opts[:return_type]
    prepare_file(response) if opts[:return_type] == 'File'
    data = deserialize(response, opts[:return_type], api_client)
  elsif !response.body.empty?
    data = JSON.parse(response.body)
  else
    data = nil
  end
  return data, response.status, response.headers
end

#connectionsObject

Connection heplers



236
237
238
239
240
241
# File 'lib/xero-ruby/api_client.rb', line 236

def connections
  @config.base_url = 'https://api.xero.com'
  opts = { :header_params => {'Content-Type': 'application/json'}, :auth_names => ['OAuth2'] }
  response = call_api(:GET, "/connections/", nil, opts)
  response[0]
end

#convert_to_type(data, return_type, api_client) ⇒ Mixed

Convert data to the given return type.

Parameters:

  • data (Object)

    Data to be converted

  • return_type (String)

    Return type

Returns:

  • (Mixed)

    Data in a particular type



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/xero-ruby/api_client.rb', line 458

def convert_to_type(data, return_type, api_client)
  return nil if data.nil?
  case return_type
  when 'String'
    data.to_s
  when 'Integer'
    data.to_i
  when 'Float'
    data.to_f
  when 'Boolean'
    data == true
  when 'DateTime'
    # parse date time (expecting ISO 8601 format)
    DateTime.parse data
  when 'Date'
    # parse date time (expecting ISO 8601 format)
    Date.parse data
  when 'Object'
    # generic object (usually a Hash), return directly
    data
  when /\AArray<(.+)>\z/
    # e.g. Array<Pet>
    sub_type = $1
    data.map { |item| convert_to_type(item, sub_type, api_client) }
  when /\AHash\<String, (.+)\>\z/
    # e.g. Hash<String, Integer>
    sub_type = $1
    {}.tap do |hash|
      data.each { |k, v| hash[k] = convert_to_type(v, sub_type, api_client) }
    end
  else
    case api_client
    when 'AccountingApi'
      XeroRuby::Accounting.const_get(return_type).build_from_hash(data)
    when 'AssetApi'
      XeroRuby::Assets.const_get(return_type).build_from_hash(data)
    when 'ProjectApi'
      XeroRuby::Projects.const_get(return_type).build_from_hash(data)
    when 'FilesApi'
      XeroRuby::Files.const_get(return_type).build_from_hash(data)
    when 'PayrollAuApi'
      XeroRuby::PayrollAu.const_get(return_type).build_from_hash(data)
    when 'PayrollNzApi'
      XeroRuby::PayrollNz.const_get(return_type).build_from_hash(data)
    when 'PayrollUkApi'
      XeroRuby::PayrollUk.const_get(return_type).build_from_hash(data)
    else
      XeroRuby::Accounting.const_get(return_type).build_from_hash(data)
    end
  end
end

#decode_jwt(tkn, verify = true) ⇒ Object



187
188
189
190
191
192
193
194
195
# File 'lib/xero-ruby/api_client.rb', line 187

def decode_jwt(tkn, verify=true)
  if verify == true
    jwks_data = JSON.parse(Faraday.get('https://identity.xero.com/.well-known/openid-configuration/jwks').body)
    jwk_set = JSON::JWK::Set.new(jwks_data)
    JSON::JWT.decode(tkn, jwk_set)
  else
    JSON::JWT.decode(tkn, :skip_verification)
  end
end

#decoded_access_tokenObject



121
122
123
# File 'lib/xero-ruby/api_client.rb', line 121

def decoded_access_token
  decode_jwt(@config.access_token, false)
end

#decoded_id_tokenObject



125
126
127
# File 'lib/xero-ruby/api_client.rb', line 125

def decoded_id_token
  decode_jwt(@config.id_token, false)
end

#deserialize(response, return_type, api_client) ⇒ Object

Deserialize the response to the given return type.

Parameters:

  • response (Response)

    HTTP response

  • return_type (String)

    some examples: "User", "Array", "Hash<String, Integer>"



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/xero-ruby/api_client.rb', line 424

def deserialize(response, return_type, api_client)
  body = response.body

  # handle file downloading - return the File instance processed in request callbacks
  # note that response body is empty when the file is written in chunks in request on_body callback
  return @tempfile if return_type == 'File'

  return nil if body.nil? || body.empty?

  # return response body directly for String return type
  return body if return_type == 'String'

  # ensuring a default content type
  content_type = response.headers['Content-Type'] || 'application/json'

  fail "Content-Type is not supported: #{content_type}" unless json_mime?(content_type)

  begin
    data = JSON.parse("[#{body}]", :symbolize_names => true)[0]
  rescue JSON::ParserError => e
    if %w(String Date DateTime).include?(return_type)
      data = body
    else
      raise e
    end
  end 

  convert_to_type(data, return_type, api_client)
end

#disconnect(connection_id) ⇒ Object



247
248
249
250
251
252
# File 'lib/xero-ruby/api_client.rb', line 247

def disconnect(connection_id)
  @config.base_url = 'https://api.xero.com'
  opts = { :header_params => {'Content-Type': 'application/json'}, :auth_names => ['OAuth2'] }
  call_api(:DELETE, "/connections/#{connection_id}", nil, opts)
  connections
end

#files_apiObject



88
89
90
91
# File 'lib/xero-ruby/api_client.rb', line 88

def files_api
  @config.base_url = @config.files_url
  XeroRuby::FilesApi.new(self)
end

#get_client_credentials_tokenObject



147
148
149
150
151
152
153
154
# File 'lib/xero-ruby/api_client.rb', line 147

def get_client_credentials_token
  data = {
    grant_type: @grant_type
  }
  token_set = token_request(data, '/token')

  return token_set
end

#get_token_set_from_callback(params) ⇒ Object



156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/xero-ruby/api_client.rb', line 156

def get_token_set_from_callback(params)
  data = {
    grant_type: @grant_type,
    code: params['code'],
    redirect_uri: @redirect_uri
  }
  token_set = token_request(data, '/token')

  validate_tokens(token_set)
  validate_state(params)
  return token_set
end

#id_tokenObject



117
118
119
# File 'lib/xero-ruby/api_client.rb', line 117

def id_token
  @config.id_token
end

#json_mime?(mime) ⇒ Boolean

Check if the given MIME is a JSON MIME. JSON MIME examples:

application/json
application/json; charset=UTF8
APPLICATION/JSON
*/*

Parameters:

  • mime (String)

    MIME

Returns:

  • (Boolean)

    True if the MIME is application/json



416
417
418
# File 'lib/xero-ruby/api_client.rb', line 416

def json_mime?(mime)
  (mime == '*/*') || !(mime =~ /Application\/.*json(?!p)(;.*)?/i).nil?
end

#last_connectionObject



243
244
245
# File 'lib/xero-ruby/api_client.rb', line 243

def last_connection
  connections.sort { |a,b| DateTime.parse(a['updatedDateUtc']) <=> DateTime.parse(b['updatedDateUtc'])}.first
end

#object_to_hash(obj) ⇒ String

Convert object(non-array) to hash.

Parameters:

  • obj (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



619
620
621
622
623
624
625
# File 'lib/xero-ruby/api_client.rb', line 619

def object_to_hash(obj)
  if obj.respond_to?(:to_hash)
    to_camel_keys(obj).to_hash
  else
    to_camel_keys(obj)
  end
end

#object_to_http_body(model) ⇒ String

Convert object (array, hash, object, etc) to JSON string.

Parameters:

  • model (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



605
606
607
608
609
610
611
612
613
614
# File 'lib/xero-ruby/api_client.rb', line 605

def object_to_http_body(model)
  return model if model.nil? || model.is_a?(String)
  local_body = nil
  if model.is_a?(Array)
    local_body = model.map { |m| object_to_hash(m) }
  else
    local_body = object_to_hash(model)
  end
  local_body.to_json
end

#parameterize_where(where_opts) ⇒ Object



647
648
649
# File 'lib/xero-ruby/api_client.rb', line 647

def parameterize_where(where_opts)
  Where.new(where_opts).to_param
end

#payroll_au_apiObject



93
94
95
96
# File 'lib/xero-ruby/api_client.rb', line 93

def payroll_au_api
  @config.base_url = @config.payroll_au_url
  XeroRuby::PayrollAuApi.new(self)
end

#payroll_nz_apiObject



98
99
100
101
# File 'lib/xero-ruby/api_client.rb', line 98

def payroll_nz_api
  @config.base_url = @config.payroll_nz_url
  XeroRuby::PayrollNzApi.new(self)
end

#payroll_uk_apiObject



103
104
105
106
# File 'lib/xero-ruby/api_client.rb', line 103

def payroll_uk_api
  @config.base_url = @config.payroll_uk_url
  XeroRuby::PayrollUkApi.new(self)
end

#prepare_file(response) ⇒ Object

Save response body into a file in (the defined) temporary folder, using the filename from the "Content-Disposition" header if provided, otherwise a random filename. The response body is written to the file in chunks in order to handle files which size is larger than maximum Ruby String or even larger than the maximum memory a Ruby process can use.



517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
# File 'lib/xero-ruby/api_client.rb', line 517

def prepare_file(response)
  content_disposition = response.headers['Content-Disposition']
  if content_disposition && content_disposition =~ /filename=/i
    filename = content_disposition[/filename=['"]?([^'"\s]+)['"]?/, 1]
    prefix = sanitize_filename(filename)
  else
    prefix = 'download-'
  end
  prefix = prefix + '-' unless prefix.end_with?('-')
  encoding = response.body.encoding
  tempfile = Tempfile.open(prefix, @config.temp_folder_path, encoding: encoding)
  @tempfile = tempfile
  tempfile.write(response.body)
  tempfile.close if tempfile
  @config.logger.info "Temp file written to #{tempfile.path}, please copy the file to a proper folder "\
                      "with e.g. `FileUtils.cp(tempfile.path, '/new/file/path')` otherwise the temp file "\
                      "will be deleted automatically with GC. It's also recommended to delete the temp file "\
                      "explicitly with `tempfile.delete`"
end

#project_apiObject



83
84
85
86
# File 'lib/xero-ruby/api_client.rb', line 83

def project_api
  @config.base_url = @config.project_url
  XeroRuby::ProjectApi.new(self)
end

#refresh_token_set(token_set) ⇒ Object



202
203
204
205
206
207
208
209
# File 'lib/xero-ruby/api_client.rb', line 202

def refresh_token_set(token_set)
  token_set = token_set.with_indifferent_access
  data = {
    grant_type: 'refresh_token',
    refresh_token: token_set[:refresh_token]
  }
  return token_request(data, '/token')
end

#return_error(response) ⇒ Object



320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/xero-ruby/api_client.rb', line 320

def return_error(response)
  if response.status == 0
    # Errors from libcurl will be made visible here
    fail ApiError.new(:code => 0,
                      :message => response.return_message)
  else
    fail ApiError.new(:code => response.status,
                      :response_headers => response.headers,
                      :response_body => response.body),
          response.reason_phrase
  end
end

#revoke_token(token_set) ⇒ Object



211
212
213
214
215
216
217
# File 'lib/xero-ruby/api_client.rb', line 211

def revoke_token(token_set)
  token_set = token_set.with_indifferent_access
  data = {
    token: token_set[:refresh_token]
  }
  return token_request(data, '/revocation')
end

#sanitize_filename(filename) ⇒ String

Sanitize filename by removing path. e.g. ../../sun.gif becomes sun.gif

Parameters:

  • filename (String)

    the filename to be sanitized

Returns:

  • (String)

    the sanitized filename



542
543
544
# File 'lib/xero-ruby/api_client.rb', line 542

def sanitize_filename(filename)
  filename.gsub(/.*[\/\\]/, '')
end

#select_header_accept(accepts) ⇒ String

Return Accept header based on an array of accepts provided.

Parameters:

  • accepts (Array)

    array for Accept

Returns:

  • (String)

    the Accept header (e.g. application/json)



584
585
586
587
588
589
# File 'lib/xero-ruby/api_client.rb', line 584

def select_header_accept(accepts)
  return nil if accepts.nil? || accepts.empty?
  # use JSON when present, otherwise use all of the provided
  json_accept = accepts.find { |s| json_mime?(s) }
  json_accept || accepts.join(',')
end

#select_header_content_type(content_types) ⇒ String

Return Content-Type header based on an array of content types provided.

Parameters:

  • content_types (Array)

    array for Content-Type

Returns:

  • (String)

    the Content-Type header (e.g. application/json)



594
595
596
597
598
599
600
# File 'lib/xero-ruby/api_client.rb', line 594

def select_header_content_type(content_types)
  # use application/json by default
  return 'application/json' if content_types.nil? || content_types.empty?
  # use JSON when present, otherwise use the first one
  json_content_type = content_types.find { |s| json_mime?(s) }
  json_content_type || content_types.first
end

#set_access_token(access_token) ⇒ Object



139
140
141
# File 'lib/xero-ruby/api_client.rb', line 139

def set_access_token(access_token)
  @config.access_token = access_token
end

#set_id_token(id_token) ⇒ Object



143
144
145
# File 'lib/xero-ruby/api_client.rb', line 143

def set_id_token(id_token)
  @config.id_token = id_token
end

#set_token_set(token_set) ⇒ Object



129
130
131
132
133
134
135
136
137
# File 'lib/xero-ruby/api_client.rb', line 129

def set_token_set(token_set)
  token_set = token_set.with_indifferent_access
  @config.token_set = token_set

  set_access_token(token_set[:access_token]) if token_set[:access_token]
  set_id_token(token_set[:id_token]) if token_set[:id_token]
  
  return true
end

#token_expired?Boolean

Returns:

  • (Boolean)


197
198
199
200
# File 'lib/xero-ruby/api_client.rb', line 197

def token_expired?
  token_expiry = Time.at(decoded_access_token['exp'])
  token_expiry < Time.now
end

#token_request(data, path) ⇒ Object



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/xero-ruby/api_client.rb', line 219

def token_request(data, path)
  response = Faraday.post("#{@config.token_url}#{path}") do |req|
    req.headers['Authorization'] = "Basic " + Base64.strict_encode64("#{@client_id}:#{@client_secret}")
    req.headers['Content-Type'] = 'application/x-www-form-urlencoded'
    req.body = URI.encode_www_form(data)
  end
  return_error(response) unless response.success?
  if !response.body.nil? && !response.body.empty?
    body = JSON.parse(response.body)
    set_token_set(body)
  else
    body = {}
  end
  return body
end

#token_setObject

Token Helpers



109
110
111
# File 'lib/xero-ruby/api_client.rb', line 109

def token_set
  @config.token_set
end

#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object

Update hearder and query params based on authentication settings.

Parameters:

  • header_params (Hash)

    Header parameters

  • query_params (Hash)

    Query parameters

  • auth_names (String)

    Authentication scheme name



561
562
563
564
565
566
567
568
569
570
571
# File 'lib/xero-ruby/api_client.rb', line 561

def update_params_for_auth!(header_params, query_params, auth_names)
  Array(auth_names).each do |auth_name|
    auth_setting = @config.auth_settings[auth_name]
    next unless auth_setting
    case auth_setting[:in]
    when 'header' then header_params[auth_setting[:key]] = auth_setting[:value]
    when 'query'  then query_params[auth_setting[:key]] = auth_setting[:value]
    else fail ArgumentError, 'Authentication token must be in `query` of `header`'
    end
  end
end

#user_agent=(user_agent) ⇒ Object

Sets user agent in HTTP header

Parameters:

  • user_agent (String)

    User agent (e.g. openapi-generator/ruby/1.0.0)



576
577
578
579
# File 'lib/xero-ruby/api_client.rb', line 576

def user_agent=(user_agent)
  @user_agent = user_agent
  @default_headers['User-Agent'] = @user_agent
end

#validate_state(params) ⇒ Object



180
181
182
183
184
185
# File 'lib/xero-ruby/api_client.rb', line 180

def validate_state(params)
  if params[:state] != @state
    raise StandardError.new "WARNING: @config.state: #{@state} and OAuth callback state: #{params['state']} do not match!"
  end
  return true
end

#validate_tokens(token_set) ⇒ Object



169
170
171
172
173
174
175
176
177
178
# File 'lib/xero-ruby/api_client.rb', line 169

def validate_tokens(token_set)
  token_set = token_set.with_indifferent_access
  id_token = token_set[:id_token]
  access_token = token_set[:access_token]
  if id_token || access_token
    decode_jwt(access_token) if access_token
    decode_jwt(id_token) if id_token
  end
  return true
end