Class: XeroRuby::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/configuration.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|_self| ... } ⇒ Configuration

Returns a new instance of Configuration.

Yields:

  • (_self)

Yield Parameters:



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/xero-ruby/configuration.rb', line 136

def initialize
  @scheme = 'https'
  @host = 'api.xero.com'
  @base_path = '/api.xro/2.0'
  @login_url = 'https://login.xero.com/identity/connect/authorize'
  @token_url = 'https://identity.xero.com/connect/token'
  @accounting_url = 'https://api.xero.com/api.xro/2.0'
  @asset_url = 'https://api.xero.com/assets.xro/1.0'
  @project_url = 'https://api.xero.com/projects.xro/2.0/'
  @api_key = {}
  @api_key_prefix = {}
  @timeout = 0
  @client_side_validation = true
  @ssl_verify = true
  @ssl_verify_mode = nil
  @ssl_ca_file = nil
  @ssl_client_cert = nil
  @ssl_client_key = nil
  @debugging = false
  @inject_format = false
  @force_ending_format = false
  @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT)

  yield(self) if block_given?
end

Instance Attribute Details

#access_token ⇒ Object

Defines the access token (Bearer) used with OAuth2.



61
62
63
# File 'lib/xero-ruby/configuration.rb', line 61

def access_token
  @access_token
end

#accounting_url ⇒ Object

Defines base paths for seperate API's



30
31
32
# File 'lib/xero-ruby/configuration.rb', line 30

def accounting_url
  @accounting_url
end

#api_key ⇒ Hash

Defines API keys used with API Key authentications.

Examples:

parameter name is "api_key", API key is "xxx" (e.g. "api_key=xxx" in query string)

config.api_key['api_key'] = 'xxx'

Returns:

  • (Hash) —

    key: parameter name, value: parameter value (API key)



40
41
42
# File 'lib/xero-ruby/configuration.rb', line 40

def api_key
  @api_key
end

#api_key_prefix ⇒ Hash

Defines API key prefixes used with API Key authentications.

Examples:

parameter name is "Authorization", API key prefix is "Token" (e.g. "Authorization: Token xxx" in headers)

config.api_key_prefix['api_key'] = 'Token'

Returns:

  • (Hash) —

    key: parameter name, value: API key prefix



48
49
50
# File 'lib/xero-ruby/configuration.rb', line 48

def api_key_prefix
  @api_key_prefix
end

#asset_url ⇒ Object

Returns the value of attribute asset_url.



31
32
33
# File 'lib/xero-ruby/configuration.rb', line 31

def asset_url
  @asset_url
end

#base_path ⇒ Object

Defines url base path & url for overwriting



22
23
24
# File 'lib/xero-ruby/configuration.rb', line 22

def base_path
  @base_path
end

#base_url ⇒ Object

Returns the value of attribute base_url.



23
24
25
# File 'lib/xero-ruby/configuration.rb', line 23

def base_url
  @base_url
end

#client_side_validation ⇒ true, false

Set this to false to skip client side validation in the operation. Default to true.

Returns:

  • (true, false)


93
94
95
# File 'lib/xero-ruby/configuration.rb', line 93

def client_side_validation
  @client_side_validation
end

#debugging ⇒ true, false

Set this to enable/disable debugging. When enabled (set to true), HTTP request/response details will be logged with logger.debug (see the logger attribute). Default to false.

Returns:

  • (true, false)


71
72
73
# File 'lib/xero-ruby/configuration.rb', line 71

def debugging
  @debugging
end

#force_ending_format ⇒ Object

Returns the value of attribute force_ending_format.



134
135
136
# File 'lib/xero-ruby/configuration.rb', line 134

def force_ending_format
  @force_ending_format
end

#host ⇒ Object

Defines url host



19
20
21
# File 'lib/xero-ruby/configuration.rb', line 19

def host
  @host
end

#inject_format ⇒ Object

Returns the value of attribute inject_format.



132
133
134
# File 'lib/xero-ruby/configuration.rb', line 132

def inject_format
  @inject_format
end

#logger ⇒ #debug

Defines the logger used for debugging. Default to Rails.logger (when in Rails) or logging to STDOUT.

Returns:

  • (#debug)


77
78
79
# File 'lib/xero-ruby/configuration.rb', line 77

def logger
  @logger
end

#login_url ⇒ Object

Defines url for identity routes



26
27
28
# File 'lib/xero-ruby/configuration.rb', line 26

def 
  @login_url
end

#params_encoding ⇒ Object

Set this to customize parameters encoding of array parameter with multi collectionFormat. Default to nil.

https://github.com/typhoeus/ethon/blob/master/lib/ethon/easy/queryable.rb#L96

See Also:

  • params_encoding option of Ethon. Related source code:


130
131
132
# File 'lib/xero-ruby/configuration.rb', line 130

def params_encoding
  @params_encoding
end

#password ⇒ String

Defines the password used with HTTP basic authentication.

Returns:

  • (String)


58
59
60
# File 'lib/xero-ruby/configuration.rb', line 58

def password
  @password
end

#project_url ⇒ Object

Returns the value of attribute project_url.



32
33
34
# File 'lib/xero-ruby/configuration.rb', line 32

def project_url
  @project_url
end

#scheme ⇒ Object

Defines url scheme



16
17
18
# File 'lib/xero-ruby/configuration.rb', line 16

def scheme
  @scheme
end

#ssl_ca_file ⇒ String

TLS/SSL setting Set this to customize the certificate file to verify the peer.

Returns:

  • (String) —

    the path to the certificate file



115
116
117
# File 'lib/xero-ruby/configuration.rb', line 115

def ssl_ca_file
  @ssl_ca_file
end

#ssl_client_cert ⇒ Object

TLS/SSL setting Client certificate file (for client certificate)



119
120
121
# File 'lib/xero-ruby/configuration.rb', line 119

def ssl_client_cert
  @ssl_client_cert
end

#ssl_client_key ⇒ Object

TLS/SSL setting Client private key file (for client certificate)



123
124
125
# File 'lib/xero-ruby/configuration.rb', line 123

def ssl_client_key
  @ssl_client_key
end

#ssl_verify ⇒ true, false

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.

Returns:

  • (true, false)


102
103
104
# File 'lib/xero-ruby/configuration.rb', line 102

def ssl_verify
  @ssl_verify
end

#ssl_verify_mode ⇒ Object

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Any OpenSSL::SSL:: constant (see https://ruby-doc.org/stdlib-2.5.1/libdoc/openssl/rdoc/OpenSSL/SSL.html)



109
110
111
# File 'lib/xero-ruby/configuration.rb', line 109

def ssl_verify_mode
  @ssl_verify_mode
end

#temp_folder_path ⇒ String

Defines the temporary folder to store downloaded files (for API endpoints that have file response). Default to use Tempfile.

Returns:

  • (String)


84
85
86
# File 'lib/xero-ruby/configuration.rb', line 84

def temp_folder_path
  @temp_folder_path
end

#timeout ⇒ Object

The time limit for HTTP request in seconds. Default to 0 (never times out).



88
89
90
# File 'lib/xero-ruby/configuration.rb', line 88

def timeout
  @timeout
end

#token_set ⇒ Object

Defines the token set used with OAuth2. May include id/access/refresh token & other meta info.



64
65
66
# File 'lib/xero-ruby/configuration.rb', line 64

def token_set
  @token_set
end

#token_url ⇒ Object

Returns the value of attribute token_url.



27
28
29
# File 'lib/xero-ruby/configuration.rb', line 27

def token_url
  @token_url
end

#username ⇒ String

Defines the username used with HTTP basic authentication.

Returns:

  • (String)


53
54
55
# File 'lib/xero-ruby/configuration.rb', line 53

def username
  @username
end

Class Method Details

.default ⇒ Object

The default Configuration object.



163
164
165
# File 'lib/xero-ruby/configuration.rb', line 163

def self.default
  @@default ||= Configuration.new
end

Instance Method Details

#api_key_with_prefix(param_name) ⇒ Object

Gets API key (with prefix if set).

Parameters:

  • param_name (String) —

    the parameter name of API key auth



193
194
195
196
197
198
199
# File 'lib/xero-ruby/configuration.rb', line 193

def api_key_with_prefix(param_name)
  if @api_key_prefix[param_name]
    "#{@api_key_prefix[param_name]} #{@api_key[param_name]}"
  else
    @api_key[param_name]
  end
end

#auth_settings ⇒ Object

Returns Auth Settings hash for api client.



207
208
209
210
211
212
213
214
215
216
217
# File 'lib/xero-ruby/configuration.rb', line 207

def auth_settings
  {
    'OAuth2' =>
      {
        type: 'oauth2',
        in: 'header',
        key: 'Authorization',
        value: "Bearer #{access_token}"
      },
  }
end

#basic_auth_token ⇒ Object

Gets Basic Auth token string



202
203
204
# File 'lib/xero-ruby/configuration.rb', line 202

def basic_auth_token
  'Basic ' + ["#{username}:#{password}"].pack('m').delete("\r\n")
end

#configure {|_self| ... } ⇒ Object

Yields:

  • (_self)

Yield Parameters:



167
168
169
# File 'lib/xero-ruby/configuration.rb', line 167

def configure
  yield(self) if block_given?
end

#server_settings ⇒ Object

Returns an array of Server setting



220
221
222
223
224
225
226
227
# File 'lib/xero-ruby/configuration.rb', line 220

def server_settings
  [
    {
      url: "https://api.xero.com/api.xro/2.0",
      description: "Xero Accounting API servers",
    }
  ]
end

#server_url(index, variables = {}) ⇒ Object

Returns URL based on server settings

Parameters:

  • index —

    array index of the server settings

  • variables (defaults to: {}) —

    hash of variable and the corresponding value



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/xero-ruby/configuration.rb', line 233

def server_url(index, variables = {})
  servers = server_settings

  # check array index out of bound
  if (index < 0 || index >= servers.size)
    fail ArgumentError, "Invalid index #{index} when selecting the server. Must be less than #{servers.size}"
  end

  server = servers[index]
  url = server[:url]

  # go through variable and assign a value
  server[:variables].each do |name, variable|
    if variables.key?(name)
      if (server[:variables][name][:enum_values].include? variables[name])
        url.gsub! "{" + name.to_s + "}", variables[name]
      else
        fail ArgumentError, "The variable `#{name}` in the server URL has invalid value #{variables[name]}. Must be #{server[:variables][name][:enum_values]}."
      end
    else
      # use default value
      url.gsub! "{" + name.to_s + "}", server[:variables][name][:default_value]
    end
  end

  url
end