Class: XeroRuby::CreditNote

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/credit_note.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreditNote

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/xero-ruby/models/credit_note.rb', line 166

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::CreditNote` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::CreditNote`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'contact')
    self.contact = attributes[:'contact']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'line_amount_types')
    self.line_amount_types = attributes[:'line_amount_types']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'sub_total')
    self.sub_total = attributes[:'sub_total']
  end

  if attributes.key?(:'total_tax')
    self.total_tax = attributes[:'total_tax']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'currency_code')
    self.currency_code = attributes[:'currency_code']
  end

  if attributes.key?(:'fully_paid_on_date')
    self.fully_paid_on_date = attributes[:'fully_paid_on_date']
  end

  if attributes.key?(:'credit_note_id')
    self.credit_note_id = attributes[:'credit_note_id']
  end

  if attributes.key?(:'credit_note_number')
    self.credit_note_number = attributes[:'credit_note_number']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'sent_to_contact')
    self.sent_to_contact = attributes[:'sent_to_contact']
  end

  if attributes.key?(:'currency_rate')
    self.currency_rate = attributes[:'currency_rate']
  end

  if attributes.key?(:'remaining_credit')
    self.remaining_credit = attributes[:'remaining_credit']
  end

  if attributes.key?(:'allocations')
    if (value = attributes[:'allocations']).is_a?(Array)
      self.allocations = value
    end
  end

  if attributes.key?(:'payments')
    if (value = attributes[:'payments']).is_a?(Array)
      self.payments = value
    end
  end

  if attributes.key?(:'branding_theme_id')
    self.branding_theme_id = attributes[:'branding_theme_id']
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end
end

Instance Attribute Details

#allocations ⇒ Object

See Allocations



70
71
72
# File 'lib/xero-ruby/models/credit_note.rb', line 70

def allocations
  @allocations
end

#branding_theme_id ⇒ Object

See BrandingThemes



76
77
78
# File 'lib/xero-ruby/models/credit_note.rb', line 76

def branding_theme_id
  @branding_theme_id
end

#contact ⇒ Object

Returns the value of attribute contact.



21
22
23
# File 'lib/xero-ruby/models/credit_note.rb', line 21

def contact
  @contact
end

#credit_note_id ⇒ Object

Xero generated unique identifier



52
53
54
# File 'lib/xero-ruby/models/credit_note.rb', line 52

def credit_note_id
  @credit_note_id
end

#credit_note_number ⇒ Object

ACCRECCREDIT – Unique alpha numeric code identifying credit note (when missing will auto-generate from your Organisation Invoice Settings)



55
56
57
# File 'lib/xero-ruby/models/credit_note.rb', line 55

def credit_note_number
  @credit_note_number
end

#currency_code ⇒ Object

Returns the value of attribute currency_code.



46
47
48
# File 'lib/xero-ruby/models/credit_note.rb', line 46

def currency_code
  @currency_code
end

#currency_rate ⇒ Object

The currency rate for a multicurrency invoice. If no rate is specified, the XE.com day rate is used



64
65
66
# File 'lib/xero-ruby/models/credit_note.rb', line 64

def currency_rate
  @currency_rate
end

#date ⇒ Object

The date the credit note is issued YYYY-MM-DD. If the Date element is not specified then it will default to the current date based on the timezone setting of the organisation



24
25
26
# File 'lib/xero-ruby/models/credit_note.rb', line 24

def date
  @date
end

#fully_paid_on_date ⇒ Object

Date when credit note was fully paid(UTC format)



49
50
51
# File 'lib/xero-ruby/models/credit_note.rb', line 49

def fully_paid_on_date
  @fully_paid_on_date
end

#has_attachments ⇒ Object

boolean to indicate if a credit note has an attachment



79
80
81
# File 'lib/xero-ruby/models/credit_note.rb', line 79

def has_attachments
  @has_attachments
end

#line_amount_types ⇒ Object

Returns the value of attribute line_amount_types.



29
30
31
# File 'lib/xero-ruby/models/credit_note.rb', line 29

def line_amount_types
  @line_amount_types
end

#line_items ⇒ Object

See Invoice Line Items



32
33
34
# File 'lib/xero-ruby/models/credit_note.rb', line 32

def line_items
  @line_items
end

#payments ⇒ Object

See Payments



73
74
75
# File 'lib/xero-ruby/models/credit_note.rb', line 73

def payments
  @payments
end

#reference ⇒ Object

ACCRECCREDIT only – additional reference number



58
59
60
# File 'lib/xero-ruby/models/credit_note.rb', line 58

def reference
  @reference
end

#remaining_credit ⇒ Object

The remaining credit balance on the Credit Note



67
68
69
# File 'lib/xero-ruby/models/credit_note.rb', line 67

def remaining_credit
  @remaining_credit
end

#sent_to_contact ⇒ Object

boolean to indicate if a credit note has been sent to a contact via the Xero app (currently read only)



61
62
63
# File 'lib/xero-ruby/models/credit_note.rb', line 61

def sent_to_contact
  @sent_to_contact
end

#status ⇒ Object

See Credit Note Status Codes



27
28
29
# File 'lib/xero-ruby/models/credit_note.rb', line 27

def status
  @status
end

#sub_total ⇒ Object

The subtotal of the credit note excluding taxes



35
36
37
# File 'lib/xero-ruby/models/credit_note.rb', line 35

def sub_total
  @sub_total
end

#total ⇒ Object

The total of the Credit Note(subtotal + total tax)



41
42
43
# File 'lib/xero-ruby/models/credit_note.rb', line 41

def total
  @total
end

#total_tax ⇒ Object

The total tax on the credit note



38
39
40
# File 'lib/xero-ruby/models/credit_note.rb', line 38

def total_tax
  @total_tax
end

#type ⇒ Object

See Credit Note Types



19
20
21
# File 'lib/xero-ruby/models/credit_note.rb', line 19

def type
  @type
end

#updated_date_utc ⇒ Object

UTC timestamp of last update to the credit note



44
45
46
# File 'lib/xero-ruby/models/credit_note.rb', line 44

def updated_date_utc
  @updated_date_utc
end

#validation_errors ⇒ Object

Displays array of validation error messages from the API



82
83
84
# File 'lib/xero-ruby/models/credit_note.rb', line 82

def validation_errors
  @validation_errors
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/xero-ruby/models/credit_note.rb', line 107

def self.attribute_map
  {
    :'type' => :'Type',
    :'contact' => :'Contact',
    :'date' => :'Date',
    :'status' => :'Status',
    :'line_amount_types' => :'LineAmountTypes',
    :'line_items' => :'LineItems',
    :'sub_total' => :'SubTotal',
    :'total_tax' => :'TotalTax',
    :'total' => :'Total',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'currency_code' => :'CurrencyCode',
    :'fully_paid_on_date' => :'FullyPaidOnDate',
    :'credit_note_id' => :'CreditNoteID',
    :'credit_note_number' => :'CreditNoteNumber',
    :'reference' => :'Reference',
    :'sent_to_contact' => :'SentToContact',
    :'currency_rate' => :'CurrencyRate',
    :'remaining_credit' => :'RemainingCredit',
    :'allocations' => :'Allocations',
    :'payments' => :'Payments',
    :'branding_theme_id' => :'BrandingThemeID',
    :'has_attachments' => :'HasAttachments',
    :'validation_errors' => :'ValidationErrors'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



362
363
364
# File 'lib/xero-ruby/models/credit_note.rb', line 362

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/xero-ruby/models/credit_note.rb', line 136

def self.openapi_types
  {
    :'type' => :'String',
    :'contact' => :'Contact',
    :'date' => :'Date',
    :'status' => :'String',
    :'line_amount_types' => :'LineAmountTypes',
    :'line_items' => :'Array<LineItem>',
    :'sub_total' => :'Float',
    :'total_tax' => :'Float',
    :'total' => :'Float',
    :'updated_date_utc' => :'DateTime',
    :'currency_code' => :'CurrencyCode',
    :'fully_paid_on_date' => :'Date',
    :'credit_note_id' => :'String',
    :'credit_note_number' => :'String',
    :'reference' => :'String',
    :'sent_to_contact' => :'Boolean',
    :'currency_rate' => :'Float',
    :'remaining_credit' => :'Float',
    :'allocations' => :'Array<Allocation>',
    :'payments' => :'Array<Payment>',
    :'branding_theme_id' => :'String',
    :'has_attachments' => :'Boolean',
    :'validation_errors' => :'Array<ValidationError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/xero-ruby/models/credit_note.rb', line 319

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      contact == o.contact &&
      date == o.date &&
      status == o.status &&
      line_amount_types == o.line_amount_types &&
      line_items == o.line_items &&
      sub_total == o.sub_total &&
      total_tax == o.total_tax &&
      total == o.total &&
      updated_date_utc == o.updated_date_utc &&
      currency_code == o.currency_code &&
      fully_paid_on_date == o.fully_paid_on_date &&
      credit_note_id == o.credit_note_id &&
      credit_note_number == o.credit_note_number &&
      reference == o.reference &&
      sent_to_contact == o.sent_to_contact &&
      currency_rate == o.currency_rate &&
      remaining_credit == o.remaining_credit &&
      allocations == o.allocations &&
      payments == o.payments &&
      branding_theme_id == o.branding_theme_id &&
      has_attachments == o.has_attachments &&
      validation_errors == o.validation_errors
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/xero-ruby/models/credit_note.rb', line 390

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/xero-ruby/models/credit_note.rb', line 455

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/xero-ruby/models/credit_note.rb', line 369

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


349
350
351
# File 'lib/xero-ruby/models/credit_note.rb', line 349

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



355
356
357
# File 'lib/xero-ruby/models/credit_note.rb', line 355

def hash
  [type, contact, date, status, line_amount_types, line_items, sub_total, total_tax, total, updated_date_utc, currency_code, fully_paid_on_date, credit_note_id, credit_note_number, reference, sent_to_contact, currency_rate, remaining_credit, allocations, payments, branding_theme_id, has_attachments, validation_errors].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



282
283
284
285
# File 'lib/xero-ruby/models/credit_note.rb', line 282

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



470
471
472
473
# File 'lib/xero-ruby/models/credit_note.rb', line 470

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



435
436
437
# File 'lib/xero-ruby/models/credit_note.rb', line 435

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



441
442
443
444
445
446
447
448
449
# File 'lib/xero-ruby/models/credit_note.rb', line 441

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



429
430
431
# File 'lib/xero-ruby/models/credit_note.rb', line 429

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



289
290
291
292
293
294
295
# File 'lib/xero-ruby/models/credit_note.rb', line 289

def valid?
  type_validator = EnumAttributeValidator.new('String', ["ACCPAYCREDIT", "ACCRECCREDIT"])
  return false unless type_validator.valid?(@type)
  status_validator = EnumAttributeValidator.new('String', ["DRAFT", "SUBMITTED", "DELETED", "AUTHORISED", "PAID", "VOIDED"])
  return false unless status_validator.valid?(@status)
  true
end