Class: XeroRuby::PayrollAu::DeductionType

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/payroll_au/deduction_type.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

NONE =
"NONE".freeze
UNIONFEES =
"UNIONFEES".freeze
WORKPLACEGIVING =
"WORKPLACEGIVING".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DeductionType

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollAu::DeductionType` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollAu::DeductionType`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'account_code')
    self. = attributes[:'account_code']
  end

  if attributes.key?(:'reduces_tax')
    self.reduces_tax = attributes[:'reduces_tax']
  end

  if attributes.key?(:'reduces_super')
    self.reduces_super = attributes[:'reduces_super']
  end

  if attributes.key?(:'is_exempt_from_w1')
    self.is_exempt_from_w1 = attributes[:'is_exempt_from_w1']
  end

  if attributes.key?(:'deduction_type_id')
    self.deduction_type_id = attributes[:'deduction_type_id']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'deduction_category')
    self.deduction_category = attributes[:'deduction_category']
  end

  if attributes.key?(:'current_record')
    self.current_record = attributes[:'current_record']
  end
end

Instance Attribute Details

#account_codeObject

See Accounts



24
25
26
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 24

def 
  @account_code
end

#current_recordObject

Is the current record



48
49
50
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 48

def current_record
  @current_record
end

#deduction_categoryObject

Returns the value of attribute deduction_category.



42
43
44
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 42

def deduction_category
  @deduction_category
end

#deduction_type_idObject

Xero identifier



36
37
38
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 36

def deduction_type_id
  @deduction_type_id
end

#is_exempt_from_w1Object

Boolean to determine if the deduction type is reportable or exempt from W1



33
34
35
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 33

def is_exempt_from_w1
  @is_exempt_from_w1
end

#nameObject

Name of the earnings rate (max length = 100)



21
22
23
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 21

def name
  @name
end

#reduces_superObject

Most deductions don’t reduce your superannuation guarantee contribution liability, so typically you will not set any value for this.



30
31
32
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 30

def reduces_super
  @reduces_super
end

#reduces_taxObject

Indicates that this is a pre-tax deduction that will reduce the amount of tax you withhold from an employee.



27
28
29
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 27

def reduces_tax
  @reduces_tax
end

#updated_date_utcObject

Last modified timestamp



39
40
41
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 39

def updated_date_utc
  @updated_date_utc
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 73

def self.attribute_map
  {
    :'name' => :'Name',
    :'account_code' => :'AccountCode',
    :'reduces_tax' => :'ReducesTax',
    :'reduces_super' => :'ReducesSuper',
    :'is_exempt_from_w1' => :'IsExemptFromW1',
    :'deduction_type_id' => :'DeductionTypeID',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'deduction_category' => :'DeductionCategory',
    :'current_record' => :'CurrentRecord'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 225

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 88

def self.openapi_types
  {
    :'name' => :'String',
    :'account_code' => :'String',
    :'reduces_tax' => :'Boolean',
    :'reduces_super' => :'Boolean',
    :'is_exempt_from_w1' => :'Boolean',
    :'deduction_type_id' => :'String',
    :'updated_date_utc' => :'DateTime',
    :'deduction_category' => :'String',
    :'current_record' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 196

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
       == o. &&
      reduces_tax == o.reduces_tax &&
      reduces_super == o.reduces_super &&
      is_exempt_from_w1 == o.is_exempt_from_w1 &&
      deduction_type_id == o.deduction_type_id &&
      updated_date_utc == o.updated_date_utc &&
      deduction_category == o.deduction_category &&
      current_record == o.current_record
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 253

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BigDecimal
    BigDecimal(value.to_s)
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::PayrollAu.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 320

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 232

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


212
213
214
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 212

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



218
219
220
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 218

def hash
  [name, , reduces_tax, reduces_super, is_exempt_from_w1, deduction_type_id, updated_date_utc, deduction_category, current_record].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
161
162
163
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 156

def list_invalid_properties
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



335
336
337
338
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 335

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



300
301
302
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 300

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



306
307
308
309
310
311
312
313
314
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 306

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



294
295
296
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 294

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
# File 'lib/xero-ruby/models/payroll_au/deduction_type.rb', line 167

def valid?
  return false if !@name.nil? && @name.to_s.length > 100
  deduction_category_validator = EnumAttributeValidator.new('String', ["NONE", "UNIONFEES", "WORKPLACEGIVING"])
  return false unless deduction_category_validator.valid?(@deduction_category)
  true
end