Class: XeroRuby::PayrollAu::EarningsRate

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/payroll_au/earnings_rate.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EarningsRate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollAu::EarningsRate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollAu::EarningsRate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'account_code')
    self. = attributes[:'account_code']
  end

  if attributes.key?(:'type_of_units')
    self.type_of_units = attributes[:'type_of_units']
  end

  if attributes.key?(:'is_exempt_from_tax')
    self.is_exempt_from_tax = attributes[:'is_exempt_from_tax']
  end

  if attributes.key?(:'is_exempt_from_super')
    self.is_exempt_from_super = attributes[:'is_exempt_from_super']
  end

  if attributes.key?(:'is_reportable_as_w1')
    self.is_reportable_as_w1 = attributes[:'is_reportable_as_w1']
  end

  if attributes.key?(:'earnings_type')
    self.earnings_type = attributes[:'earnings_type']
  end

  if attributes.key?(:'earnings_rate_id')
    self.earnings_rate_id = attributes[:'earnings_rate_id']
  end

  if attributes.key?(:'rate_type')
    self.rate_type = attributes[:'rate_type']
  end

  if attributes.key?(:'rate_per_unit')
    self.rate_per_unit = attributes[:'rate_per_unit']
  end

  if attributes.key?(:'multiplier')
    self.multiplier = attributes[:'multiplier']
  end

  if attributes.key?(:'accrue_leave')
    self.accrue_leave = attributes[:'accrue_leave']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'employment_termination_payment_type')
    self.employment_termination_payment_type = attributes[:'employment_termination_payment_type']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'current_record')
    self.current_record = attributes[:'current_record']
  end

  if attributes.key?(:'allowance_type')
    self.allowance_type = attributes[:'allowance_type']
  end
end

Instance Attribute Details

#account_codeObject

See Accounts



24
25
26
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 24

def 
  @account_code
end

#accrue_leaveObject

Indicates that this earnings rate should accrue leave. Only applicable if RateType is MULTIPLE



54
55
56
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 54

def accrue_leave
  @accrue_leave
end

#allowance_typeObject

Returns the value of attribute allowance_type.



69
70
71
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 69

def allowance_type
  @allowance_type
end

#amountObject

Optional Amount for FIXEDAMOUNT RateType EarningsRate



57
58
59
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 57

def amount
  @amount
end

#current_recordObject

Is the current record



66
67
68
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 66

def current_record
  @current_record
end

#earnings_rate_idObject

Xero identifier



42
43
44
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 42

def earnings_rate_id
  @earnings_rate_id
end

#earnings_typeObject

Returns the value of attribute earnings_type.



39
40
41
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 39

def earnings_type
  @earnings_type
end

#employment_termination_payment_typeObject

Returns the value of attribute employment_termination_payment_type.



60
61
62
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 60

def employment_termination_payment_type
  @employment_termination_payment_type
end

#is_exempt_from_superObject

See the ATO website for details of which payments are exempt from SGC



33
34
35
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 33

def is_exempt_from_super
  @is_exempt_from_super
end

#is_exempt_from_taxObject

Most payments are subject to tax, so you should only set this value if you are sure that a payment is exempt from PAYG withholding



30
31
32
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 30

def is_exempt_from_tax
  @is_exempt_from_tax
end

#is_reportable_as_w1Object

Boolean to determine if the earnings rate is reportable or exempt from W1



36
37
38
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 36

def is_reportable_as_w1
  @is_reportable_as_w1
end

#multiplierObject

This is the multiplier used to calculate the rate per unit, based on the employee’s ordinary earnings rate. For example, for time and a half enter 1.5. Only applicable if RateType is MULTIPLE



51
52
53
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 51

def multiplier
  @multiplier
end

#nameObject

Name of the earnings rate (max length = 100)



21
22
23
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 21

def name
  @name
end

#rate_per_unitObject

Default rate per unit (optional). Only applicable if RateType is RATEPERUNIT.



48
49
50
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 48

def rate_per_unit
  @rate_per_unit
end

#rate_typeObject

Returns the value of attribute rate_type.



45
46
47
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 45

def rate_type
  @rate_type
end

#type_of_unitsObject

Type of units used to record earnings (max length = 50). Only When RateType is RATEPERUNIT



27
28
29
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 27

def type_of_units
  @type_of_units
end

#updated_date_utcObject

Last modified timestamp



63
64
65
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 63

def updated_date_utc
  @updated_date_utc
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 72

def self.attribute_map
  {
    :'name' => :'Name',
    :'account_code' => :'AccountCode',
    :'type_of_units' => :'TypeOfUnits',
    :'is_exempt_from_tax' => :'IsExemptFromTax',
    :'is_exempt_from_super' => :'IsExemptFromSuper',
    :'is_reportable_as_w1' => :'IsReportableAsW1',
    :'earnings_type' => :'EarningsType',
    :'earnings_rate_id' => :'EarningsRateID',
    :'rate_type' => :'RateType',
    :'rate_per_unit' => :'RatePerUnit',
    :'multiplier' => :'Multiplier',
    :'accrue_leave' => :'AccrueLeave',
    :'amount' => :'Amount',
    :'employment_termination_payment_type' => :'EmploymentTerminationPaymentType',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'current_record' => :'CurrentRecord',
    :'allowance_type' => :'AllowanceType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 283

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 95

def self.openapi_types
  {
    :'name' => :'String',
    :'account_code' => :'String',
    :'type_of_units' => :'String',
    :'is_exempt_from_tax' => :'Boolean',
    :'is_exempt_from_super' => :'Boolean',
    :'is_reportable_as_w1' => :'Boolean',
    :'earnings_type' => :'EarningsType',
    :'earnings_rate_id' => :'String',
    :'rate_type' => :'RateType',
    :'rate_per_unit' => :'String',
    :'multiplier' => :'BigDecimal',
    :'accrue_leave' => :'Boolean',
    :'amount' => :'BigDecimal',
    :'employment_termination_payment_type' => :'EmploymentTerminationPaymentType',
    :'updated_date_utc' => :'DateTime',
    :'current_record' => :'Boolean',
    :'allowance_type' => :'AllowanceType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
       == o. &&
      type_of_units == o.type_of_units &&
      is_exempt_from_tax == o.is_exempt_from_tax &&
      is_exempt_from_super == o.is_exempt_from_super &&
      is_reportable_as_w1 == o.is_reportable_as_w1 &&
      earnings_type == o.earnings_type &&
      earnings_rate_id == o.earnings_rate_id &&
      rate_type == o.rate_type &&
      rate_per_unit == o.rate_per_unit &&
      multiplier == o.multiplier &&
      accrue_leave == o.accrue_leave &&
      amount == o.amount &&
      employment_termination_payment_type == o.employment_termination_payment_type &&
      updated_date_utc == o.updated_date_utc &&
      current_record == o.current_record &&
      allowance_type == o.allowance_type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 311

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BigDecimal
    BigDecimal(value.to_s)
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::PayrollAu.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 378

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 290

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


270
271
272
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 270

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



276
277
278
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 276

def hash
  [name, , type_of_units, is_exempt_from_tax, is_exempt_from_super, is_reportable_as_w1, earnings_type, earnings_rate_id, rate_type, rate_per_unit, multiplier, accrue_leave, amount, employment_termination_payment_type, updated_date_utc, current_record, allowance_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 203

def list_invalid_properties
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if !@type_of_units.nil? && @type_of_units.to_s.length > 50
    invalid_properties.push('invalid value for "type_of_units", the character length must be smaller than or equal to 50.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



393
394
395
396
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 393

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



358
359
360
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 358

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



364
365
366
367
368
369
370
371
372
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 364

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



352
353
354
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 352

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



218
219
220
221
222
# File 'lib/xero-ruby/models/payroll_au/earnings_rate.rb', line 218

def valid?
  return false if !@name.nil? && @name.to_s.length > 100
  return false if !@type_of_units.nil? && @type_of_units.to_s.length > 50
  true
end