Class: XeroRuby::PayrollAu::LeaveApplication

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/payroll_au/leave_application.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LeaveApplication

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollAu::LeaveApplication` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollAu::LeaveApplication`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'leave_application_id')
    self.leave_application_id = attributes[:'leave_application_id']
  end

  if attributes.key?(:'employee_id')
    self.employee_id = attributes[:'employee_id']
  end

  if attributes.key?(:'leave_type_id')
    self.leave_type_id = attributes[:'leave_type_id']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'leave_periods')
    if (value = attributes[:'leave_periods']).is_a?(Array)
      self.leave_periods = value
    end
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end
end

Instance Attribute Details

#descriptionObject

The Description of the Leave



39
40
41
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 39

def description
  @description
end

#employee_idObject

The Xero identifier for Payroll Employee



24
25
26
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 24

def employee_id
  @employee_id
end

#end_dateObject

End date of the leave (YYYY-MM-DD)



36
37
38
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 36

def end_date
  @end_date
end

#leave_application_idObject

The Xero identifier for Payroll Employee



21
22
23
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 21

def leave_application_id
  @leave_application_id
end

#leave_periodsObject

Returns the value of attribute leave_periods.



42
43
44
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 42

def leave_periods
  @leave_periods
end

#leave_type_idObject

The Xero identifier for Leave Type



27
28
29
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 27

def leave_type_id
  @leave_type_id
end

#start_dateObject

Start date of the leave (YYYY-MM-DD)



33
34
35
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 33

def start_date
  @start_date
end

#titleObject

The title of the leave



30
31
32
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 30

def title
  @title
end

#updated_date_utcObject

Last modified timestamp



45
46
47
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 45

def updated_date_utc
  @updated_date_utc
end

#validation_errorsObject

Displays array of validation error messages from the API



48
49
50
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 48

def validation_errors
  @validation_errors
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 51

def self.attribute_map
  {
    :'leave_application_id' => :'LeaveApplicationID',
    :'employee_id' => :'EmployeeID',
    :'leave_type_id' => :'LeaveTypeID',
    :'title' => :'Title',
    :'start_date' => :'StartDate',
    :'end_date' => :'EndDate',
    :'description' => :'Description',
    :'leave_periods' => :'LeavePeriods',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'validation_errors' => :'ValidationErrors'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



187
188
189
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 187

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 67

def self.openapi_types
  {
    :'leave_application_id' => :'String',
    :'employee_id' => :'String',
    :'leave_type_id' => :'String',
    :'title' => :'String',
    :'start_date' => :'Date',
    :'end_date' => :'Date',
    :'description' => :'String',
    :'leave_periods' => :'Array<LeavePeriod>',
    :'updated_date_utc' => :'DateTime',
    :'validation_errors' => :'Array<ValidationError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 157

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      leave_application_id == o.leave_application_id &&
      employee_id == o.employee_id &&
      leave_type_id == o.leave_type_id &&
      title == o.title &&
      start_date == o.start_date &&
      end_date == o.end_date &&
      description == o.description &&
      leave_periods == o.leave_periods &&
      updated_date_utc == o.updated_date_utc &&
      validation_errors == o.validation_errors
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 215

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BigDecimal
    BigDecimal(value.to_s)
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::PayrollAu.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 282

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 194

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • to be compared

Returns:

See Also:

  • `==` method


174
175
176
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 174

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



180
181
182
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 180

def hash
  [leave_application_id, employee_id, leave_type_id, title, start_date, end_date, description, leave_periods, updated_date_utc, validation_errors].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 144

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



297
298
299
300
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 297

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



262
263
264
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 262

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



268
269
270
271
272
273
274
275
276
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 268

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



256
257
258
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 256

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



151
152
153
# File 'lib/xero-ruby/models/payroll_au/leave_application.rb', line 151

def valid?
  true
end