Class: XeroRuby::PayrollAu::LeaveLine
- Inherits:
-
Object
- Object
- XeroRuby::PayrollAu::LeaveLine
- Defined in:
- lib/xero-ruby/models/payroll_au/leave_line.rb
Instance Attribute Summary collapse
-
#annual_number_of_units ⇒ Object
Hours of leave accrued each year.
-
#calculation_type ⇒ Object
Returns the value of attribute calculation_type.
-
#employment_termination_payment_type ⇒ Object
Returns the value of attribute employment_termination_payment_type.
-
#entitlement_final_pay_payout_type ⇒ Object
Returns the value of attribute entitlement_final_pay_payout_type.
-
#full_time_number_of_units_per_period ⇒ Object
Normal ordinary earnings number of units for leave line.
-
#include_superannuation_guarantee_contribution ⇒ Object
amount of leave line.
-
#is_qualifying_earnings ⇒ Object
Optional Boolean to determine if the earnings rate is considered as qualifying earnings for superannuation guarantee calculations.
-
#leave_type_id ⇒ Object
Xero leave type identifier.
-
#number_of_units ⇒ Object
Number of units for leave line.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value, downcase: false) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LeaveLine
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
- #parse_date(datestring) ⇒ Object
-
#to_attributes ⇒ Object
Returns the object in the form of hash with snake_case.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash(downcase: false) ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ LeaveLine
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollAu::LeaveLine` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollAu::LeaveLine`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'leave_type_id') self.leave_type_id = attributes[:'leave_type_id'] end if attributes.key?(:'calculation_type') self.calculation_type = attributes[:'calculation_type'] end if attributes.key?(:'entitlement_final_pay_payout_type') self.entitlement_final_pay_payout_type = attributes[:'entitlement_final_pay_payout_type'] end if attributes.key?(:'employment_termination_payment_type') self.employment_termination_payment_type = attributes[:'employment_termination_payment_type'] end if attributes.key?(:'include_superannuation_guarantee_contribution') self.include_superannuation_guarantee_contribution = attributes[:'include_superannuation_guarantee_contribution'] end if attributes.key?(:'is_qualifying_earnings') self. = attributes[:'is_qualifying_earnings'] end if attributes.key?(:'number_of_units') self.number_of_units = attributes[:'number_of_units'] end if attributes.key?(:'annual_number_of_units') self.annual_number_of_units = attributes[:'annual_number_of_units'] end if attributes.key?(:'full_time_number_of_units_per_period') self.full_time_number_of_units_per_period = attributes[:'full_time_number_of_units_per_period'] end end |
Instance Attribute Details
#annual_number_of_units ⇒ Object
Hours of leave accrued each year
41 42 43 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 41 def annual_number_of_units @annual_number_of_units end |
#calculation_type ⇒ Object
Returns the value of attribute calculation_type.
23 24 25 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 23 def calculation_type @calculation_type end |
#employment_termination_payment_type ⇒ Object
Returns the value of attribute employment_termination_payment_type.
29 30 31 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 29 def employment_termination_payment_type @employment_termination_payment_type end |
#entitlement_final_pay_payout_type ⇒ Object
Returns the value of attribute entitlement_final_pay_payout_type.
26 27 28 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 26 def entitlement_final_pay_payout_type @entitlement_final_pay_payout_type end |
#full_time_number_of_units_per_period ⇒ Object
Normal ordinary earnings number of units for leave line.
44 45 46 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 44 def full_time_number_of_units_per_period @full_time_number_of_units_per_period end |
#include_superannuation_guarantee_contribution ⇒ Object
amount of leave line
32 33 34 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 32 def include_superannuation_guarantee_contribution @include_superannuation_guarantee_contribution end |
#is_qualifying_earnings ⇒ Object
Optional Boolean to determine if the earnings rate is considered as qualifying earnings for superannuation guarantee calculations. When not specified value is calculated based on superannuation settings
35 36 37 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 35 def @is_qualifying_earnings end |
#leave_type_id ⇒ Object
Xero leave type identifier
20 21 22 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 20 def leave_type_id @leave_type_id end |
#number_of_units ⇒ Object
Number of units for leave line.
38 39 40 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 38 def number_of_units @number_of_units end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 47 def self.attribute_map { :'leave_type_id' => :'LeaveTypeID', :'calculation_type' => :'CalculationType', :'entitlement_final_pay_payout_type' => :'EntitlementFinalPayPayoutType', :'employment_termination_payment_type' => :'EmploymentTerminationPaymentType', :'include_superannuation_guarantee_contribution' => :'IncludeSuperannuationGuaranteeContribution', :'is_qualifying_earnings' => :'IsQualifyingEarnings', :'number_of_units' => :'NumberOfUnits', :'annual_number_of_units' => :'AnnualNumberOfUnits', :'full_time_number_of_units_per_period' => :'FullTimeNumberOfUnitsPerPeriod' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 172 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 62 def self.openapi_types { :'leave_type_id' => :'String', :'calculation_type' => :'LeaveLineCalculationType', :'entitlement_final_pay_payout_type' => :'EntitlementFinalPayPayoutType', :'employment_termination_payment_type' => :'EmploymentTerminationPaymentType', :'include_superannuation_guarantee_contribution' => :'Boolean', :'is_qualifying_earnings' => :'Boolean', :'number_of_units' => :'BigDecimal', :'annual_number_of_units' => :'BigDecimal', :'full_time_number_of_units_per_period' => :'BigDecimal' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 143 def ==(o) return true if self.equal?(o) self.class == o.class && leave_type_id == o.leave_type_id && calculation_type == o.calculation_type && entitlement_final_pay_payout_type == o.entitlement_final_pay_payout_type && employment_termination_payment_type == o.employment_termination_payment_type && include_superannuation_guarantee_contribution == o.include_superannuation_guarantee_contribution && == o. && number_of_units == o.number_of_units && annual_number_of_units == o.annual_number_of_units && full_time_number_of_units_per_period == o.full_time_number_of_units_per_period end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 200 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::PayrollAu.const_get(type).build_from_hash(value) end end |
#_to_hash(value, downcase: false) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 273 def _to_hash(value, downcase: false) if value.is_a?(Array) value.map do |v| v.to_hash(downcase: downcase) end elsif value.is_a?(Hash) {}.tap do |hash| value.map { |k, v| hash[k] = _to_hash(v, downcase: downcase) } end elsif value.respond_to? :to_hash value.to_hash(downcase: downcase) else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 179 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 165 def hash [leave_type_id, calculation_type, entitlement_final_pay_payout_type, employment_termination_payment_type, include_superannuation_guarantee_contribution, , number_of_units, annual_number_of_units, full_time_number_of_units_per_period].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
130 131 132 133 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 130 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 289 def parse_date(datestring) if datestring.include?('Date') date_pattern = /\/Date\((-?\d+)(\+\d+)?\)\// original, date, timezone = *date_pattern.match(datestring) date = (date.to_i / 1000) Time.at(date).utc.strftime('%Y-%m-%dT%H:%M:%S%z').to_s elsif /(\d\d\d\d)-(\d\d)/.match(datestring) # handles dates w/out Days: YYYY-MM*-DD Time.parse(datestring + '-01').strftime('%Y-%m-%dT%H:%M:%S').to_s else # handle date 'types' for small subset of payroll API's Time.parse(datestring).strftime('%Y-%m-%dT%H:%M:%S').to_s end end |
#to_attributes ⇒ Object
Returns the object in the form of hash with snake_case
265 266 267 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 265 def to_attributes to_hash(downcase: true) end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
247 248 249 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 247 def to_body to_hash end |
#to_hash(downcase: false) ⇒ Hash
Returns the object in the form of hash
253 254 255 256 257 258 259 260 261 262 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 253 def to_hash(downcase: false) hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? key = downcase ? attr : param hash[key] = _to_hash(value, downcase: downcase) end hash end |
#to_s ⇒ String
Returns the string representation of the object
241 242 243 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 241 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 |
# File 'lib/xero-ruby/models/payroll_au/leave_line.rb', line 137 def valid? true end |