Class: XeroRuby::PayrollAu::PayRun
- Inherits:
-
Object
- Object
- XeroRuby::PayrollAu::PayRun
- Defined in:
- lib/xero-ruby/models/payroll_au/pay_run.rb
Instance Attribute Summary collapse
-
#_super ⇒ Object
The total Super for the Payrun.
-
#deductions ⇒ Object
The total Deductions for the Payrun.
-
#net_pay ⇒ Object
The total NetPay for the Payrun.
-
#pay_run_id ⇒ Object
Xero identifier for pay run.
-
#pay_run_period_end_date ⇒ Object
Period End Date for the PayRun (YYYY-MM-DD).
-
#pay_run_period_start_date ⇒ Object
Period Start Date for the PayRun (YYYY-MM-DD).
-
#pay_run_status ⇒ Object
Returns the value of attribute pay_run_status.
-
#payment_date ⇒ Object
Payment Date for the PayRun (YYYY-MM-DD).
-
#payroll_calendar_id ⇒ Object
Xero identifier for pay run.
-
#payslip_message ⇒ Object
Payslip message for the PayRun.
-
#payslips ⇒ Object
The payslips in the payrun.
-
#reimbursement ⇒ Object
The total Reimbursements for the Payrun.
-
#tax ⇒ Object
The total Tax for the Payrun.
-
#updated_date_utc ⇒ Object
Last modified timestamp.
-
#validation_errors ⇒ Object
Displays array of validation error messages from the API.
-
#wages ⇒ Object
The total Wages for the Payrun.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PayRun
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PayRun
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollAu::PayRun` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollAu::PayRun`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'payroll_calendar_id') self.payroll_calendar_id = attributes[:'payroll_calendar_id'] end if attributes.key?(:'pay_run_id') self.pay_run_id = attributes[:'pay_run_id'] end if attributes.key?(:'pay_run_period_start_date') self.pay_run_period_start_date = attributes[:'pay_run_period_start_date'] end if attributes.key?(:'pay_run_period_end_date') self.pay_run_period_end_date = attributes[:'pay_run_period_end_date'] end if attributes.key?(:'pay_run_status') self.pay_run_status = attributes[:'pay_run_status'] end if attributes.key?(:'payment_date') self.payment_date = attributes[:'payment_date'] end if attributes.key?(:'payslip_message') self. = attributes[:'payslip_message'] end if attributes.key?(:'updated_date_utc') self.updated_date_utc = attributes[:'updated_date_utc'] end if attributes.key?(:'payslips') if (value = attributes[:'payslips']).is_a?(Array) self.payslips = value end end if attributes.key?(:'wages') self.wages = attributes[:'wages'] end if attributes.key?(:'deductions') self.deductions = attributes[:'deductions'] end if attributes.key?(:'tax') self.tax = attributes[:'tax'] end if attributes.key?(:'_super') self._super = attributes[:'_super'] end if attributes.key?(:'reimbursement') self.reimbursement = attributes[:'reimbursement'] end if attributes.key?(:'net_pay') self.net_pay = attributes[:'net_pay'] end if attributes.key?(:'validation_errors') if (value = attributes[:'validation_errors']).is_a?(Array) self.validation_errors = value end end end |
Instance Attribute Details
#_super ⇒ Object
The total Super for the Payrun
57 58 59 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 57 def _super @_super end |
#deductions ⇒ Object
The total Deductions for the Payrun
51 52 53 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 51 def deductions @deductions end |
#net_pay ⇒ Object
The total NetPay for the Payrun
63 64 65 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 63 def net_pay @net_pay end |
#pay_run_id ⇒ Object
Xero identifier for pay run
24 25 26 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 24 def pay_run_id @pay_run_id end |
#pay_run_period_end_date ⇒ Object
Period End Date for the PayRun (YYYY-MM-DD)
30 31 32 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 30 def pay_run_period_end_date @pay_run_period_end_date end |
#pay_run_period_start_date ⇒ Object
Period Start Date for the PayRun (YYYY-MM-DD)
27 28 29 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 27 def pay_run_period_start_date @pay_run_period_start_date end |
#pay_run_status ⇒ Object
Returns the value of attribute pay_run_status.
33 34 35 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 33 def pay_run_status @pay_run_status end |
#payment_date ⇒ Object
Payment Date for the PayRun (YYYY-MM-DD)
36 37 38 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 36 def payment_date @payment_date end |
#payroll_calendar_id ⇒ Object
Xero identifier for pay run
21 22 23 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 21 def payroll_calendar_id @payroll_calendar_id end |
#payslip_message ⇒ Object
Payslip message for the PayRun
39 40 41 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 39 def @payslip_message end |
#payslips ⇒ Object
The payslips in the payrun
45 46 47 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 45 def payslips @payslips end |
#reimbursement ⇒ Object
The total Reimbursements for the Payrun
60 61 62 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 60 def reimbursement @reimbursement end |
#tax ⇒ Object
The total Tax for the Payrun
54 55 56 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 54 def tax @tax end |
#updated_date_utc ⇒ Object
Last modified timestamp
42 43 44 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 42 def updated_date_utc @updated_date_utc end |
#validation_errors ⇒ Object
Displays array of validation error messages from the API
66 67 68 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 66 def validation_errors @validation_errors end |
#wages ⇒ Object
The total Wages for the Payrun
48 49 50 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 48 def wages @wages end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 69 def self.attribute_map { :'payroll_calendar_id' => :'PayrollCalendarID', :'pay_run_id' => :'PayRunID', :'pay_run_period_start_date' => :'PayRunPeriodStartDate', :'pay_run_period_end_date' => :'PayRunPeriodEndDate', :'pay_run_status' => :'PayRunStatus', :'payment_date' => :'PaymentDate', :'payslip_message' => :'PayslipMessage', :'updated_date_utc' => :'UpdatedDateUTC', :'payslips' => :'Payslips', :'wages' => :'Wages', :'deductions' => :'Deductions', :'tax' => :'Tax', :'_super' => :'Super', :'reimbursement' => :'Reimbursement', :'net_pay' => :'NetPay', :'validation_errors' => :'ValidationErrors' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
252 253 254 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 252 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 91 def self.openapi_types { :'payroll_calendar_id' => :'String', :'pay_run_id' => :'String', :'pay_run_period_start_date' => :'Date', :'pay_run_period_end_date' => :'Date', :'pay_run_status' => :'PayRunStatus', :'payment_date' => :'Date', :'payslip_message' => :'String', :'updated_date_utc' => :'DateTime', :'payslips' => :'Array<PayslipSummary>', :'wages' => :'BigDecimal', :'deductions' => :'BigDecimal', :'tax' => :'BigDecimal', :'_super' => :'BigDecimal', :'reimbursement' => :'BigDecimal', :'net_pay' => :'BigDecimal', :'validation_errors' => :'Array<ValidationError>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 216 def ==(o) return true if self.equal?(o) self.class == o.class && payroll_calendar_id == o.payroll_calendar_id && pay_run_id == o.pay_run_id && pay_run_period_start_date == o.pay_run_period_start_date && pay_run_period_end_date == o.pay_run_period_end_date && pay_run_status == o.pay_run_status && payment_date == o.payment_date && == o. && updated_date_utc == o.updated_date_utc && payslips == o.payslips && wages == o.wages && deductions == o.deductions && tax == o.tax && _super == o._super && reimbursement == o.reimbursement && net_pay == o.net_pay && validation_errors == o.validation_errors end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 280 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::PayrollAu.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 347 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 259 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
239 240 241 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 239 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
245 246 247 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 245 def hash [payroll_calendar_id, pay_run_id, pay_run_period_start_date, pay_run_period_end_date, pay_run_status, payment_date, , updated_date_utc, payslips, wages, deductions, tax, _super, reimbursement, net_pay, validation_errors].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
198 199 200 201 202 203 204 205 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 198 def list_invalid_properties invalid_properties = Array.new if @payroll_calendar_id.nil? invalid_properties.push('invalid value for "payroll_calendar_id", payroll_calendar_id cannot be nil.') end invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
362 363 364 365 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 362 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
327 328 329 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 327 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
333 334 335 336 337 338 339 340 341 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 333 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
321 322 323 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 321 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
209 210 211 212 |
# File 'lib/xero-ruby/models/payroll_au/pay_run.rb', line 209 def valid? return false if @payroll_calendar_id.nil? true end |