Class: XeroRuby::PayrollAu::PayrollCalendar

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/payroll_au/payroll_calendar.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PayrollCalendar

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollAu::PayrollCalendar` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollAu::PayrollCalendar`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'calendar_type')
    self.calendar_type = attributes[:'calendar_type']
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'payment_date')
    self.payment_date = attributes[:'payment_date']
  end

  if attributes.key?(:'payroll_calendar_id')
    self.payroll_calendar_id = attributes[:'payroll_calendar_id']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end
end

Instance Attribute Details

#calendar_typeObject

Returns the value of attribute calendar_type.



24
25
26
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 24

def calendar_type
  @calendar_type
end

#nameObject

Name of the Payroll Calendar



21
22
23
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 21

def name
  @name
end

#payment_dateObject

The date on which employees will be paid for the upcoming pay period (YYYY-MM-DD)



30
31
32
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 30

def payment_date
  @payment_date
end

#payroll_calendar_idObject

Xero identifier



33
34
35
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 33

def payroll_calendar_id
  @payroll_calendar_id
end

#start_dateObject

The start date of the upcoming pay period. The end date will be calculated based upon this date, and the calendar type selected (YYYY-MM-DD)



27
28
29
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 27

def start_date
  @start_date
end

#updated_date_utcObject

Last modified timestamp



36
37
38
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 36

def updated_date_utc
  @updated_date_utc
end

#validation_errorsObject

Displays array of validation error messages from the API



39
40
41
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 39

def validation_errors
  @validation_errors
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 42

def self.attribute_map
  {
    :'name' => :'Name',
    :'calendar_type' => :'CalendarType',
    :'start_date' => :'StartDate',
    :'payment_date' => :'PaymentDate',
    :'payroll_calendar_id' => :'PayrollCalendarID',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'validation_errors' => :'ValidationErrors'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



155
156
157
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 155

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 55

def self.openapi_types
  {
    :'name' => :'String',
    :'calendar_type' => :'CalendarType',
    :'start_date' => :'Date',
    :'payment_date' => :'Date',
    :'payroll_calendar_id' => :'String',
    :'updated_date_utc' => :'DateTime',
    :'validation_errors' => :'Array<ValidationError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



128
129
130
131
132
133
134
135
136
137
138
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 128

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      calendar_type == o.calendar_type &&
      start_date == o.start_date &&
      payment_date == o.payment_date &&
      payroll_calendar_id == o.payroll_calendar_id &&
      updated_date_utc == o.updated_date_utc &&
      validation_errors == o.validation_errors
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 183

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BigDecimal
    BigDecimal(value.to_s)
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::PayrollAu.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 250

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 162

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


142
143
144
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 142

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



148
149
150
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 148

def hash
  [name, calendar_type, start_date, payment_date, payroll_calendar_id, updated_date_utc, validation_errors].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



115
116
117
118
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 115

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



265
266
267
268
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 265

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 230

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



236
237
238
239
240
241
242
243
244
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



224
225
226
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 224

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



122
123
124
# File 'lib/xero-ruby/models/payroll_au/payroll_calendar.rb', line 122

def valid?
  true
end