Class: XeroRuby::PayrollAu::PayslipSummary
- Inherits:
-
Object
- Object
- XeroRuby::PayrollAu::PayslipSummary
- Defined in:
- lib/xero-ruby/models/payroll_au/payslip_summary.rb
Instance Attribute Summary collapse
-
#_super ⇒ Object
The Super for the Payslip.
-
#deductions ⇒ Object
The Deductions for the Payslip.
-
#employee_group ⇒ Object
Employee group name.
-
#employee_id ⇒ Object
The Xero identifier for an employee.
-
#first_name ⇒ Object
First name of employee.
-
#last_name ⇒ Object
Last name of employee.
-
#net_pay ⇒ Object
The NetPay for the Payslip.
-
#payslip_id ⇒ Object
Xero identifier for the payslip.
-
#reimbursements ⇒ Object
The Reimbursements for the Payslip.
-
#tax ⇒ Object
The Tax for the Payslip.
-
#updated_date_utc ⇒ Object
Last modified timestamp.
-
#wages ⇒ Object
The Wages for the Payslip.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PayslipSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PayslipSummary
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollAu::PayslipSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollAu::PayslipSummary`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'employee_id') self.employee_id = attributes[:'employee_id'] end if attributes.key?(:'payslip_id') self.payslip_id = attributes[:'payslip_id'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'employee_group') self.employee_group = attributes[:'employee_group'] end if attributes.key?(:'wages') self.wages = attributes[:'wages'] end if attributes.key?(:'deductions') self.deductions = attributes[:'deductions'] end if attributes.key?(:'tax') self.tax = attributes[:'tax'] end if attributes.key?(:'_super') self._super = attributes[:'_super'] end if attributes.key?(:'reimbursements') self.reimbursements = attributes[:'reimbursements'] end if attributes.key?(:'net_pay') self.net_pay = attributes[:'net_pay'] end if attributes.key?(:'updated_date_utc') self.updated_date_utc = attributes[:'updated_date_utc'] end end |
Instance Attribute Details
#_super ⇒ Object
The Super for the Payslip
45 46 47 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 45 def _super @_super end |
#deductions ⇒ Object
The Deductions for the Payslip
39 40 41 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 39 def deductions @deductions end |
#employee_group ⇒ Object
Employee group name
33 34 35 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 33 def employee_group @employee_group end |
#employee_id ⇒ Object
The Xero identifier for an employee
21 22 23 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 21 def employee_id @employee_id end |
#first_name ⇒ Object
First name of employee
27 28 29 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 27 def first_name @first_name end |
#last_name ⇒ Object
Last name of employee
30 31 32 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 30 def last_name @last_name end |
#net_pay ⇒ Object
The NetPay for the Payslip
51 52 53 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 51 def net_pay @net_pay end |
#payslip_id ⇒ Object
Xero identifier for the payslip
24 25 26 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 24 def payslip_id @payslip_id end |
#reimbursements ⇒ Object
The Reimbursements for the Payslip
48 49 50 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 48 def reimbursements @reimbursements end |
#tax ⇒ Object
The Tax for the Payslip
42 43 44 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 42 def tax @tax end |
#updated_date_utc ⇒ Object
Last modified timestamp
54 55 56 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 54 def updated_date_utc @updated_date_utc end |
#wages ⇒ Object
The Wages for the Payslip
36 37 38 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 36 def wages @wages end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 57 def self.attribute_map { :'employee_id' => :'EmployeeID', :'payslip_id' => :'PayslipID', :'first_name' => :'FirstName', :'last_name' => :'LastName', :'employee_group' => :'EmployeeGroup', :'wages' => :'Wages', :'deductions' => :'Deductions', :'tax' => :'Tax', :'_super' => :'Super', :'reimbursements' => :'Reimbursements', :'net_pay' => :'NetPay', :'updated_date_utc' => :'UpdatedDateUTC' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 203 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 75 def self.openapi_types { :'employee_id' => :'String', :'payslip_id' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'employee_group' => :'String', :'wages' => :'BigDecimal', :'deductions' => :'BigDecimal', :'tax' => :'BigDecimal', :'_super' => :'BigDecimal', :'reimbursements' => :'BigDecimal', :'net_pay' => :'BigDecimal', :'updated_date_utc' => :'DateTime' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 171 def ==(o) return true if self.equal?(o) self.class == o.class && employee_id == o.employee_id && payslip_id == o.payslip_id && first_name == o.first_name && last_name == o.last_name && employee_group == o.employee_group && wages == o.wages && deductions == o.deductions && tax == o.tax && _super == o._super && reimbursements == o.reimbursements && net_pay == o.net_pay && updated_date_utc == o.updated_date_utc end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 231 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::PayrollAu.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 298 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 210 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
190 191 192 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 190 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 196 def hash [employee_id, payslip_id, first_name, last_name, employee_group, wages, deductions, tax, _super, reimbursements, net_pay, updated_date_utc].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 158 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
313 314 315 316 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 313 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
278 279 280 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 278 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
284 285 286 287 288 289 290 291 292 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 284 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
272 273 274 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 272 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 |
# File 'lib/xero-ruby/models/payroll_au/payslip_summary.rb', line 165 def valid? true end |