Class: XeroRuby::PayrollAu::TaxDeclaration

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/payroll_au/tax_declaration.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TaxDeclaration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollAu::TaxDeclaration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollAu::TaxDeclaration`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'employee_id')
    self.employee_id = attributes[:'employee_id']
  end

  if attributes.key?(:'employment_basis')
    self.employment_basis = attributes[:'employment_basis']
  end

  if attributes.key?(:'tfn_exemption_type')
    self.tfn_exemption_type = attributes[:'tfn_exemption_type']
  end

  if attributes.key?(:'tax_file_number')
    self.tax_file_number = attributes[:'tax_file_number']
  end

  if attributes.key?(:'australian_resident_for_tax_purposes')
    self.australian_resident_for_tax_purposes = attributes[:'australian_resident_for_tax_purposes']
  end

  if attributes.key?(:'residency_status')
    self.residency_status = attributes[:'residency_status']
  end

  if attributes.key?(:'tax_free_threshold_claimed')
    self.tax_free_threshold_claimed = attributes[:'tax_free_threshold_claimed']
  end

  if attributes.key?(:'tax_offset_estimated_amount')
    self.tax_offset_estimated_amount = attributes[:'tax_offset_estimated_amount']
  end

  if attributes.key?(:'has_help_debt')
    self.has_help_debt = attributes[:'has_help_debt']
  end

  if attributes.key?(:'has_sfss_debt')
    self.has_sfss_debt = attributes[:'has_sfss_debt']
  end

  if attributes.key?(:'has_trade_support_loan_debt')
    self.has_trade_support_loan_debt = attributes[:'has_trade_support_loan_debt']
  end

  if attributes.key?(:'upward_variation_tax_withholding_amount')
    self.upward_variation_tax_withholding_amount = attributes[:'upward_variation_tax_withholding_amount']
  end

  if attributes.key?(:'eligible_to_receive_leave_loading')
    self.eligible_to_receive_leave_loading = attributes[:'eligible_to_receive_leave_loading']
  end

  if attributes.key?(:'approved_withholding_variation_percentage')
    self.approved_withholding_variation_percentage = attributes[:'approved_withholding_variation_percentage']
  end

  if attributes.key?(:'has_student_startup_loan')
    self.has_student_startup_loan = attributes[:'has_student_startup_loan']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end
end

Instance Attribute Details

#approved_withholding_variation_percentageObject

If the employee has approved withholding variation. e.g (0 - 100)



60
61
62
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 60

def approved_withholding_variation_percentage
  @approved_withholding_variation_percentage
end

#australian_resident_for_tax_purposesObject

If the employee is Australian resident for tax purposes. e.g true or false



33
34
35
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 33

def australian_resident_for_tax_purposes
  @australian_resident_for_tax_purposes
end

#eligible_to_receive_leave_loadingObject

If the employee is eligible to receive an additional percentage on top of ordinary earnings when they take leave (typically 17.5%). e.g true or false



57
58
59
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 57

def eligible_to_receive_leave_loading
  @eligible_to_receive_leave_loading
end

#employee_idObject

Address line 1 for employee home address



21
22
23
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 21

def employee_id
  @employee_id
end

#employment_basisObject

Returns the value of attribute employment_basis.



24
25
26
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 24

def employment_basis
  @employment_basis
end

#has_help_debtObject

If employee has HECS or HELP debt. e.g true or false



45
46
47
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 45

def has_help_debt
  @has_help_debt
end

#has_sfss_debtObject

If employee has financial supplement debt. e.g true or false



48
49
50
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 48

def has_sfss_debt
  @has_sfss_debt
end

#has_student_startup_loanObject

If the employee is eligible for student startup loan rules



63
64
65
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 63

def has_student_startup_loan
  @has_student_startup_loan
end

#has_trade_support_loan_debtObject

If employee has trade support loan. e.g true or false



51
52
53
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 51

def has_trade_support_loan_debt
  @has_trade_support_loan_debt
end

#residency_statusObject

Returns the value of attribute residency_status.



36
37
38
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 36

def residency_status
  @residency_status
end

#tax_file_numberObject

The tax file number e.g 123123123.



30
31
32
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 30

def tax_file_number
  @tax_file_number
end

#tax_free_threshold_claimedObject

If tax free threshold claimed. e.g true or false



39
40
41
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 39

def tax_free_threshold_claimed
  @tax_free_threshold_claimed
end

#tax_offset_estimated_amountObject

If has tax offset estimated then the tax offset estimated amount. e.g 100



42
43
44
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 42

def tax_offset_estimated_amount
  @tax_offset_estimated_amount
end

#tfn_exemption_typeObject

Returns the value of attribute tfn_exemption_type.



27
28
29
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 27

def tfn_exemption_type
  @tfn_exemption_type
end

#updated_date_utcObject

Last modified timestamp



66
67
68
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 66

def updated_date_utc
  @updated_date_utc
end

#upward_variation_tax_withholding_amountObject

If the employee has requested that additional tax be withheld each pay run. e.g 50



54
55
56
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 54

def upward_variation_tax_withholding_amount
  @upward_variation_tax_withholding_amount
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 69

def self.attribute_map
  {
    :'employee_id' => :'EmployeeID',
    :'employment_basis' => :'EmploymentBasis',
    :'tfn_exemption_type' => :'TFNExemptionType',
    :'tax_file_number' => :'TaxFileNumber',
    :'australian_resident_for_tax_purposes' => :'AustralianResidentForTaxPurposes',
    :'residency_status' => :'ResidencyStatus',
    :'tax_free_threshold_claimed' => :'TaxFreeThresholdClaimed',
    :'tax_offset_estimated_amount' => :'TaxOffsetEstimatedAmount',
    :'has_help_debt' => :'HasHELPDebt',
    :'has_sfss_debt' => :'HasSFSSDebt',
    :'has_trade_support_loan_debt' => :'HasTradeSupportLoanDebt',
    :'upward_variation_tax_withholding_amount' => :'UpwardVariationTaxWithholdingAmount',
    :'eligible_to_receive_leave_loading' => :'EligibleToReceiveLeaveLoading',
    :'approved_withholding_variation_percentage' => :'ApprovedWithholdingVariationPercentage',
    :'has_student_startup_loan' => :'HasStudentStartupLoan',
    :'updated_date_utc' => :'UpdatedDateUTC'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 243

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 91

def self.openapi_types
  {
    :'employee_id' => :'String',
    :'employment_basis' => :'EmploymentBasis',
    :'tfn_exemption_type' => :'TFNExemptionType',
    :'tax_file_number' => :'String',
    :'australian_resident_for_tax_purposes' => :'Boolean',
    :'residency_status' => :'ResidencyStatus',
    :'tax_free_threshold_claimed' => :'Boolean',
    :'tax_offset_estimated_amount' => :'Float',
    :'has_help_debt' => :'Boolean',
    :'has_sfss_debt' => :'Boolean',
    :'has_trade_support_loan_debt' => :'Boolean',
    :'upward_variation_tax_withholding_amount' => :'Float',
    :'eligible_to_receive_leave_loading' => :'Boolean',
    :'approved_withholding_variation_percentage' => :'Float',
    :'has_student_startup_loan' => :'Boolean',
    :'updated_date_utc' => :'DateTime'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 207

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      employee_id == o.employee_id &&
      employment_basis == o.employment_basis &&
      tfn_exemption_type == o.tfn_exemption_type &&
      tax_file_number == o.tax_file_number &&
      australian_resident_for_tax_purposes == o.australian_resident_for_tax_purposes &&
      residency_status == o.residency_status &&
      tax_free_threshold_claimed == o.tax_free_threshold_claimed &&
      tax_offset_estimated_amount == o.tax_offset_estimated_amount &&
      has_help_debt == o.has_help_debt &&
      has_sfss_debt == o.has_sfss_debt &&
      has_trade_support_loan_debt == o.has_trade_support_loan_debt &&
      upward_variation_tax_withholding_amount == o.upward_variation_tax_withholding_amount &&
      eligible_to_receive_leave_loading == o.eligible_to_receive_leave_loading &&
      approved_withholding_variation_percentage == o.approved_withholding_variation_percentage &&
      has_student_startup_loan == o.has_student_startup_loan &&
      updated_date_utc == o.updated_date_utc
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 271

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BigDecimal
    BigDecimal(value.to_s)
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::PayrollAu.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 338

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 250

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 236

def hash
  [employee_id, employment_basis, tfn_exemption_type, tax_file_number, australian_resident_for_tax_purposes, residency_status, tax_free_threshold_claimed, tax_offset_estimated_amount, has_help_debt, has_sfss_debt, has_trade_support_loan_debt, upward_variation_tax_withholding_amount, eligible_to_receive_leave_loading, approved_withholding_variation_percentage, has_student_startup_loan, updated_date_utc].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



194
195
196
197
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 194

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



353
354
355
356
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 353

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 318

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



324
325
326
327
328
329
330
331
332
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 324

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



312
313
314
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 312

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
# File 'lib/xero-ruby/models/payroll_au/tax_declaration.rb', line 201

def valid?
  true
end