Class: XeroRuby::PayrollAuV2Api

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/api/payroll_au_v2_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.new) ⇒ PayrollAuV2Api

Returns a new instance of PayrollAuV2Api.



16
17
18
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 16

def initialize(api_client = ApiClient.new)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



14
15
16
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 14

def api_client
  @api_client
end

Instance Method Details

#approve_timesheet(xero_tenant_id, timesheet_id, opts = {}) ⇒ TimesheetObject

Approves a specific timesheet

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    This allows you to safely retry requests without the risk of duplicate processing. 128 character max.

Returns:

  • (TimesheetObject)


25
26
27
28
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 25

def approve_timesheet(xero_tenant_id, timesheet_id, opts = {})
  data, _status_code, _headers = approve_timesheet_with_http_info(xero_tenant_id, timesheet_id, opts)
  data
end

#approve_timesheet_with_http_info(xero_tenant_id, timesheet_id, options = {}) ⇒ Array<(TimesheetObject, Integer, Hash)>

Approves a specific timesheet

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • opts (Hash)

    the optional parameters

Returns:

  • (Array<(TimesheetObject, Integer, Hash)>)

    TimesheetObject data, response status code and response headers



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 36

def approve_timesheet_with_http_info(xero_tenant_id, timesheet_id, options = {})
  opts = options.dup
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PayrollAuV2Api.approve_timesheet ...'
  end
  # verify the required parameter 'xero_tenant_id' is set
  if @api_client.config.client_side_validation && xero_tenant_id.nil?
    fail ArgumentError, "Missing the required parameter 'xero_tenant_id' when calling PayrollAuV2Api.approve_timesheet"
  end
  # verify the required parameter 'timesheet_id' is set
  if @api_client.config.client_side_validation && timesheet_id.nil?
    fail ArgumentError, "Missing the required parameter 'timesheet_id' when calling PayrollAuV2Api.approve_timesheet"
  end
  # resource path
  local_var_path = '/Timesheets/{TimesheetID}/Approve'.sub('{' + 'TimesheetID' + '}', timesheet_id.to_s)

  # camelize keys of incoming `where` opts
  opts[:'where'] = @api_client.parameterize_where(opts[:'where']) if !opts[:'where'].nil?

  # query parameters
  query_params = opts[:query_params] || {}
  
  # XeroAPI's `IDs` convention openapi-generator does not snake_case properly.. manual over-riding `i_ds` malformations:
  query_params[:'IDs'] = @api_client.build_collection_param(opts[:'ids'], :csv) if !opts[:'ids'].nil?
  query_params[:'ContactIDs'] = @api_client.build_collection_param(opts[:'contact_ids'], :csv) if !opts[:'contact_ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'Xero-Tenant-Id'] = xero_tenant_id
  header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'TimesheetObject' 

  # auth_names
  auth_names = opts[:auth_names] || ['OAuth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, "PayrollAuV2Api", new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PayrollAuV2Api#approve_timesheet\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_timesheet(xero_tenant_id, timesheet, opts = {}) ⇒ TimesheetObject

Creates a new timesheet

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet (Timesheet)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    This allows you to safely retry requests without the risk of duplicate processing. 128 character max.

Returns:

  • (TimesheetObject)


103
104
105
106
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 103

def create_timesheet(xero_tenant_id, timesheet, opts = {})
  data, _status_code, _headers = create_timesheet_with_http_info(xero_tenant_id, timesheet, opts)
  data
end

#create_timesheet_line(xero_tenant_id, timesheet_id, timesheet_line, opts = {}) ⇒ TimesheetLineObject

Creates a new timesheet line for a specific timesheet using a unique timesheet ID

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • timesheet_line (TimesheetLine)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    This allows you to safely retry requests without the risk of duplicate processing. 128 character max.

Returns:

  • (TimesheetLineObject)


184
185
186
187
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 184

def create_timesheet_line(xero_tenant_id, timesheet_id, timesheet_line, opts = {})
  data, _status_code, _headers = create_timesheet_line_with_http_info(xero_tenant_id, timesheet_id, timesheet_line, opts)
  data
end

#create_timesheet_line_with_http_info(xero_tenant_id, timesheet_id, timesheet_line, options = {}) ⇒ Array<(TimesheetLineObject, Integer, Hash)>

Creates a new timesheet line for a specific timesheet using a unique timesheet ID

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • timesheet_line (TimesheetLine)
  • opts (Hash)

    the optional parameters

Returns:

  • (Array<(TimesheetLineObject, Integer, Hash)>)

    TimesheetLineObject data, response status code and response headers



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 196

def create_timesheet_line_with_http_info(xero_tenant_id, timesheet_id, timesheet_line, options = {})
  opts = options.dup
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PayrollAuV2Api.create_timesheet_line ...'
  end
  # verify the required parameter 'xero_tenant_id' is set
  if @api_client.config.client_side_validation && xero_tenant_id.nil?
    fail ArgumentError, "Missing the required parameter 'xero_tenant_id' when calling PayrollAuV2Api.create_timesheet_line"
  end
  # verify the required parameter 'timesheet_id' is set
  if @api_client.config.client_side_validation && timesheet_id.nil?
    fail ArgumentError, "Missing the required parameter 'timesheet_id' when calling PayrollAuV2Api.create_timesheet_line"
  end
  # verify the required parameter 'timesheet_line' is set
  if @api_client.config.client_side_validation && timesheet_line.nil?
    fail ArgumentError, "Missing the required parameter 'timesheet_line' when calling PayrollAuV2Api.create_timesheet_line"
  end
  # resource path
  local_var_path = '/Timesheets/{TimesheetID}/Lines'.sub('{' + 'TimesheetID' + '}', timesheet_id.to_s)

  # camelize keys of incoming `where` opts
  opts[:'where'] = @api_client.parameterize_where(opts[:'where']) if !opts[:'where'].nil?

  # query parameters
  query_params = opts[:query_params] || {}
  
  # XeroAPI's `IDs` convention openapi-generator does not snake_case properly.. manual over-riding `i_ds` malformations:
  query_params[:'IDs'] = @api_client.build_collection_param(opts[:'ids'], :csv) if !opts[:'ids'].nil?
  query_params[:'ContactIDs'] = @api_client.build_collection_param(opts[:'contact_ids'], :csv) if !opts[:'contact_ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  header_params[:'Xero-Tenant-Id'] = xero_tenant_id
  header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(timesheet_line) 

  # return_type
  return_type = opts[:return_type] || 'TimesheetLineObject' 

  # auth_names
  auth_names = opts[:auth_names] || ['OAuth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, "PayrollAuV2Api", new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PayrollAuV2Api#create_timesheet_line\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_timesheet_with_http_info(xero_tenant_id, timesheet, options = {}) ⇒ Array<(TimesheetObject, Integer, Hash)>

Creates a new timesheet

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet (Timesheet)
  • opts (Hash)

    the optional parameters

Returns:

  • (Array<(TimesheetObject, Integer, Hash)>)

    TimesheetObject data, response status code and response headers



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 114

def create_timesheet_with_http_info(xero_tenant_id, timesheet, options = {})
  opts = options.dup
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PayrollAuV2Api.create_timesheet ...'
  end
  # verify the required parameter 'xero_tenant_id' is set
  if @api_client.config.client_side_validation && xero_tenant_id.nil?
    fail ArgumentError, "Missing the required parameter 'xero_tenant_id' when calling PayrollAuV2Api.create_timesheet"
  end
  # verify the required parameter 'timesheet' is set
  if @api_client.config.client_side_validation && timesheet.nil?
    fail ArgumentError, "Missing the required parameter 'timesheet' when calling PayrollAuV2Api.create_timesheet"
  end
  # resource path
  local_var_path = '/Timesheets'

  # camelize keys of incoming `where` opts
  opts[:'where'] = @api_client.parameterize_where(opts[:'where']) if !opts[:'where'].nil?

  # query parameters
  query_params = opts[:query_params] || {}
  
  # XeroAPI's `IDs` convention openapi-generator does not snake_case properly.. manual over-riding `i_ds` malformations:
  query_params[:'IDs'] = @api_client.build_collection_param(opts[:'ids'], :csv) if !opts[:'ids'].nil?
  query_params[:'ContactIDs'] = @api_client.build_collection_param(opts[:'contact_ids'], :csv) if !opts[:'contact_ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  header_params[:'Xero-Tenant-Id'] = xero_tenant_id
  header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(timesheet) 

  # return_type
  return_type = opts[:return_type] || 'TimesheetObject' 

  # auth_names
  auth_names = opts[:auth_names] || ['OAuth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, "PayrollAuV2Api", new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PayrollAuV2Api#create_timesheet\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_timesheet(xero_tenant_id, timesheet_id, opts = {}) ⇒ TimesheetLine

Deletes a specific timesheet

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (TimesheetLine)


268
269
270
271
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 268

def delete_timesheet(xero_tenant_id, timesheet_id, opts = {})
  data, _status_code, _headers = delete_timesheet_with_http_info(xero_tenant_id, timesheet_id, opts)
  data
end

#delete_timesheet_line(xero_tenant_id, timesheet_id, timesheet_line_id, opts = {}) ⇒ TimesheetLine

Deletes a specific timesheet line

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • timesheet_line_id (String)

    Identifier for the timesheet line

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (TimesheetLine)


344
345
346
347
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 344

def delete_timesheet_line(xero_tenant_id, timesheet_id, timesheet_line_id, opts = {})
  data, _status_code, _headers = delete_timesheet_line_with_http_info(xero_tenant_id, timesheet_id, timesheet_line_id, opts)
  data
end

#delete_timesheet_line_with_http_info(xero_tenant_id, timesheet_id, timesheet_line_id, options = {}) ⇒ Array<(TimesheetLine, Integer, Hash)>

Deletes a specific timesheet line

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • timesheet_line_id (String)

    Identifier for the timesheet line

  • opts (Hash)

    the optional parameters

Returns:

  • (Array<(TimesheetLine, Integer, Hash)>)

    TimesheetLine data, response status code and response headers



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 355

def delete_timesheet_line_with_http_info(xero_tenant_id, timesheet_id, timesheet_line_id, options = {})
  opts = options.dup
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PayrollAuV2Api.delete_timesheet_line ...'
  end
  # verify the required parameter 'xero_tenant_id' is set
  if @api_client.config.client_side_validation && xero_tenant_id.nil?
    fail ArgumentError, "Missing the required parameter 'xero_tenant_id' when calling PayrollAuV2Api.delete_timesheet_line"
  end
  # verify the required parameter 'timesheet_id' is set
  if @api_client.config.client_side_validation && timesheet_id.nil?
    fail ArgumentError, "Missing the required parameter 'timesheet_id' when calling PayrollAuV2Api.delete_timesheet_line"
  end
  # verify the required parameter 'timesheet_line_id' is set
  if @api_client.config.client_side_validation && timesheet_line_id.nil?
    fail ArgumentError, "Missing the required parameter 'timesheet_line_id' when calling PayrollAuV2Api.delete_timesheet_line"
  end
  # resource path
  local_var_path = '/Timesheets/{TimesheetID}/Lines/{TimesheetLineID}'.sub('{' + 'TimesheetID' + '}', timesheet_id.to_s).sub('{' + 'TimesheetLineID' + '}', timesheet_line_id.to_s)

  # camelize keys of incoming `where` opts
  opts[:'where'] = @api_client.parameterize_where(opts[:'where']) if !opts[:'where'].nil?

  # query parameters
  query_params = opts[:query_params] || {}
  
  # XeroAPI's `IDs` convention openapi-generator does not snake_case properly.. manual over-riding `i_ds` malformations:
  query_params[:'IDs'] = @api_client.build_collection_param(opts[:'ids'], :csv) if !opts[:'ids'].nil?
  query_params[:'ContactIDs'] = @api_client.build_collection_param(opts[:'contact_ids'], :csv) if !opts[:'contact_ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'Xero-Tenant-Id'] = xero_tenant_id

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'TimesheetLine' 

  # auth_names
  auth_names = opts[:auth_names] || ['OAuth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, "PayrollAuV2Api", new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PayrollAuV2Api#delete_timesheet_line\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_timesheet_with_http_info(xero_tenant_id, timesheet_id, options = {}) ⇒ Array<(TimesheetLine, Integer, Hash)>

Deletes a specific timesheet

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • opts (Hash)

    the optional parameters

Returns:

  • (Array<(TimesheetLine, Integer, Hash)>)

    TimesheetLine data, response status code and response headers



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 278

def delete_timesheet_with_http_info(xero_tenant_id, timesheet_id, options = {})
  opts = options.dup
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PayrollAuV2Api.delete_timesheet ...'
  end
  # verify the required parameter 'xero_tenant_id' is set
  if @api_client.config.client_side_validation && xero_tenant_id.nil?
    fail ArgumentError, "Missing the required parameter 'xero_tenant_id' when calling PayrollAuV2Api.delete_timesheet"
  end
  # verify the required parameter 'timesheet_id' is set
  if @api_client.config.client_side_validation && timesheet_id.nil?
    fail ArgumentError, "Missing the required parameter 'timesheet_id' when calling PayrollAuV2Api.delete_timesheet"
  end
  # resource path
  local_var_path = '/Timesheets/{TimesheetID}'.sub('{' + 'TimesheetID' + '}', timesheet_id.to_s)

  # camelize keys of incoming `where` opts
  opts[:'where'] = @api_client.parameterize_where(opts[:'where']) if !opts[:'where'].nil?

  # query parameters
  query_params = opts[:query_params] || {}
  
  # XeroAPI's `IDs` convention openapi-generator does not snake_case properly.. manual over-riding `i_ds` malformations:
  query_params[:'IDs'] = @api_client.build_collection_param(opts[:'ids'], :csv) if !opts[:'ids'].nil?
  query_params[:'ContactIDs'] = @api_client.build_collection_param(opts[:'contact_ids'], :csv) if !opts[:'contact_ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'Xero-Tenant-Id'] = xero_tenant_id

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'TimesheetLine' 

  # auth_names
  auth_names = opts[:auth_names] || ['OAuth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, "PayrollAuV2Api", new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PayrollAuV2Api#delete_timesheet\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_timesheet(xero_tenant_id, timesheet_id, opts = {}) ⇒ TimesheetObject

Retrieve a specific timesheet by using a unique timesheet ID

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (TimesheetObject)


424
425
426
427
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 424

def get_timesheet(xero_tenant_id, timesheet_id, opts = {})
  data, _status_code, _headers = get_timesheet_with_http_info(xero_tenant_id, timesheet_id, opts)
  data
end

#get_timesheet_with_http_info(xero_tenant_id, timesheet_id, options = {}) ⇒ Array<(TimesheetObject, Integer, Hash)>

Retrieve a specific timesheet by using a unique timesheet ID

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • opts (Hash)

    the optional parameters

Returns:

  • (Array<(TimesheetObject, Integer, Hash)>)

    TimesheetObject data, response status code and response headers



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 434

def get_timesheet_with_http_info(xero_tenant_id, timesheet_id, options = {})
  opts = options.dup
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PayrollAuV2Api.get_timesheet ...'
  end
  # verify the required parameter 'xero_tenant_id' is set
  if @api_client.config.client_side_validation && xero_tenant_id.nil?
    fail ArgumentError, "Missing the required parameter 'xero_tenant_id' when calling PayrollAuV2Api.get_timesheet"
  end
  # verify the required parameter 'timesheet_id' is set
  if @api_client.config.client_side_validation && timesheet_id.nil?
    fail ArgumentError, "Missing the required parameter 'timesheet_id' when calling PayrollAuV2Api.get_timesheet"
  end
  # resource path
  local_var_path = '/Timesheets/{TimesheetID}'.sub('{' + 'TimesheetID' + '}', timesheet_id.to_s)

  # camelize keys of incoming `where` opts
  opts[:'where'] = @api_client.parameterize_where(opts[:'where']) if !opts[:'where'].nil?

  # query parameters
  query_params = opts[:query_params] || {}
  
  # XeroAPI's `IDs` convention openapi-generator does not snake_case properly.. manual over-riding `i_ds` malformations:
  query_params[:'IDs'] = @api_client.build_collection_param(opts[:'ids'], :csv) if !opts[:'ids'].nil?
  query_params[:'ContactIDs'] = @api_client.build_collection_param(opts[:'contact_ids'], :csv) if !opts[:'contact_ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'Xero-Tenant-Id'] = xero_tenant_id

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'TimesheetObject' 

  # auth_names
  auth_names = opts[:auth_names] || ['OAuth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, "PayrollAuV2Api", new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PayrollAuV2Api#get_timesheet\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_timesheets(xero_tenant_id, opts = {}) ⇒ Timesheets

Retrieves timesheets

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number which specifies the set of records to retrieve. By default the number of the records per set is 100.

  • :filter (String)

    Filter by employeeId and/or payrollCalendarId

  • :status (String)

    filter results by any timesheets with a matching timesheet status

  • :start_date (String)

    filter results by any timesheets with a startDate on or after the provided date

  • :end_date (String)

    filter results by any timesheets with a endDate on or before the provided date

  • :sort (String)

    sort the order of timesheets returned. The default is based on the timesheets createdDate, sorted oldest to newest. Currently, the only other option is to reverse the order based on the timesheets startDate, sorted newest to oldest.

Returns:

  • (Timesheets)


504
505
506
507
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 504

def get_timesheets(xero_tenant_id, opts = {})
  data, _status_code, _headers = get_timesheets_with_http_info(xero_tenant_id, opts)
  data
end

#get_timesheets_with_http_info(xero_tenant_id, options = {}) ⇒ Array<(Timesheets, Integer, Hash)>

Retrieves timesheets

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • opts (Hash)

    the optional parameters

Returns:

  • (Array<(Timesheets, Integer, Hash)>)

    Timesheets data, response status code and response headers



519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 519

def get_timesheets_with_http_info(xero_tenant_id, options = {})
  opts = options.dup
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PayrollAuV2Api.get_timesheets ...'
  end
  # verify the required parameter 'xero_tenant_id' is set
  if @api_client.config.client_side_validation && xero_tenant_id.nil?
    fail ArgumentError, "Missing the required parameter 'xero_tenant_id' when calling PayrollAuV2Api.get_timesheets"
  end
  # resource path
  local_var_path = '/Timesheets'

  # camelize keys of incoming `where` opts
  opts[:'where'] = @api_client.parameterize_where(opts[:'where']) if !opts[:'where'].nil?

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil?
  query_params[:'startDate'] = opts[:'start_date'] if !opts[:'start_date'].nil?
  query_params[:'endDate'] = opts[:'end_date'] if !opts[:'end_date'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  
  # XeroAPI's `IDs` convention openapi-generator does not snake_case properly.. manual over-riding `i_ds` malformations:
  query_params[:'IDs'] = @api_client.build_collection_param(opts[:'ids'], :csv) if !opts[:'ids'].nil?
  query_params[:'ContactIDs'] = @api_client.build_collection_param(opts[:'contact_ids'], :csv) if !opts[:'contact_ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'Xero-Tenant-Id'] = xero_tenant_id

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'Timesheets' 

  # auth_names
  auth_names = opts[:auth_names] || ['OAuth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, "PayrollAuV2Api", new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PayrollAuV2Api#get_timesheets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#revert_timesheet(xero_tenant_id, timesheet_id, opts = {}) ⇒ TimesheetObject

Reverts a specific timesheet to draft

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    This allows you to safely retry requests without the risk of duplicate processing. 128 character max.

Returns:

  • (TimesheetObject)


587
588
589
590
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 587

def revert_timesheet(xero_tenant_id, timesheet_id, opts = {})
  data, _status_code, _headers = revert_timesheet_with_http_info(xero_tenant_id, timesheet_id, opts)
  data
end

#revert_timesheet_with_http_info(xero_tenant_id, timesheet_id, options = {}) ⇒ Array<(TimesheetObject, Integer, Hash)>

Reverts a specific timesheet to draft

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • opts (Hash)

    the optional parameters

Returns:

  • (Array<(TimesheetObject, Integer, Hash)>)

    TimesheetObject data, response status code and response headers



598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 598

def revert_timesheet_with_http_info(xero_tenant_id, timesheet_id, options = {})
  opts = options.dup
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PayrollAuV2Api.revert_timesheet ...'
  end
  # verify the required parameter 'xero_tenant_id' is set
  if @api_client.config.client_side_validation && xero_tenant_id.nil?
    fail ArgumentError, "Missing the required parameter 'xero_tenant_id' when calling PayrollAuV2Api.revert_timesheet"
  end
  # verify the required parameter 'timesheet_id' is set
  if @api_client.config.client_side_validation && timesheet_id.nil?
    fail ArgumentError, "Missing the required parameter 'timesheet_id' when calling PayrollAuV2Api.revert_timesheet"
  end
  # resource path
  local_var_path = '/Timesheets/{TimesheetID}/RevertToDraft'.sub('{' + 'TimesheetID' + '}', timesheet_id.to_s)

  # camelize keys of incoming `where` opts
  opts[:'where'] = @api_client.parameterize_where(opts[:'where']) if !opts[:'where'].nil?

  # query parameters
  query_params = opts[:query_params] || {}
  
  # XeroAPI's `IDs` convention openapi-generator does not snake_case properly.. manual over-riding `i_ds` malformations:
  query_params[:'IDs'] = @api_client.build_collection_param(opts[:'ids'], :csv) if !opts[:'ids'].nil?
  query_params[:'ContactIDs'] = @api_client.build_collection_param(opts[:'contact_ids'], :csv) if !opts[:'contact_ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  header_params[:'Xero-Tenant-Id'] = xero_tenant_id
  header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'TimesheetObject' 

  # auth_names
  auth_names = opts[:auth_names] || ['OAuth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, "PayrollAuV2Api", new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PayrollAuV2Api#revert_timesheet\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_timesheet_line(xero_tenant_id, timesheet_id, timesheet_line_id, timesheet_line, opts = {}) ⇒ TimesheetLineObject

Updates a specific timesheet line for a specific timesheet

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • timesheet_line_id (String)

    Identifier for the timesheet line

  • timesheet_line (TimesheetLine)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :idempotency_key (String)

    This allows you to safely retry requests without the risk of duplicate processing. 128 character max.

Returns:

  • (TimesheetLineObject)


667
668
669
670
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 667

def update_timesheet_line(xero_tenant_id, timesheet_id, timesheet_line_id, timesheet_line, opts = {})
  data, _status_code, _headers = update_timesheet_line_with_http_info(xero_tenant_id, timesheet_id, timesheet_line_id, timesheet_line, opts)
  data
end

#update_timesheet_line_with_http_info(xero_tenant_id, timesheet_id, timesheet_line_id, timesheet_line, options = {}) ⇒ Array<(TimesheetLineObject, Integer, Hash)>

Updates a specific timesheet line for a specific timesheet

Parameters:

  • xero_tenant_id (String)

    Xero identifier for Tenant

  • timesheet_id (String)

    Identifier for the timesheet

  • timesheet_line_id (String)

    Identifier for the timesheet line

  • timesheet_line (TimesheetLine)
  • opts (Hash)

    the optional parameters

Returns:

  • (Array<(TimesheetLineObject, Integer, Hash)>)

    TimesheetLineObject data, response status code and response headers



680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
# File 'lib/xero-ruby/api/payroll_au_v2_api.rb', line 680

def update_timesheet_line_with_http_info(xero_tenant_id, timesheet_id, timesheet_line_id, timesheet_line, options = {})
  opts = options.dup
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PayrollAuV2Api.update_timesheet_line ...'
  end
  # verify the required parameter 'xero_tenant_id' is set
  if @api_client.config.client_side_validation && xero_tenant_id.nil?
    fail ArgumentError, "Missing the required parameter 'xero_tenant_id' when calling PayrollAuV2Api.update_timesheet_line"
  end
  # verify the required parameter 'timesheet_id' is set
  if @api_client.config.client_side_validation && timesheet_id.nil?
    fail ArgumentError, "Missing the required parameter 'timesheet_id' when calling PayrollAuV2Api.update_timesheet_line"
  end
  # verify the required parameter 'timesheet_line_id' is set
  if @api_client.config.client_side_validation && timesheet_line_id.nil?
    fail ArgumentError, "Missing the required parameter 'timesheet_line_id' when calling PayrollAuV2Api.update_timesheet_line"
  end
  # verify the required parameter 'timesheet_line' is set
  if @api_client.config.client_side_validation && timesheet_line.nil?
    fail ArgumentError, "Missing the required parameter 'timesheet_line' when calling PayrollAuV2Api.update_timesheet_line"
  end
  # resource path
  local_var_path = '/Timesheets/{TimesheetID}/Lines/{TimesheetLineID}'.sub('{' + 'TimesheetID' + '}', timesheet_id.to_s).sub('{' + 'TimesheetLineID' + '}', timesheet_line_id.to_s)

  # camelize keys of incoming `where` opts
  opts[:'where'] = @api_client.parameterize_where(opts[:'where']) if !opts[:'where'].nil?

  # query parameters
  query_params = opts[:query_params] || {}
  
  # XeroAPI's `IDs` convention openapi-generator does not snake_case properly.. manual over-riding `i_ds` malformations:
  query_params[:'IDs'] = @api_client.build_collection_param(opts[:'ids'], :csv) if !opts[:'ids'].nil?
  query_params[:'ContactIDs'] = @api_client.build_collection_param(opts[:'contact_ids'], :csv) if !opts[:'contact_ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
  header_params[:'Xero-Tenant-Id'] = xero_tenant_id
  header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil?

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(timesheet_line) 

  # return_type
  return_type = opts[:return_type] || 'TimesheetLineObject' 

  # auth_names
  auth_names = opts[:auth_names] || ['OAuth2']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, "PayrollAuV2Api", new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PayrollAuV2Api#update_timesheet_line\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end