Class: XeroRuby::PayrollNz::BankAccount
- Inherits:
-
Object
- Object
- XeroRuby::PayrollNz::BankAccount
- Defined in:
- lib/xero-ruby/models/payroll_nz/bank_account.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Constant Summary collapse
- FIXED_AMOUNT =
"FixedAmount".freeze
- BALANCE =
"Balance".freeze
Instance Attribute Summary collapse
-
#account_name ⇒ Object
Bank account name (max length = 32).
-
#account_number ⇒ Object
Bank account number (digits only; max length = 8).
-
#calculation_type ⇒ Object
Calculation type for the transaction can be 'Fixed Amount' or 'Balance'.
-
#code ⇒ Object
Code of a transaction that appear on the statement.
-
#dollar_amount ⇒ Object
Dollar amount of a transaction.
-
#particulars ⇒ Object
Particulars that appear on the statement.
-
#reference ⇒ Object
Statement Text/reference for a transaction that appear on the statement.
-
#sort_code ⇒ Object
Bank account sort code (6 digits).
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BankAccount
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ BankAccount
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollNz::BankAccount` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollNz::BankAccount`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_name') self.account_name = attributes[:'account_name'] end if attributes.key?(:'account_number') self.account_number = attributes[:'account_number'] end if attributes.key?(:'sort_code') self.sort_code = attributes[:'sort_code'] end if attributes.key?(:'particulars') self.particulars = attributes[:'particulars'] end if attributes.key?(:'code') self.code = attributes[:'code'] end if attributes.key?(:'dollar_amount') self.dollar_amount = attributes[:'dollar_amount'] end if attributes.key?(:'reference') self.reference = attributes[:'reference'] end if attributes.key?(:'calculation_type') self.calculation_type = attributes[:'calculation_type'] end end |
Instance Attribute Details
#account_name ⇒ Object
Bank account name (max length = 32)
21 22 23 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 21 def account_name @account_name end |
#account_number ⇒ Object
Bank account number (digits only; max length = 8)
24 25 26 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 24 def account_number @account_number end |
#calculation_type ⇒ Object
Calculation type for the transaction can be 'Fixed Amount' or 'Balance'
42 43 44 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 42 def calculation_type @calculation_type end |
#code ⇒ Object
Code of a transaction that appear on the statement.
33 34 35 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 33 def code @code end |
#dollar_amount ⇒ Object
Dollar amount of a transaction.
36 37 38 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 36 def dollar_amount @dollar_amount end |
#particulars ⇒ Object
Particulars that appear on the statement.
30 31 32 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 30 def particulars @particulars end |
#reference ⇒ Object
Statement Text/reference for a transaction that appear on the statement.
39 40 41 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 39 def reference @reference end |
#sort_code ⇒ Object
Bank account sort code (6 digits)
27 28 29 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 27 def sort_code @sort_code end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 69 def self.attribute_map { :'account_name' => :'accountName', :'account_number' => :'accountNumber', :'sort_code' => :'sortCode', :'particulars' => :'particulars', :'code' => :'code', :'dollar_amount' => :'dollarAmount', :'reference' => :'reference', :'calculation_type' => :'calculationType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 214 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 83 def self.openapi_types { :'account_name' => :'String', :'account_number' => :'String', :'sort_code' => :'String', :'particulars' => :'String', :'code' => :'String', :'dollar_amount' => :'BigDecimal', :'reference' => :'String', :'calculation_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && account_name == o.account_name && account_number == o.account_number && sort_code == o.sort_code && particulars == o.particulars && code == o.code && dollar_amount == o.dollar_amount && reference == o.reference && calculation_type == o.calculation_type end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 242 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::PayrollNz.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 309 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 221 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 207 def hash [account_name, account_number, sort_code, particulars, code, dollar_amount, reference, calculation_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 146 def list_invalid_properties invalid_properties = Array.new if @account_name.nil? invalid_properties.push('invalid value for "account_name", account_name cannot be nil.') end if @account_number.nil? invalid_properties.push('invalid value for "account_number", account_number cannot be nil.') end if @sort_code.nil? invalid_properties.push('invalid value for "sort_code", sort_code cannot be nil.') end invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
324 325 326 327 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 324 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
289 290 291 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 289 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
295 296 297 298 299 300 301 302 303 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 295 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
283 284 285 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 283 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 168 169 170 171 172 |
# File 'lib/xero-ruby/models/payroll_nz/bank_account.rb', line 165 def valid? return false if @account_name.nil? return false if @account_number.nil? return false if @sort_code.nil? calculation_type_validator = EnumAttributeValidator.new('String', ["FixedAmount", "Balance"]) return false unless calculation_type_validator.valid?(@calculation_type) true end |