Class: XeroRuby::PayrollNz::Benefit
- Inherits:
-
Object
- Object
- XeroRuby::PayrollNz::Benefit
- Defined in:
- lib/xero-ruby/models/payroll_nz/benefit.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Constant Summary collapse
- KIWI_SAVER =
"KiwiSaver".freeze
- COMPLYING_FUND =
"ComplyingFund".freeze
- OTHER =
"Other".freeze
- FIXED_AMOUNT =
"FixedAmount".freeze
- PERCENTAGE_OF_TAXABLE_EARNINGS =
"PercentageOfTaxableEarnings".freeze
Instance Attribute Summary collapse
-
#calculation_type_nz ⇒ Object
Calculation Type of the superannuation either FixedAmount or PercentageOfTaxableEarnings.
-
#category ⇒ Object
Superannuations Category type.
-
#company_max ⇒ Object
Company Maximum amount of the superannuation.
-
#current_record ⇒ Object
Identifier of a record is active or not.
-
#expense_account_id ⇒ Object
Xero identifier for Expense Account.
-
#id ⇒ Object
The Xero identifier for superannuation.
-
#liability_account_id ⇒ Object
Xero identifier for Liability Account.
-
#name ⇒ Object
Name of the superannuations.
-
#percentage ⇒ Object
Percentage of Taxable Earnings of the superannuation.
-
#standard_amount ⇒ Object
Standard amount of the superannuation.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Benefit
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Benefit
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollNz::Benefit` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollNz::Benefit`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'liability_account_id') self.liability_account_id = attributes[:'liability_account_id'] end if attributes.key?(:'expense_account_id') self.expense_account_id = attributes[:'expense_account_id'] end if attributes.key?(:'calculation_type_nz') self.calculation_type_nz = attributes[:'calculation_type_nz'] end if attributes.key?(:'standard_amount') self.standard_amount = attributes[:'standard_amount'] end if attributes.key?(:'percentage') self.percentage = attributes[:'percentage'] end if attributes.key?(:'company_max') self.company_max = attributes[:'company_max'] end if attributes.key?(:'current_record') self.current_record = attributes[:'current_record'] end end |
Instance Attribute Details
#calculation_type_nz ⇒ Object
Calculation Type of the superannuation either FixedAmount or PercentageOfTaxableEarnings
39 40 41 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 39 def calculation_type_nz @calculation_type_nz end |
#category ⇒ Object
Superannuations Category type
27 28 29 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 27 def category @category end |
#company_max ⇒ Object
Company Maximum amount of the superannuation
50 51 52 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 50 def company_max @company_max end |
#current_record ⇒ Object
Identifier of a record is active or not.
53 54 55 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 53 def current_record @current_record end |
#expense_account_id ⇒ Object
Xero identifier for Expense Account
36 37 38 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 36 def expense_account_id @expense_account_id end |
#id ⇒ Object
The Xero identifier for superannuation
21 22 23 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 21 def id @id end |
#liability_account_id ⇒ Object
Xero identifier for Liability Account
33 34 35 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 33 def liability_account_id @liability_account_id end |
#name ⇒ Object
Name of the superannuations
24 25 26 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 24 def name @name end |
#percentage ⇒ Object
Percentage of Taxable Earnings of the superannuation
47 48 49 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 47 def percentage @percentage end |
#standard_amount ⇒ Object
Standard amount of the superannuation
44 45 46 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 44 def standard_amount @standard_amount end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 78 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'category' => :'category', :'liability_account_id' => :'liabilityAccountId', :'expense_account_id' => :'expenseAccountId', :'calculation_type_nz' => :'calculationTypeNZ', :'standard_amount' => :'standardAmount', :'percentage' => :'percentage', :'company_max' => :'companyMax', :'current_record' => :'currentRecord' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
254 255 256 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 254 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 94 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'category' => :'String', :'liability_account_id' => :'String', :'expense_account_id' => :'String', :'calculation_type_nz' => :'String', :'standard_amount' => :'BigDecimal', :'percentage' => :'BigDecimal', :'company_max' => :'BigDecimal', :'current_record' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 224 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && category == o.category && liability_account_id == o.liability_account_id && expense_account_id == o.expense_account_id && calculation_type_nz == o.calculation_type_nz && standard_amount == o.standard_amount && percentage == o.percentage && company_max == o.company_max && current_record == o.current_record end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 282 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::PayrollNz.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 349 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 261 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
241 242 243 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 241 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
247 248 249 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 247 def hash [id, name, category, liability_account_id, expense_account_id, calculation_type_nz, standard_amount, percentage, company_max, current_record].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 167 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @category.nil? invalid_properties.push('invalid value for "category", category cannot be nil.') end if @liability_account_id.nil? invalid_properties.push('invalid value for "liability_account_id", liability_account_id cannot be nil.') end if @expense_account_id.nil? invalid_properties.push('invalid value for "expense_account_id", expense_account_id cannot be nil.') end invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
364 365 366 367 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 364 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
329 330 331 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 329 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
335 336 337 338 339 340 341 342 343 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 335 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
323 324 325 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 323 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/xero-ruby/models/payroll_nz/benefit.rb', line 190 def valid? return false if @name.nil? return false if @category.nil? category_validator = EnumAttributeValidator.new('String', ["KiwiSaver", "ComplyingFund", "Other"]) return false unless category_validator.valid?(@category) return false if @liability_account_id.nil? return false if @expense_account_id.nil? calculation_type_nz_validator = EnumAttributeValidator.new('String', ["FixedAmount", "PercentageOfTaxableEarnings"]) return false unless calculation_type_nz_validator.valid?(@calculation_type_nz) true end |