Class: XeroRuby::PayrollNz::EarningsRate
- Inherits:
-
Object
- Object
- XeroRuby::PayrollNz::EarningsRate
- Defined in:
- lib/xero-ruby/models/payroll_nz/earnings_rate.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Constant Summary collapse
- ALLOWANCE =
"Allowance".freeze
- BACKPAY =
"Backpay".freeze
- BONUS =
"Bonus".freeze
- COMMISSION =
"Commission".freeze
- DISCRETIONARY_PAYMENTS =
"DiscretionaryPayments".freeze
- HOLIDAY_PAY =
"HolidayPay".freeze
- LUMP_SUM =
"LumpSum".freeze
- OTHER_EARNINGS =
"OtherEarnings".freeze
- OTHER_GROSS_EARNINGS =
"OtherGrossEarnings".freeze
- OVERTIME_EARNINGS =
"OvertimeEarnings".freeze
- REGULAR_EARNINGS =
"RegularEarnings".freeze
- SALARY_SACRIFICE_FOR_KIWI_SAVER =
"SalarySacrificeForKiwiSaver".freeze
- TIPS_DIRECT =
"Tips(Direct)".freeze
- TIPS_NON_DIRECT =
"Tips(Non-Direct)".freeze
- WITHHOLDING_INCOME =
"WithholdingIncome".freeze
- RATE_PER_UNIT =
"RatePerUnit".freeze
- MULTIPLE_OF_ORDINARY_EARNINGS_RATE =
"MultipleOfOrdinaryEarningsRate".freeze
- FIXED_AMOUNT =
"FixedAmount".freeze
Instance Attribute Summary collapse
-
#current_record ⇒ Object
Indicates whether an earning type is active.
-
#earnings_rate_id ⇒ Object
Xero unique identifier for an earning rate.
-
#earnings_type ⇒ Object
Indicates how an employee will be paid when taking this type of earning.
-
#expense_account_id ⇒ Object
The account that will be used for the earnings rate.
-
#fixed_amount ⇒ Object
Optional Fixed Rate Amount.
-
#multiple_of_ordinary_earnings_rate ⇒ Object
This is the multiplier used to calculate the rate per unit, based on the employee’s ordinary earnings rate.
-
#name ⇒ Object
Name of the earning rate.
-
#rate_per_unit ⇒ Object
Default rate per unit (optional).
-
#rate_type ⇒ Object
Indicates the type of the earning rate.
-
#type_of_units ⇒ Object
The type of units used to record earnings.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EarningsRate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EarningsRate
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 124 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollNz::EarningsRate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollNz::EarningsRate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'earnings_rate_id') self.earnings_rate_id = attributes[:'earnings_rate_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'earnings_type') self.earnings_type = attributes[:'earnings_type'] end if attributes.key?(:'rate_type') self.rate_type = attributes[:'rate_type'] end if attributes.key?(:'type_of_units') self.type_of_units = attributes[:'type_of_units'] end if attributes.key?(:'current_record') self.current_record = attributes[:'current_record'] end if attributes.key?(:'expense_account_id') self.expense_account_id = attributes[:'expense_account_id'] end if attributes.key?(:'rate_per_unit') self.rate_per_unit = attributes[:'rate_per_unit'] end if attributes.key?(:'multiple_of_ordinary_earnings_rate') self.multiple_of_ordinary_earnings_rate = attributes[:'multiple_of_ordinary_earnings_rate'] end if attributes.key?(:'fixed_amount') self.fixed_amount = attributes[:'fixed_amount'] end end |
Instance Attribute Details
#current_record ⇒ Object
Indicates whether an earning type is active
54 55 56 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 54 def current_record @current_record end |
#earnings_rate_id ⇒ Object
Xero unique identifier for an earning rate
21 22 23 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 21 def earnings_rate_id @earnings_rate_id end |
#earnings_type ⇒ Object
Indicates how an employee will be paid when taking this type of earning
27 28 29 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 27 def earnings_type @earnings_type end |
#expense_account_id ⇒ Object
The account that will be used for the earnings rate
57 58 59 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 57 def expense_account_id @expense_account_id end |
#fixed_amount ⇒ Object
Optional Fixed Rate Amount. Applicable for FixedAmount Rate
66 67 68 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 66 def fixed_amount @fixed_amount end |
#multiple_of_ordinary_earnings_rate ⇒ Object
This is the multiplier used to calculate the rate per unit, based on the employee’s ordinary earnings rate. For example, for time and a half enter 1.5. Only applicable if RateType is MultipleOfOrdinaryEarningsRate
63 64 65 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 63 def multiple_of_ordinary_earnings_rate @multiple_of_ordinary_earnings_rate end |
#name ⇒ Object
Name of the earning rate
24 25 26 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 24 def name @name end |
#rate_per_unit ⇒ Object
Default rate per unit (optional). Only applicable if RateType is RatePerUnit
60 61 62 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 60 def rate_per_unit @rate_per_unit end |
#rate_type ⇒ Object
Indicates the type of the earning rate
45 46 47 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 45 def rate_type @rate_type end |
#type_of_units ⇒ Object
The type of units used to record earnings
51 52 53 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 51 def type_of_units @type_of_units end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 91 def self.attribute_map { :'earnings_rate_id' => :'earningsRateID', :'name' => :'name', :'earnings_type' => :'earningsType', :'rate_type' => :'rateType', :'type_of_units' => :'typeOfUnits', :'current_record' => :'currentRecord', :'expense_account_id' => :'expenseAccountID', :'rate_per_unit' => :'ratePerUnit', :'multiple_of_ordinary_earnings_rate' => :'multipleOfOrdinaryEarningsRate', :'fixed_amount' => :'fixedAmount' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
272 273 274 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 272 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 107 def self.openapi_types { :'earnings_rate_id' => :'String', :'name' => :'String', :'earnings_type' => :'String', :'rate_type' => :'String', :'type_of_units' => :'String', :'current_record' => :'Boolean', :'expense_account_id' => :'String', :'rate_per_unit' => :'BigDecimal', :'multiple_of_ordinary_earnings_rate' => :'BigDecimal', :'fixed_amount' => :'BigDecimal' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 242 def ==(o) return true if self.equal?(o) self.class == o.class && earnings_rate_id == o.earnings_rate_id && name == o.name && earnings_type == o.earnings_type && rate_type == o.rate_type && type_of_units == o.type_of_units && current_record == o.current_record && expense_account_id == o.expense_account_id && rate_per_unit == o.rate_per_unit && multiple_of_ordinary_earnings_rate == o.multiple_of_ordinary_earnings_rate && fixed_amount == o.fixed_amount end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 300 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::PayrollNz.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 367 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 279 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
259 260 261 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 259 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
265 266 267 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 265 def hash [earnings_rate_id, name, earnings_type, rate_type, type_of_units, current_record, expense_account_id, rate_per_unit, multiple_of_ordinary_earnings_rate, fixed_amount].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 180 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @earnings_type.nil? invalid_properties.push('invalid value for "earnings_type", earnings_type cannot be nil.') end if @rate_type.nil? invalid_properties.push('invalid value for "rate_type", rate_type cannot be nil.') end if @type_of_units.nil? invalid_properties.push('invalid value for "type_of_units", type_of_units cannot be nil.') end if @expense_account_id.nil? invalid_properties.push('invalid value for "expense_account_id", expense_account_id cannot be nil.') end invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
382 383 384 385 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 382 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
347 348 349 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 347 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
353 354 355 356 357 358 359 360 361 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 353 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
341 342 343 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 341 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/xero-ruby/models/payroll_nz/earnings_rate.rb', line 207 def valid? return false if @name.nil? return false if @earnings_type.nil? earnings_type_validator = EnumAttributeValidator.new('String', ["Allowance", "Backpay", "Bonus", "Commission", "DiscretionaryPayments", "HolidayPay", "LumpSum", "OtherEarnings", "OtherGrossEarnings", "OvertimeEarnings", "RegularEarnings", "SalarySacrificeForKiwiSaver", "Tips(Direct)", "Tips(Non-Direct)", "WithholdingIncome"]) return false unless earnings_type_validator.valid?(@earnings_type) return false if @rate_type.nil? rate_type_validator = EnumAttributeValidator.new('String', ["RatePerUnit", "MultipleOfOrdinaryEarningsRate", "FixedAmount"]) return false unless rate_type_validator.valid?(@rate_type) return false if @type_of_units.nil? return false if @expense_account_id.nil? true end |