Class: XeroRuby::PayrollNz::EmployeeLeaveSetup
- Inherits:
-
Object
- Object
- XeroRuby::PayrollNz::EmployeeLeaveSetup
- Defined in:
- lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb
Instance Attribute Summary collapse
-
#annual_leave_opening_balance ⇒ Object
Initial annual leave balance.
-
#holiday_pay_opening_balance ⇒ Object
Initial holiday pay balance.
-
#include_holiday_pay ⇒ Object
Identifier if holiday pay will be included in each payslip.
-
#negative_annual_leave_balance_paid_amount ⇒ Object
The dollar value of annual leave opening balance if negative.
-
#sick_leave_hours_to_accrue_annually ⇒ Object
Number of hours accrued annually for sick leave.
-
#sick_leave_maximum_hours_to_accrue ⇒ Object
Maximum number of hours accrued annually for sick leave.
-
#sick_leave_opening_balance ⇒ Object
Initial sick leave balance.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmployeeLeaveSetup
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EmployeeLeaveSetup
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollNz::EmployeeLeaveSetup` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollNz::EmployeeLeaveSetup`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'include_holiday_pay') self.include_holiday_pay = attributes[:'include_holiday_pay'] end if attributes.key?(:'holiday_pay_opening_balance') self.holiday_pay_opening_balance = attributes[:'holiday_pay_opening_balance'] end if attributes.key?(:'annual_leave_opening_balance') self.annual_leave_opening_balance = attributes[:'annual_leave_opening_balance'] end if attributes.key?(:'negative_annual_leave_balance_paid_amount') self.negative_annual_leave_balance_paid_amount = attributes[:'negative_annual_leave_balance_paid_amount'] end if attributes.key?(:'sick_leave_hours_to_accrue_annually') self.sick_leave_hours_to_accrue_annually = attributes[:'sick_leave_hours_to_accrue_annually'] end if attributes.key?(:'sick_leave_maximum_hours_to_accrue') self.sick_leave_maximum_hours_to_accrue = attributes[:'sick_leave_maximum_hours_to_accrue'] end if attributes.key?(:'sick_leave_opening_balance') self.sick_leave_opening_balance = attributes[:'sick_leave_opening_balance'] end end |
Instance Attribute Details
#annual_leave_opening_balance ⇒ Object
Initial annual leave balance. The balance at their last anniversary, less any leave taken since then and excluding accrued annual leave.
27 28 29 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 27 def annual_leave_opening_balance @annual_leave_opening_balance end |
#holiday_pay_opening_balance ⇒ Object
Initial holiday pay balance. A percentage — usually 8% — of gross earnings since their last work anniversary.
24 25 26 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 24 def holiday_pay_opening_balance @holiday_pay_opening_balance end |
#include_holiday_pay ⇒ Object
Identifier if holiday pay will be included in each payslip
21 22 23 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 21 def include_holiday_pay @include_holiday_pay end |
#negative_annual_leave_balance_paid_amount ⇒ Object
The dollar value of annual leave opening balance if negative.
30 31 32 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 30 def negative_annual_leave_balance_paid_amount @negative_annual_leave_balance_paid_amount end |
#sick_leave_hours_to_accrue_annually ⇒ Object
Number of hours accrued annually for sick leave. Multiply the number of days they're entitled to by the hours worked per day
33 34 35 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 33 def sick_leave_hours_to_accrue_annually @sick_leave_hours_to_accrue_annually end |
#sick_leave_maximum_hours_to_accrue ⇒ Object
Maximum number of hours accrued annually for sick leave. Multiply the maximum days they can accrue by the hours worked per day
36 37 38 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 36 def sick_leave_maximum_hours_to_accrue @sick_leave_maximum_hours_to_accrue end |
#sick_leave_opening_balance ⇒ Object
Initial sick leave balance. This will be positive unless they've taken sick leave in advance
39 40 41 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 39 def sick_leave_opening_balance @sick_leave_opening_balance end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 42 def self.attribute_map { :'include_holiday_pay' => :'includeHolidayPay', :'holiday_pay_opening_balance' => :'holidayPayOpeningBalance', :'annual_leave_opening_balance' => :'annualLeaveOpeningBalance', :'negative_annual_leave_balance_paid_amount' => :'negativeAnnualLeaveBalancePaidAmount', :'sick_leave_hours_to_accrue_annually' => :'sickLeaveHoursToAccrueAnnually', :'sick_leave_maximum_hours_to_accrue' => :'sickLeaveMaximumHoursToAccrue', :'sick_leave_opening_balance' => :'sickLeaveOpeningBalance' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 153 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 55 def self.openapi_types { :'include_holiday_pay' => :'Boolean', :'holiday_pay_opening_balance' => :'BigDecimal', :'annual_leave_opening_balance' => :'BigDecimal', :'negative_annual_leave_balance_paid_amount' => :'BigDecimal', :'sick_leave_hours_to_accrue_annually' => :'BigDecimal', :'sick_leave_maximum_hours_to_accrue' => :'BigDecimal', :'sick_leave_opening_balance' => :'BigDecimal' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 126 def ==(o) return true if self.equal?(o) self.class == o.class && include_holiday_pay == o.include_holiday_pay && holiday_pay_opening_balance == o.holiday_pay_opening_balance && annual_leave_opening_balance == o.annual_leave_opening_balance && negative_annual_leave_balance_paid_amount == o.negative_annual_leave_balance_paid_amount && sick_leave_hours_to_accrue_annually == o.sick_leave_hours_to_accrue_annually && sick_leave_maximum_hours_to_accrue == o.sick_leave_maximum_hours_to_accrue && sick_leave_opening_balance == o.sick_leave_opening_balance end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 181 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::PayrollNz.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 248 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 160 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
140 141 142 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 140 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 146 def hash [include_holiday_pay, holiday_pay_opening_balance, annual_leave_opening_balance, negative_annual_leave_balance_paid_amount, sick_leave_hours_to_accrue_annually, sick_leave_maximum_hours_to_accrue, sick_leave_opening_balance].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
113 114 115 116 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 113 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
263 264 265 266 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 263 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
228 229 230 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 228 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
234 235 236 237 238 239 240 241 242 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 234 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
222 223 224 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 222 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
120 121 122 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_setup.rb', line 120 def valid? true end |