Class: XeroRuby::PayrollNz::EmployeeLeaveType

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/payroll_nz/employee_leave_type.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EmployeeLeaveType

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollNz::EmployeeLeaveType` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollNz::EmployeeLeaveType`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'leave_type_id')
    self.leave_type_id = attributes[:'leave_type_id']
  end

  if attributes.key?(:'schedule_of_accrual')
    self.schedule_of_accrual = attributes[:'schedule_of_accrual']
  end

  if attributes.key?(:'units_accrued_annually')
    self.units_accrued_annually = attributes[:'units_accrued_annually']
  end

  if attributes.key?(:'type_of_units_to_accrue')
    self.type_of_units_to_accrue = attributes[:'type_of_units_to_accrue']
  end

  if attributes.key?(:'maximum_to_accrue')
    self.maximum_to_accrue = attributes[:'maximum_to_accrue']
  end

  if attributes.key?(:'opening_balance')
    self.opening_balance = attributes[:'opening_balance']
  end

  if attributes.key?(:'opening_balance_type_of_units')
    self.opening_balance_type_of_units = attributes[:'opening_balance_type_of_units']
  end

  if attributes.key?(:'rate_accrued_hourly')
    self.rate_accrued_hourly = attributes[:'rate_accrued_hourly']
  end

  if attributes.key?(:'percentage_of_gross_earnings')
    self.percentage_of_gross_earnings = attributes[:'percentage_of_gross_earnings']
  end

  if attributes.key?(:'include_holiday_pay_every_pay')
    self.include_holiday_pay_every_pay = attributes[:'include_holiday_pay_every_pay']
  end

  if attributes.key?(:'show_annual_leave_in_advance')
    self.show_annual_leave_in_advance = attributes[:'show_annual_leave_in_advance']
  end

  if attributes.key?(:'annual_leave_total_amount_paid')
    self.annual_leave_total_amount_paid = attributes[:'annual_leave_total_amount_paid']
  end

  if attributes.key?(:'schedule_of_accrual_date')
    self.schedule_of_accrual_date = attributes[:'schedule_of_accrual_date']
  end
end

Instance Attribute Details

#annual_leave_total_amount_paidObject

Specific to Annual Leave. Annual leave balance in dollars



57
58
59
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 57

def annual_leave_total_amount_paid
  @annual_leave_total_amount_paid
end

#include_holiday_pay_every_payObject

Specific to Holiday pay. Flag determining if pay for leave type is added on each pay run.



51
52
53
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 51

def include_holiday_pay_every_pay
  @include_holiday_pay_every_pay
end

#leave_type_idObject

The Xero identifier for leave type



20
21
22
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 20

def leave_type_id
  @leave_type_id
end

#maximum_to_accrueObject

The maximum number of units that can be accrued for the leave



36
37
38
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 36

def maximum_to_accrue
  @maximum_to_accrue
end

#opening_balanceObject

The initial number of units assigned when the leave was added to the employee



39
40
41
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 39

def opening_balance
  @opening_balance
end

#opening_balance_type_of_unitsObject

The type of units for the opening balance



42
43
44
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 42

def opening_balance_type_of_units
  @opening_balance_type_of_units
end

#percentage_of_gross_earningsObject

Specific for scheduleOfAccrual having percentage of gross earnings. Identifies how much percentage of gross earnings is accrued per pay period.



48
49
50
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 48

def percentage_of_gross_earnings
  @percentage_of_gross_earnings
end

#rate_accrued_hourlyObject

not supported in Payroll NZ



45
46
47
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 45

def rate_accrued_hourly
  @rate_accrued_hourly
end

#schedule_of_accrualObject

The schedule of accrual



23
24
25
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 23

def schedule_of_accrual
  @schedule_of_accrual
end

#schedule_of_accrual_dateObject

The date when an employee becomes entitled to their accrual.



60
61
62
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 60

def schedule_of_accrual_date
  @schedule_of_accrual_date
end

#show_annual_leave_in_advanceObject

Specific to Annual Leave. Flag to include leave available to take in advance in the balance in the payslip



54
55
56
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 54

def show_annual_leave_in_advance
  @show_annual_leave_in_advance
end

#type_of_units_to_accrueObject

The type of units accrued for the leave annually



33
34
35
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 33

def type_of_units_to_accrue
  @type_of_units_to_accrue
end

#units_accrued_annuallyObject

The number of units accrued for the leave annually. This is 0 when the ScheduleOfAccrual chosen is "NoAccruals"



30
31
32
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 30

def units_accrued_annually
  @units_accrued_annually
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 85

def self.attribute_map
  {
    :'leave_type_id' => :'leaveTypeID',
    :'schedule_of_accrual' => :'scheduleOfAccrual',
    :'units_accrued_annually' => :'unitsAccruedAnnually',
    :'type_of_units_to_accrue' => :'typeOfUnitsToAccrue',
    :'maximum_to_accrue' => :'maximumToAccrue',
    :'opening_balance' => :'openingBalance',
    :'opening_balance_type_of_units' => :'openingBalanceTypeOfUnits',
    :'rate_accrued_hourly' => :'rateAccruedHourly',
    :'percentage_of_gross_earnings' => :'percentageOfGrossEarnings',
    :'include_holiday_pay_every_pay' => :'includeHolidayPayEveryPay',
    :'show_annual_leave_in_advance' => :'showAnnualLeaveInAdvance',
    :'annual_leave_total_amount_paid' => :'annualLeaveTotalAmountPaid',
    :'schedule_of_accrual_date' => :'scheduleOfAccrualDate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



250
251
252
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 250

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 104

def self.openapi_types
  {
    :'leave_type_id' => :'String',
    :'schedule_of_accrual' => :'String',
    :'units_accrued_annually' => :'BigDecimal',
    :'type_of_units_to_accrue' => :'String',
    :'maximum_to_accrue' => :'BigDecimal',
    :'opening_balance' => :'BigDecimal',
    :'opening_balance_type_of_units' => :'String',
    :'rate_accrued_hourly' => :'BigDecimal',
    :'percentage_of_gross_earnings' => :'BigDecimal',
    :'include_holiday_pay_every_pay' => :'Boolean',
    :'show_annual_leave_in_advance' => :'Boolean',
    :'annual_leave_total_amount_paid' => :'BigDecimal',
    :'schedule_of_accrual_date' => :'Date'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      leave_type_id == o.leave_type_id &&
      schedule_of_accrual == o.schedule_of_accrual &&
      units_accrued_annually == o.units_accrued_annually &&
      type_of_units_to_accrue == o.type_of_units_to_accrue &&
      maximum_to_accrue == o.maximum_to_accrue &&
      opening_balance == o.opening_balance &&
      opening_balance_type_of_units == o.opening_balance_type_of_units &&
      rate_accrued_hourly == o.rate_accrued_hourly &&
      percentage_of_gross_earnings == o.percentage_of_gross_earnings &&
      include_holiday_pay_every_pay == o.include_holiday_pay_every_pay &&
      show_annual_leave_in_advance == o.show_annual_leave_in_advance &&
      annual_leave_total_amount_paid == o.annual_leave_total_amount_paid &&
      schedule_of_accrual_date == o.schedule_of_accrual_date
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 278

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BigDecimal
    BigDecimal(value.to_s)
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::PayrollNz.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value, downcase: false) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 351

def _to_hash(value, downcase: false)
  if value.is_a?(Array)
    value.map do |v|
      v.to_hash(downcase: downcase)
    end
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.map { |k, v| hash[k] = _to_hash(v, downcase: downcase) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash(downcase: downcase)
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 257

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


237
238
239
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 237

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



243
244
245
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 243

def hash
  [leave_type_id, schedule_of_accrual, units_accrued_annually, type_of_units_to_accrue, maximum_to_accrue, opening_balance, opening_balance_type_of_units, rate_accrued_hourly, percentage_of_gross_earnings, include_holiday_pay_every_pay, show_annual_leave_in_advance, annual_leave_total_amount_paid, schedule_of_accrual_date].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 192

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object



367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 367

def parse_date(datestring)
  if datestring.include?('Date')
    date_pattern = /\/Date\((-?\d+)(\+\d+)?\)\//
    original, date, timezone = *date_pattern.match(datestring)
    date = (date.to_i / 1000)
    Time.at(date).utc.strftime('%Y-%m-%dT%H:%M:%S%z').to_s
  elsif /(\d\d\d\d)-(\d\d)/.match(datestring) # handles dates w/out Days: YYYY-MM*-DD
    Time.parse(datestring + '-01').strftime('%Y-%m-%dT%H:%M:%S').to_s
  else # handle date 'types' for small subset of payroll API's
    Time.parse(datestring).strftime('%Y-%m-%dT%H:%M:%S').to_s
  end
end

#to_attributesObject

Returns the object in the form of hash with snake_case



343
344
345
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 343

def to_attributes
  to_hash(downcase: true)
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



325
326
327
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 325

def to_body
  to_hash
end

#to_hash(downcase: false) ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
334
335
336
337
338
339
340
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 331

def to_hash(downcase: false)
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    key = downcase ? attr : param
    hash[key] = _to_hash(value, downcase: downcase)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



319
320
321
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 319

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



199
200
201
202
203
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 199

def valid?
  schedule_of_accrual_validator = EnumAttributeValidator.new('String', ["AnnuallyAfter6Months", "OnAnniversaryDate", "PercentageOfGrossEarnings", "NoAccruals"])
  return false unless schedule_of_accrual_validator.valid?(@schedule_of_accrual)
  true
end