Class: XeroRuby::PayrollNz::EmployeeStatutoryLeaveSummary
- Inherits:
-
Object
- Object
- XeroRuby::PayrollNz::EmployeeStatutoryLeaveSummary
- Defined in:
- lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Constant Summary collapse
- SICK =
"Sick".freeze
- ADOPTION =
"Adoption".freeze
- MATERNITY =
"Maternity".freeze
- PATERNITY =
"Paternity".freeze
- SHAREDPARENTAL =
"Sharedparental".freeze
- PENDING =
"Pending".freeze
- IN_PROGRESS =
"In-Progress".freeze
- COMPLETED =
"Completed".freeze
Instance Attribute Summary collapse
-
#employee_id ⇒ Object
The unique identifier (guid) of the employee.
-
#end_date ⇒ Object
The date when the leave ends.
-
#is_entitled ⇒ Object
Whether the leave was entitled to receive payment.
-
#start_date ⇒ Object
The date when the leave starts.
-
#status ⇒ Object
The status of the leave.
-
#statutory_leave_id ⇒ Object
The unique identifier (guid) of a statutory leave.
-
#type ⇒ Object
The category of statutory leave.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmployeeStatutoryLeaveSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EmployeeStatutoryLeaveSummary
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollNz::EmployeeStatutoryLeaveSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollNz::EmployeeStatutoryLeaveSummary`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'statutory_leave_id') self.statutory_leave_id = attributes[:'statutory_leave_id'] end if attributes.key?(:'employee_id') self.employee_id = attributes[:'employee_id'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] end if attributes.key?(:'is_entitled') self.is_entitled = attributes[:'is_entitled'] end if attributes.key?(:'status') self.status = attributes[:'status'] end end |
Instance Attribute Details
#employee_id ⇒ Object
The unique identifier (guid) of the employee
24 25 26 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 24 def employee_id @employee_id end |
#end_date ⇒ Object
The date when the leave ends
38 39 40 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 38 def end_date @end_date end |
#is_entitled ⇒ Object
Whether the leave was entitled to receive payment
41 42 43 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 41 def is_entitled @is_entitled end |
#start_date ⇒ Object
The date when the leave starts
35 36 37 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 35 def start_date @start_date end |
#status ⇒ Object
The status of the leave
44 45 46 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 44 def status @status end |
#statutory_leave_id ⇒ Object
The unique identifier (guid) of a statutory leave.
21 22 23 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 21 def statutory_leave_id @statutory_leave_id end |
#type ⇒ Object
The category of statutory leave
27 28 29 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 27 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 72 def self.attribute_map { :'statutory_leave_id' => :'statutoryLeaveID', :'employee_id' => :'employeeID', :'type' => :'type', :'start_date' => :'startDate', :'end_date' => :'endDate', :'is_entitled' => :'isEntitled', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 207 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 85 def self.openapi_types { :'statutory_leave_id' => :'String', :'employee_id' => :'String', :'type' => :'String', :'start_date' => :'Date', :'end_date' => :'Date', :'is_entitled' => :'Boolean', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && statutory_leave_id == o.statutory_leave_id && employee_id == o.employee_id && type == o.type && start_date == o.start_date && end_date == o.end_date && is_entitled == o.is_entitled && status == o.status end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 235 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::PayrollNz.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 302 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 214 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
194 195 196 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 194 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 200 def hash [statutory_leave_id, employee_id, type, start_date, end_date, is_entitled, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 143 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
317 318 319 320 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 317 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
282 283 284 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 282 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
276 277 278 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 276 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
150 151 152 153 154 155 156 |
# File 'lib/xero-ruby/models/payroll_nz/employee_statutory_leave_summary.rb', line 150 def valid? type_validator = EnumAttributeValidator.new('String', ["Sick", "Adoption", "Maternity", "Paternity", "Sharedparental"]) return false unless type_validator.valid?(@type) status_validator = EnumAttributeValidator.new('String', ["Pending", "In-Progress", "Completed"]) return false unless status_validator.valid?(@status) true end |