Class: XeroRuby::PayrollNz::Reimbursement

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/payroll_nz/reimbursement.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

GST =
"GST".freeze
NO_GST =
"NoGST".freeze
GST_INCLUSIVE =
"GSTInclusive".freeze
UNKNOWN =
"Unknown".freeze
FIXED_AMOUNT =
"FixedAmount".freeze
RATE_PER_UNIT =
"RatePerUnit".freeze
HOURS =
"Hours".freeze
KM =
"km".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Reimbursement

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollNz::Reimbursement` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollNz::Reimbursement`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'reimbursement_id')
    self.reimbursement_id = attributes[:'reimbursement_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'current_record')
    self.current_record = attributes[:'current_record']
  end

  if attributes.key?(:'reimbursement_category')
    self.reimbursement_category = attributes[:'reimbursement_category']
  end

  if attributes.key?(:'calculation_type')
    self.calculation_type = attributes[:'calculation_type']
  end

  if attributes.key?(:'standard_amount')
    self.standard_amount = attributes[:'standard_amount']
  end

  if attributes.key?(:'standard_type_of_units')
    self.standard_type_of_units = attributes[:'standard_type_of_units']
  end

  if attributes.key?(:'standard_rate_per_unit')
    self.standard_rate_per_unit = attributes[:'standard_rate_per_unit']
  end
end

Instance Attribute Details

#account_idObject

Xero unique identifier for the account used for the reimbursement



27
28
29
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 27

def 
  @account_id
end

#calculation_typeObject

See Calculation Types



39
40
41
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 39

def calculation_type
  @calculation_type
end

#current_recordObject

Indicates that whether the reimbursement is active



30
31
32
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 30

def current_record
  @current_record
end

#nameObject

Name of the reimbursement



24
25
26
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 24

def name
  @name
end

#reimbursement_categoryObject

See Reimbursement Categories



33
34
35
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 33

def reimbursement_category
  @reimbursement_category
end

#reimbursement_idObject

Xero unique identifier for a reimbursement



21
22
23
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 21

def reimbursement_id
  @reimbursement_id
end

#standard_amountObject

Optional Fixed Rate Amount. Applicable when calculation type is Fixed Amount



45
46
47
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 45

def standard_amount
  @standard_amount
end

#standard_rate_per_unitObject

Optional Rate Per Unit. Applicable when calculation type is Rate Per Unit



53
54
55
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 53

def standard_rate_per_unit
  @standard_rate_per_unit
end

#standard_type_of_unitsObject

Optional Type Of Units. Applicable when calculation type is Rate Per Unit



48
49
50
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 48

def standard_type_of_units
  @standard_type_of_units
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 78

def self.attribute_map
  {
    :'reimbursement_id' => :'reimbursementID',
    :'name' => :'name',
    :'account_id' => :'accountID',
    :'current_record' => :'currentRecord',
    :'reimbursement_category' => :'reimbursementCategory',
    :'calculation_type' => :'calculationType',
    :'standard_amount' => :'standardAmount',
    :'standard_type_of_units' => :'standardTypeOfUnits',
    :'standard_rate_per_unit' => :'standardRatePerUnit'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



249
250
251
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 249

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 93

def self.openapi_types
  {
    :'reimbursement_id' => :'String',
    :'name' => :'String',
    :'account_id' => :'String',
    :'current_record' => :'Boolean',
    :'reimbursement_category' => :'String',
    :'calculation_type' => :'String',
    :'standard_amount' => :'String',
    :'standard_type_of_units' => :'String',
    :'standard_rate_per_unit' => :'BigDecimal'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 220

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      reimbursement_id == o.reimbursement_id &&
      name == o.name &&
       == o. &&
      current_record == o.current_record &&
      reimbursement_category == o.reimbursement_category &&
      calculation_type == o.calculation_type &&
      standard_amount == o.standard_amount &&
      standard_type_of_units == o.standard_type_of_units &&
      standard_rate_per_unit == o.standard_rate_per_unit
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 277

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BigDecimal
    BigDecimal(value.to_s)
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::PayrollNz.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 344

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 256

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


236
237
238
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 236

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



242
243
244
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 242

def hash
  [reimbursement_id, name, , current_record, reimbursement_category, calculation_type, standard_amount, standard_type_of_units, standard_rate_per_unit].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 161

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



359
360
361
362
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 359

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



324
325
326
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 324

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
333
334
335
336
337
338
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 330

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



318
319
320
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 318

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
181
182
183
184
185
186
# File 'lib/xero-ruby/models/payroll_nz/reimbursement.rb', line 176

def valid?
  return false if @name.nil?
  return false if @account_id.nil?
  reimbursement_category_validator = EnumAttributeValidator.new('String', ["GST", "NoGST", "GSTInclusive"])
  return false unless reimbursement_category_validator.valid?(@reimbursement_category)
  calculation_type_validator = EnumAttributeValidator.new('String', ["Unknown", "FixedAmount", "RatePerUnit"])
  return false unless calculation_type_validator.valid?(@calculation_type)
  standard_type_of_units_validator = EnumAttributeValidator.new('String', ["Hours", "km"])
  return false unless standard_type_of_units_validator.valid?(@standard_type_of_units)
  true
end