Class: XeroRuby::PayrollUk::Benefit

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/payroll_uk/benefit.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

STAKEHOLDER_PENSION =
"StakeholderPension".freeze
OTHER =
"Other".freeze
FIXED_AMOUNT =
"FixedAmount".freeze
PERCENTAGE_OF_GROSS =
"PercentageOfGross".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Benefit

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollUk::Benefit` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollUk::Benefit`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'liability_account_id')
    self. = attributes[:'liability_account_id']
  end

  if attributes.key?(:'expense_account_id')
    self. = attributes[:'expense_account_id']
  end

  if attributes.key?(:'standard_amount')
    self.standard_amount = attributes[:'standard_amount']
  end

  if attributes.key?(:'percentage')
    self.percentage = attributes[:'percentage']
  end

  if attributes.key?(:'calculation_type')
    self.calculation_type = attributes[:'calculation_type']
  end

  if attributes.key?(:'current_record')
    self.current_record = attributes[:'current_record']
  end

  if attributes.key?(:'subject_to_nic')
    self.subject_to_nic = attributes[:'subject_to_nic']
  end

  if attributes.key?(:'subject_to_pension')
    self.subject_to_pension = attributes[:'subject_to_pension']
  end

  if attributes.key?(:'subject_to_tax')
    self.subject_to_tax = attributes[:'subject_to_tax']
  end

  if attributes.key?(:'is_calculating_on_qualifying_earnings')
    self.is_calculating_on_qualifying_earnings = attributes[:'is_calculating_on_qualifying_earnings']
  end

  if attributes.key?(:'show_balance_to_employee')
    self.show_balance_to_employee = attributes[:'show_balance_to_employee']
  end
end

Instance Attribute Details

#calculation_typeObject

Calculation Type of the employer pension (FixedAmount or PercentageOfGross).



44
45
46
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 44

def calculation_type
  @calculation_type
end

#categoryObject

Category type of the employer pension



27
28
29
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 27

def category
  @category
end

#current_recordObject

Identifier of a record is active or not.



49
50
51
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 49

def current_record
  @current_record
end

#expense_account_idObject

Xero identifier for Expense Account



35
36
37
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 35

def 
  
end

#idObject

unique identifier in Xero



21
22
23
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 21

def id
  @id
end

#is_calculating_on_qualifying_earningsObject

Identifier of calculating on qualifying earnings



61
62
63
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 61

def is_calculating_on_qualifying_earnings
  @is_calculating_on_qualifying_earnings
end

#liability_account_idObject

Xero identifier for Liability Account



32
33
34
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 32

def 
  
end

#nameObject

Name of the employer pension



24
25
26
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 24

def name
  @name
end

#percentageObject

Percentage of gross of the employer pension



41
42
43
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 41

def percentage
  @percentage
end

#show_balance_to_employeeObject

display the balance to employee



64
65
66
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 64

def show_balance_to_employee
  @show_balance_to_employee
end

#standard_amountObject

Standard amount of the employer pension



38
39
40
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 38

def standard_amount
  @standard_amount
end

#subject_to_nicObject

Identifier of subject To NIC



52
53
54
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 52

def subject_to_nic
  @subject_to_nic
end

#subject_to_pensionObject

Identifier of subject To pension



55
56
57
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 55

def subject_to_pension
  @subject_to_pension
end

#subject_to_taxObject

Identifier of subject To Tax



58
59
60
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 58

def subject_to_tax
  @subject_to_tax
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 89

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'category' => :'category',
    :'liability_account_id' => :'liabilityAccountId',
    :'expense_account_id' => :'expenseAccountId',
    :'standard_amount' => :'standardAmount',
    :'percentage' => :'percentage',
    :'calculation_type' => :'calculationType',
    :'current_record' => :'currentRecord',
    :'subject_to_nic' => :'subjectToNIC',
    :'subject_to_pension' => :'subjectToPension',
    :'subject_to_tax' => :'subjectToTax',
    :'is_calculating_on_qualifying_earnings' => :'isCalculatingOnQualifyingEarnings',
    :'show_balance_to_employee' => :'showBalanceToEmployee'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



303
304
305
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 303

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 109

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'category' => :'String',
    :'liability_account_id' => :'String',
    :'expense_account_id' => :'String',
    :'standard_amount' => :'BigDecimal',
    :'percentage' => :'BigDecimal',
    :'calculation_type' => :'String',
    :'current_record' => :'Boolean',
    :'subject_to_nic' => :'Boolean',
    :'subject_to_pension' => :'Boolean',
    :'subject_to_tax' => :'Boolean',
    :'is_calculating_on_qualifying_earnings' => :'Boolean',
    :'show_balance_to_employee' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 269

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      category == o.category &&
       == o. &&
       == o. &&
      standard_amount == o.standard_amount &&
      percentage == o.percentage &&
      calculation_type == o.calculation_type &&
      current_record == o.current_record &&
      subject_to_nic == o.subject_to_nic &&
      subject_to_pension == o.subject_to_pension &&
      subject_to_tax == o.subject_to_tax &&
      is_calculating_on_qualifying_earnings == o.is_calculating_on_qualifying_earnings &&
      show_balance_to_employee == o.show_balance_to_employee
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 331

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BigDecimal
    BigDecimal(value.to_s)
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::PayrollUk.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 398

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 310

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


290
291
292
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 290

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



296
297
298
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 296

def hash
  [id, name, category, , , standard_amount, percentage, calculation_type, current_record, subject_to_nic, subject_to_pension, subject_to_tax, is_calculating_on_qualifying_earnings, show_balance_to_employee].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 202

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  if .nil?
    invalid_properties.push('invalid value for "liability_account_id", liability_account_id cannot be nil.')
  end

  if .nil?
    invalid_properties.push('invalid value for "expense_account_id", expense_account_id cannot be nil.')
  end

  if @percentage.nil?
    invalid_properties.push('invalid value for "percentage", percentage cannot be nil.')
  end

  if @calculation_type.nil?
    invalid_properties.push('invalid value for "calculation_type", calculation_type cannot be nil.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



413
414
415
416
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 413

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



378
379
380
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 378

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



384
385
386
387
388
389
390
391
392
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 384

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



372
373
374
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 372

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/xero-ruby/models/payroll_uk/benefit.rb', line 233

def valid?
  return false if @name.nil?
  return false if @category.nil?
  category_validator = EnumAttributeValidator.new('String', ["StakeholderPension", "Other"])
  return false unless category_validator.valid?(@category)
  return false if .nil?
  return false if .nil?
  return false if @percentage.nil?
  return false if @calculation_type.nil?
  calculation_type_validator = EnumAttributeValidator.new('String', ["FixedAmount", "PercentageOfGross"])
  return false unless calculation_type_validator.valid?(@calculation_type)
  true
end