Class: XeroRuby::PayrollUk::Employee

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/payroll_uk/employee.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

M =
"M".freeze
F =
"F".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Employee

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 133

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollUk::Employee` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollUk::Employee`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'employee_id')
    self.employee_id = attributes[:'employee_id']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'gender')
    self.gender = attributes[:'gender']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'payroll_calendar_id')
    self.payroll_calendar_id = attributes[:'payroll_calendar_id']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'created_date_utc')
    self.created_date_utc = attributes[:'created_date_utc']
  end

  if attributes.key?(:'national_insurance_number')
    self.national_insurance_number = attributes[:'national_insurance_number']
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



36
37
38
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 36

def address
  @address
end

#created_date_utcObject

UTC timestamp when the employee was created in Xero



62
63
64
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 62

def created_date_utc
  @created_date_utc
end

#date_of_birthObject

Date of birth of the employee (YYYY-MM-DD)



33
34
35
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 33

def date_of_birth
  @date_of_birth
end

#emailObject

The email address for the employee



39
40
41
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 39

def email
  @email
end

#employee_idObject

Xero unique identifier for the employee



21
22
23
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 21

def employee_id
  @employee_id
end

#end_dateObject

Employment end date of the employee at the time it was requested



53
54
55
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 53

def end_date
  @end_date
end

#first_nameObject

First name of employee



27
28
29
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 27

def first_name
  @first_name
end

#genderObject

The employee’s gender



42
43
44
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 42

def gender
  @gender
end

#last_nameObject

Last name of employee



30
31
32
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 30

def last_name
  @last_name
end

#national_insurance_numberObject

National insurance number of the employee



65
66
67
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 65

def national_insurance_number
  @national_insurance_number
end

#payroll_calendar_idObject

Xero unique identifier for the payroll calendar of the employee



56
57
58
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 56

def payroll_calendar_id
  @payroll_calendar_id
end

#phone_numberObject

Employee phone number



47
48
49
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 47

def phone_number
  @phone_number
end

#start_dateObject

Employment start date of the employee at the time it was requested



50
51
52
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 50

def start_date
  @start_date
end

#titleObject

Title of the employee



24
25
26
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 24

def title
  @title
end

#updated_date_utcObject

UTC timestamp of last update to the employee



59
60
61
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 59

def updated_date_utc
  @updated_date_utc
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 90

def self.attribute_map
  {
    :'employee_id' => :'employeeID',
    :'title' => :'title',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'date_of_birth' => :'dateOfBirth',
    :'address' => :'address',
    :'email' => :'email',
    :'gender' => :'gender',
    :'phone_number' => :'phoneNumber',
    :'start_date' => :'startDate',
    :'end_date' => :'endDate',
    :'payroll_calendar_id' => :'payrollCalendarID',
    :'updated_date_utc' => :'updatedDateUTC',
    :'created_date_utc' => :'createdDateUTC',
    :'national_insurance_number' => :'nationalInsuranceNumber'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



269
270
271
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 269

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 111

def self.openapi_types
  {
    :'employee_id' => :'String',
    :'title' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'date_of_birth' => :'Date',
    :'address' => :'Address',
    :'email' => :'String',
    :'gender' => :'String',
    :'phone_number' => :'String',
    :'start_date' => :'Date',
    :'end_date' => :'Date',
    :'payroll_calendar_id' => :'String',
    :'updated_date_utc' => :'DateTime',
    :'created_date_utc' => :'DateTime',
    :'national_insurance_number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 234

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      employee_id == o.employee_id &&
      title == o.title &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      date_of_birth == o.date_of_birth &&
      address == o.address &&
      email == o.email &&
      gender == o.gender &&
      phone_number == o.phone_number &&
      start_date == o.start_date &&
      end_date == o.end_date &&
      payroll_calendar_id == o.payroll_calendar_id &&
      updated_date_utc == o.updated_date_utc &&
      created_date_utc == o.created_date_utc &&
      national_insurance_number == o.national_insurance_number
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 297

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BigDecimal
    BigDecimal(value.to_s)
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::PayrollUk.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 364

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 276

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


256
257
258
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 256

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



262
263
264
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 262

def hash
  [employee_id, title, first_name, last_name, date_of_birth, address, email, gender, phone_number, start_date, end_date, payroll_calendar_id, updated_date_utc, created_date_utc, national_insurance_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



209
210
211
212
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 209

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



379
380
381
382
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 379

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



344
345
346
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 344

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
353
354
355
356
357
358
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 350

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



338
339
340
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 338

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



216
217
218
219
220
# File 'lib/xero-ruby/models/payroll_uk/employee.rb', line 216

def valid?
  gender_validator = EnumAttributeValidator.new('String', ["M", "F"])
  return false unless gender_validator.valid?(@gender)
  true
end