Class: XeroRuby::PayrollUk::EmployeeStatutorySickLeave
- Inherits:
-
Object
- Object
- XeroRuby::PayrollUk::EmployeeStatutorySickLeave
- Defined in:
- lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#employee_id ⇒ Object
The unique identifier (guid) of the employee.
-
#end_date ⇒ Object
The date when the leave ends.
-
#entitlement_failure_reasons ⇒ Object
If the leave requested was considered "not entitled", the reasons why are listed here.
-
#entitlement_weeks_qualified ⇒ Object
The amount of statutory sick leave time off (in weeks) that is available to take at the time the leave was requested.
-
#entitlement_weeks_remaining ⇒ Object
A calculated amount of time (in weeks) that remains for the statutory sick leave period.
-
#entitlement_weeks_requested ⇒ Object
The amount of requested time (in weeks).
-
#is_entitled ⇒ Object
Whether the leave was entitled to receive payment.
-
#is_pregnancy_related ⇒ Object
Whether the sick leave was pregnancy related.
-
#leave_type_id ⇒ Object
The unique identifier (guid) of the "Statutory Sick Leave (non-pensionable)" pay item.
-
#overlaps_with_other_leave ⇒ Object
Whether another leave (Paternity, Shared Parental specifically) occurs during the requested leave's period.
-
#start_date ⇒ Object
The date when the leave starts.
-
#status ⇒ Object
the type of statutory leave.
-
#statutory_leave_id ⇒ Object
The unique identifier (guid) of a statutory leave.
-
#sufficient_notice ⇒ Object
Whether the employee provided sufficent notice and documentation as required by the employer supporting the sick leave request.
-
#type ⇒ Object
the type of statutory leave.
-
#work_pattern ⇒ Object
The days of the work week the employee is scheduled to work at the time the leave is taken.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmployeeStatutorySickLeave
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EmployeeStatutorySickLeave
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 136 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollUk::EmployeeStatutorySickLeave` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollUk::EmployeeStatutorySickLeave`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'statutory_leave_id') self.statutory_leave_id = attributes[:'statutory_leave_id'] end if attributes.key?(:'employee_id') self.employee_id = attributes[:'employee_id'] end if attributes.key?(:'leave_type_id') self.leave_type_id = attributes[:'leave_type_id'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'work_pattern') if (value = attributes[:'work_pattern']).is_a?(Array) self.work_pattern = value end end if attributes.key?(:'is_pregnancy_related') self. = attributes[:'is_pregnancy_related'] end if attributes.key?(:'sufficient_notice') self.sufficient_notice = attributes[:'sufficient_notice'] end if attributes.key?(:'is_entitled') self.is_entitled = attributes[:'is_entitled'] end if attributes.key?(:'entitlement_weeks_requested') self.entitlement_weeks_requested = attributes[:'entitlement_weeks_requested'] end if attributes.key?(:'entitlement_weeks_qualified') self.entitlement_weeks_qualified = attributes[:'entitlement_weeks_qualified'] end if attributes.key?(:'entitlement_weeks_remaining') self.entitlement_weeks_remaining = attributes[:'entitlement_weeks_remaining'] end if attributes.key?(:'overlaps_with_other_leave') self.overlaps_with_other_leave = attributes[:'overlaps_with_other_leave'] end if attributes.key?(:'entitlement_failure_reasons') if (value = attributes[:'entitlement_failure_reasons']).is_a?(Array) self.entitlement_failure_reasons = value end end end |
Instance Attribute Details
#employee_id ⇒ Object
The unique identifier (guid) of the employee
24 25 26 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 24 def employee_id @employee_id end |
#end_date ⇒ Object
The date when the leave ends
33 34 35 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 33 def end_date @end_date end |
#entitlement_failure_reasons ⇒ Object
If the leave requested was considered "not entitled", the reasons why are listed here.
66 67 68 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 66 def entitlement_failure_reasons @entitlement_failure_reasons end |
#entitlement_weeks_qualified ⇒ Object
The amount of statutory sick leave time off (in weeks) that is available to take at the time the leave was requested
57 58 59 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 57 def entitlement_weeks_qualified @entitlement_weeks_qualified end |
#entitlement_weeks_remaining ⇒ Object
A calculated amount of time (in weeks) that remains for the statutory sick leave period
60 61 62 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 60 def entitlement_weeks_remaining @entitlement_weeks_remaining end |
#entitlement_weeks_requested ⇒ Object
The amount of requested time (in weeks)
54 55 56 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 54 def entitlement_weeks_requested @entitlement_weeks_requested end |
#is_entitled ⇒ Object
Whether the leave was entitled to receive payment
51 52 53 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 51 def is_entitled @is_entitled end |
#is_pregnancy_related ⇒ Object
Whether the sick leave was pregnancy related
45 46 47 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 45 def @is_pregnancy_related end |
#leave_type_id ⇒ Object
The unique identifier (guid) of the "Statutory Sick Leave (non-pensionable)" pay item
27 28 29 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 27 def leave_type_id @leave_type_id end |
#overlaps_with_other_leave ⇒ Object
Whether another leave (Paternity, Shared Parental specifically) occurs during the requested leave's period. While this is allowed it could affect payment amounts
63 64 65 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 63 def overlaps_with_other_leave @overlaps_with_other_leave end |
#start_date ⇒ Object
The date when the leave starts
30 31 32 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 30 def start_date @start_date end |
#status ⇒ Object
the type of statutory leave
39 40 41 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 39 def status @status end |
#statutory_leave_id ⇒ Object
The unique identifier (guid) of a statutory leave
21 22 23 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 21 def statutory_leave_id @statutory_leave_id end |
#sufficient_notice ⇒ Object
Whether the employee provided sufficent notice and documentation as required by the employer supporting the sick leave request
48 49 50 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 48 def sufficient_notice @sufficient_notice end |
#type ⇒ Object
the type of statutory leave
36 37 38 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 36 def type @type end |
#work_pattern ⇒ Object
The days of the work week the employee is scheduled to work at the time the leave is taken
42 43 44 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 42 def work_pattern @work_pattern end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 91 def self.attribute_map { :'statutory_leave_id' => :'statutoryLeaveID', :'employee_id' => :'employeeID', :'leave_type_id' => :'leaveTypeID', :'start_date' => :'startDate', :'end_date' => :'endDate', :'type' => :'type', :'status' => :'status', :'work_pattern' => :'workPattern', :'is_pregnancy_related' => :'isPregnancyRelated', :'sufficient_notice' => :'sufficientNotice', :'is_entitled' => :'isEntitled', :'entitlement_weeks_requested' => :'entitlementWeeksRequested', :'entitlement_weeks_qualified' => :'entitlementWeeksQualified', :'entitlement_weeks_remaining' => :'entitlementWeeksRemaining', :'overlaps_with_other_leave' => :'overlapsWithOtherLeave', :'entitlement_failure_reasons' => :'entitlementFailureReasons' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
304 305 306 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 304 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 113 def self.openapi_types { :'statutory_leave_id' => :'String', :'employee_id' => :'String', :'leave_type_id' => :'String', :'start_date' => :'Date', :'end_date' => :'Date', :'type' => :'String', :'status' => :'String', :'work_pattern' => :'Array<String>', :'is_pregnancy_related' => :'Boolean', :'sufficient_notice' => :'Boolean', :'is_entitled' => :'Boolean', :'entitlement_weeks_requested' => :'Float', :'entitlement_weeks_qualified' => :'Float', :'entitlement_weeks_remaining' => :'Float', :'overlaps_with_other_leave' => :'Boolean', :'entitlement_failure_reasons' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 268 def ==(o) return true if self.equal?(o) self.class == o.class && statutory_leave_id == o.statutory_leave_id && employee_id == o.employee_id && leave_type_id == o.leave_type_id && start_date == o.start_date && end_date == o.end_date && type == o.type && status == o.status && work_pattern == o.work_pattern && == o. && sufficient_notice == o.sufficient_notice && is_entitled == o.is_entitled && entitlement_weeks_requested == o.entitlement_weeks_requested && entitlement_weeks_qualified == o.entitlement_weeks_qualified && entitlement_weeks_remaining == o.entitlement_weeks_remaining && overlaps_with_other_leave == o.overlaps_with_other_leave && entitlement_failure_reasons == o.entitlement_failure_reasons end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 332 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::PayrollUk.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 399 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 311 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
291 292 293 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 291 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
297 298 299 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 297 def hash [statutory_leave_id, employee_id, leave_type_id, start_date, end_date, type, status, work_pattern, , sufficient_notice, is_entitled, entitlement_weeks_requested, entitlement_weeks_qualified, entitlement_weeks_remaining, overlaps_with_other_leave, entitlement_failure_reasons].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 220 def list_invalid_properties invalid_properties = Array.new if @employee_id.nil? invalid_properties.push('invalid value for "employee_id", employee_id cannot be nil.') end if @leave_type_id.nil? invalid_properties.push('invalid value for "leave_type_id", leave_type_id cannot be nil.') end if @start_date.nil? invalid_properties.push('invalid value for "start_date", start_date cannot be nil.') end if @end_date.nil? invalid_properties.push('invalid value for "end_date", end_date cannot be nil.') end if @work_pattern.nil? invalid_properties.push('invalid value for "work_pattern", work_pattern cannot be nil.') end if @is_pregnancy_related.nil? invalid_properties.push('invalid value for "is_pregnancy_related", is_pregnancy_related cannot be nil.') end if @sufficient_notice.nil? invalid_properties.push('invalid value for "sufficient_notice", sufficient_notice cannot be nil.') end invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
414 415 416 417 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 414 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
379 380 381 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 379 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
385 386 387 388 389 390 391 392 393 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 385 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
373 374 375 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 373 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
255 256 257 258 259 260 261 262 263 264 |
# File 'lib/xero-ruby/models/payroll_uk/employee_statutory_sick_leave.rb', line 255 def valid? return false if @employee_id.nil? return false if @leave_type_id.nil? return false if @start_date.nil? return false if @end_date.nil? return false if @work_pattern.nil? return false if @is_pregnancy_related.nil? return false if @sufficient_notice.nil? true end |