Class: XeroRuby::Projects::Project

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/projects/project.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Project

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/xero-ruby/models/projects/project.rb', line 142

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Projects::Project` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Projects::Project`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'contact_id')
    self.contact_id = attributes[:'contact_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'currency_code')
    self.currency_code = attributes[:'currency_code']
  end

  if attributes.key?(:'minutes_logged')
    self.minutes_logged = attributes[:'minutes_logged']
  end

  if attributes.key?(:'total_task_amount')
    self.total_task_amount = attributes[:'total_task_amount']
  end

  if attributes.key?(:'total_expense_amount')
    self.total_expense_amount = attributes[:'total_expense_amount']
  end

  if attributes.key?(:'estimate_amount')
    self.estimate_amount = attributes[:'estimate_amount']
  end

  if attributes.key?(:'minutes_to_be_invoiced')
    self.minutes_to_be_invoiced = attributes[:'minutes_to_be_invoiced']
  end

  if attributes.key?(:'task_amount_to_be_invoiced')
    self.task_amount_to_be_invoiced = attributes[:'task_amount_to_be_invoiced']
  end

  if attributes.key?(:'task_amount_invoiced')
    self.task_amount_invoiced = attributes[:'task_amount_invoiced']
  end

  if attributes.key?(:'expense_amount_to_be_invoiced')
    self.expense_amount_to_be_invoiced = attributes[:'expense_amount_to_be_invoiced']
  end

  if attributes.key?(:'expense_amount_invoiced')
    self.expense_amount_invoiced = attributes[:'expense_amount_invoiced']
  end

  if attributes.key?(:'project_amount_invoiced')
    self.project_amount_invoiced = attributes[:'project_amount_invoiced']
  end

  if attributes.key?(:'deposit')
    self.deposit = attributes[:'deposit']
  end

  if attributes.key?(:'deposit_applied')
    self.deposit_applied = attributes[:'deposit_applied']
  end

  if attributes.key?(:'credit_note_amount')
    self.credit_note_amount = attributes[:'credit_note_amount']
  end

  if attributes.key?(:'deadline_utc')
    self.deadline_utc = attributes[:'deadline_utc']
  end

  if attributes.key?(:'total_invoiced')
    self.total_invoiced = attributes[:'total_invoiced']
  end

  if attributes.key?(:'total_to_be_invoiced')
    self.total_to_be_invoiced = attributes[:'total_to_be_invoiced']
  end

  if attributes.key?(:'estimate')
    self.estimate = attributes[:'estimate']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#contact_id ⇒ Object

Identifier of the contact this project was created for.



22
23
24
# File 'lib/xero-ruby/models/projects/project.rb', line 22

def contact_id
  @contact_id
end

#credit_note_amount ⇒ Object

Returns the value of attribute credit_note_amount.



67
68
69
# File 'lib/xero-ruby/models/projects/project.rb', line 67

def credit_note_amount
  @credit_note_amount
end

#currency_code ⇒ Object

Returns the value of attribute currency_code.



28
29
30
# File 'lib/xero-ruby/models/projects/project.rb', line 28

def currency_code
  @currency_code
end

#deadline_utc ⇒ Object

Deadline for the project. UTC Date Time in ISO-8601 format.



70
71
72
# File 'lib/xero-ruby/models/projects/project.rb', line 70

def deadline_utc
  @deadline_utc
end

#deposit ⇒ Object

Returns the value of attribute deposit.



61
62
63
# File 'lib/xero-ruby/models/projects/project.rb', line 61

def deposit
  @deposit
end

#deposit_applied ⇒ Object

Returns the value of attribute deposit_applied.



64
65
66
# File 'lib/xero-ruby/models/projects/project.rb', line 64

def deposit_applied
  @deposit_applied
end

#estimate ⇒ Object

Returns the value of attribute estimate.



79
80
81
# File 'lib/xero-ruby/models/projects/project.rb', line 79

def estimate
  @estimate
end

#estimate_amount ⇒ Object

Returns the value of attribute estimate_amount.



40
41
42
# File 'lib/xero-ruby/models/projects/project.rb', line 40

def estimate_amount
  @estimate_amount
end

#expense_amount_invoiced ⇒ Object

Returns the value of attribute expense_amount_invoiced.



55
56
57
# File 'lib/xero-ruby/models/projects/project.rb', line 55

def expense_amount_invoiced
  @expense_amount_invoiced
end

#expense_amount_to_be_invoiced ⇒ Object

Returns the value of attribute expense_amount_to_be_invoiced.



52
53
54
# File 'lib/xero-ruby/models/projects/project.rb', line 52

def expense_amount_to_be_invoiced
  @expense_amount_to_be_invoiced
end

#minutes_logged ⇒ Object

A total of minutes logged against all tasks on the Project.



31
32
33
# File 'lib/xero-ruby/models/projects/project.rb', line 31

def minutes_logged
  @minutes_logged
end

#minutes_to_be_invoiced ⇒ Object

Minutes which have not been invoiced across all chargeable tasks in the project.



43
44
45
# File 'lib/xero-ruby/models/projects/project.rb', line 43

def minutes_to_be_invoiced
  @minutes_to_be_invoiced
end

#name ⇒ Object

Name of the project.



25
26
27
# File 'lib/xero-ruby/models/projects/project.rb', line 25

def name
  @name
end

#project_amount_invoiced ⇒ Object

Returns the value of attribute project_amount_invoiced.



58
59
60
# File 'lib/xero-ruby/models/projects/project.rb', line 58

def project_amount_invoiced
  @project_amount_invoiced
end

#project_id ⇒ Object

Identifier of the project.



19
20
21
# File 'lib/xero-ruby/models/projects/project.rb', line 19

def project_id
  @project_id
end

#status ⇒ Object

Returns the value of attribute status.



82
83
84
# File 'lib/xero-ruby/models/projects/project.rb', line 82

def status
  @status
end

#task_amount_invoiced ⇒ Object

Returns the value of attribute task_amount_invoiced.



49
50
51
# File 'lib/xero-ruby/models/projects/project.rb', line 49

def task_amount_invoiced
  @task_amount_invoiced
end

#task_amount_to_be_invoiced ⇒ Object

Returns the value of attribute task_amount_to_be_invoiced.



46
47
48
# File 'lib/xero-ruby/models/projects/project.rb', line 46

def task_amount_to_be_invoiced
  @task_amount_to_be_invoiced
end

#total_expense_amount ⇒ Object

Returns the value of attribute total_expense_amount.



37
38
39
# File 'lib/xero-ruby/models/projects/project.rb', line 37

def total_expense_amount
  @total_expense_amount
end

#total_invoiced ⇒ Object

Returns the value of attribute total_invoiced.



73
74
75
# File 'lib/xero-ruby/models/projects/project.rb', line 73

def total_invoiced
  @total_invoiced
end

#total_task_amount ⇒ Object

Returns the value of attribute total_task_amount.



34
35
36
# File 'lib/xero-ruby/models/projects/project.rb', line 34

def total_task_amount
  @total_task_amount
end

#total_to_be_invoiced ⇒ Object

Returns the value of attribute total_to_be_invoiced.



76
77
78
# File 'lib/xero-ruby/models/projects/project.rb', line 76

def total_to_be_invoiced
  @total_to_be_invoiced
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/xero-ruby/models/projects/project.rb', line 85

def self.attribute_map
  {
    :'project_id' => :'projectId',
    :'contact_id' => :'contactId',
    :'name' => :'name',
    :'currency_code' => :'currencyCode',
    :'minutes_logged' => :'minutesLogged',
    :'total_task_amount' => :'totalTaskAmount',
    :'total_expense_amount' => :'totalExpenseAmount',
    :'estimate_amount' => :'estimateAmount',
    :'minutes_to_be_invoiced' => :'minutesToBeInvoiced',
    :'task_amount_to_be_invoiced' => :'taskAmountToBeInvoiced',
    :'task_amount_invoiced' => :'taskAmountInvoiced',
    :'expense_amount_to_be_invoiced' => :'expenseAmountToBeInvoiced',
    :'expense_amount_invoiced' => :'expenseAmountInvoiced',
    :'project_amount_invoiced' => :'projectAmountInvoiced',
    :'deposit' => :'deposit',
    :'deposit_applied' => :'depositApplied',
    :'credit_note_amount' => :'creditNoteAmount',
    :'deadline_utc' => :'deadlineUtc',
    :'total_invoiced' => :'totalInvoiced',
    :'total_to_be_invoiced' => :'totalToBeInvoiced',
    :'estimate' => :'estimate',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



306
307
308
# File 'lib/xero-ruby/models/projects/project.rb', line 306

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/xero-ruby/models/projects/project.rb', line 113

def self.openapi_types
  {
    :'project_id' => :'String',
    :'contact_id' => :'String',
    :'name' => :'String',
    :'currency_code' => :'CurrencyCode',
    :'minutes_logged' => :'Integer',
    :'total_task_amount' => :'Amount',
    :'total_expense_amount' => :'Amount',
    :'estimate_amount' => :'Amount',
    :'minutes_to_be_invoiced' => :'Integer',
    :'task_amount_to_be_invoiced' => :'Amount',
    :'task_amount_invoiced' => :'Amount',
    :'expense_amount_to_be_invoiced' => :'Amount',
    :'expense_amount_invoiced' => :'Amount',
    :'project_amount_invoiced' => :'Amount',
    :'deposit' => :'Amount',
    :'deposit_applied' => :'Amount',
    :'credit_note_amount' => :'Amount',
    :'deadline_utc' => :'DateTime',
    :'total_invoiced' => :'Amount',
    :'total_to_be_invoiced' => :'Amount',
    :'estimate' => :'Amount',
    :'status' => :'ProjectStatus'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/xero-ruby/models/projects/project.rb', line 264

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      project_id == o.project_id &&
      contact_id == o.contact_id &&
      name == o.name &&
      currency_code == o.currency_code &&
      minutes_logged == o.minutes_logged &&
      total_task_amount == o.total_task_amount &&
      total_expense_amount == o.total_expense_amount &&
      estimate_amount == o.estimate_amount &&
      minutes_to_be_invoiced == o.minutes_to_be_invoiced &&
      task_amount_to_be_invoiced == o.task_amount_to_be_invoiced &&
      task_amount_invoiced == o.task_amount_invoiced &&
      expense_amount_to_be_invoiced == o.expense_amount_to_be_invoiced &&
      expense_amount_invoiced == o.expense_amount_invoiced &&
      project_amount_invoiced == o.project_amount_invoiced &&
      deposit == o.deposit &&
      deposit_applied == o.deposit_applied &&
      credit_note_amount == o.credit_note_amount &&
      deadline_utc == o.deadline_utc &&
      total_invoiced == o.total_invoiced &&
      total_to_be_invoiced == o.total_to_be_invoiced &&
      estimate == o.estimate &&
      status == o.status
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/xero-ruby/models/projects/project.rb', line 334

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Projects.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/xero-ruby/models/projects/project.rb', line 399

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/xero-ruby/models/projects/project.rb', line 313

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


293
294
295
# File 'lib/xero-ruby/models/projects/project.rb', line 293

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



299
300
301
# File 'lib/xero-ruby/models/projects/project.rb', line 299

def hash
  [project_id, contact_id, name, currency_code, minutes_logged, total_task_amount, total_expense_amount, estimate_amount, minutes_to_be_invoiced, task_amount_to_be_invoiced, task_amount_invoiced, expense_amount_to_be_invoiced, expense_amount_invoiced, project_amount_invoiced, deposit, deposit_applied, credit_note_amount, deadline_utc, total_invoiced, total_to_be_invoiced, estimate, status].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



246
247
248
249
250
251
252
253
# File 'lib/xero-ruby/models/projects/project.rb', line 246

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



414
415
416
417
# File 'lib/xero-ruby/models/projects/project.rb', line 414

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



379
380
381
# File 'lib/xero-ruby/models/projects/project.rb', line 379

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



385
386
387
388
389
390
391
392
393
# File 'lib/xero-ruby/models/projects/project.rb', line 385

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



373
374
375
# File 'lib/xero-ruby/models/projects/project.rb', line 373

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



257
258
259
260
# File 'lib/xero-ruby/models/projects/project.rb', line 257

def valid?
  return false if @name.nil?
  true
end