Class: XeroRuby::Projects::Task
- Inherits:
-
Object
- Object
- XeroRuby::Projects::Task
- Defined in:
- lib/xero-ruby/models/projects/task.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Constant Summary collapse
- ACTIVE =
"ACTIVE".freeze
- INVOICED =
"INVOICED".freeze
- LOCKED =
"LOCKED".freeze
Instance Attribute Summary collapse
-
#amount_invoiced ⇒ Object
Returns the value of attribute amount_invoiced.
-
#amount_to_be_invoiced ⇒ Object
Returns the value of attribute amount_to_be_invoiced.
-
#charge_type ⇒ Object
Returns the value of attribute charge_type.
-
#estimate_minutes ⇒ Object
An estimated time to perform the task.
-
#fixed_minutes ⇒ Object
Minutes logged against this task if its charge type is
FIXED. -
#minutes_invoiced ⇒ Object
Minutes on this task which have been invoiced.
-
#minutes_to_be_invoiced ⇒ Object
Minutes on this task which have not been invoiced.
-
#name ⇒ Object
Name of the task.
-
#non_chargeable_minutes ⇒ Object
Minutes logged against this task if its charge type is
NON_CHARGEABLE. -
#project_id ⇒ Object
Identifier of the project task belongs to.
-
#rate ⇒ Object
Returns the value of attribute rate.
-
#status ⇒ Object
Status of the task.
-
#task_id ⇒ Object
Identifier of the task.
-
#total_amount ⇒ Object
Returns the value of attribute total_amount.
-
#total_minutes ⇒ Object
Total minutes which have been logged against the task.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Task
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Task
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/xero-ruby/models/projects/task.rb', line 132 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Projects::Task` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Projects::Task`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'task_id') self.task_id = attributes[:'task_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'rate') self.rate = attributes[:'rate'] end if attributes.key?(:'charge_type') self.charge_type = attributes[:'charge_type'] end if attributes.key?(:'estimate_minutes') self.estimate_minutes = attributes[:'estimate_minutes'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'total_minutes') self.total_minutes = attributes[:'total_minutes'] end if attributes.key?(:'total_amount') self.total_amount = attributes[:'total_amount'] end if attributes.key?(:'minutes_invoiced') self.minutes_invoiced = attributes[:'minutes_invoiced'] end if attributes.key?(:'minutes_to_be_invoiced') self.minutes_to_be_invoiced = attributes[:'minutes_to_be_invoiced'] end if attributes.key?(:'fixed_minutes') self.fixed_minutes = attributes[:'fixed_minutes'] end if attributes.key?(:'non_chargeable_minutes') self.non_chargeable_minutes = attributes[:'non_chargeable_minutes'] end if attributes.key?(:'amount_to_be_invoiced') self.amount_to_be_invoiced = attributes[:'amount_to_be_invoiced'] end if attributes.key?(:'amount_invoiced') self.amount_invoiced = attributes[:'amount_invoiced'] end if attributes.key?(:'status') self.status = attributes[:'status'] end end |
Instance Attribute Details
#amount_invoiced ⇒ Object
Returns the value of attribute amount_invoiced.
58 59 60 |
# File 'lib/xero-ruby/models/projects/task.rb', line 58 def amount_invoiced @amount_invoiced end |
#amount_to_be_invoiced ⇒ Object
Returns the value of attribute amount_to_be_invoiced.
55 56 57 |
# File 'lib/xero-ruby/models/projects/task.rb', line 55 def amount_to_be_invoiced @amount_to_be_invoiced end |
#charge_type ⇒ Object
Returns the value of attribute charge_type.
28 29 30 |
# File 'lib/xero-ruby/models/projects/task.rb', line 28 def charge_type @charge_type end |
#estimate_minutes ⇒ Object
An estimated time to perform the task
31 32 33 |
# File 'lib/xero-ruby/models/projects/task.rb', line 31 def estimate_minutes @estimate_minutes end |
#fixed_minutes ⇒ Object
Minutes logged against this task if its charge type is FIXED.
49 50 51 |
# File 'lib/xero-ruby/models/projects/task.rb', line 49 def fixed_minutes @fixed_minutes end |
#minutes_invoiced ⇒ Object
Minutes on this task which have been invoiced.
43 44 45 |
# File 'lib/xero-ruby/models/projects/task.rb', line 43 def minutes_invoiced @minutes_invoiced end |
#minutes_to_be_invoiced ⇒ Object
Minutes on this task which have not been invoiced.
46 47 48 |
# File 'lib/xero-ruby/models/projects/task.rb', line 46 def minutes_to_be_invoiced @minutes_to_be_invoiced end |
#name ⇒ Object
Name of the task.
22 23 24 |
# File 'lib/xero-ruby/models/projects/task.rb', line 22 def name @name end |
#non_chargeable_minutes ⇒ Object
Minutes logged against this task if its charge type is NON_CHARGEABLE.
52 53 54 |
# File 'lib/xero-ruby/models/projects/task.rb', line 52 def non_chargeable_minutes @non_chargeable_minutes end |
#project_id ⇒ Object
Identifier of the project task belongs to.
34 35 36 |
# File 'lib/xero-ruby/models/projects/task.rb', line 34 def project_id @project_id end |
#rate ⇒ Object
Returns the value of attribute rate.
25 26 27 |
# File 'lib/xero-ruby/models/projects/task.rb', line 25 def rate @rate end |
#status ⇒ Object
Status of the task. When a task of ChargeType is FIXED and the rate amount is invoiced the status will be set to INVOICED and can't be modified. A task with ChargeType of TIME or NON_CHARGEABLE cannot have a status of INVOICED. A LOCKED state indicates that the task is currently changing state (for example being invoiced) and can't be modified.
61 62 63 |
# File 'lib/xero-ruby/models/projects/task.rb', line 61 def status @status end |
#task_id ⇒ Object
Identifier of the task.
19 20 21 |
# File 'lib/xero-ruby/models/projects/task.rb', line 19 def task_id @task_id end |
#total_amount ⇒ Object
Returns the value of attribute total_amount.
40 41 42 |
# File 'lib/xero-ruby/models/projects/task.rb', line 40 def total_amount @total_amount end |
#total_minutes ⇒ Object
Total minutes which have been logged against the task. Logged by assigning a time entry to a task
37 38 39 |
# File 'lib/xero-ruby/models/projects/task.rb', line 37 def total_minutes @total_minutes end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/xero-ruby/models/projects/task.rb', line 89 def self.attribute_map { :'task_id' => :'taskId', :'name' => :'name', :'rate' => :'rate', :'charge_type' => :'chargeType', :'estimate_minutes' => :'estimateMinutes', :'project_id' => :'projectId', :'total_minutes' => :'totalMinutes', :'total_amount' => :'totalAmount', :'minutes_invoiced' => :'minutesInvoiced', :'minutes_to_be_invoiced' => :'minutesToBeInvoiced', :'fixed_minutes' => :'fixedMinutes', :'non_chargeable_minutes' => :'nonChargeableMinutes', :'amount_to_be_invoiced' => :'amountToBeInvoiced', :'amount_invoiced' => :'amountInvoiced', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 |
# File 'lib/xero-ruby/models/projects/task.rb', line 268 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/xero-ruby/models/projects/task.rb', line 110 def self.openapi_types { :'task_id' => :'String', :'name' => :'String', :'rate' => :'Amount', :'charge_type' => :'ChargeType', :'estimate_minutes' => :'Float', :'project_id' => :'String', :'total_minutes' => :'Float', :'total_amount' => :'Amount', :'minutes_invoiced' => :'Float', :'minutes_to_be_invoiced' => :'Float', :'fixed_minutes' => :'Float', :'non_chargeable_minutes' => :'Float', :'amount_to_be_invoiced' => :'Amount', :'amount_invoiced' => :'Amount', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/xero-ruby/models/projects/task.rb', line 233 def ==(o) return true if self.equal?(o) self.class == o.class && task_id == o.task_id && name == o.name && rate == o.rate && charge_type == o.charge_type && estimate_minutes == o.estimate_minutes && project_id == o.project_id && total_minutes == o.total_minutes && total_amount == o.total_amount && minutes_invoiced == o.minutes_invoiced && minutes_to_be_invoiced == o.minutes_to_be_invoiced && fixed_minutes == o.fixed_minutes && non_chargeable_minutes == o.non_chargeable_minutes && amount_to_be_invoiced == o.amount_to_be_invoiced && amount_invoiced == o.amount_invoiced && status == o.status end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/xero-ruby/models/projects/task.rb', line 296 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::Projects.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/xero-ruby/models/projects/task.rb', line 361 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/xero-ruby/models/projects/task.rb', line 275 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
255 256 257 |
# File 'lib/xero-ruby/models/projects/task.rb', line 255 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/xero-ruby/models/projects/task.rb', line 261 def hash [task_id, name, rate, charge_type, estimate_minutes, project_id, total_minutes, total_amount, minutes_invoiced, minutes_to_be_invoiced, fixed_minutes, non_chargeable_minutes, amount_to_be_invoiced, amount_invoiced, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
208 209 210 211 |
# File 'lib/xero-ruby/models/projects/task.rb', line 208 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
376 377 378 379 |
# File 'lib/xero-ruby/models/projects/task.rb', line 376 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
341 342 343 |
# File 'lib/xero-ruby/models/projects/task.rb', line 341 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
347 348 349 350 351 352 353 354 355 |
# File 'lib/xero-ruby/models/projects/task.rb', line 347 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
335 336 337 |
# File 'lib/xero-ruby/models/projects/task.rb', line 335 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
215 216 217 218 219 |
# File 'lib/xero-ruby/models/projects/task.rb', line 215 def valid? status_validator = EnumAttributeValidator.new('String', ["ACTIVE", "INVOICED", "LOCKED"]) return false unless status_validator.valid?(@status) true end |