Class: XeroRuby::Projects::TimeEntry

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/projects/time_entry.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

ACTIVE =
"ACTIVE".freeze
LOCKED =
"LOCKED".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TimeEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Projects::TimeEntry` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Projects::TimeEntry`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'time_entry_id')
    self.time_entry_id = attributes[:'time_entry_id']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'task_id')
    self.task_id = attributes[:'task_id']
  end

  if attributes.key?(:'date_utc')
    self.date_utc = attributes[:'date_utc']
  end

  if attributes.key?(:'date_entered_utc')
    self.date_entered_utc = attributes[:'date_entered_utc']
  end

  if attributes.key?(:'duration')
    self.duration = attributes[:'duration']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#date_entered_utc ⇒ Object

The date time that time entry is created. UTC Date Time in ISO-8601 format. By default it is set to server time.



34
35
36
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 34

def date_entered_utc
  @date_entered_utc
end

#date_utc ⇒ Object

The date time that time entry is logged on. UTC Date Time in ISO-8601 format.



31
32
33
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 31

def date_utc
  @date_utc
end

#description ⇒ Object

A description of the time entry.



40
41
42
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 40

def description
  @description
end

#duration ⇒ Object

The duration of logged minutes.



37
38
39
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 37

def duration
  @duration
end

#project_id ⇒ Object

Identifier of the project, that the task (which the time entry is logged against) belongs to.



25
26
27
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 25

def project_id
  @project_id
end

#status ⇒ Object

Status of the time entry. By default a time entry is created with status of ACTIVE. A LOCKED state indicates that the time entry is currently changing state (for example being invoiced). Updates are not allowed when in this state. It will have a status of INVOICED once it is invoiced.



43
44
45
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 43

def status
  @status
end

#task_id ⇒ Object

Identifier of the task that time entry is logged against.



28
29
30
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 28

def task_id
  @task_id
end

#time_entry_id ⇒ Object

Identifier of the time entry.



19
20
21
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 19

def time_entry_id
  @time_entry_id
end

#user_id ⇒ Object

The xero user identifier of the person who logged time.



22
23
24
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 22

def user_id
  @user_id
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 70

def self.attribute_map
  {
    :'time_entry_id' => :'timeEntryId',
    :'user_id' => :'userId',
    :'project_id' => :'projectId',
    :'task_id' => :'taskId',
    :'date_utc' => :'dateUtc',
    :'date_entered_utc' => :'dateEnteredUtc',
    :'duration' => :'duration',
    :'description' => :'description',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



207
208
209
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 207

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 85

def self.openapi_types
  {
    :'time_entry_id' => :'String',
    :'user_id' => :'String',
    :'project_id' => :'String',
    :'task_id' => :'String',
    :'date_utc' => :'DateTime',
    :'date_entered_utc' => :'DateTime',
    :'duration' => :'Integer',
    :'description' => :'String',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 178

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      time_entry_id == o.time_entry_id &&
      user_id == o.user_id &&
      project_id == o.project_id &&
      task_id == o.task_id &&
      date_utc == o.date_utc &&
      date_entered_utc == o.date_entered_utc &&
      duration == o.duration &&
      description == o.description &&
      status == o.status
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 235

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Projects.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 300

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 214

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


194
195
196
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 194

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



200
201
202
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 200

def hash
  [time_entry_id, user_id, project_id, task_id, date_utc, date_entered_utc, duration, description, status].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 153

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



315
316
317
318
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 315

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



280
281
282
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 280

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



286
287
288
289
290
291
292
293
294
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 286

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



274
275
276
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 274

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



160
161
162
163
164
# File 'lib/xero-ruby/models/projects/time_entry.rb', line 160

def valid?
  status_validator = EnumAttributeValidator.new('String', ["ACTIVE", "LOCKED"])
  return false unless status_validator.valid?(@status)
  true
end