Class: XeroRuby::Receipt

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/receipt.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Receipt

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/xero-ruby/models/receipt.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Receipt` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Receipt`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'contact')
    self.contact = attributes[:'contact']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'line_amount_types')
    self.line_amount_types = attributes[:'line_amount_types']
  end

  if attributes.key?(:'sub_total')
    self.sub_total = attributes[:'sub_total']
  end

  if attributes.key?(:'total_tax')
    self.total_tax = attributes[:'total_tax']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'receipt_id')
    self.receipt_id = attributes[:'receipt_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'receipt_number')
    self.receipt_number = attributes[:'receipt_number']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end
end

Instance Attribute Details

#attachments ⇒ Object

Displays array of attachments from the API



63
64
65
# File 'lib/xero-ruby/models/receipt.rb', line 63

def attachments
  @attachments
end

#contact ⇒ Object

Returns the value of attribute contact.



21
22
23
# File 'lib/xero-ruby/models/receipt.rb', line 21

def contact
  @contact
end

#date ⇒ Object

Date of receipt – YYYY-MM-DD



19
20
21
# File 'lib/xero-ruby/models/receipt.rb', line 19

def date
  @date
end

#has_attachments ⇒ Object

boolean to indicate if a receipt has an attachment



54
55
56
# File 'lib/xero-ruby/models/receipt.rb', line 54

def has_attachments
  @has_attachments
end

#line_amount_types ⇒ Object

Returns the value of attribute line_amount_types.



30
31
32
# File 'lib/xero-ruby/models/receipt.rb', line 30

def line_amount_types
  @line_amount_types
end

#line_items ⇒ Object

Returns the value of attribute line_items.



23
24
25
# File 'lib/xero-ruby/models/receipt.rb', line 23

def line_items
  @line_items
end

#receipt_id ⇒ Object

Xero generated unique identifier for receipt



42
43
44
# File 'lib/xero-ruby/models/receipt.rb', line 42

def receipt_id
  @receipt_id
end

#receipt_number ⇒ Object

Xero generated sequence number for receipt in current claim for a given user



48
49
50
# File 'lib/xero-ruby/models/receipt.rb', line 48

def receipt_number
  @receipt_number
end

#reference ⇒ Object

Additional reference number



28
29
30
# File 'lib/xero-ruby/models/receipt.rb', line 28

def reference
  @reference
end

#status ⇒ Object

Current status of receipt – see status types



45
46
47
# File 'lib/xero-ruby/models/receipt.rb', line 45

def status
  @status
end

#sub_total ⇒ Object

Total of receipt excluding taxes



33
34
35
# File 'lib/xero-ruby/models/receipt.rb', line 33

def sub_total
  @sub_total
end

#total ⇒ Object

Total of receipt tax inclusive (i.e. SubTotal + TotalTax)



39
40
41
# File 'lib/xero-ruby/models/receipt.rb', line 39

def total
  @total
end

#total_tax ⇒ Object

Total tax on receipt



36
37
38
# File 'lib/xero-ruby/models/receipt.rb', line 36

def total_tax
  @total_tax
end

#updated_date_utc ⇒ Object

Last modified date UTC format



51
52
53
# File 'lib/xero-ruby/models/receipt.rb', line 51

def updated_date_utc
  @updated_date_utc
end

#url ⇒ Object

URL link to a source document – shown as “Go to [appName]” in the Xero app



57
58
59
# File 'lib/xero-ruby/models/receipt.rb', line 57

def url
  @url
end

#user ⇒ Object

Returns the value of attribute user.



25
26
27
# File 'lib/xero-ruby/models/receipt.rb', line 25

def user
  @user
end

#validation_errors ⇒ Object

Displays array of validation error messages from the API



60
61
62
# File 'lib/xero-ruby/models/receipt.rb', line 60

def validation_errors
  @validation_errors
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/xero-ruby/models/receipt.rb', line 88

def self.attribute_map
  {
    :'date' => :'Date',
    :'contact' => :'Contact',
    :'line_items' => :'LineItems',
    :'user' => :'User',
    :'reference' => :'Reference',
    :'line_amount_types' => :'LineAmountTypes',
    :'sub_total' => :'SubTotal',
    :'total_tax' => :'TotalTax',
    :'total' => :'Total',
    :'receipt_id' => :'ReceiptID',
    :'status' => :'Status',
    :'receipt_number' => :'ReceiptNumber',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'has_attachments' => :'HasAttachments',
    :'url' => :'Url',
    :'validation_errors' => :'ValidationErrors',
    :'attachments' => :'Attachments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



307
308
309
# File 'lib/xero-ruby/models/receipt.rb', line 307

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/xero-ruby/models/receipt.rb', line 111

def self.openapi_types
  {
    :'date' => :'Date',
    :'contact' => :'Contact',
    :'line_items' => :'Array<LineItem>',
    :'user' => :'User',
    :'reference' => :'String',
    :'line_amount_types' => :'LineAmountTypes',
    :'sub_total' => :'Float',
    :'total_tax' => :'Float',
    :'total' => :'Float',
    :'receipt_id' => :'String',
    :'status' => :'String',
    :'receipt_number' => :'String',
    :'updated_date_utc' => :'DateTime',
    :'has_attachments' => :'Boolean',
    :'url' => :'String',
    :'validation_errors' => :'Array<ValidationError>',
    :'attachments' => :'Array<Attachment>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/xero-ruby/models/receipt.rb', line 270

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date == o.date &&
      contact == o.contact &&
      line_items == o.line_items &&
      user == o.user &&
      reference == o.reference &&
      line_amount_types == o.line_amount_types &&
      sub_total == o.sub_total &&
      total_tax == o.total_tax &&
      total == o.total &&
      receipt_id == o.receipt_id &&
      status == o.status &&
      receipt_number == o.receipt_number &&
      updated_date_utc == o.updated_date_utc &&
      has_attachments == o.has_attachments &&
      url == o.url &&
      validation_errors == o.validation_errors &&
      attachments == o.attachments
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/xero-ruby/models/receipt.rb', line 335

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/xero-ruby/models/receipt.rb', line 400

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/xero-ruby/models/receipt.rb', line 314

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


294
295
296
# File 'lib/xero-ruby/models/receipt.rb', line 294

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



300
301
302
# File 'lib/xero-ruby/models/receipt.rb', line 300

def hash
  [date, contact, line_items, user, reference, line_amount_types, sub_total, total_tax, total, receipt_id, status, receipt_number, updated_date_utc, has_attachments, url, validation_errors, attachments].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/xero-ruby/models/receipt.rb', line 225

def list_invalid_properties
  invalid_properties = Array.new
  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  if @contact.nil?
    invalid_properties.push('invalid value for "contact", contact cannot be nil.')
  end

  if @line_items.nil?
    invalid_properties.push('invalid value for "line_items", line_items cannot be nil.')
  end

  if @user.nil?
    invalid_properties.push('invalid value for "user", user cannot be nil.')
  end

  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



415
416
417
418
# File 'lib/xero-ruby/models/receipt.rb', line 415

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



380
381
382
# File 'lib/xero-ruby/models/receipt.rb', line 380

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



386
387
388
389
390
391
392
393
394
# File 'lib/xero-ruby/models/receipt.rb', line 386

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



374
375
376
# File 'lib/xero-ruby/models/receipt.rb', line 374

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



248
249
250
251
252
253
254
255
256
# File 'lib/xero-ruby/models/receipt.rb', line 248

def valid?
  return false if @date.nil?
  return false if @contact.nil?
  return false if @line_items.nil?
  return false if @user.nil?
  status_validator = EnumAttributeValidator.new('String', ["DRAFT", "SUBMITTED", "AUTHORISED", "DECLINED"])
  return false unless status_validator.valid?(@status)
  true
end