Class: XeroRuby::Accounting::BankTransfer
- Inherits:
-
Object
- Object
- XeroRuby::Accounting::BankTransfer
- Defined in:
- lib/xero-ruby/models/accounting/bank_transfer.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
amount of the transaction.
-
#bank_transfer_id ⇒ Object
The identifier of the Bank Transfer.
-
#created_date_utc ⇒ Object
UTC timestamp of creation date of bank transfer.
-
#currency_rate ⇒ Object
The currency rate.
-
#date ⇒ Object
The date of the Transfer YYYY-MM-DD.
-
#from_bank_account ⇒ Object
Returns the value of attribute from_bank_account.
-
#from_bank_transaction_id ⇒ Object
The Bank Transaction ID for the source account.
-
#from_is_reconciled ⇒ Object
The Bank Transaction boolean to show if it is reconciled for the source account.
-
#from_tracking ⇒ Object
Optional Tracking Category for the source account – see Tracking.
-
#has_attachments ⇒ Object
Boolean to indicate if a Bank Transfer has an attachment.
-
#reference ⇒ Object
Reference for the transactions.
-
#status ⇒ Object
AUTHORISED or DELETED (read-only).
-
#to_bank_account ⇒ Object
Returns the value of attribute to_bank_account.
-
#to_bank_transaction_id ⇒ Object
The Bank Transaction ID for the destination account.
-
#to_is_reconciled ⇒ Object
The Bank Transaction boolean to show if it is reconciled for the destination account.
-
#to_tracking ⇒ Object
Optional Tracking Category for the destination account – see Tracking.
-
#validation_errors ⇒ Object
Displays array of validation error messages from the API.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value, downcase: false) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BankTransfer
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
- #parse_date(datestring) ⇒ Object
-
#to_attributes ⇒ Object
Returns the object in the form of hash with snake_case.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash(downcase: false) ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ BankTransfer
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 142 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::BankTransfer` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::BankTransfer`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'from_bank_account') self.from_bank_account = attributes[:'from_bank_account'] end if attributes.key?(:'to_bank_account') self.to_bank_account = attributes[:'to_bank_account'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'bank_transfer_id') self.bank_transfer_id = attributes[:'bank_transfer_id'] end if attributes.key?(:'currency_rate') self.currency_rate = attributes[:'currency_rate'] end if attributes.key?(:'from_bank_transaction_id') self.from_bank_transaction_id = attributes[:'from_bank_transaction_id'] end if attributes.key?(:'to_bank_transaction_id') self.to_bank_transaction_id = attributes[:'to_bank_transaction_id'] end if attributes.key?(:'from_is_reconciled') self.from_is_reconciled = attributes[:'from_is_reconciled'] else self.from_is_reconciled = false end if attributes.key?(:'to_is_reconciled') self.to_is_reconciled = attributes[:'to_is_reconciled'] else self.to_is_reconciled = false end if attributes.key?(:'reference') self.reference = attributes[:'reference'] end if attributes.key?(:'has_attachments') self. = attributes[:'has_attachments'] else self. = false end if attributes.key?(:'created_date_utc') self.created_date_utc = attributes[:'created_date_utc'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'from_tracking') if (value = attributes[:'from_tracking']).is_a?(Array) self.from_tracking = value end end if attributes.key?(:'to_tracking') if (value = attributes[:'to_tracking']).is_a?(Array) self.to_tracking = value end end if attributes.key?(:'validation_errors') if (value = attributes[:'validation_errors']).is_a?(Array) self.validation_errors = value end end end |
Instance Attribute Details
#amount ⇒ Object
amount of the transaction
26 27 28 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 26 def amount @amount end |
#bank_transfer_id ⇒ Object
The identifier of the Bank Transfer
32 33 34 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 32 def bank_transfer_id @bank_transfer_id end |
#created_date_utc ⇒ Object
UTC timestamp of creation date of bank transfer
56 57 58 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 56 def created_date_utc @created_date_utc end |
#currency_rate ⇒ Object
The currency rate
35 36 37 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 35 def currency_rate @currency_rate end |
#date ⇒ Object
The date of the Transfer YYYY-MM-DD
29 30 31 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 29 def date @date end |
#from_bank_account ⇒ Object
Returns the value of attribute from_bank_account.
20 21 22 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 20 def from_bank_account @from_bank_account end |
#from_bank_transaction_id ⇒ Object
The Bank Transaction ID for the source account
38 39 40 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 38 def from_bank_transaction_id @from_bank_transaction_id end |
#from_is_reconciled ⇒ Object
The Bank Transaction boolean to show if it is reconciled for the source account
44 45 46 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 44 def from_is_reconciled @from_is_reconciled end |
#from_tracking ⇒ Object
Optional Tracking Category for the source account – see Tracking. A bank transfer can have a maximum of 2 tracking categories per account.
64 65 66 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 64 def from_tracking @from_tracking end |
#has_attachments ⇒ Object
Boolean to indicate if a Bank Transfer has an attachment
53 54 55 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 53 def @has_attachments end |
#reference ⇒ Object
Reference for the transactions.
50 51 52 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 50 def reference @reference end |
#status ⇒ Object
AUTHORISED or DELETED (read-only). New bank transfers will have a status of AUTHORISED.
59 60 61 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 59 def status @status end |
#to_bank_account ⇒ Object
Returns the value of attribute to_bank_account.
23 24 25 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 23 def to_bank_account @to_bank_account end |
#to_bank_transaction_id ⇒ Object
The Bank Transaction ID for the destination account
41 42 43 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 41 def to_bank_transaction_id @to_bank_transaction_id end |
#to_is_reconciled ⇒ Object
The Bank Transaction boolean to show if it is reconciled for the destination account
47 48 49 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 47 def to_is_reconciled @to_is_reconciled end |
#to_tracking ⇒ Object
Optional Tracking Category for the destination account – see Tracking. A bank transfer can have a maximum of 2 tracking categories per account.
67 68 69 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 67 def to_tracking @to_tracking end |
#validation_errors ⇒ Object
Displays array of validation error messages from the API
70 71 72 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 70 def validation_errors @validation_errors end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 95 def self.attribute_map { :'from_bank_account' => :'FromBankAccount', :'to_bank_account' => :'ToBankAccount', :'amount' => :'Amount', :'date' => :'Date', :'bank_transfer_id' => :'BankTransferID', :'currency_rate' => :'CurrencyRate', :'from_bank_transaction_id' => :'FromBankTransactionID', :'to_bank_transaction_id' => :'ToBankTransactionID', :'from_is_reconciled' => :'FromIsReconciled', :'to_is_reconciled' => :'ToIsReconciled', :'reference' => :'Reference', :'has_attachments' => :'HasAttachments', :'created_date_utc' => :'CreatedDateUTC', :'status' => :'Status', :'from_tracking' => :'FromTracking', :'to_tracking' => :'ToTracking', :'validation_errors' => :'ValidationErrors' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
315 316 317 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 315 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 118 def self.openapi_types { :'from_bank_account' => :'Account', :'to_bank_account' => :'Account', :'amount' => :'BigDecimal', :'date' => :'Date', :'bank_transfer_id' => :'String', :'currency_rate' => :'BigDecimal', :'from_bank_transaction_id' => :'String', :'to_bank_transaction_id' => :'String', :'from_is_reconciled' => :'Boolean', :'to_is_reconciled' => :'Boolean', :'reference' => :'String', :'has_attachments' => :'Boolean', :'created_date_utc' => :'DateTime', :'status' => :'String', :'from_tracking' => :'Array<TrackingReference>', :'to_tracking' => :'Array<TrackingReference>', :'validation_errors' => :'Array<ValidationError>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 278 def ==(o) return true if self.equal?(o) self.class == o.class && from_bank_account == o.from_bank_account && to_bank_account == o.to_bank_account && amount == o.amount && date == o.date && bank_transfer_id == o.bank_transfer_id && currency_rate == o.currency_rate && from_bank_transaction_id == o.from_bank_transaction_id && to_bank_transaction_id == o.to_bank_transaction_id && from_is_reconciled == o.from_is_reconciled && to_is_reconciled == o.to_is_reconciled && reference == o.reference && == o. && created_date_utc == o.created_date_utc && status == o.status && from_tracking == o.from_tracking && to_tracking == o.to_tracking && validation_errors == o.validation_errors end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 343 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::Accounting.const_get(type).build_from_hash(value) end end |
#_to_hash(value, downcase: false) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 416 def _to_hash(value, downcase: false) if value.is_a?(Array) value.map do |v| v.to_hash(downcase: downcase) end elsif value.is_a?(Hash) {}.tap do |hash| value.map { |k, v| hash[k] = _to_hash(v, downcase: downcase) } end elsif value.respond_to? :to_hash value.to_hash(downcase: downcase) else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 322 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
302 303 304 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 302 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
308 309 310 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 308 def hash [from_bank_account, to_bank_account, amount, date, bank_transfer_id, currency_rate, from_bank_transaction_id, to_bank_transaction_id, from_is_reconciled, to_is_reconciled, reference, , created_date_utc, status, from_tracking, to_tracking, validation_errors].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 238 def list_invalid_properties invalid_properties = Array.new if @from_bank_account.nil? invalid_properties.push('invalid value for "from_bank_account", from_bank_account cannot be nil.') end if @to_bank_account.nil? invalid_properties.push('invalid value for "to_bank_account", to_bank_account cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end invalid_properties end |
#parse_date(datestring) ⇒ Object
432 433 434 435 436 437 438 439 440 441 442 443 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 432 def parse_date(datestring) if datestring.include?('Date') date_pattern = /\/Date\((-?\d+)(\+\d+)?\)\// original, date, timezone = *date_pattern.match(datestring) date = (date.to_i / 1000) Time.at(date).utc.strftime('%Y-%m-%dT%H:%M:%S%z').to_s elsif /(\d\d\d\d)-(\d\d)/.match(datestring) # handles dates w/out Days: YYYY-MM*-DD Time.parse(datestring + '-01').strftime('%Y-%m-%dT%H:%M:%S').to_s else # handle date 'types' for small subset of payroll API's Time.parse(datestring).strftime('%Y-%m-%dT%H:%M:%S').to_s end end |
#to_attributes ⇒ Object
Returns the object in the form of hash with snake_case
408 409 410 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 408 def to_attributes to_hash(downcase: true) end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
390 391 392 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 390 def to_body to_hash end |
#to_hash(downcase: false) ⇒ Hash
Returns the object in the form of hash
396 397 398 399 400 401 402 403 404 405 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 396 def to_hash(downcase: false) hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? key = downcase ? attr : param hash[key] = _to_hash(value, downcase: downcase) end hash end |
#to_s ⇒ String
Returns the string representation of the object
384 385 386 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 384 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
257 258 259 260 261 262 263 264 |
# File 'lib/xero-ruby/models/accounting/bank_transfer.rb', line 257 def valid? return false if @from_bank_account.nil? return false if @to_bank_account.nil? return false if @amount.nil? status_validator = EnumAttributeValidator.new('String', ["AUTHORISED", "DELETED"]) return false unless status_validator.valid?(@status) true end |