Class: XeroRuby::Accounting::Overpayment

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/overpayment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

RECEIVE_OVERPAYMENT =
"RECEIVE-OVERPAYMENT".freeze
SPEND_OVERPAYMENT =
"SPEND-OVERPAYMENT".freeze
AROVERPAYMENT =
"AROVERPAYMENT".freeze
AUTHORISED =
"AUTHORISED".freeze
"PAID".freeze
VOIDED =
"VOIDED".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Overpayment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 155

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Overpayment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Overpayment`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'contact')
    self.contact = attributes[:'contact']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'line_amount_types')
    self.line_amount_types = attributes[:'line_amount_types']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'sub_total')
    self.sub_total = attributes[:'sub_total']
  end

  if attributes.key?(:'total_tax')
    self.total_tax = attributes[:'total_tax']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'currency_code')
    self.currency_code = attributes[:'currency_code']
  end

  if attributes.key?(:'overpayment_id')
    self.overpayment_id = attributes[:'overpayment_id']
  end

  if attributes.key?(:'currency_rate')
    self.currency_rate = attributes[:'currency_rate']
  end

  if attributes.key?(:'remaining_credit')
    self.remaining_credit = attributes[:'remaining_credit']
  end

  if attributes.key?(:'allocations')
    if (value = attributes[:'allocations']).is_a?(Array)
      self.allocations = value
    end
  end

  if attributes.key?(:'applied_amount')
    self.applied_amount = attributes[:'applied_amount']
  end

  if attributes.key?(:'payments')
    if (value = attributes[:'payments']).is_a?(Array)
      self.payments = value
    end
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  else
    self.has_attachments = false
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end
end

Instance Attribute Details

#allocations ⇒ Object

See Allocations



67
68
69
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 67

def allocations
  @allocations
end

#applied_amount ⇒ Object

The amount of applied to an invoice



70
71
72
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 70

def applied_amount
  @applied_amount
end

#attachments ⇒ Object

See Attachments



79
80
81
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 79

def attachments
  @attachments
end

#contact ⇒ Object

Returns the value of attribute contact.



25
26
27
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 25

def contact
  @contact
end

#currency_code ⇒ Object

Returns the value of attribute currency_code.



55
56
57
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 55

def currency_code
  @currency_code
end

#currency_rate ⇒ Object

The currency rate for a multicurrency overpayment. If no rate is specified, the XE.com day rate is used



61
62
63
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 61

def currency_rate
  @currency_rate
end

#date ⇒ Object

The date the overpayment is created YYYY-MM-DD



28
29
30
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 28

def date
  @date
end

#has_attachments ⇒ Object

boolean to indicate if a overpayment has an attachment



76
77
78
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 76

def has_attachments
  @has_attachments
end

#line_amount_types ⇒ Object

Returns the value of attribute line_amount_types.



37
38
39
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 37

def line_amount_types
  @line_amount_types
end

#line_items ⇒ Object

See Overpayment Line Items



40
41
42
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 40

def line_items
  @line_items
end

#overpayment_id ⇒ Object

Xero generated unique identifier



58
59
60
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 58

def overpayment_id
  @overpayment_id
end

#payments ⇒ Object

See Payments



73
74
75
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 73

def payments
  @payments
end

#remaining_credit ⇒ Object

The remaining credit balance on the overpayment



64
65
66
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 64

def remaining_credit
  @remaining_credit
end

#status ⇒ Object

See Overpayment Status Codes



31
32
33
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 31

def status
  @status
end

#sub_total ⇒ Object

The subtotal of the overpayment excluding taxes



43
44
45
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 43

def sub_total
  @sub_total
end

#total ⇒ Object

The total of the overpayment (subtotal + total tax)



49
50
51
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 49

def total
  @total
end

#total_tax ⇒ Object

The total tax on the overpayment



46
47
48
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 46

def total_tax
  @total_tax
end

#type ⇒ Object

See Overpayment Types



19
20
21
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 19

def type
  @type
end

#updated_date_utc ⇒ Object

UTC timestamp of last update to the overpayment



52
53
54
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 52

def updated_date_utc
  @updated_date_utc
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 104

def self.attribute_map
  {
    :'type' => :'Type',
    :'contact' => :'Contact',
    :'date' => :'Date',
    :'status' => :'Status',
    :'line_amount_types' => :'LineAmountTypes',
    :'line_items' => :'LineItems',
    :'sub_total' => :'SubTotal',
    :'total_tax' => :'TotalTax',
    :'total' => :'Total',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'currency_code' => :'CurrencyCode',
    :'overpayment_id' => :'OverpaymentID',
    :'currency_rate' => :'CurrencyRate',
    :'remaining_credit' => :'RemainingCredit',
    :'allocations' => :'Allocations',
    :'applied_amount' => :'AppliedAmount',
    :'payments' => :'Payments',
    :'has_attachments' => :'HasAttachments',
    :'attachments' => :'Attachments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



333
334
335
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 333

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 129

def self.openapi_types
  {
    :'type' => :'String',
    :'contact' => :'Contact',
    :'date' => :'Date',
    :'status' => :'String',
    :'line_amount_types' => :'LineAmountTypes',
    :'line_items' => :'Array<LineItem>',
    :'sub_total' => :'Float',
    :'total_tax' => :'Float',
    :'total' => :'Float',
    :'updated_date_utc' => :'DateTime',
    :'currency_code' => :'CurrencyCode',
    :'overpayment_id' => :'String',
    :'currency_rate' => :'Float',
    :'remaining_credit' => :'Float',
    :'allocations' => :'Array<Allocation>',
    :'applied_amount' => :'Float',
    :'payments' => :'Array<Payment>',
    :'has_attachments' => :'Boolean',
    :'attachments' => :'Array<Attachment>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 294

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      contact == o.contact &&
      date == o.date &&
      status == o.status &&
      line_amount_types == o.line_amount_types &&
      line_items == o.line_items &&
      sub_total == o.sub_total &&
      total_tax == o.total_tax &&
      total == o.total &&
      updated_date_utc == o.updated_date_utc &&
      currency_code == o.currency_code &&
      overpayment_id == o.overpayment_id &&
      currency_rate == o.currency_rate &&
      remaining_credit == o.remaining_credit &&
      allocations == o.allocations &&
      applied_amount == o.applied_amount &&
      payments == o.payments &&
      has_attachments == o.has_attachments &&
      attachments == o.attachments
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 361

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 426

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 340

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


320
321
322
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 320

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



326
327
328
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 326

def hash
  [type, contact, date, status, line_amount_types, line_items, sub_total, total_tax, total, updated_date_utc, currency_code, overpayment_id, currency_rate, remaining_credit, allocations, applied_amount, payments, has_attachments, attachments].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



257
258
259
260
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 257

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



441
442
443
444
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 441

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



406
407
408
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 406

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



412
413
414
415
416
417
418
419
420
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 412

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



400
401
402
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 400

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



264
265
266
267
268
269
270
# File 'lib/xero-ruby/models/accounting/overpayment.rb', line 264

def valid?
  type_validator = EnumAttributeValidator.new('String', ["RECEIVE-OVERPAYMENT", "SPEND-OVERPAYMENT", "AROVERPAYMENT"])
  return false unless type_validator.valid?(@type)
  status_validator = EnumAttributeValidator.new('String', ["AUTHORISED", "PAID", "VOIDED"])
  return false unless status_validator.valid?(@status)
  true
end