Class: XeroRuby::Accounting::Payment

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/payment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Constant Summary collapse

AUTHORISED =
"AUTHORISED".freeze
DELETED =
"DELETED".freeze
ACCRECPAYMENT =
"ACCRECPAYMENT".freeze
ACCPAYPAYMENT =
"ACCPAYPAYMENT".freeze
ARCREDITPAYMENT =
"ARCREDITPAYMENT".freeze
APCREDITPAYMENT =
"APCREDITPAYMENT".freeze
AROVERPAYMENTPAYMENT =
"AROVERPAYMENTPAYMENT".freeze
ARPREPAYMENTPAYMENT =
"ARPREPAYMENTPAYMENT".freeze
APPREPAYMENTPAYMENT =
"APPREPAYMENTPAYMENT".freeze
APOVERPAYMENTPAYMENT =
"APOVERPAYMENTPAYMENT".freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Payment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/xero-ruby/models/accounting/payment.rb', line 184

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Payment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Payment`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'invoice')
    self.invoice = attributes[:'invoice']
  end

  if attributes.key?(:'credit_note')
    self.credit_note = attributes[:'credit_note']
  end

  if attributes.key?(:'prepayment')
    self.prepayment = attributes[:'prepayment']
  end

  if attributes.key?(:'overpayment')
    self.overpayment = attributes[:'overpayment']
  end

  if attributes.key?(:'invoice_number')
    self.invoice_number = attributes[:'invoice_number']
  end

  if attributes.key?(:'credit_note_number')
    self.credit_note_number = attributes[:'credit_note_number']
  end

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'currency_rate')
    self.currency_rate = attributes[:'currency_rate']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'is_reconciled')
    self.is_reconciled = attributes[:'is_reconciled']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'payment_type')
    self.payment_type = attributes[:'payment_type']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'payment_id')
    self.payment_id = attributes[:'payment_id']
  end

  if attributes.key?(:'bank_account_number')
    self. = attributes[:'bank_account_number']
  end

  if attributes.key?(:'particulars')
    self.particulars = attributes[:'particulars']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'has_account')
    self. = attributes[:'has_account']
  else
    self. = false
  end

  if attributes.key?(:'has_validation_errors')
    self.has_validation_errors = attributes[:'has_validation_errors']
  else
    self.has_validation_errors = false
  end

  if attributes.key?(:'status_attribute_string')
    self.status_attribute_string = attributes[:'status_attribute_string']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end
end

Instance Attribute Details

#account ⇒ Object

Returns the value of attribute account.



37
38
39
# File 'lib/xero-ruby/models/accounting/payment.rb', line 37

def 
  @account
end

#amount ⇒ Object

The amount of the payment. Must be less than or equal to the outstanding amount owing on the invoice e.g. 200.00



49
50
51
# File 'lib/xero-ruby/models/accounting/payment.rb', line 49

def amount
  @amount
end

#bank_account_number ⇒ Object

The suppliers bank account number the payment is being made to



80
81
82
# File 'lib/xero-ruby/models/accounting/payment.rb', line 80

def 
  @bank_account_number
end

#code ⇒ Object

Code of account you are using to make the payment e.g. 001 (note- not all accounts have a code value)



40
41
42
# File 'lib/xero-ruby/models/accounting/payment.rb', line 40

def code
  @code
end

#credit_note ⇒ Object

Returns the value of attribute credit_note.



22
23
24
# File 'lib/xero-ruby/models/accounting/payment.rb', line 22

def credit_note
  @credit_note
end

#credit_note_number ⇒ Object

Number of invoice or credit note you are applying payment to e.g. INV-4003



34
35
36
# File 'lib/xero-ruby/models/accounting/payment.rb', line 34

def credit_note_number
  @credit_note_number
end

#currency_rate ⇒ Object

Exchange rate when payment is received. Only used for non base currency invoices and credit notes e.g. 0.7500



46
47
48
# File 'lib/xero-ruby/models/accounting/payment.rb', line 46

def currency_rate
  @currency_rate
end

#date ⇒ Object

Date the payment is being made (YYYY-MM-DD) e.g. 2009-09-06



43
44
45
# File 'lib/xero-ruby/models/accounting/payment.rb', line 43

def date
  @date
end

#details ⇒ Object

The information to appear on the supplier's bank account



86
87
88
# File 'lib/xero-ruby/models/accounting/payment.rb', line 86

def details
  @details
end

#has_account ⇒ Object

A boolean to indicate if a contact has an validation errors



89
90
91
# File 'lib/xero-ruby/models/accounting/payment.rb', line 89

def 
  @has_account
end

#has_validation_errors ⇒ Object

A boolean to indicate if a contact has an validation errors



92
93
94
# File 'lib/xero-ruby/models/accounting/payment.rb', line 92

def has_validation_errors
  @has_validation_errors
end

#invoice ⇒ Object

Returns the value of attribute invoice.



19
20
21
# File 'lib/xero-ruby/models/accounting/payment.rb', line 19

def invoice
  @invoice
end

#invoice_number ⇒ Object

Number of invoice or credit note you are applying payment to e.g.INV-4003



31
32
33
# File 'lib/xero-ruby/models/accounting/payment.rb', line 31

def invoice_number
  @invoice_number
end

#is_reconciled ⇒ Object

An optional parameter for the payment. A boolean indicating whether you would like the payment to be created as reconciled when using PUT, or whether a payment has been reconciled when using GET



55
56
57
# File 'lib/xero-ruby/models/accounting/payment.rb', line 55

def is_reconciled
  @is_reconciled
end

#overpayment ⇒ Object

Returns the value of attribute overpayment.



28
29
30
# File 'lib/xero-ruby/models/accounting/payment.rb', line 28

def overpayment
  @overpayment
end

#particulars ⇒ Object

The suppliers bank account number the payment is being made to



83
84
85
# File 'lib/xero-ruby/models/accounting/payment.rb', line 83

def particulars
  @particulars
end

#payment_id ⇒ Object

The Xero identifier for an Payment e.g. 297c2dc5-cc47-4afd-8ec8-74990b8761e9



77
78
79
# File 'lib/xero-ruby/models/accounting/payment.rb', line 77

def payment_id
  @payment_id
end

#payment_type ⇒ Object

See Payment Types.



63
64
65
# File 'lib/xero-ruby/models/accounting/payment.rb', line 63

def payment_type
  @payment_type
end

#prepayment ⇒ Object

Returns the value of attribute prepayment.



25
26
27
# File 'lib/xero-ruby/models/accounting/payment.rb', line 25

def prepayment
  @prepayment
end

#reference ⇒ Object

An optional description for the payment e.g. Direct Debit



52
53
54
# File 'lib/xero-ruby/models/accounting/payment.rb', line 52

def reference
  @reference
end

#status ⇒ Object

The status of the payment.



58
59
60
# File 'lib/xero-ruby/models/accounting/payment.rb', line 58

def status
  @status
end

#status_attribute_string ⇒ Object

A string to indicate if a invoice status



95
96
97
# File 'lib/xero-ruby/models/accounting/payment.rb', line 95

def status_attribute_string
  @status_attribute_string
end

#updated_date_utc ⇒ Object

UTC timestamp of last update to the payment



74
75
76
# File 'lib/xero-ruby/models/accounting/payment.rb', line 74

def updated_date_utc
  @updated_date_utc
end

#validation_errors ⇒ Object

Displays array of validation error messages from the API



98
99
100
# File 'lib/xero-ruby/models/accounting/payment.rb', line 98

def validation_errors
  @validation_errors
end

Class Method Details

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/xero-ruby/models/accounting/payment.rb', line 123

def self.attribute_map
  {
    :'invoice' => :'Invoice',
    :'credit_note' => :'CreditNote',
    :'prepayment' => :'Prepayment',
    :'overpayment' => :'Overpayment',
    :'invoice_number' => :'InvoiceNumber',
    :'credit_note_number' => :'CreditNoteNumber',
    :'account' => :'Account',
    :'code' => :'Code',
    :'date' => :'Date',
    :'currency_rate' => :'CurrencyRate',
    :'amount' => :'Amount',
    :'reference' => :'Reference',
    :'is_reconciled' => :'IsReconciled',
    :'status' => :'Status',
    :'payment_type' => :'PaymentType',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'payment_id' => :'PaymentID',
    :'bank_account_number' => :'BankAccountNumber',
    :'particulars' => :'Particulars',
    :'details' => :'Details',
    :'has_account' => :'HasAccount',
    :'has_validation_errors' => :'HasValidationErrors',
    :'status_attribute_string' => :'StatusAttributeString',
    :'validation_errors' => :'ValidationErrors'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



383
384
385
# File 'lib/xero-ruby/models/accounting/payment.rb', line 383

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_types ⇒ Object

Attribute type mapping.



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/xero-ruby/models/accounting/payment.rb', line 153

def self.openapi_types
  {
    :'invoice' => :'Invoice',
    :'credit_note' => :'CreditNote',
    :'prepayment' => :'Prepayment',
    :'overpayment' => :'Overpayment',
    :'invoice_number' => :'String',
    :'credit_note_number' => :'String',
    :'account' => :'Account',
    :'code' => :'String',
    :'date' => :'Date',
    :'currency_rate' => :'Float',
    :'amount' => :'Float',
    :'reference' => :'String',
    :'is_reconciled' => :'Boolean',
    :'status' => :'String',
    :'payment_type' => :'String',
    :'updated_date_utc' => :'DateTime',
    :'payment_id' => :'String',
    :'bank_account_number' => :'String',
    :'particulars' => :'String',
    :'details' => :'String',
    :'has_account' => :'Boolean',
    :'has_validation_errors' => :'Boolean',
    :'status_attribute_string' => :'String',
    :'validation_errors' => :'Array<ValidationError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/xero-ruby/models/accounting/payment.rb', line 339

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      invoice == o.invoice &&
      credit_note == o.credit_note &&
      prepayment == o.prepayment &&
      overpayment == o.overpayment &&
      invoice_number == o.invoice_number &&
      credit_note_number == o.credit_note_number &&
       == o. &&
      code == o.code &&
      date == o.date &&
      currency_rate == o.currency_rate &&
      amount == o.amount &&
      reference == o.reference &&
      is_reconciled == o.is_reconciled &&
      status == o.status &&
      payment_type == o.payment_type &&
      updated_date_utc == o.updated_date_utc &&
      payment_id == o.payment_id &&
       == o. &&
      particulars == o.particulars &&
      details == o.details &&
       == o. &&
      has_validation_errors == o.has_validation_errors &&
      status_attribute_string == o.status_attribute_string &&
      validation_errors == o.validation_errors
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/xero-ruby/models/accounting/payment.rb', line 411

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/xero-ruby/models/accounting/payment.rb', line 476

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/xero-ruby/models/accounting/payment.rb', line 390

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


370
371
372
# File 'lib/xero-ruby/models/accounting/payment.rb', line 370

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



376
377
378
# File 'lib/xero-ruby/models/accounting/payment.rb', line 376

def hash
  [invoice, credit_note, prepayment, overpayment, invoice_number, credit_note_number, , code, date, currency_rate, amount, reference, is_reconciled, status, payment_type, updated_date_utc, payment_id, , particulars, details, , has_validation_errors, status_attribute_string, validation_errors].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



302
303
304
305
# File 'lib/xero-ruby/models/accounting/payment.rb', line 302

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object

customized data_parser



491
492
493
494
# File 'lib/xero-ruby/models/accounting/payment.rb', line 491

def parse_date(datestring)
  seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0
  return Time.at(seconds_since_epoch).to_s
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



456
457
458
# File 'lib/xero-ruby/models/accounting/payment.rb', line 456

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



462
463
464
465
466
467
468
469
470
# File 'lib/xero-ruby/models/accounting/payment.rb', line 462

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



450
451
452
# File 'lib/xero-ruby/models/accounting/payment.rb', line 450

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



309
310
311
312
313
314
315
# File 'lib/xero-ruby/models/accounting/payment.rb', line 309

def valid?
  status_validator = EnumAttributeValidator.new('String', ["AUTHORISED", "DELETED"])
  return false unless status_validator.valid?(@status)
  payment_type_validator = EnumAttributeValidator.new('String', ["ACCRECPAYMENT", "ACCPAYPAYMENT", "ARCREDITPAYMENT", "APCREDITPAYMENT", "AROVERPAYMENTPAYMENT", "ARPREPAYMENTPAYMENT", "APPREPAYMENTPAYMENT", "APOVERPAYMENTPAYMENT"])
  return false unless payment_type_validator.valid?(@payment_type)
  true
end