Class: XeroRuby::Accounting::Prepayment

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/models/accounting/prepayment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Prepayment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 172

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Prepayment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Prepayment`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'contact')
    self.contact = attributes[:'contact']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'line_amount_types')
    self.line_amount_types = attributes[:'line_amount_types']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'sub_total')
    self.sub_total = attributes[:'sub_total']
  end

  if attributes.key?(:'total_tax')
    self.total_tax = attributes[:'total_tax']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'invoice_number')
    self.invoice_number = attributes[:'invoice_number']
  end

  if attributes.key?(:'updated_date_utc')
    self.updated_date_utc = attributes[:'updated_date_utc']
  end

  if attributes.key?(:'currency_code')
    self.currency_code = attributes[:'currency_code']
  end

  if attributes.key?(:'prepayment_id')
    self.prepayment_id = attributes[:'prepayment_id']
  end

  if attributes.key?(:'branding_theme_id')
    self.branding_theme_id = attributes[:'branding_theme_id']
  end

  if attributes.key?(:'currency_rate')
    self.currency_rate = attributes[:'currency_rate']
  end

  if attributes.key?(:'remaining_credit')
    self.remaining_credit = attributes[:'remaining_credit']
  end

  if attributes.key?(:'allocations')
    if (value = attributes[:'allocations']).is_a?(Array)
      self.allocations = value
    end
  end

  if attributes.key?(:'payments')
    if (value = attributes[:'payments']).is_a?(Array)
      self.payments = value
    end
  end

  if attributes.key?(:'applied_amount')
    self.applied_amount = attributes[:'applied_amount']
  end

  if attributes.key?(:'has_attachments')
    self.has_attachments = attributes[:'has_attachments']
  else
    self.has_attachments = false
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end
end

Instance Attribute Details

#allocationsObject

See Allocations



78
79
80
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 78

def allocations
  @allocations
end

#applied_amountObject

The amount of applied to an invoice



84
85
86
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 84

def applied_amount
  @applied_amount
end

#attachmentsObject

See Attachments



90
91
92
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 90

def attachments
  @attachments
end

#branding_theme_idObject

The unique identifier of the branding template applied to a receive prepayment



69
70
71
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 69

def branding_theme_id
  @branding_theme_id
end

#contactObject

Returns the value of attribute contact.



27
28
29
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 27

def contact
  @contact
end

#currency_codeObject

Returns the value of attribute currency_code.



63
64
65
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 63

def currency_code
  @currency_code
end

#currency_rateObject

The currency rate for a multicurrency prepayment. If no rate is specified, the XE.com day rate is used



72
73
74
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 72

def currency_rate
  @currency_rate
end

#dateObject

The date the prepayment is created YYYY-MM-DD



30
31
32
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 30

def date
  @date
end

#has_attachmentsObject

boolean to indicate if a prepayment has an attachment



87
88
89
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 87

def has_attachments
  @has_attachments
end

#invoice_numberObject

Returns Invoice number for prepayment receive document only.



57
58
59
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 57

def invoice_number
  @invoice_number
end

#line_amount_typesObject

Returns the value of attribute line_amount_types.



39
40
41
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 39

def line_amount_types
  @line_amount_types
end

#line_itemsObject

See Prepayment Line Items



42
43
44
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 42

def line_items
  @line_items
end

#paymentsObject

See Payments



81
82
83
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 81

def payments
  @payments
end

#prepayment_idObject

Xero generated unique identifier



66
67
68
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 66

def prepayment_id
  @prepayment_id
end

#referenceObject

Returns Invoice number field. Reference field isn’t available.



54
55
56
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 54

def reference
  @reference
end

#remaining_creditObject

The remaining credit balance on the prepayment



75
76
77
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 75

def remaining_credit
  @remaining_credit
end

#statusObject

See Prepayment Status Codes



33
34
35
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 33

def status
  @status
end

#sub_totalObject

The subtotal of the prepayment excluding taxes



45
46
47
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 45

def sub_total
  @sub_total
end

#totalObject

The total of the prepayment(subtotal + total tax)



51
52
53
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 51

def total
  @total
end

#total_taxObject

The total tax on the prepayment



48
49
50
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 48

def total_tax
  @total_tax
end

#typeObject

See Prepayment Types



20
21
22
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 20

def type
  @type
end

#updated_date_utcObject

UTC timestamp of last update to the prepayment



60
61
62
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 60

def updated_date_utc
  @updated_date_utc
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 115

def self.attribute_map
  {
    :'type' => :'Type',
    :'contact' => :'Contact',
    :'date' => :'Date',
    :'status' => :'Status',
    :'line_amount_types' => :'LineAmountTypes',
    :'line_items' => :'LineItems',
    :'sub_total' => :'SubTotal',
    :'total_tax' => :'TotalTax',
    :'total' => :'Total',
    :'reference' => :'Reference',
    :'invoice_number' => :'InvoiceNumber',
    :'updated_date_utc' => :'UpdatedDateUTC',
    :'currency_code' => :'CurrencyCode',
    :'prepayment_id' => :'PrepaymentID',
    :'branding_theme_id' => :'BrandingThemeID',
    :'currency_rate' => :'CurrencyRate',
    :'remaining_credit' => :'RemainingCredit',
    :'allocations' => :'Allocations',
    :'payments' => :'Payments',
    :'applied_amount' => :'AppliedAmount',
    :'has_attachments' => :'HasAttachments',
    :'attachments' => :'Attachments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



365
366
367
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 365

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_typesObject

Attribute type mapping.



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 143

def self.openapi_types
  {
    :'type' => :'String',
    :'contact' => :'Contact',
    :'date' => :'Date',
    :'status' => :'String',
    :'line_amount_types' => :'LineAmountTypes',
    :'line_items' => :'Array<LineItem>',
    :'sub_total' => :'BigDecimal',
    :'total_tax' => :'BigDecimal',
    :'total' => :'BigDecimal',
    :'reference' => :'String',
    :'invoice_number' => :'String',
    :'updated_date_utc' => :'DateTime',
    :'currency_code' => :'CurrencyCode',
    :'prepayment_id' => :'String',
    :'branding_theme_id' => :'String',
    :'currency_rate' => :'BigDecimal',
    :'remaining_credit' => :'BigDecimal',
    :'allocations' => :'Array<Allocation>',
    :'payments' => :'Array<Payment>',
    :'applied_amount' => :'Float',
    :'has_attachments' => :'Boolean',
    :'attachments' => :'Array<Attachment>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 323

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      contact == o.contact &&
      date == o.date &&
      status == o.status &&
      line_amount_types == o.line_amount_types &&
      line_items == o.line_items &&
      sub_total == o.sub_total &&
      total_tax == o.total_tax &&
      total == o.total &&
      reference == o.reference &&
      invoice_number == o.invoice_number &&
      updated_date_utc == o.updated_date_utc &&
      currency_code == o.currency_code &&
      prepayment_id == o.prepayment_id &&
      branding_theme_id == o.branding_theme_id &&
      currency_rate == o.currency_rate &&
      remaining_credit == o.remaining_credit &&
      allocations == o.allocations &&
      payments == o.payments &&
      applied_amount == o.applied_amount &&
      has_attachments == o.has_attachments &&
      attachments == o.attachments
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 393

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(parse_date(value))
  when :Date
    Date.parse(parse_date(value))
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BigDecimal
    BigDecimal(value.to_s)
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    XeroRuby::Accounting.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value, downcase: false) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 466

def _to_hash(value, downcase: false)
  if value.is_a?(Array)
    value.map do |v|
      v.to_hash(downcase: downcase)
    end
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.map { |k, v| hash[k] = _to_hash(v, downcase: downcase) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash(downcase: downcase)
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 372

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


352
353
354
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 352

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



358
359
360
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 358

def hash
  [type, contact, date, status, line_amount_types, line_items, sub_total, total_tax, total, reference, invoice_number, updated_date_utc, currency_code, prepayment_id, branding_theme_id, currency_rate, remaining_credit, allocations, payments, applied_amount, has_attachments, attachments].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



286
287
288
289
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 286

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#parse_date(datestring) ⇒ Object



482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 482

def parse_date(datestring)
  if datestring.include?('Date')
    date_pattern = /\/Date\((-?\d+)(\+\d+)?\)\//
    original, date, timezone = *date_pattern.match(datestring)
    date = (date.to_i / 1000)
    Time.at(date).utc.strftime('%Y-%m-%dT%H:%M:%S%z').to_s
  elsif /(\d\d\d\d)-(\d\d)/.match(datestring) # handles dates w/out Days: YYYY-MM*-DD
    Time.parse(datestring + '-01').strftime('%Y-%m-%dT%H:%M:%S').to_s
  else # handle date 'types' for small subset of payroll API's
    Time.parse(datestring).strftime('%Y-%m-%dT%H:%M:%S').to_s
  end
end

#to_attributesObject

Returns the object in the form of hash with snake_case



458
459
460
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 458

def to_attributes
  to_hash(downcase: true)
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



440
441
442
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 440

def to_body
  to_hash
end

#to_hash(downcase: false) ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



446
447
448
449
450
451
452
453
454
455
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 446

def to_hash(downcase: false)
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    key = downcase ? attr : param
    hash[key] = _to_hash(value, downcase: downcase)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



434
435
436
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 434

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



293
294
295
296
297
298
299
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 293

def valid?
  type_validator = EnumAttributeValidator.new('String', ["RECEIVE-PREPAYMENT", "SPEND-PREPAYMENT", "ARPREPAYMENT", "APPREPAYMENT"])
  return false unless type_validator.valid?(@type)
  status_validator = EnumAttributeValidator.new('String', ["AUTHORISED", "PAID", "VOIDED"])
  return false unless status_validator.valid?(@status)
  true
end