Class: XeroRuby::Accounting::Prepayment
- Inherits:
-
Object
- Object
- XeroRuby::Accounting::Prepayment
- Defined in:
- lib/xero-ruby/models/accounting/prepayment.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Constant Summary collapse
- RECEIVE_PREPAYMENT =
"RECEIVE-PREPAYMENT".freeze
- SPEND_PREPAYMENT =
"SPEND-PREPAYMENT".freeze
- ARPREPAYMENT =
"ARPREPAYMENT".freeze
- APPREPAYMENT =
"APPREPAYMENT".freeze
- AUTHORISED =
"AUTHORISED".freeze
- PAID =
"PAID".freeze
- VOIDED =
"VOIDED".freeze
Instance Attribute Summary collapse
-
#allocations ⇒ Object
See Allocations.
-
#applied_amount ⇒ Object
The amount of applied to an invoice.
-
#attachments ⇒ Object
See Attachments.
-
#contact ⇒ Object
Returns the value of attribute contact.
-
#currency_code ⇒ Object
Returns the value of attribute currency_code.
-
#currency_rate ⇒ Object
The currency rate for a multicurrency prepayment.
-
#date ⇒ Object
The date the prepayment is created YYYY-MM-DD.
-
#has_attachments ⇒ Object
boolean to indicate if a prepayment has an attachment.
-
#line_amount_types ⇒ Object
Returns the value of attribute line_amount_types.
-
#line_items ⇒ Object
See Prepayment Line Items.
-
#prepayment_id ⇒ Object
Xero generated unique identifier.
-
#reference ⇒ Object
Returns Invoice number field.
-
#remaining_credit ⇒ Object
The remaining credit balance on the prepayment.
-
#status ⇒ Object
See Prepayment Status Codes.
-
#sub_total ⇒ Object
The subtotal of the prepayment excluding taxes.
-
#total ⇒ Object
The total of the prepayment(subtotal + total tax).
-
#total_tax ⇒ Object
The total tax on the prepayment.
-
#type ⇒ Object
See Prepayment Types.
-
#updated_date_utc ⇒ Object
UTC timestamp of last update to the prepayment.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Prepayment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Prepayment
Initializes the object
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 156 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::Prepayment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::Prepayment`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'contact') self.contact = attributes[:'contact'] end if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'line_amount_types') self.line_amount_types = attributes[:'line_amount_types'] end if attributes.key?(:'line_items') if (value = attributes[:'line_items']).is_a?(Array) self.line_items = value end end if attributes.key?(:'sub_total') self.sub_total = attributes[:'sub_total'] end if attributes.key?(:'total_tax') self.total_tax = attributes[:'total_tax'] end if attributes.key?(:'total') self.total = attributes[:'total'] end if attributes.key?(:'reference') self.reference = attributes[:'reference'] end if attributes.key?(:'updated_date_utc') self.updated_date_utc = attributes[:'updated_date_utc'] end if attributes.key?(:'currency_code') self.currency_code = attributes[:'currency_code'] end if attributes.key?(:'prepayment_id') self.prepayment_id = attributes[:'prepayment_id'] end if attributes.key?(:'currency_rate') self.currency_rate = attributes[:'currency_rate'] end if attributes.key?(:'remaining_credit') self.remaining_credit = attributes[:'remaining_credit'] end if attributes.key?(:'allocations') if (value = attributes[:'allocations']).is_a?(Array) self.allocations = value end end if attributes.key?(:'applied_amount') self.applied_amount = attributes[:'applied_amount'] end if attributes.key?(:'has_attachments') self. = attributes[:'has_attachments'] else self. = false end if attributes.key?(:'attachments') if (value = attributes[:'attachments']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#allocations ⇒ Object
See Allocations
71 72 73 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 71 def allocations @allocations end |
#applied_amount ⇒ Object
The amount of applied to an invoice
74 75 76 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 74 def applied_amount @applied_amount end |
#attachments ⇒ Object
See Attachments
80 81 82 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 80 def end |
#contact ⇒ Object
Returns the value of attribute contact.
26 27 28 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 26 def contact @contact end |
#currency_code ⇒ Object
Returns the value of attribute currency_code.
59 60 61 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 59 def currency_code @currency_code end |
#currency_rate ⇒ Object
The currency rate for a multicurrency prepayment. If no rate is specified, the XE.com day rate is used
65 66 67 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 65 def currency_rate @currency_rate end |
#date ⇒ Object
The date the prepayment is created YYYY-MM-DD
29 30 31 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 29 def date @date end |
#has_attachments ⇒ Object
boolean to indicate if a prepayment has an attachment
77 78 79 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 77 def end |
#line_amount_types ⇒ Object
Returns the value of attribute line_amount_types.
38 39 40 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 38 def line_amount_types @line_amount_types end |
#line_items ⇒ Object
See Prepayment Line Items
41 42 43 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 41 def line_items @line_items end |
#prepayment_id ⇒ Object
Xero generated unique identifier
62 63 64 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 62 def prepayment_id @prepayment_id end |
#reference ⇒ Object
Returns Invoice number field. Reference field isn't available.
53 54 55 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 53 def reference @reference end |
#remaining_credit ⇒ Object
The remaining credit balance on the prepayment
68 69 70 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 68 def remaining_credit @remaining_credit end |
#status ⇒ Object
See Prepayment Status Codes
32 33 34 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 32 def status @status end |
#sub_total ⇒ Object
The subtotal of the prepayment excluding taxes
44 45 46 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 44 def sub_total @sub_total end |
#total ⇒ Object
The total of the prepayment(subtotal + total tax)
50 51 52 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 50 def total @total end |
#total_tax ⇒ Object
The total tax on the prepayment
47 48 49 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 47 def total_tax @total_tax end |
#type ⇒ Object
See Prepayment Types
19 20 21 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 19 def type @type end |
#updated_date_utc ⇒ Object
UTC timestamp of last update to the prepayment
56 57 58 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 56 def updated_date_utc @updated_date_utc end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 105 def self.attribute_map { :'type' => :'Type', :'contact' => :'Contact', :'date' => :'Date', :'status' => :'Status', :'line_amount_types' => :'LineAmountTypes', :'line_items' => :'LineItems', :'sub_total' => :'SubTotal', :'total_tax' => :'TotalTax', :'total' => :'Total', :'reference' => :'Reference', :'updated_date_utc' => :'UpdatedDateUTC', :'currency_code' => :'CurrencyCode', :'prepayment_id' => :'PrepaymentID', :'currency_rate' => :'CurrencyRate', :'remaining_credit' => :'RemainingCredit', :'allocations' => :'Allocations', :'applied_amount' => :'AppliedAmount', :'has_attachments' => :'HasAttachments', :'attachments' => :'Attachments' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
332 333 334 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 332 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 130 def self.openapi_types { :'type' => :'String', :'contact' => :'Contact', :'date' => :'Date', :'status' => :'String', :'line_amount_types' => :'LineAmountTypes', :'line_items' => :'Array<LineItem>', :'sub_total' => :'Float', :'total_tax' => :'Float', :'total' => :'Float', :'reference' => :'String', :'updated_date_utc' => :'DateTime', :'currency_code' => :'CurrencyCode', :'prepayment_id' => :'String', :'currency_rate' => :'Float', :'remaining_credit' => :'Float', :'allocations' => :'Array<Allocation>', :'applied_amount' => :'Float', :'has_attachments' => :'Boolean', :'attachments' => :'Array<Attachment>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 293 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && contact == o.contact && date == o.date && status == o.status && line_amount_types == o.line_amount_types && line_items == o.line_items && sub_total == o.sub_total && total_tax == o.total_tax && total == o.total && reference == o.reference && updated_date_utc == o.updated_date_utc && currency_code == o.currency_code && prepayment_id == o.prepayment_id && currency_rate == o.currency_rate && remaining_credit == o.remaining_credit && allocations == o.allocations && applied_amount == o.applied_amount && == o. && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 360 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::Accounting.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 425 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 339 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
319 320 321 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 319 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
325 326 327 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 325 def hash [type, contact, date, status, line_amount_types, line_items, sub_total, total_tax, total, reference, updated_date_utc, currency_code, prepayment_id, currency_rate, remaining_credit, allocations, applied_amount, , ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
256 257 258 259 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 256 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
440 441 442 443 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 440 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
405 406 407 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 405 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
411 412 413 414 415 416 417 418 419 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 411 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
399 400 401 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 399 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
263 264 265 266 267 268 269 |
# File 'lib/xero-ruby/models/accounting/prepayment.rb', line 263 def valid? type_validator = EnumAttributeValidator.new('String', ["RECEIVE-PREPAYMENT", "SPEND-PREPAYMENT", "ARPREPAYMENT", "APPREPAYMENT"]) return false unless type_validator.valid?(@type) status_validator = EnumAttributeValidator.new('String', ["AUTHORISED", "PAID", "VOIDED"]) return false unless status_validator.valid?(@status) true end |