Class: XeroRuby::Accounting::PurchaseOrder
- Inherits:
-
Object
- Object
- XeroRuby::Accounting::PurchaseOrder
- Defined in:
- lib/xero-ruby/models/accounting/purchase_order.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Constant Summary collapse
- DRAFT =
"DRAFT".freeze
- SUBMITTED =
"SUBMITTED".freeze
- AUTHORISED =
"AUTHORISED".freeze
- BILLED =
"BILLED".freeze
- DELETED =
"DELETED".freeze
Instance Attribute Summary collapse
-
#attachments ⇒ Object
Displays array of attachments from the API.
-
#attention_to ⇒ Object
The person that the delivery is going to.
-
#branding_theme_id ⇒ Object
See BrandingThemes.
-
#contact ⇒ Object
Returns the value of attribute contact.
-
#currency_code ⇒ Object
Returns the value of attribute currency_code.
-
#currency_rate ⇒ Object
The currency rate for a multicurrency purchase order.
-
#date ⇒ Object
Date purchase order was issued – YYYY-MM-DD.
-
#delivery_address ⇒ Object
The address the goods are to be delivered to.
-
#delivery_date ⇒ Object
Date the goods are to be delivered – YYYY-MM-DD.
-
#delivery_instructions ⇒ Object
A free text feild for instructions (500 characters max).
-
#expected_arrival_date ⇒ Object
The date the goods are expected to arrive.
-
#has_attachments ⇒ Object
boolean to indicate if a purchase order has an attachment.
-
#line_amount_types ⇒ Object
Returns the value of attribute line_amount_types.
-
#line_items ⇒ Object
See LineItems.
-
#purchase_order_id ⇒ Object
Xero generated unique identifier for purchase order.
-
#purchase_order_number ⇒ Object
Unique alpha numeric code identifying purchase order (when missing will auto-generate from your Organisation Invoice Settings).
-
#reference ⇒ Object
Additional reference number.
-
#sent_to_contact ⇒ Object
Boolean to set whether the purchase order should be marked as “sent”.
-
#status ⇒ Object
See Purchase Order Status Codes.
-
#status_attribute_string ⇒ Object
A string to indicate if a invoice status.
-
#sub_total ⇒ Object
Total of purchase order excluding taxes.
-
#telephone ⇒ Object
The phone number for the person accepting the delivery.
-
#total ⇒ Object
Total of Purchase Order tax inclusive (i.e. SubTotal + TotalTax).
-
#total_discount ⇒ Object
Total of discounts applied on the purchase order line items.
-
#total_tax ⇒ Object
Total tax on purchase order.
-
#updated_date_utc ⇒ Object
Last modified date UTC format.
-
#validation_errors ⇒ Object
Displays array of validation error messages from the API.
-
#warnings ⇒ Object
Displays array of warning messages from the API.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PurchaseOrder
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PurchaseOrder
Initializes the object
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 199 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::Accounting::PurchaseOrder` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::Accounting::PurchaseOrder`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'contact') self.contact = attributes[:'contact'] end if attributes.key?(:'line_items') if (value = attributes[:'line_items']).is_a?(Array) self.line_items = value end end if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'delivery_date') self.delivery_date = attributes[:'delivery_date'] end if attributes.key?(:'line_amount_types') self.line_amount_types = attributes[:'line_amount_types'] end if attributes.key?(:'purchase_order_number') self.purchase_order_number = attributes[:'purchase_order_number'] end if attributes.key?(:'reference') self.reference = attributes[:'reference'] end if attributes.key?(:'branding_theme_id') self.branding_theme_id = attributes[:'branding_theme_id'] end if attributes.key?(:'currency_code') self.currency_code = attributes[:'currency_code'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'sent_to_contact') self.sent_to_contact = attributes[:'sent_to_contact'] end if attributes.key?(:'delivery_address') self.delivery_address = attributes[:'delivery_address'] end if attributes.key?(:'attention_to') self.attention_to = attributes[:'attention_to'] end if attributes.key?(:'telephone') self.telephone = attributes[:'telephone'] end if attributes.key?(:'delivery_instructions') self.delivery_instructions = attributes[:'delivery_instructions'] end if attributes.key?(:'expected_arrival_date') self.expected_arrival_date = attributes[:'expected_arrival_date'] end if attributes.key?(:'purchase_order_id') self.purchase_order_id = attributes[:'purchase_order_id'] end if attributes.key?(:'currency_rate') self.currency_rate = attributes[:'currency_rate'] end if attributes.key?(:'sub_total') self.sub_total = attributes[:'sub_total'] end if attributes.key?(:'total_tax') self.total_tax = attributes[:'total_tax'] end if attributes.key?(:'total') self.total = attributes[:'total'] end if attributes.key?(:'total_discount') self.total_discount = attributes[:'total_discount'] end if attributes.key?(:'has_attachments') self. = attributes[:'has_attachments'] else self. = false end if attributes.key?(:'updated_date_utc') self.updated_date_utc = attributes[:'updated_date_utc'] end if attributes.key?(:'status_attribute_string') self.status_attribute_string = attributes[:'status_attribute_string'] end if attributes.key?(:'validation_errors') if (value = attributes[:'validation_errors']).is_a?(Array) self.validation_errors = value end end if attributes.key?(:'warnings') if (value = attributes[:'warnings']).is_a?(Array) self.warnings = value end end if attributes.key?(:'attachments') if (value = attributes[:'attachments']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#attachments ⇒ Object
Displays array of attachments from the API
105 106 107 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 105 def @attachments end |
#attention_to ⇒ Object
The person that the delivery is going to
60 61 62 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 60 def attention_to @attention_to end |
#branding_theme_id ⇒ Object
See BrandingThemes
40 41 42 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 40 def branding_theme_id @branding_theme_id end |
#contact ⇒ Object
Returns the value of attribute contact.
19 20 21 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 19 def contact @contact end |
#currency_code ⇒ Object
Returns the value of attribute currency_code.
43 44 45 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 43 def currency_code @currency_code end |
#currency_rate ⇒ Object
The currency rate for a multicurrency purchase order. If no rate is specified, the XE.com day rate is used.
75 76 77 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 75 def currency_rate @currency_rate end |
#date ⇒ Object
Date purchase order was issued – YYYY-MM-DD. If the Date element is not specified then it will default to the current date based on the timezone setting of the organisation
25 26 27 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 25 def date @date end |
#delivery_address ⇒ Object
The address the goods are to be delivered to
57 58 59 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 57 def delivery_address @delivery_address end |
#delivery_date ⇒ Object
Date the goods are to be delivered – YYYY-MM-DD
28 29 30 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 28 def delivery_date @delivery_date end |
#delivery_instructions ⇒ Object
A free text feild for instructions (500 characters max)
66 67 68 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 66 def delivery_instructions @delivery_instructions end |
#expected_arrival_date ⇒ Object
The date the goods are expected to arrive.
69 70 71 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 69 def expected_arrival_date @expected_arrival_date end |
#has_attachments ⇒ Object
boolean to indicate if a purchase order has an attachment
90 91 92 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 90 def @has_attachments end |
#line_amount_types ⇒ Object
Returns the value of attribute line_amount_types.
31 32 33 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 31 def line_amount_types @line_amount_types end |
#line_items ⇒ Object
See LineItems
22 23 24 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 22 def line_items @line_items end |
#purchase_order_id ⇒ Object
Xero generated unique identifier for purchase order
72 73 74 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 72 def purchase_order_id @purchase_order_id end |
#purchase_order_number ⇒ Object
Unique alpha numeric code identifying purchase order (when missing will auto-generate from your Organisation Invoice Settings)
34 35 36 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 34 def purchase_order_number @purchase_order_number end |
#reference ⇒ Object
Additional reference number
37 38 39 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 37 def reference @reference end |
#sent_to_contact ⇒ Object
Boolean to set whether the purchase order should be marked as “sent”. This can be set only on purchase orders that have been approved or billed
54 55 56 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 54 def sent_to_contact @sent_to_contact end |
#status ⇒ Object
See Purchase Order Status Codes
46 47 48 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 46 def status @status end |
#status_attribute_string ⇒ Object
A string to indicate if a invoice status
96 97 98 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 96 def status_attribute_string @status_attribute_string end |
#sub_total ⇒ Object
Total of purchase order excluding taxes
78 79 80 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 78 def sub_total @sub_total end |
#telephone ⇒ Object
The phone number for the person accepting the delivery
63 64 65 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 63 def telephone @telephone end |
#total ⇒ Object
Total of Purchase Order tax inclusive (i.e. SubTotal + TotalTax)
84 85 86 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 84 def total @total end |
#total_discount ⇒ Object
Total of discounts applied on the purchase order line items
87 88 89 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 87 def total_discount @total_discount end |
#total_tax ⇒ Object
Total tax on purchase order
81 82 83 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 81 def total_tax @total_tax end |
#updated_date_utc ⇒ Object
Last modified date UTC format
93 94 95 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 93 def updated_date_utc @updated_date_utc end |
#validation_errors ⇒ Object
Displays array of validation error messages from the API
99 100 101 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 99 def validation_errors @validation_errors end |
#warnings ⇒ Object
Displays array of warning messages from the API
102 103 104 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 102 def warnings @warnings end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 130 def self.attribute_map { :'contact' => :'Contact', :'line_items' => :'LineItems', :'date' => :'Date', :'delivery_date' => :'DeliveryDate', :'line_amount_types' => :'LineAmountTypes', :'purchase_order_number' => :'PurchaseOrderNumber', :'reference' => :'Reference', :'branding_theme_id' => :'BrandingThemeID', :'currency_code' => :'CurrencyCode', :'status' => :'Status', :'sent_to_contact' => :'SentToContact', :'delivery_address' => :'DeliveryAddress', :'attention_to' => :'AttentionTo', :'telephone' => :'Telephone', :'delivery_instructions' => :'DeliveryInstructions', :'expected_arrival_date' => :'ExpectedArrivalDate', :'purchase_order_id' => :'PurchaseOrderID', :'currency_rate' => :'CurrencyRate', :'sub_total' => :'SubTotal', :'total_tax' => :'TotalTax', :'total' => :'Total', :'total_discount' => :'TotalDiscount', :'has_attachments' => :'HasAttachments', :'updated_date_utc' => :'UpdatedDateUTC', :'status_attribute_string' => :'StatusAttributeString', :'validation_errors' => :'ValidationErrors', :'warnings' => :'Warnings', :'attachments' => :'Attachments' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
410 411 412 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 410 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 164 def self.openapi_types { :'contact' => :'Contact', :'line_items' => :'Array<LineItem>', :'date' => :'Date', :'delivery_date' => :'Date', :'line_amount_types' => :'LineAmountTypes', :'purchase_order_number' => :'String', :'reference' => :'String', :'branding_theme_id' => :'String', :'currency_code' => :'CurrencyCode', :'status' => :'String', :'sent_to_contact' => :'Boolean', :'delivery_address' => :'String', :'attention_to' => :'String', :'telephone' => :'String', :'delivery_instructions' => :'String', :'expected_arrival_date' => :'Date', :'purchase_order_id' => :'String', :'currency_rate' => :'Float', :'sub_total' => :'Float', :'total_tax' => :'Float', :'total' => :'Float', :'total_discount' => :'Float', :'has_attachments' => :'Boolean', :'updated_date_utc' => :'DateTime', :'status_attribute_string' => :'String', :'validation_errors' => :'Array<ValidationError>', :'warnings' => :'Array<ValidationError>', :'attachments' => :'Array<Attachment>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 362 def ==(o) return true if self.equal?(o) self.class == o.class && contact == o.contact && line_items == o.line_items && date == o.date && delivery_date == o.delivery_date && line_amount_types == o.line_amount_types && purchase_order_number == o.purchase_order_number && reference == o.reference && branding_theme_id == o.branding_theme_id && currency_code == o.currency_code && status == o.status && sent_to_contact == o.sent_to_contact && delivery_address == o.delivery_address && attention_to == o.attention_to && telephone == o.telephone && delivery_instructions == o.delivery_instructions && expected_arrival_date == o.expected_arrival_date && purchase_order_id == o.purchase_order_id && currency_rate == o.currency_rate && sub_total == o.sub_total && total_tax == o.total_tax && total == o.total && total_discount == o.total_discount && == o. && updated_date_utc == o.updated_date_utc && status_attribute_string == o.status_attribute_string && validation_errors == o.validation_errors && warnings == o.warnings && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 438 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::Accounting.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
503 504 505 506 507 508 509 510 511 512 513 514 515 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 503 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 417 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
397 398 399 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 397 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
403 404 405 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 403 def hash [contact, line_items, date, delivery_date, line_amount_types, purchase_order_number, reference, branding_theme_id, currency_code, status, sent_to_contact, delivery_address, attention_to, telephone, delivery_instructions, expected_arrival_date, purchase_order_id, currency_rate, sub_total, total_tax, total, total_discount, , updated_date_utc, status_attribute_string, validation_errors, warnings, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
337 338 339 340 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 337 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
518 519 520 521 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 518 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
483 484 485 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 483 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
489 490 491 492 493 494 495 496 497 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 489 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
477 478 479 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 477 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
344 345 346 347 348 |
# File 'lib/xero-ruby/models/accounting/purchase_order.rb', line 344 def valid? status_validator = EnumAttributeValidator.new('String', ["DRAFT", "SUBMITTED", "AUTHORISED", "BILLED", "DELETED"]) return false unless status_validator.valid?(@status) true end |