Class: XeroRuby::ApiClient

Inherits:
Object
  • Object
show all
Includes:
StringSerialization
Defined in:
lib/xero-ruby/api_client.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from StringSerialization

#camelize, #camelize_key, #capitalize_first, #gsubbed, #to_camel_keys

Constructor Details

#initialize(config: Configuration.default, credentials: {}) ⇒ ApiClient

Initializes the ApiClient

Parameters:

  • config (Hash) (defaults to: Configuration.default)

    a customizable set of options

Options Hash (config:):

  • Configuration (Configuration)

    for initializing the object, default to Configuration.default



33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/xero-ruby/api_client.rb', line 33

def initialize(config: Configuration.default, credentials: {})
  @client_id = credentials[:client_id]
  @client_secret = credentials[:client_secret]
  @redirect_uri = credentials[:redirect_uri]
  @scopes = credentials[:scopes]
  @state = credentials[:state]
  @config = config
  @user_agent = "xero-ruby-#{VERSION}"
  @default_headers = {
    'Content-Type' => 'application/json',
    'User-Agent' => @user_agent
  }
end

Instance Attribute Details

#configObject

The Configuration object holding settings to be used in the API client.



24
25
26
# File 'lib/xero-ruby/api_client.rb', line 24

def config
  @config
end

#default_headersHash

Defines the headers to be used in HTTP requests of all API calls by default.

Returns:

  • (Hash)


29
30
31
# File 'lib/xero-ruby/api_client.rb', line 29

def default_headers
  @default_headers
end

Instance Method Details

#access_tokenObject



93
94
95
# File 'lib/xero-ruby/api_client.rb', line 93

def access_token
  XeroRuby.configure.access_token
end

#accounting_apiObject



53
54
55
56
# File 'lib/xero-ruby/api_client.rb', line 53

def accounting_api
  @config.base_url = @config.accounting_url
  XeroRuby::AccountingApi.new(self)
end

#asset_apiObject



58
59
60
61
# File 'lib/xero-ruby/api_client.rb', line 58

def asset_api
  @config.base_url = @config.asset_url
  XeroRuby::AssetApi.new(self)
end

#authorization_urlObject



47
48
49
50
51
# File 'lib/xero-ruby/api_client.rb', line 47

def authorization_url
  url = "#{@config.}?response_type=code&client_id=#{@client_id}&redirect_uri=#{@redirect_uri}&scope=#{@scopes}"
  url << "&state=#{@state}" if @state
  return url
end

#build_collection_param(param, collection_format) ⇒ Object

Build parameter value according to the given collection format.

Parameters:

  • collection_format (String)

    one of :csv, :ssv, :tsv, :pipes and :multi



517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
# File 'lib/xero-ruby/api_client.rb', line 517

def build_collection_param(param, collection_format)
  case collection_format
  when :csv
    param.join(',')
  when :ssv
    param.join(' ')
  when :tsv
    param.join("\t")
  when :pipes
    param.join('|')
  when :multi
    # return the array directly as http client will handle it as expected
    param
  else
    fail "unknown collection format: #{collection_format.inspect}"
  end
end

#build_request(http_method, path, request, opts = {}) ⇒ Object

Builds the HTTP request

Parameters:

  • http_method (String)

    HTTP method/verb (e.g. POST)

  • path (String)

    URL path (e.g. /account/new)

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :header_params (Hash)

    Header parameters

  • :query_params (Hash)

    Query parameters

  • :form_params (Hash)

    Query parameters

  • :body (Object)

    HTTP body (JSON/XML)

Returns:

  • A Faraday Request



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/xero-ruby/api_client.rb', line 232

def build_request(http_method, path, request, opts = {})
  url = build_request_url(path)
  http_method = http_method.to_sym.downcase

  header_params = @default_headers.merge(opts[:header_params] || {})
  query_params = opts[:query_params] || {}
  form_params = opts[:form_params] || {}

  update_params_for_auth! header_params, query_params, opts[:auth_names]

  req_opts = {
    :method => http_method,
    :headers => header_params,
    :params => query_params,
    :params_encoding => @config.params_encoding,
    :timeout => @config.timeout,
    :verbose => @config.debugging
  }

  if [:post, :patch, :put, :delete].include?(http_method)
    req_body = build_request_body(header_params, form_params, opts[:body])
    req_opts.update :body => req_body
    if @config.debugging
      @config.logger.debug "HTTP request body param ~BEGIN~\n#{req_body}\n~END~\n"
    end
  end
  request.headers = header_params
  request.body = req_body
  request.url url
  request.params = query_params
  request
end

#build_request_body(header_params, form_params, body) ⇒ String

Builds the HTTP request body

Parameters:

  • header_params (Hash)

    Header parameters

  • form_params (Hash)

    Query parameters

  • body (Object)

    HTTP body (JSON/XML)

Returns:

  • (String)

    HTTP body data in the form of string



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/xero-ruby/api_client.rb', line 271

def build_request_body(header_params, form_params, body)
  # http form
  if header_params['Content-Type'] == 'application/x-www-form-urlencoded'
    data = URI.encode_www_form(form_params)
  elsif header_params['Content-Type'] == 'multipart/form-data'
    data = {}
    form_params.each do |key, value|
      case value
      when ::File, ::Tempfile
        data[form_params["name"]] = Faraday::UploadIO.new(value.path, form_params["mimeType"], value.path)
      when ::Array, nil
        # let Faraday handle Array and nil parameters
        data[key] = value
      else
        data[key] = value.to_s
      end
    end
  elsif body
    data = body.is_a?(String) ? body : body.to_json
  else
    data = nil
  end
  data
end

#build_request_url(path) ⇒ Object



434
435
436
437
438
439
440
441
442
# File 'lib/xero-ruby/api_client.rb', line 434

def build_request_url(path)
  if @config.base_url
    # Add leading and trailing slashes to path
    path = "/#{path}".gsub(/\/+/, '/')
    @config.base_url + path
  else
    path
  end
end

#call_api(http_method, path, api_client, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Call an API with given options.

Returns:

  • (Array<(Object, Integer, Hash)>)

    an array of 3 elements: the data deserialized from response body (could be nil), response status code and response headers.



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/xero-ruby/api_client.rb', line 167

def call_api(http_method, path, api_client, opts = {})
  ssl_options = {
    :ca_file => @config.ssl_ca_file,
    :verify => @config.ssl_verify,
    :verify_mode => @config.ssl_verify_mode,
    :client_cert => @config.ssl_client_cert,
    :client_key => @config.ssl_client_key
  }

  connection = Faraday.new(:url => config.base_url, :ssl => ssl_options) do |conn|
    conn.basic_auth(config.username, config.password)
    if opts[:header_params]["Content-Type"] == "multipart/form-data"
      conn.request :multipart
      conn.request :url_encoded
    end
    conn.adapter(Faraday.default_adapter)
  end

  begin
    response = connection.public_send(http_method.to_sym.downcase) do |req|
      build_request(http_method, path, req, opts)
    end

    if @config.debugging
      @config.logger.debug "HTTP response body ~BEGIN~\n#{response.body}\n~END~\n"
    end

    return_error(response) unless response.success?
  rescue Faraday::TimeoutError
    fail ApiError.new('Connection timed out')
  end

  if opts[:return_type]
    prepare_file(response) if opts[:return_type] == 'File'
    data = deserialize(response, opts[:return_type], api_client)
  elsif !response.body.empty?
    data = JSON.parse(response.body)
  else
    data = nil
  end
  return data, response.status, response.headers
end

#connectionsObject

Connection heplers



149
150
151
152
153
154
# File 'lib/xero-ruby/api_client.rb', line 149

def connections
  @config.base_url = 'https://api.xero.com'
  opts = { :header_params => {'Content-Type': 'application/json'}, :auth_names => ['OAuth2'] }
  response = call_api(:GET, "/connections/", nil, opts)
  response[0]
end

#convert_to_type(data, return_type, api_client) ⇒ Mixed

Convert data to the given return type.

Parameters:

  • data (Object)

    Data to be converted

  • return_type (String)

    Return type

Returns:

  • (Mixed)

    Data in a particular type



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/xero-ruby/api_client.rb', line 346

def convert_to_type(data, return_type, api_client)
  return nil if data.nil?
  case return_type
  when 'String'
    data.to_s
  when 'Integer'
    data.to_i
  when 'Float'
    data.to_f
  when 'Boolean'
    data == true
  when 'DateTime'
    # parse date time (expecting ISO 8601 format)
    DateTime.parse data
  when 'Date'
    # parse date time (expecting ISO 8601 format)
    Date.parse data
  when 'Object'
    # generic object (usually a Hash), return directly
    data
  when /\AArray<(.+)>\z/
    # e.g. Array<Pet>
    sub_type = $1
    data.map { |item| convert_to_type(item, sub_type, api_client) }
  when /\AHash\<String, (.+)\>\z/
    # e.g. Hash<String, Integer>
    sub_type = $1
    {}.tap do |hash|
      data.each { |k, v| hash[k] = convert_to_type(v, sub_type, api_client) }
    end
  else
    case api_client
    when 'AccountingApi'
      XeroRuby::Accounting.const_get(return_type).build_from_hash(data)
    when 'AssetApi'
      XeroRuby::Assets.const_get(return_type).build_from_hash(data)
    when 'ProjectApi'
      XeroRuby::Projects.const_get(return_type).build_from_hash(data)
    when 'FilesApi'
      XeroRuby::Files.const_get(return_type).build_from_hash(data)
    when 'PayrollAuApi'
      XeroRuby::PayrollAu.const_get(return_type).build_from_hash(data)
    when 'PayrollNzApi'
      XeroRuby::PayrollNz.const_get(return_type).build_from_hash(data)
    when 'PayrollUkApi'
      XeroRuby::PayrollUk.const_get(return_type).build_from_hash(data)
    else
      XeroRuby::Accounting.const_get(return_type).build_from_hash(data)
    end
  end
end

#deserialize(response, return_type, api_client) ⇒ Object

Deserialize the response to the given return type.

Parameters:

  • response (Response)

    HTTP response

  • return_type (String)

    some examples: "User", "Array", "Hash<String, Integer>"



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/xero-ruby/api_client.rb', line 312

def deserialize(response, return_type, api_client)
  body = response.body

  # handle file downloading - return the File instance processed in request callbacks
  # note that response body is empty when the file is written in chunks in request on_body callback
  return @tempfile if return_type == 'File'

  return nil if body.nil? || body.empty?

  # return response body directly for String return type
  return body if return_type == 'String'

  # ensuring a default content type
  content_type = response.headers['Content-Type'] || 'application/json'

  fail "Content-Type is not supported: #{content_type}" unless json_mime?(content_type)

  begin
    data = JSON.parse("[#{body}]", :symbolize_names => true)[0]
  rescue JSON::ParserError => e
    if %w(String Date DateTime).include?(return_type)
      data = body
    else
      raise e
    end
  end 

  convert_to_type(data, return_type, api_client)
end

#disconnect(connection_id) ⇒ Object



156
157
158
159
160
161
# File 'lib/xero-ruby/api_client.rb', line 156

def disconnect(connection_id)
  @config.base_url = 'https://api.xero.com'
  opts = { :header_params => {'Content-Type': 'application/json'}, :auth_names => ['OAuth2'] }
  call_api(:DELETE, "/connections/#{connection_id}", nil, opts)
  connections
end

#files_apiObject



68
69
70
71
# File 'lib/xero-ruby/api_client.rb', line 68

def files_api
  @config.base_url = @config.files_url
  XeroRuby::FilesApi.new(self)
end

#get_token_set_from_callback(params) ⇒ Object



108
109
110
111
112
113
114
115
# File 'lib/xero-ruby/api_client.rb', line 108

def get_token_set_from_callback(params)
  data = {
    grant_type: 'authorization_code',
    code: params['code'],
    redirect_uri: @redirect_uri
  }
  return token_request(data, '/token')
end

#json_mime?(mime) ⇒ Boolean

Check if the given MIME is a JSON MIME. JSON MIME examples:

application/json
application/json; charset=UTF8
APPLICATION/JSON
*/*

Parameters:

  • mime (String)

    MIME

Returns:

  • (Boolean)

    True if the MIME is application/json



304
305
306
# File 'lib/xero-ruby/api_client.rb', line 304

def json_mime?(mime)
  (mime == '*/*') || !(mime =~ /Application\/.*json(?!p)(;.*)?/i).nil?
end

#object_to_hash(obj) ⇒ String

Convert object(non-array) to hash.

Parameters:

  • obj (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



507
508
509
510
511
512
513
# File 'lib/xero-ruby/api_client.rb', line 507

def object_to_hash(obj)
  if obj.respond_to?(:to_hash)
    to_camel_keys(obj).to_hash
  else
    to_camel_keys(obj)
  end
end

#object_to_http_body(model) ⇒ String

Convert object (array, hash, object, etc) to JSON string.

Parameters:

  • model (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



493
494
495
496
497
498
499
500
501
502
# File 'lib/xero-ruby/api_client.rb', line 493

def object_to_http_body(model)
  return model if model.nil? || model.is_a?(String)
  local_body = nil
  if model.is_a?(Array)
    local_body = model.map { |m| object_to_hash(m) }
  else
    local_body = object_to_hash(model)
  end
  local_body.to_json
end

#parameterize_where(where_opts) ⇒ Object



535
536
537
# File 'lib/xero-ruby/api_client.rb', line 535

def parameterize_where(where_opts)
  Where.new(where_opts).to_param
end

#payroll_au_apiObject



73
74
75
76
# File 'lib/xero-ruby/api_client.rb', line 73

def payroll_au_api
  @config.base_url = @config.payroll_au_url
  XeroRuby::PayrollAuApi.new(self)
end

#payroll_nz_apiObject



78
79
80
81
# File 'lib/xero-ruby/api_client.rb', line 78

def payroll_nz_api
  @config.base_url = @config.payroll_nz_url
  XeroRuby::PayrollNzApi.new(self)
end

#payroll_uk_apiObject



83
84
85
86
# File 'lib/xero-ruby/api_client.rb', line 83

def payroll_uk_api
  @config.base_url = @config.payroll_uk_url
  XeroRuby::PayrollUkApi.new(self)
end

#prepare_file(response) ⇒ Object

Save response body into a file in (the defined) temporary folder, using the filename from the "Content-Disposition" header if provided, otherwise a random filename. The response body is written to the file in chunks in order to handle files which size is larger than maximum Ruby String or even larger than the maximum memory a Ruby process can use.



405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/xero-ruby/api_client.rb', line 405

def prepare_file(response)
  content_disposition = response.headers['Content-Disposition']
  if content_disposition && content_disposition =~ /filename=/i
    filename = content_disposition[/filename=['"]?([^'"\s]+)['"]?/, 1]
    prefix = sanitize_filename(filename)
  else
    prefix = 'download-'
  end
  prefix = prefix + '-' unless prefix.end_with?('-')
  encoding = response.body.encoding
  tempfile = Tempfile.open(prefix, @config.temp_folder_path, encoding: encoding)
  @tempfile = tempfile
  tempfile.write(response.body)
  tempfile.close if tempfile
  @config.logger.info "Temp file written to #{tempfile.path}, please copy the file to a proper folder "\
                      "with e.g. `FileUtils.cp(tempfile.path, '/new/file/path')` otherwise the temp file "\
                      "will be deleted automatically with GC. It's also recommended to delete the temp file "\
                      "explicitly with `tempfile.delete`"
end

#project_apiObject



63
64
65
66
# File 'lib/xero-ruby/api_client.rb', line 63

def project_api
  @config.base_url = @config.project_url
  XeroRuby::ProjectApi.new(self)
end

#refresh_token_set(token_set) ⇒ Object



117
118
119
120
121
122
123
# File 'lib/xero-ruby/api_client.rb', line 117

def refresh_token_set(token_set)
  data = {
    grant_type: 'refresh_token',
    refresh_token: token_set['refresh_token']
  }
  return token_request(data, '/token')
end

#return_error(response) ⇒ Object



210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/xero-ruby/api_client.rb', line 210

def return_error(response)
  if response.status == 0
    # Errors from libcurl will be made visible here
    fail ApiError.new(:code => 0,
                      :message => response.return_message)
  else
    fail ApiError.new(:code => response.status,
                      :response_headers => response.headers,
                      :response_body => response.body),
          response.reason_phrase
  end
end

#revoke_token(token_set) ⇒ Object



125
126
127
128
129
130
# File 'lib/xero-ruby/api_client.rb', line 125

def revoke_token(token_set)
  data = {
    token: token_set['refresh_token']
  }
  return token_request(data, '/revocation')
end

#sanitize_filename(filename) ⇒ String

Sanitize filename by removing path. e.g. ../../sun.gif becomes sun.gif

Parameters:

  • filename (String)

    the filename to be sanitized

Returns:

  • (String)

    the sanitized filename



430
431
432
# File 'lib/xero-ruby/api_client.rb', line 430

def sanitize_filename(filename)
  filename.gsub(/.*[\/\\]/, '')
end

#select_header_accept(accepts) ⇒ String

Return Accept header based on an array of accepts provided.

Parameters:

  • accepts (Array)

    array for Accept

Returns:

  • (String)

    the Accept header (e.g. application/json)



472
473
474
475
476
477
# File 'lib/xero-ruby/api_client.rb', line 472

def select_header_accept(accepts)
  return nil if accepts.nil? || accepts.empty?
  # use JSON when present, otherwise use all of the provided
  json_accept = accepts.find { |s| json_mime?(s) }
  json_accept || accepts.join(',')
end

#select_header_content_type(content_types) ⇒ String

Return Content-Type header based on an array of content types provided.

Parameters:

  • content_types (Array)

    array for Content-Type

Returns:

  • (String)

    the Content-Type header (e.g. application/json)



482
483
484
485
486
487
488
# File 'lib/xero-ruby/api_client.rb', line 482

def select_header_content_type(content_types)
  # use application/json by default
  return 'application/json' if content_types.nil? || content_types.empty?
  # use JSON when present, otherwise use the first one
  json_content_type = content_types.find { |s| json_mime?(s) }
  json_content_type || content_types.first
end

#set_access_token(access_token) ⇒ Object



104
105
106
# File 'lib/xero-ruby/api_client.rb', line 104

def set_access_token(access_token)
  XeroRuby.configure.access_token = access_token
end

#set_token_set(token_set) ⇒ Object



97
98
99
100
101
102
# File 'lib/xero-ruby/api_client.rb', line 97

def set_token_set(token_set)
  # helper to set the token_set on a client once the user
  # has a valid token set ( access_token & refresh_token )
  XeroRuby.configure.token_set = token_set
  set_access_token(token_set['access_token'])
end

#token_request(data, path) ⇒ Object



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/xero-ruby/api_client.rb', line 132

def token_request(data, path)
  response = Faraday.post("#{@config.token_url}#{path}") do |req|
    req.headers['Authorization'] = "Basic " + Base64.strict_encode64("#{@client_id}:#{@client_secret}")
    req.headers['Content-Type'] = 'application/x-www-form-urlencoded'
    req.body = URI.encode_www_form(data)
  end
  return_error(response) unless response.success?
  if !response.body.blank?
    body = JSON.parse(response.body)
    set_token_set(body)
  else
    body = {}
  end
  return body
end

#token_setObject

Token Helpers



89
90
91
# File 'lib/xero-ruby/api_client.rb', line 89

def token_set
  XeroRuby.configure.token_set
end

#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object

Update hearder and query params based on authentication settings.

Parameters:

  • header_params (Hash)

    Header parameters

  • query_params (Hash)

    Query parameters

  • auth_names (String)

    Authentication scheme name



449
450
451
452
453
454
455
456
457
458
459
# File 'lib/xero-ruby/api_client.rb', line 449

def update_params_for_auth!(header_params, query_params, auth_names)
  Array(auth_names).each do |auth_name|
    auth_setting = @config.auth_settings[auth_name]
    next unless auth_setting
    case auth_setting[:in]
    when 'header' then header_params[auth_setting[:key]] = auth_setting[:value]
    when 'query'  then query_params[auth_setting[:key]] = auth_setting[:value]
    else fail ArgumentError, 'Authentication token must be in `query` of `header`'
    end
  end
end

#user_agent=(user_agent) ⇒ Object

Sets user agent in HTTP header

Parameters:

  • user_agent (String)

    User agent (e.g. openapi-generator/ruby/1.0.0)



464
465
466
467
# File 'lib/xero-ruby/api_client.rb', line 464

def user_agent=(user_agent)
  @user_agent = user_agent
  @default_headers['User-Agent'] = @user_agent
end