Class: XeroRuby::ApiClient

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/api_client.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config: Configuration.default, credentials: {}) ⇒ ApiClient

Initializes the ApiClient

Options Hash (config:):

  • Configuration (Configuration)

    for initializing the object, default to Configuration.default



32
33
34
35
36
37
38
39
40
41
42
43
# File 'lib/xero-ruby/api_client.rb', line 32

def initialize(config: Configuration.default, credentials: {})
  @client_id = credentials[:client_id]
  @client_secret = credentials[:client_secret]
  @redirect_uri = credentials[:redirect_uri]
  @scopes = credentials[:scopes]
  @config = config
  @user_agent = "xero-ruby-#{VERSION}"
  @default_headers = {
    'Content-Type' => 'application/json',
    'User-Agent' => @user_agent
  }
end

Instance Attribute Details

#configObject

The Configuration object holding settings to be used in the API client.



23
24
25
# File 'lib/xero-ruby/api_client.rb', line 23

def config
  @config
end

#default_headersHash

Defines the headers to be used in HTTP requests of all API calls by default.



28
29
30
# File 'lib/xero-ruby/api_client.rb', line 28

def default_headers
  @default_headers
end

Instance Method Details

#access_tokenObject



90
91
92
# File 'lib/xero-ruby/api_client.rb', line 90

def access_token
  XeroRuby.configure.access_token
end

#accounting_apiObject



50
51
52
53
# File 'lib/xero-ruby/api_client.rb', line 50

def accounting_api
  @config.base_url = @config.accounting_url
  XeroRuby::AccountingApi.new(self)
end

#asset_apiObject



55
56
57
58
# File 'lib/xero-ruby/api_client.rb', line 55

def asset_api
  @config.base_url = @config.asset_url
  XeroRuby::AssetApi.new(self)
end

#authorization_urlObject



45
46
47
48
# File 'lib/xero-ruby/api_client.rb', line 45

def authorization_url
  url = "#{@config.login_url}?response_type=code&client_id=#{@client_id}&redirect_uri=#{@redirect_uri}&scope=#{@scopes}"
  return url
end

#build_collection_param(param, collection_format) ⇒ Object

Build parameter value according to the given collection format.



546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
# File 'lib/xero-ruby/api_client.rb', line 546

def build_collection_param(param, collection_format)
  case collection_format
  when :csv
    param.join(',')
  when :ssv
    param.join(' ')
  when :tsv
    param.join("\t")
  when :pipes
    param.join('|')
  when :multi
    # return the array directly as http client will handle it as expected
    param
  else
    fail "unknown collection format: #{collection_format.inspect}"
  end
end

#build_request(http_method, path, request, opts = {}) ⇒ Object

Builds the HTTP request

Options Hash (opts):

  • :header_params (Hash)

    Header parameters

  • :query_params (Hash)

    Query parameters

  • :form_params (Hash)

    Query parameters

  • :body (Object)

    HTTP body (JSON/XML)



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/xero-ruby/api_client.rb', line 216

def build_request(http_method, path, request, opts = {})
  url = build_request_url(path)
  http_method = http_method.to_sym.downcase

  header_params = @default_headers.merge(opts[:header_params] || {})
  query_params = opts[:query_params] || {}
  form_params = opts[:form_params] || {}

  update_params_for_auth! header_params, query_params, opts[:auth_names]

  req_opts = {
    :method => http_method,
    :headers => header_params,
    :params => query_params,
    :params_encoding => @config.params_encoding,
    :timeout => @config.timeout,
    :verbose => @config.debugging
  }

  if [:post, :patch, :put, :delete].include?(http_method)
    req_body = build_request_body(header_params, form_params, opts[:body])
    req_opts.update :body => req_body
    if @config.debugging
      @config.logger.debug "HTTP request body param ~BEGIN~\n#{req_body}\n~END~\n"
    end
  end
  request.headers = header_params
  request.body = req_body
  request.url url
  request.params = query_params
  request
end

#build_request_body(header_params, form_params, body) ⇒ String

Builds the HTTP request body



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/xero-ruby/api_client.rb', line 255

def build_request_body(header_params, form_params, body)
  # http form
  if header_params['Content-Type'] == 'application/x-www-form-urlencoded'
    data = URI.encode_www_form(form_params)
  elsif header_params['Content-Type'] == 'multipart/form-data'
    data = {}
    form_params.each do |key, value|
      case value
      when ::File, ::Tempfile
        data[form_params["name"]] = Faraday::UploadIO.new(value.path, form_params["mimeType"], value.path)
      when ::Array, nil
        # let Faraday handle Array and nil parameters
        data[key] = value
      else
        data[key] = value.to_s
      end
    end
  elsif body
    data = body.is_a?(String) ? body : body.to_json
  else
    data = nil
  end
  data
end

#build_request_url(path) ⇒ Object



418
419
420
421
422
# File 'lib/xero-ruby/api_client.rb', line 418

def build_request_url(path)
  # Add leading and trailing slashes to path
  path = "/#{path}".gsub(/\/+/, '/')
  @config.base_url + path
end

#call_api(http_method, path, api_client, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Call an API with given options.



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/xero-ruby/api_client.rb', line 155

def call_api(http_method, path, api_client, opts = {})
  ssl_options = {
    :ca_file => @config.ssl_ca_file,
    :verify => @config.ssl_verify,
    :verify_mode => @config.ssl_verify_mode,
    :client_cert => @config.ssl_client_cert,
    :client_key => @config.ssl_client_key
  }

  connection = Faraday.new(:url => config.base_url, :ssl => ssl_options) do |conn|
    conn.basic_auth(config.username, config.password)
    if opts[:header_params]["Content-Type"] == "multipart/form-data"
      conn.request :multipart
      conn.request :url_encoded
    end
    conn.adapter(Faraday.default_adapter)
  end

  begin
    response = connection.public_send(http_method.to_sym.downcase) do |req|
      build_request(http_method, path, req, opts)
    end

    if @config.debugging
      @config.logger.debug "HTTP response body ~BEGIN~\n#{response.body}\n~END~\n"
    end

    unless response.success?
      if response.status == 0
        # Errors from libcurl will be made visible here
        fail ApiError.new(:code => 0,
                          :message => response.return_message)
      else
        fail ApiError.new(:code => response.status,
                          :response_headers => response.headers,
                          :response_body => response.body),
             response.reason_phrase
      end
    end
  rescue Faraday::TimeoutError
    fail ApiError.new('Connection timed out')
  end

  if opts[:return_type]
    prepare_file(response) if opts[:return_type] == 'File'
    data = deserialize(response, opts[:return_type], api_client)
  else
    data = nil
  end
  return data, response.status, response.headers
end

#camelize(word, first_upper = true) ⇒ Object



517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/xero-ruby/api_client.rb', line 517

def camelize(word, first_upper = true)
  if first_upper
    str = word.to_s
    str = gsubbed(str, /(?:^|_)([^_\s]+)/)
    str = gsubbed(str, %r{/([^/]*)}, "::")
    str
  else
    parts = word.split("_", 2)
    parts[0] << camelize(parts[1]) if parts.size > 1
    parts[0] || ""
  end
end

#camelize_key(key, first_upper = true) ⇒ Object



507
508
509
510
511
512
513
514
515
# File 'lib/xero-ruby/api_client.rb', line 507

def camelize_key(key, first_upper = true)
  if key.is_a? Symbol
    camelize(key.to_s, first_upper).to_sym
  elsif key.is_a? String
    camelize(key, first_upper)
  else
    key # can't camelize anything except strings and symbols
  end
end

#capitalize_first(word) ⇒ Object



538
539
540
541
# File 'lib/xero-ruby/api_client.rb', line 538

def capitalize_first(word)
  split = word.split('')
  "#{split[0].capitalize}#{split[1..-1].join}"
end

#connectionsObject

Connection heplers



134
135
136
137
138
139
140
141
# File 'lib/xero-ruby/api_client.rb', line 134

def connections
  response = Faraday.get('https://api.xero.com/connections') do |req|
    req.headers['Authorization'] = "Bearer #{access_token}" 
    req.headers['Content-Type'] = 'application/json'
  end
  body = JSON.parse(response.body)
  return body
end

#convert_to_type(data, return_type, api_client) ⇒ Mixed

Convert data to the given return type.



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/xero-ruby/api_client.rb', line 330

def convert_to_type(data, return_type, api_client)
  return nil if data.nil?
  case return_type
  when 'String'
    data.to_s
  when 'Integer'
    data.to_i
  when 'Float'
    data.to_f
  when 'Boolean'
    data == true
  when 'DateTime'
    # parse date time (expecting ISO 8601 format)
    DateTime.parse data
  when 'Date'
    # parse date time (expecting ISO 8601 format)
    Date.parse data
  when 'Object'
    # generic object (usually a Hash), return directly
    data
  when /\AArray<(.+)>\z/
    # e.g. Array<Pet>
    sub_type = $1
    data.map { |item| convert_to_type(item, sub_type, api_client) }
  when /\AHash\<String, (.+)\>\z/
    # e.g. Hash<String, Integer>
    sub_type = $1
    {}.tap do |hash|
      data.each { |k, v| hash[k] = convert_to_type(v, sub_type, api_client) }
    end
  else
    case api_client
    when 'AccountingApi'
      XeroRuby::Accounting.const_get(return_type).build_from_hash(data)
    when 'AssetApi'
      XeroRuby::Assets.const_get(return_type).build_from_hash(data)
    when 'ProjectApi'
      XeroRuby::Projects.const_get(return_type).build_from_hash(data)
    when 'FilesApi'
      XeroRuby::Files.const_get(return_type).build_from_hash(data)
    when 'PayrollAuApi'
      XeroRuby::PayrollAu.const_get(return_type).build_from_hash(data)
    when 'PayrollNzApi'
      XeroRuby::PayrollNz.const_get(return_type).build_from_hash(data)
    when 'PayrollUkApi'
      XeroRuby::PayrollUk.const_get(return_type).build_from_hash(data)
    else
      XeroRuby::Accounting.const_get(return_type).build_from_hash(data)
    end
  end
end

#deserialize(response, return_type, api_client) ⇒ Object

Deserialize the response to the given return type.



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/xero-ruby/api_client.rb', line 296

def deserialize(response, return_type, api_client)
  body = response.body

  # handle file downloading - return the File instance processed in request callbacks
  # note that response body is empty when the file is written in chunks in request on_body callback
  return @tempfile if return_type == 'File'

  return nil if body.nil? || body.empty?

  # return response body directly for String return type
  return body if return_type == 'String'

  # ensuring a default content type
  content_type = response.headers['Content-Type'] || 'application/json'

  fail "Content-Type is not supported: #{content_type}" unless json_mime?(content_type)

  begin
    data = JSON.parse("[#{body}]", :symbolize_names => true)[0]
  rescue JSON::ParserError => e
    if %w(String Date DateTime).include?(return_type)
      data = body
    else
      raise e
    end
  end 

  convert_to_type(data, return_type, api_client)
end

#disconnect(connection_id) ⇒ Object



143
144
145
146
147
148
149
# File 'lib/xero-ruby/api_client.rb', line 143

def disconnect(connection_id)
  Faraday.delete("https://api.xero.com/connections/#{connection_id}") do |req|
    req.headers['Authorization'] = "Bearer #{access_token}"
    req.headers['Content-Type'] = 'application/json'
  end
  return connections
end

#files_apiObject



65
66
67
68
# File 'lib/xero-ruby/api_client.rb', line 65

def files_api
  @config.base_url = @config.files_url
  XeroRuby::FilesApi.new(self)
end

#get_token_set_from_callback(params) ⇒ Object



105
106
107
108
109
110
111
112
# File 'lib/xero-ruby/api_client.rb', line 105

def get_token_set_from_callback(params)
  data = {
    grant_type: 'authorization_code',
    code: params['code'],
    redirect_uri: @redirect_uri
  }
  return token_request(data)
end

#gsubbed(str, pattern, extra = "") ⇒ Object



530
531
532
533
534
535
536
# File 'lib/xero-ruby/api_client.rb', line 530

def gsubbed(str, pattern, extra = "")
  key_map_scronyms = {}
  str = str.gsub(pattern) do
    extra + (key_map_scronyms[Regexp.last_match(1)] || capitalize_first(Regexp.last_match(1)))
  end
  str
end

#json_mime?(mime) ⇒ Boolean

Check if the given MIME is a JSON MIME. JSON MIME examples:

application/json
application/json; charset=UTF8
APPLICATION/JSON
*/*


288
289
290
# File 'lib/xero-ruby/api_client.rb', line 288

def json_mime?(mime)
  (mime == '*/*') || !(mime =~ /Application\/.*json(?!p)(;.*)?/i).nil?
end

#object_to_hash(obj) ⇒ String

Convert object(non-array) to hash.



487
488
489
490
491
492
493
# File 'lib/xero-ruby/api_client.rb', line 487

def object_to_hash(obj)
  if obj.respond_to?(:to_hash)
    to_camel_keys(obj).to_hash
  else
    to_camel_keys(obj)
  end
end

#object_to_http_body(model) ⇒ String

Convert object (array, hash, object, etc) to JSON string.



473
474
475
476
477
478
479
480
481
482
# File 'lib/xero-ruby/api_client.rb', line 473

def object_to_http_body(model)
  return model if model.nil? || model.is_a?(String)
  local_body = nil
  if model.is_a?(Array)
    local_body = model.map { |m| object_to_hash(m) }
  else
    local_body = object_to_hash(model)
  end
  local_body.to_json
end

#parameterize_where(where_opts) ⇒ Object



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
# File 'lib/xero-ruby/api_client.rb', line 564

def parameterize_where(where_opts)
  where_opts.map do |k,v|
    case v
    when Array
      operator = v.first
      query = v.last
      if query.is_a?(Date)
        "#{camelize_key(k)} #{operator} DateTime(#{query.strftime("%Y,%m,%d")})"
      elsif [Float, Integer].member?(query.class)
        %{#{camelize_key(k)} #{operator} #{query}}
      elsif [true, false].member?(query)
        %{#{camelize_key(k)} #{operator} #{query}}
      else
        if k == :contact_id
          %{Contact.ContactID #{operator} guid("#{query}")}
        elsif k == :contact_number
          %{Contact.ContactNumber #{operator} "#{query}"}
        else
          %{#{camelize_key(k)} #{operator} "#{query}"}
        end
      end
    when Range
      if v.first.is_a?(DateTime) || v.first.is_a?(Date) || v.first.is_a?(Time)
        "#{camelize_key(k)} >= DateTime(#{v.first.strftime("%Y,%m,%d")}) AND #{camelize_key(k)} <= DateTime(#{v.last.strftime("%Y,%m,%d")})" 
      else
        "#{camelize_key(k)} >= #{v.first} AND #{camelize_key(k)} <= #{v.last}"
      end
    else
      %{#{camelize_key(k)} #{v}}
    end
  end.join(' AND ')
end

#payroll_au_apiObject



70
71
72
73
# File 'lib/xero-ruby/api_client.rb', line 70

def payroll_au_api
  @config.base_url = @config.payroll_au_url
  XeroRuby::PayrollAuApi.new(self)
end

#payroll_nz_apiObject



75
76
77
78
# File 'lib/xero-ruby/api_client.rb', line 75

def payroll_nz_api
  @config.base_url = @config.payroll_nz_url
  XeroRuby::PayrollNzApi.new(self)
end

#payroll_uk_apiObject



80
81
82
83
# File 'lib/xero-ruby/api_client.rb', line 80

def payroll_uk_api
  @config.base_url = @config.payroll_uk_url
  XeroRuby::PayrollUkApi.new(self)
end

#prepare_file(response) ⇒ Object

Save response body into a file in (the defined) temporary folder, using the filename from the “Content-Disposition” header if provided, otherwise a random filename. The response body is written to the file in chunks in order to handle files which size is larger than maximum Ruby String or even larger than the maximum memory a Ruby process can use.



389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/xero-ruby/api_client.rb', line 389

def prepare_file(response)
  content_disposition = response.headers['Content-Disposition']
  if content_disposition && content_disposition =~ /filename=/i
    filename = content_disposition[/filename=['"]?([^'"\s]+)['"]?/, 1]
    prefix = sanitize_filename(filename)
  else
    prefix = 'download-'
  end
  prefix = prefix + '-' unless prefix.end_with?('-')
  encoding = response.body.encoding
  tempfile = Tempfile.open(prefix, @config.temp_folder_path, encoding: encoding)
  @tempfile = tempfile
  tempfile.write(response.body)
  tempfile.close if tempfile
  @config.logger.info "Temp file written to #{tempfile.path}, please copy the file to a proper folder "\
                      "with e.g. `FileUtils.cp(tempfile.path, '/new/file/path')` otherwise the temp file "\
                      "will be deleted automatically with GC. It's also recommended to delete the temp file "\
                      "explicitly with `tempfile.delete`"
end

#project_apiObject



60
61
62
63
# File 'lib/xero-ruby/api_client.rb', line 60

def project_api
  @config.base_url = @config.project_url
  XeroRuby::ProjectApi.new(self)
end

#refresh_token_set(token_set) ⇒ Object



114
115
116
117
118
119
120
# File 'lib/xero-ruby/api_client.rb', line 114

def refresh_token_set(token_set)
  data = {
    grant_type: 'refresh_token',
    refresh_token: token_set['refresh_token']
  }
  return token_request(data)
end

#sanitize_filename(filename) ⇒ String

Sanitize filename by removing path. e.g. ../../sun.gif becomes sun.gif



414
415
416
# File 'lib/xero-ruby/api_client.rb', line 414

def sanitize_filename(filename)
  filename.gsub(/.*[\/\\]/, '')
end

#select_header_accept(accepts) ⇒ String

Return Accept header based on an array of accepts provided.



452
453
454
455
456
457
# File 'lib/xero-ruby/api_client.rb', line 452

def select_header_accept(accepts)
  return nil if accepts.nil? || accepts.empty?
  # use JSON when present, otherwise use all of the provided
  json_accept = accepts.find { |s| json_mime?(s) }
  json_accept || accepts.join(',')
end

#select_header_content_type(content_types) ⇒ String

Return Content-Type header based on an array of content types provided.



462
463
464
465
466
467
468
# File 'lib/xero-ruby/api_client.rb', line 462

def select_header_content_type(content_types)
  # use application/json by default
  return 'application/json' if content_types.nil? || content_types.empty?
  # use JSON when present, otherwise use the first one
  json_content_type = content_types.find { |s| json_mime?(s) }
  json_content_type || content_types.first
end

#set_access_token(access_token) ⇒ Object



101
102
103
# File 'lib/xero-ruby/api_client.rb', line 101

def set_access_token(access_token)
  XeroRuby.configure.access_token = access_token
end

#set_token_set(token_set) ⇒ Object



94
95
96
97
98
99
# File 'lib/xero-ruby/api_client.rb', line 94

def set_token_set(token_set)
  # helper to set the token_set on a client once the user has y
  # has a valid token set ( access_token & refresh_token )
  XeroRuby.configure.token_set = token_set
  set_access_token(token_set['access_token'])
end

#to_camel_keys(value = self) ⇒ Object

START - Re-serializes snake_cased params to PascalCase required by XeroAPI



496
497
498
499
500
501
502
503
504
505
# File 'lib/xero-ruby/api_client.rb', line 496

def to_camel_keys(value = self)
  case value
  when Array
    value.map { |v| to_camel_keys(v) }
  when Hash
    Hash[value.map { |k, v| [camelize_key(k), to_camel_keys(v)] }]
  else
    value
  end
end

#token_request(data) ⇒ Object



122
123
124
125
126
127
128
129
130
131
# File 'lib/xero-ruby/api_client.rb', line 122

def token_request(data)
  response = Faraday.post(@config.token_url) do |req|
    req.headers['Authorization'] = "Basic " + Base64.strict_encode64("#{@client_id}:#{@client_secret}")
    req.headers['Content-Type'] = 'application/x-www-form-urlencoded'
    req.body = URI.encode_www_form(data)
  end
  body = JSON.parse(response.body)
  set_token_set(body)
  return body
end

#token_setObject

Token Helpers



86
87
88
# File 'lib/xero-ruby/api_client.rb', line 86

def token_set
  XeroRuby.configure.token_set
end

#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object

Update hearder and query params based on authentication settings.



429
430
431
432
433
434
435
436
437
438
439
# File 'lib/xero-ruby/api_client.rb', line 429

def update_params_for_auth!(header_params, query_params, auth_names)
  Array(auth_names).each do |auth_name|
    auth_setting = @config.auth_settings[auth_name]
    next unless auth_setting
    case auth_setting[:in]
    when 'header' then header_params[auth_setting[:key]] = auth_setting[:value]
    when 'query'  then query_params[auth_setting[:key]] = auth_setting[:value]
    else fail ArgumentError, 'Authentication token must be in `query` of `header`'
    end
  end
end

#user_agent=(user_agent) ⇒ Object

Sets user agent in HTTP header



444
445
446
447
# File 'lib/xero-ruby/api_client.rb', line 444

def user_agent=(user_agent)
  @user_agent = user_agent
  @default_headers['User-Agent'] = @user_agent
end