Class: XeroRuby::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/xero-ruby/configuration.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|_self| ... } ⇒ Configuration

Returns a new instance of Configuration.

Yields:

  • (_self)

Yield Parameters:



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/xero-ruby/configuration.rb', line 135

def initialize
  @scheme = 'https'
  @host = 'api.xero.com'
  @base_path = '/api.xro/2.0'
  @login_url = 'https://login.xero.com/identity/connect/authorize'
  @token_url = 'https://identity.xero.com/connect/token'
  @accounting_url = 'https://api.xero.com/api.xro/2.0'
  @asset_url = 'https://api.xero.com/assets.xro/1.0'
  @api_key = {}
  @api_key_prefix = {}
  @timeout = 0
  @client_side_validation = true
  @ssl_verify = true
  @ssl_verify_mode = nil
  @ssl_ca_file = nil
  @ssl_client_cert = nil
  @ssl_client_key = nil
  @debugging = false
  @inject_format = false
  @force_ending_format = false
  @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT)

  yield(self) if block_given?
end

Instance Attribute Details

#access_tokenObject

Defines the access token (Bearer) used with OAuth2.



60
61
62
# File 'lib/xero-ruby/configuration.rb', line 60

def access_token
  @access_token
end

#accounting_urlObject

Defines base paths for seperate API's



30
31
32
# File 'lib/xero-ruby/configuration.rb', line 30

def accounting_url
  @accounting_url
end

#api_keyHash

Defines API keys used with API Key authentications.

Examples:

parameter name is "api_key", API key is "xxx" (e.g. "api_key=xxx" in query string)

config.api_key['api_key'] = 'xxx'

Returns:

  • (Hash)

    key: parameter name, value: parameter value (API key)



39
40
41
# File 'lib/xero-ruby/configuration.rb', line 39

def api_key
  @api_key
end

#api_key_prefixHash

Defines API key prefixes used with API Key authentications.

Examples:

parameter name is "Authorization", API key prefix is "Token" (e.g. "Authorization: Token xxx" in headers)

config.api_key_prefix['api_key'] = 'Token'

Returns:

  • (Hash)

    key: parameter name, value: API key prefix



47
48
49
# File 'lib/xero-ruby/configuration.rb', line 47

def api_key_prefix
  @api_key_prefix
end

#asset_urlObject

Returns the value of attribute asset_url.



31
32
33
# File 'lib/xero-ruby/configuration.rb', line 31

def asset_url
  @asset_url
end

#base_pathObject

Defines url base path & url for overwriting



22
23
24
# File 'lib/xero-ruby/configuration.rb', line 22

def base_path
  @base_path
end

#base_urlObject

Returns the value of attribute base_url.



23
24
25
# File 'lib/xero-ruby/configuration.rb', line 23

def base_url
  @base_url
end

#client_side_validationtrue, false

Set this to false to skip client side validation in the operation. Default to true.

Returns:

  • (true, false)


92
93
94
# File 'lib/xero-ruby/configuration.rb', line 92

def client_side_validation
  @client_side_validation
end

#debuggingtrue, false

Set this to enable/disable debugging. When enabled (set to true), HTTP request/response details will be logged with logger.debug (see the logger attribute). Default to false.

Returns:

  • (true, false)


70
71
72
# File 'lib/xero-ruby/configuration.rb', line 70

def debugging
  @debugging
end

#force_ending_formatObject

Returns the value of attribute force_ending_format.



133
134
135
# File 'lib/xero-ruby/configuration.rb', line 133

def force_ending_format
  @force_ending_format
end

#hostObject

Defines url host



19
20
21
# File 'lib/xero-ruby/configuration.rb', line 19

def host
  @host
end

#inject_formatObject

Returns the value of attribute inject_format.



131
132
133
# File 'lib/xero-ruby/configuration.rb', line 131

def inject_format
  @inject_format
end

#logger#debug

Defines the logger used for debugging. Default to Rails.logger (when in Rails) or logging to STDOUT.

Returns:

  • (#debug)


76
77
78
# File 'lib/xero-ruby/configuration.rb', line 76

def logger
  @logger
end

#login_urlObject

Defines url for identity routes



26
27
28
# File 'lib/xero-ruby/configuration.rb', line 26

def 
  @login_url
end

#params_encodingObject

Set this to customize parameters encoding of array parameter with multi collectionFormat. Default to nil.

https://github.com/typhoeus/ethon/blob/master/lib/ethon/easy/queryable.rb#L96

See Also:

  • params_encoding option of Ethon. Related source code:


129
130
131
# File 'lib/xero-ruby/configuration.rb', line 129

def params_encoding
  @params_encoding
end

#passwordString

Defines the password used with HTTP basic authentication.

Returns:

  • (String)


57
58
59
# File 'lib/xero-ruby/configuration.rb', line 57

def password
  @password
end

#schemeObject

Defines url scheme



16
17
18
# File 'lib/xero-ruby/configuration.rb', line 16

def scheme
  @scheme
end

#ssl_ca_fileString

TLS/SSL setting Set this to customize the certificate file to verify the peer.

Returns:

  • (String)

    the path to the certificate file



114
115
116
# File 'lib/xero-ruby/configuration.rb', line 114

def ssl_ca_file
  @ssl_ca_file
end

#ssl_client_certObject

TLS/SSL setting Client certificate file (for client certificate)



118
119
120
# File 'lib/xero-ruby/configuration.rb', line 118

def ssl_client_cert
  @ssl_client_cert
end

#ssl_client_keyObject

TLS/SSL setting Client private key file (for client certificate)



122
123
124
# File 'lib/xero-ruby/configuration.rb', line 122

def ssl_client_key
  @ssl_client_key
end

#ssl_verifytrue, false

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.

Returns:

  • (true, false)


101
102
103
# File 'lib/xero-ruby/configuration.rb', line 101

def ssl_verify
  @ssl_verify
end

#ssl_verify_modeObject

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Any OpenSSL::SSL:: constant (see https://ruby-doc.org/stdlib-2.5.1/libdoc/openssl/rdoc/OpenSSL/SSL.html)



108
109
110
# File 'lib/xero-ruby/configuration.rb', line 108

def ssl_verify_mode
  @ssl_verify_mode
end

#temp_folder_pathString

Defines the temporary folder to store downloaded files (for API endpoints that have file response). Default to use Tempfile.

Returns:

  • (String)


83
84
85
# File 'lib/xero-ruby/configuration.rb', line 83

def temp_folder_path
  @temp_folder_path
end

#timeoutObject

The time limit for HTTP request in seconds. Default to 0 (never times out).



87
88
89
# File 'lib/xero-ruby/configuration.rb', line 87

def timeout
  @timeout
end

#token_setObject

Defines the token set used with OAuth2. May include id/access/refresh token & other meta info.



63
64
65
# File 'lib/xero-ruby/configuration.rb', line 63

def token_set
  @token_set
end

#token_urlObject

Returns the value of attribute token_url.



27
28
29
# File 'lib/xero-ruby/configuration.rb', line 27

def token_url
  @token_url
end

#usernameString

Defines the username used with HTTP basic authentication.

Returns:

  • (String)


52
53
54
# File 'lib/xero-ruby/configuration.rb', line 52

def username
  @username
end

Class Method Details

.defaultObject

The default Configuration object.



161
162
163
# File 'lib/xero-ruby/configuration.rb', line 161

def self.default
  @@default ||= Configuration.new
end

Instance Method Details

#api_key_with_prefix(param_name) ⇒ Object

Gets API key (with prefix if set).

Parameters:

  • param_name (String)

    the parameter name of API key auth



191
192
193
194
195
196
197
# File 'lib/xero-ruby/configuration.rb', line 191

def api_key_with_prefix(param_name)
  if @api_key_prefix[param_name]
    "#{@api_key_prefix[param_name]} #{@api_key[param_name]}"
  else
    @api_key[param_name]
  end
end

#auth_settingsObject

Returns Auth Settings hash for api client.



205
206
207
208
209
210
211
212
213
214
215
# File 'lib/xero-ruby/configuration.rb', line 205

def auth_settings
  {
    'OAuth2' =>
      {
        type: 'oauth2',
        in: 'header',
        key: 'Authorization',
        value: "Bearer #{access_token}"
      },
  }
end

#basic_auth_tokenObject

Gets Basic Auth token string



200
201
202
# File 'lib/xero-ruby/configuration.rb', line 200

def basic_auth_token
  'Basic ' + ["#{username}:#{password}"].pack('m').delete("\r\n")
end

#configure {|_self| ... } ⇒ Object

Yields:

  • (_self)

Yield Parameters:



165
166
167
# File 'lib/xero-ruby/configuration.rb', line 165

def configure
  yield(self) if block_given?
end

#server_settingsObject

Returns an array of Server setting



218
219
220
221
222
223
224
225
# File 'lib/xero-ruby/configuration.rb', line 218

def server_settings
  [
    {
      url: "https://api.xero.com/api.xro/2.0",
      description: "Xero Accounting API servers",
    }
  ]
end

#server_url(index, variables = {}) ⇒ Object

Returns URL based on server settings

Parameters:

  • index

    array index of the server settings

  • variables (defaults to: {})

    hash of variable and the corresponding value



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/xero-ruby/configuration.rb', line 231

def server_url(index, variables = {})
  servers = server_settings

  # check array index out of bound
  if (index < 0 || index >= servers.size)
    fail ArgumentError, "Invalid index #{index} when selecting the server. Must be less than #{servers.size}"
  end

  server = servers[index]
  url = server[:url]

  # go through variable and assign a value
  server[:variables].each do |name, variable|
    if variables.key?(name)
      if (server[:variables][name][:enum_values].include? variables[name])
        url.gsub! "{" + name.to_s + "}", variables[name]
      else
        fail ArgumentError, "The variable `#{name}` in the server URL has invalid value #{variables[name]}. Must be #{server[:variables][name][:enum_values]}."
      end
    else
      # use default value
      url.gsub! "{" + name.to_s + "}", server[:variables][name][:default_value]
    end
  end

  url
end