Class: XeroRuby::PayrollAu::Payslip
- Inherits:
-
Object
- Object
- XeroRuby::PayrollAu::Payslip
- Defined in:
- lib/xero-ruby/models/payroll_au/payslip.rb
Instance Attribute Summary collapse
-
#_super ⇒ Object
The Super for the Payslip.
-
#deduction_lines ⇒ Object
Returns the value of attribute deduction_lines.
-
#deductions ⇒ Object
The Deductions for the Payslip.
-
#earnings_lines ⇒ Object
Returns the value of attribute earnings_lines.
-
#employee_id ⇒ Object
The Xero identifier for an employee.
-
#first_name ⇒ Object
First name of employee.
-
#last_name ⇒ Object
Last name of employee.
-
#leave_accrual_lines ⇒ Object
Returns the value of attribute leave_accrual_lines.
-
#leave_earnings_lines ⇒ Object
Returns the value of attribute leave_earnings_lines.
-
#net_pay ⇒ Object
The NetPay for the Payslip.
-
#payslip_id ⇒ Object
Xero identifier for the payslip.
-
#reimbursement_lines ⇒ Object
Returns the value of attribute reimbursement_lines.
-
#reimbursements ⇒ Object
The Reimbursements for the Payslip.
-
#superannuation_lines ⇒ Object
Returns the value of attribute superannuation_lines.
-
#tax ⇒ Object
The Tax for the Payslip.
-
#tax_lines ⇒ Object
Returns the value of attribute tax_lines.
-
#timesheet_earnings_lines ⇒ Object
Returns the value of attribute timesheet_earnings_lines.
-
#updated_date_utc ⇒ Object
Last modified timestamp.
-
#wages ⇒ Object
The Wages for the Payslip.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Payslip
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Payslip
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 129 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollAu::Payslip` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollAu::Payslip`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'employee_id') self.employee_id = attributes[:'employee_id'] end if attributes.key?(:'payslip_id') self.payslip_id = attributes[:'payslip_id'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'wages') self.wages = attributes[:'wages'] end if attributes.key?(:'deductions') self.deductions = attributes[:'deductions'] end if attributes.key?(:'tax') self.tax = attributes[:'tax'] end if attributes.key?(:'_super') self._super = attributes[:'_super'] end if attributes.key?(:'reimbursements') self.reimbursements = attributes[:'reimbursements'] end if attributes.key?(:'net_pay') self.net_pay = attributes[:'net_pay'] end if attributes.key?(:'earnings_lines') if (value = attributes[:'earnings_lines']).is_a?(Array) self.earnings_lines = value end end if attributes.key?(:'leave_earnings_lines') if (value = attributes[:'leave_earnings_lines']).is_a?(Array) self.leave_earnings_lines = value end end if attributes.key?(:'timesheet_earnings_lines') if (value = attributes[:'timesheet_earnings_lines']).is_a?(Array) self.timesheet_earnings_lines = value end end if attributes.key?(:'deduction_lines') if (value = attributes[:'deduction_lines']).is_a?(Array) self.deduction_lines = value end end if attributes.key?(:'leave_accrual_lines') if (value = attributes[:'leave_accrual_lines']).is_a?(Array) self.leave_accrual_lines = value end end if attributes.key?(:'reimbursement_lines') if (value = attributes[:'reimbursement_lines']).is_a?(Array) self.reimbursement_lines = value end end if attributes.key?(:'superannuation_lines') if (value = attributes[:'superannuation_lines']).is_a?(Array) self.superannuation_lines = value end end if attributes.key?(:'tax_lines') if (value = attributes[:'tax_lines']).is_a?(Array) self.tax_lines = value end end if attributes.key?(:'updated_date_utc') self.updated_date_utc = attributes[:'updated_date_utc'] end end |
Instance Attribute Details
#_super ⇒ Object
The Super for the Payslip
42 43 44 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 42 def _super @_super end |
#deduction_lines ⇒ Object
Returns the value of attribute deduction_lines.
60 61 62 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 60 def deduction_lines @deduction_lines end |
#deductions ⇒ Object
The Deductions for the Payslip
36 37 38 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 36 def deductions @deductions end |
#earnings_lines ⇒ Object
Returns the value of attribute earnings_lines.
51 52 53 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 51 def earnings_lines @earnings_lines end |
#employee_id ⇒ Object
The Xero identifier for an employee
21 22 23 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 21 def employee_id @employee_id end |
#first_name ⇒ Object
First name of employee
27 28 29 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 27 def first_name @first_name end |
#last_name ⇒ Object
Last name of employee
30 31 32 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 30 def last_name @last_name end |
#leave_accrual_lines ⇒ Object
Returns the value of attribute leave_accrual_lines.
63 64 65 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 63 def leave_accrual_lines @leave_accrual_lines end |
#leave_earnings_lines ⇒ Object
Returns the value of attribute leave_earnings_lines.
54 55 56 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 54 def leave_earnings_lines @leave_earnings_lines end |
#net_pay ⇒ Object
The NetPay for the Payslip
48 49 50 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 48 def net_pay @net_pay end |
#payslip_id ⇒ Object
Xero identifier for the payslip
24 25 26 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 24 def payslip_id @payslip_id end |
#reimbursement_lines ⇒ Object
Returns the value of attribute reimbursement_lines.
66 67 68 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 66 def reimbursement_lines @reimbursement_lines end |
#reimbursements ⇒ Object
The Reimbursements for the Payslip
45 46 47 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 45 def reimbursements @reimbursements end |
#superannuation_lines ⇒ Object
Returns the value of attribute superannuation_lines.
69 70 71 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 69 def superannuation_lines @superannuation_lines end |
#tax ⇒ Object
The Tax for the Payslip
39 40 41 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 39 def tax @tax end |
#tax_lines ⇒ Object
Returns the value of attribute tax_lines.
72 73 74 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 72 def tax_lines @tax_lines end |
#timesheet_earnings_lines ⇒ Object
Returns the value of attribute timesheet_earnings_lines.
57 58 59 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 57 def timesheet_earnings_lines @timesheet_earnings_lines end |
#updated_date_utc ⇒ Object
Last modified timestamp
75 76 77 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 75 def updated_date_utc @updated_date_utc end |
#wages ⇒ Object
The Wages for the Payslip
33 34 35 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 33 def wages @wages end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 78 def self.attribute_map { :'employee_id' => :'EmployeeID', :'payslip_id' => :'PayslipID', :'first_name' => :'FirstName', :'last_name' => :'LastName', :'wages' => :'Wages', :'deductions' => :'Deductions', :'tax' => :'Tax', :'_super' => :'Super', :'reimbursements' => :'Reimbursements', :'net_pay' => :'NetPay', :'earnings_lines' => :'EarningsLines', :'leave_earnings_lines' => :'LeaveEarningsLines', :'timesheet_earnings_lines' => :'TimesheetEarningsLines', :'deduction_lines' => :'DeductionLines', :'leave_accrual_lines' => :'LeaveAccrualLines', :'reimbursement_lines' => :'ReimbursementLines', :'superannuation_lines' => :'SuperannuationLines', :'tax_lines' => :'TaxLines', :'updated_date_utc' => :'UpdatedDateUTC' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
289 290 291 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 289 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 103 def self.openapi_types { :'employee_id' => :'String', :'payslip_id' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'wages' => :'BigDecimal', :'deductions' => :'BigDecimal', :'tax' => :'BigDecimal', :'_super' => :'BigDecimal', :'reimbursements' => :'BigDecimal', :'net_pay' => :'BigDecimal', :'earnings_lines' => :'Array<EarningsLine>', :'leave_earnings_lines' => :'Array<LeaveEarningsLine>', :'timesheet_earnings_lines' => :'Array<EarningsLine>', :'deduction_lines' => :'Array<DeductionLine>', :'leave_accrual_lines' => :'Array<LeaveAccrualLine>', :'reimbursement_lines' => :'Array<ReimbursementLine>', :'superannuation_lines' => :'Array<SuperannuationLine>', :'tax_lines' => :'Array<TaxLine>', :'updated_date_utc' => :'DateTime' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 250 def ==(o) return true if self.equal?(o) self.class == o.class && employee_id == o.employee_id && payslip_id == o.payslip_id && first_name == o.first_name && last_name == o.last_name && wages == o.wages && deductions == o.deductions && tax == o.tax && _super == o._super && reimbursements == o.reimbursements && net_pay == o.net_pay && earnings_lines == o.earnings_lines && leave_earnings_lines == o.leave_earnings_lines && timesheet_earnings_lines == o.timesheet_earnings_lines && deduction_lines == o.deduction_lines && leave_accrual_lines == o.leave_accrual_lines && reimbursement_lines == o.reimbursement_lines && superannuation_lines == o.superannuation_lines && tax_lines == o.tax_lines && updated_date_utc == o.updated_date_utc end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 317 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::PayrollAu.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 384 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 296 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
276 277 278 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 276 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
282 283 284 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 282 def hash [employee_id, payslip_id, first_name, last_name, wages, deductions, tax, _super, reimbursements, net_pay, earnings_lines, leave_earnings_lines, timesheet_earnings_lines, deduction_lines, leave_accrual_lines, reimbursement_lines, superannuation_lines, tax_lines, updated_date_utc].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
237 238 239 240 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 237 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
399 400 401 402 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 399 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
364 365 366 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 364 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
370 371 372 373 374 375 376 377 378 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 370 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
358 359 360 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 358 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
244 245 246 |
# File 'lib/xero-ruby/models/payroll_au/payslip.rb', line 244 def valid? true end |