Class: XeroRuby::PayrollNz::EmployeeLeaveType
- Inherits:
-
Object
- Object
- XeroRuby::PayrollNz::EmployeeLeaveType
- Defined in:
- lib/xero-ruby/models/payroll_nz/employee_leave_type.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Constant Summary collapse
- ANNUALLY_AFTER6_MONTHS =
"AnnuallyAfter6Months".freeze
- ON_ANNIVERSARY_DATE =
"OnAnniversaryDate".freeze
- PERCENTAGE_OF_GROSS_EARNINGS =
"PercentageOfGrossEarnings".freeze
- NO_ACCRUALS =
"NoAccruals".freeze
Instance Attribute Summary collapse
-
#annual_leave_total_amount_paid ⇒ Object
Specific to Annual Leave.
-
#hours_accrued_annually ⇒ Object
The number of hours accrued for the leave annually.
-
#include_holiday_pay_every_pay ⇒ Object
Specific to Holiday pay.
-
#leave_type_id ⇒ Object
The Xero identifier for leave type.
-
#maximum_to_accrue ⇒ Object
The maximum number of hours that can be accrued for the leave.
-
#opening_balance ⇒ Object
The initial number of hours assigned when the leave was added to the employee.
-
#percentage_of_gross_earnings ⇒ Object
Specific for scheduleOfAccrual having percentage of gross earnings.
-
#rate_accrued_hourly ⇒ Object
The number of hours added to the leave balance for every hour worked by the employee.
-
#schedule_of_accrual ⇒ Object
The schedule of accrual.
-
#show_annual_leave_in_advance ⇒ Object
Specific to Annual Leave.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmployeeLeaveType
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EmployeeLeaveType
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollNz::EmployeeLeaveType` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollNz::EmployeeLeaveType`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'leave_type_id') self.leave_type_id = attributes[:'leave_type_id'] end if attributes.key?(:'schedule_of_accrual') self.schedule_of_accrual = attributes[:'schedule_of_accrual'] end if attributes.key?(:'hours_accrued_annually') self.hours_accrued_annually = attributes[:'hours_accrued_annually'] end if attributes.key?(:'maximum_to_accrue') self.maximum_to_accrue = attributes[:'maximum_to_accrue'] end if attributes.key?(:'opening_balance') self.opening_balance = attributes[:'opening_balance'] end if attributes.key?(:'rate_accrued_hourly') self.rate_accrued_hourly = attributes[:'rate_accrued_hourly'] end if attributes.key?(:'percentage_of_gross_earnings') self.percentage_of_gross_earnings = attributes[:'percentage_of_gross_earnings'] end if attributes.key?(:'include_holiday_pay_every_pay') self.include_holiday_pay_every_pay = attributes[:'include_holiday_pay_every_pay'] end if attributes.key?(:'show_annual_leave_in_advance') self.show_annual_leave_in_advance = attributes[:'show_annual_leave_in_advance'] end if attributes.key?(:'annual_leave_total_amount_paid') self.annual_leave_total_amount_paid = attributes[:'annual_leave_total_amount_paid'] end end |
Instance Attribute Details
#annual_leave_total_amount_paid ⇒ Object
Specific to Annual Leave. Annual leave balance in dollars
52 53 54 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 52 def annual_leave_total_amount_paid @annual_leave_total_amount_paid end |
#hours_accrued_annually ⇒ Object
The number of hours accrued for the leave annually. This is 0 when the scheduleOfAccrual chosen is "OnHourWorked"
31 32 33 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 31 def hours_accrued_annually @hours_accrued_annually end |
#include_holiday_pay_every_pay ⇒ Object
Specific to Holiday pay. Flag determining if pay for leave type is added on each pay run.
46 47 48 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 46 def include_holiday_pay_every_pay @include_holiday_pay_every_pay end |
#leave_type_id ⇒ Object
The Xero identifier for leave type
21 22 23 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 21 def leave_type_id @leave_type_id end |
#maximum_to_accrue ⇒ Object
The maximum number of hours that can be accrued for the leave
34 35 36 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 34 def maximum_to_accrue @maximum_to_accrue end |
#opening_balance ⇒ Object
The initial number of hours assigned when the leave was added to the employee
37 38 39 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 37 def opening_balance @opening_balance end |
#percentage_of_gross_earnings ⇒ Object
Specific for scheduleOfAccrual having percentage of gross earnings. Identifies how much percentage of gross earnings is accrued per pay period.
43 44 45 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 43 def percentage_of_gross_earnings @percentage_of_gross_earnings end |
#rate_accrued_hourly ⇒ Object
The number of hours added to the leave balance for every hour worked by the employee. This is normally 0, unless the scheduleOfAccrual chosen is "OnHourWorked"
40 41 42 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 40 def rate_accrued_hourly @rate_accrued_hourly end |
#schedule_of_accrual ⇒ Object
The schedule of accrual
24 25 26 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 24 def schedule_of_accrual @schedule_of_accrual end |
#show_annual_leave_in_advance ⇒ Object
Specific to Annual Leave. Flag to include leave available to take in advance in the balance in the payslip
49 50 51 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 49 def show_annual_leave_in_advance @show_annual_leave_in_advance end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 77 def self.attribute_map { :'leave_type_id' => :'leaveTypeID', :'schedule_of_accrual' => :'scheduleOfAccrual', :'hours_accrued_annually' => :'hoursAccruedAnnually', :'maximum_to_accrue' => :'maximumToAccrue', :'opening_balance' => :'openingBalance', :'rate_accrued_hourly' => :'rateAccruedHourly', :'percentage_of_gross_earnings' => :'percentageOfGrossEarnings', :'include_holiday_pay_every_pay' => :'includeHolidayPayEveryPay', :'show_annual_leave_in_advance' => :'showAnnualLeaveInAdvance', :'annual_leave_total_amount_paid' => :'annualLeaveTotalAmountPaid' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 221 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 93 def self.openapi_types { :'leave_type_id' => :'String', :'schedule_of_accrual' => :'String', :'hours_accrued_annually' => :'BigDecimal', :'maximum_to_accrue' => :'BigDecimal', :'opening_balance' => :'BigDecimal', :'rate_accrued_hourly' => :'BigDecimal', :'percentage_of_gross_earnings' => :'BigDecimal', :'include_holiday_pay_every_pay' => :'Boolean', :'show_annual_leave_in_advance' => :'Boolean', :'annual_leave_total_amount_paid' => :'BigDecimal' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && leave_type_id == o.leave_type_id && schedule_of_accrual == o.schedule_of_accrual && hours_accrued_annually == o.hours_accrued_annually && maximum_to_accrue == o.maximum_to_accrue && opening_balance == o.opening_balance && rate_accrued_hourly == o.rate_accrued_hourly && percentage_of_gross_earnings == o.percentage_of_gross_earnings && include_holiday_pay_every_pay == o.include_holiday_pay_every_pay && show_annual_leave_in_advance == o.show_annual_leave_in_advance && annual_leave_total_amount_paid == o.annual_leave_total_amount_paid end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 249 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::PayrollNz.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 316 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 228 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
208 209 210 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 208 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
214 215 216 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 214 def hash [leave_type_id, schedule_of_accrual, hours_accrued_annually, maximum_to_accrue, opening_balance, rate_accrued_hourly, percentage_of_gross_earnings, include_holiday_pay_every_pay, show_annual_leave_in_advance, annual_leave_total_amount_paid].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 166 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
331 332 333 334 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 331 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
296 297 298 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 296 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
290 291 292 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 290 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 177 |
# File 'lib/xero-ruby/models/payroll_nz/employee_leave_type.rb', line 173 def valid? schedule_of_accrual_validator = EnumAttributeValidator.new('String', ["AnnuallyAfter6Months", "OnAnniversaryDate", "PercentageOfGrossEarnings", "NoAccruals"]) return false unless schedule_of_accrual_validator.valid?(@schedule_of_accrual) true end |