Class: XeroRuby::PayrollNz::PayRun
- Inherits:
-
Object
- Object
- XeroRuby::PayrollNz::PayRun
- Defined in:
- lib/xero-ruby/models/payroll_nz/pay_run.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Constant Summary collapse
- DRAFT =
"Draft".freeze
- POSTED =
"Posted".freeze
- SCHEDULED =
"Scheduled".freeze
- UNSCHEDULED =
"Unscheduled".freeze
- EARLIER_YEAR_UPDATE =
"EarlierYearUpdate".freeze
Instance Attribute Summary collapse
-
#calendar_type ⇒ Object
Returns the value of attribute calendar_type.
-
#pay_run_id ⇒ Object
Xero unique identifier for the pay run.
-
#pay_run_status ⇒ Object
Pay run status.
-
#pay_run_type ⇒ Object
Pay run type.
-
#pay_slips ⇒ Object
Returns the value of attribute pay_slips.
-
#payment_date ⇒ Object
Payment date of the pay run.
-
#payroll_calendar_id ⇒ Object
Xero unique identifier for the payroll calendar.
-
#period_end_date ⇒ Object
Period end date of the payroll calendar.
-
#period_start_date ⇒ Object
Period start date of the payroll calendar.
-
#posted_date_time ⇒ Object
Posted date time of the pay run.
-
#total_cost ⇒ Object
Total cost of the pay run.
-
#total_pay ⇒ Object
Total pay of the pay run.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PayRun
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#parse_date(datestring) ⇒ Object
customized data_parser.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PayRun
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 121 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `XeroRuby::PayrollNz::PayRun` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `XeroRuby::PayrollNz::PayRun`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pay_run_id') self.pay_run_id = attributes[:'pay_run_id'] end if attributes.key?(:'payroll_calendar_id') self.payroll_calendar_id = attributes[:'payroll_calendar_id'] end if attributes.key?(:'period_start_date') self.period_start_date = attributes[:'period_start_date'] end if attributes.key?(:'period_end_date') self.period_end_date = attributes[:'period_end_date'] end if attributes.key?(:'payment_date') self.payment_date = attributes[:'payment_date'] end if attributes.key?(:'total_cost') self.total_cost = attributes[:'total_cost'] end if attributes.key?(:'total_pay') self.total_pay = attributes[:'total_pay'] end if attributes.key?(:'pay_run_status') self.pay_run_status = attributes[:'pay_run_status'] end if attributes.key?(:'pay_run_type') self.pay_run_type = attributes[:'pay_run_type'] end if attributes.key?(:'calendar_type') self.calendar_type = attributes[:'calendar_type'] end if attributes.key?(:'posted_date_time') self.posted_date_time = attributes[:'posted_date_time'] end if attributes.key?(:'pay_slips') if (value = attributes[:'pay_slips']).is_a?(Array) self.pay_slips = value end end end |
Instance Attribute Details
#calendar_type ⇒ Object
Returns the value of attribute calendar_type.
53 54 55 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 53 def calendar_type @calendar_type end |
#pay_run_id ⇒ Object
Xero unique identifier for the pay run
21 22 23 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 21 def pay_run_id @pay_run_id end |
#pay_run_status ⇒ Object
Pay run status
42 43 44 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 42 def pay_run_status @pay_run_status end |
#pay_run_type ⇒ Object
Pay run type
47 48 49 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 47 def pay_run_type @pay_run_type end |
#pay_slips ⇒ Object
Returns the value of attribute pay_slips.
59 60 61 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 59 def pay_slips @pay_slips end |
#payment_date ⇒ Object
Payment date of the pay run
33 34 35 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 33 def payment_date @payment_date end |
#payroll_calendar_id ⇒ Object
Xero unique identifier for the payroll calendar
24 25 26 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 24 def payroll_calendar_id @payroll_calendar_id end |
#period_end_date ⇒ Object
Period end date of the payroll calendar
30 31 32 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 30 def period_end_date @period_end_date end |
#period_start_date ⇒ Object
Period start date of the payroll calendar
27 28 29 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 27 def period_start_date @period_start_date end |
#posted_date_time ⇒ Object
Posted date time of the pay run
56 57 58 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 56 def posted_date_time @posted_date_time end |
#total_cost ⇒ Object
Total cost of the pay run
36 37 38 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 36 def total_cost @total_cost end |
#total_pay ⇒ Object
Total pay of the pay run
39 40 41 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 39 def total_pay @total_pay end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 84 def self.attribute_map { :'pay_run_id' => :'payRunID', :'payroll_calendar_id' => :'payrollCalendarID', :'period_start_date' => :'periodStartDate', :'period_end_date' => :'periodEndDate', :'payment_date' => :'paymentDate', :'total_cost' => :'totalCost', :'total_pay' => :'totalPay', :'pay_run_status' => :'payRunStatus', :'pay_run_type' => :'payRunType', :'calendar_type' => :'calendarType', :'posted_date_time' => :'postedDateTime', :'pay_slips' => :'paySlips' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
256 257 258 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 256 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 102 def self.openapi_types { :'pay_run_id' => :'String', :'payroll_calendar_id' => :'String', :'period_start_date' => :'Date', :'period_end_date' => :'Date', :'payment_date' => :'Date', :'total_cost' => :'BigDecimal', :'total_pay' => :'BigDecimal', :'pay_run_status' => :'String', :'pay_run_type' => :'String', :'calendar_type' => :'CalendarType', :'posted_date_time' => :'Date', :'pay_slips' => :'Array<PaySlip>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 224 def ==(o) return true if self.equal?(o) self.class == o.class && pay_run_id == o.pay_run_id && payroll_calendar_id == o.payroll_calendar_id && period_start_date == o.period_start_date && period_end_date == o.period_end_date && payment_date == o.payment_date && total_cost == o.total_cost && total_pay == o.total_pay && pay_run_status == o.pay_run_status && pay_run_type == o.pay_run_type && calendar_type == o.calendar_type && posted_date_time == o.posted_date_time && pay_slips == o.pay_slips end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 284 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(parse_date(value)) when :Date Date.parse(parse_date(value)) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BigDecimal BigDecimal(value.to_s) when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model XeroRuby::PayrollNz.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 351 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 263 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
243 244 245 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 243 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
249 250 251 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 249 def hash [pay_run_id, payroll_calendar_id, period_start_date, period_end_date, payment_date, total_cost, total_pay, pay_run_status, pay_run_type, calendar_type, posted_date_time, pay_slips].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
187 188 189 190 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 187 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#parse_date(datestring) ⇒ Object
customized data_parser
366 367 368 369 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 366 def parse_date(datestring) seconds_since_epoch = datestring.scan(/[0-9]+/)[0].to_i / 1000.0 return Time.at(seconds_since_epoch).strftime('%Y-%m-%dT%l:%M:%S%z').to_s end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
331 332 333 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 331 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
337 338 339 340 341 342 343 344 345 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 337 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
325 326 327 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 325 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
194 195 196 197 198 199 200 |
# File 'lib/xero-ruby/models/payroll_nz/pay_run.rb', line 194 def valid? pay_run_status_validator = EnumAttributeValidator.new('String', ["Draft", "Posted"]) return false unless pay_run_status_validator.valid?(@pay_run_status) pay_run_type_validator = EnumAttributeValidator.new('String', ["Scheduled", "Unscheduled", "EarlierYearUpdate"]) return false unless pay_run_type_validator.valid?(@pay_run_type) true end |